/*
 * JNpp - Java bindings for NPP, to be used with JCuda
 *
 * Copyright (c) 2010-2013 Marco Hutter - http://www.jcuda.org
 *
 * Permission is hereby granted, free of charge, to any person
 * obtaining a copy of this software and associated documentation
 * files (the "Software"), to deal in the Software without
 * restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following
 * conditions:
 *
 * The above copyright notice and this permission notice shall be
 * included in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
 * OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
 * HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
 * WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 * OTHER DEALINGS IN THE SOFTWARE.
 */
package jcuda.jnpp;

import jcuda.*;
import jcuda.jnpp.types.*;

/**
 * Java bindings for the image functions of NPP. Most of the documentation 
 * is extracted from the NPPI header files.
 */
public class JNppi
{
    /**
     * Private constructor to prevent instantiation
     */
    private JNppi()
    {
    }

    static
    {
        JNpp.initialize();
    }

    //=== Auto-generated part ================================================

    /**
     * <pre>
     * 1 channel 8-bit unsigned image memory allocator.
     * @param nWidthPixels Image width.
     * @param nHeightPixels Image height.
     * @param pStepBytes \ref line_step.
     * @return
     *  Pointer to new image data.
     * </pre>
     */
    public static TypedPointer<Npp8u> nppiMalloc_8u_C1(
        int nWidthPixels, 
        int nHeightPixels, 
        int[] pStepBytes)
    {
        return JNpp.checkResult(nppiMalloc_8u_C1Native(nWidthPixels, nHeightPixels, pStepBytes));
    }
    private static native TypedPointer<Npp8u> nppiMalloc_8u_C1Native(
        int nWidthPixels, 
        int nHeightPixels, 
        int[] pStepBytes);


    /**
     * <pre>
     * 2 channel 8-bit unsigned image memory allocator.
     * @param nWidthPixels Image width.
     * @param nHeightPixels Image height.
     * @param pStepBytes \ref line_step.
     * @return
     *  Pointer to new image data.
     * </pre>
     */
    public static TypedPointer<Npp8u> nppiMalloc_8u_C2(
        int nWidthPixels, 
        int nHeightPixels, 
        int[] pStepBytes)
    {
        return JNpp.checkResult(nppiMalloc_8u_C2Native(nWidthPixels, nHeightPixels, pStepBytes));
    }
    private static native TypedPointer<Npp8u> nppiMalloc_8u_C2Native(
        int nWidthPixels, 
        int nHeightPixels, 
        int[] pStepBytes);


    /**
     * <pre>
     * 3 channel 8-bit unsigned image memory allocator.
     * @param nWidthPixels Image width.
     * @param nHeightPixels Image height.
     * @param pStepBytes \ref line_step.
     * @return
     *  Pointer to new image data.
     * </pre>
     */
    public static TypedPointer<Npp8u> nppiMalloc_8u_C3(
        int nWidthPixels, 
        int nHeightPixels, 
        int[] pStepBytes)
    {
        return JNpp.checkResult(nppiMalloc_8u_C3Native(nWidthPixels, nHeightPixels, pStepBytes));
    }
    private static native TypedPointer<Npp8u> nppiMalloc_8u_C3Native(
        int nWidthPixels, 
        int nHeightPixels, 
        int[] pStepBytes);


    /**
     * <pre>
     * 4 channel 8-bit unsigned image memory allocator.
     * @param nWidthPixels Image width.
     * @param nHeightPixels Image height.
     * @param pStepBytes \ref line_step.
     * @return
     *  Pointer to new image data.
     * </pre>
     */
    public static TypedPointer<Npp8u> nppiMalloc_8u_C4(
        int nWidthPixels, 
        int nHeightPixels, 
        int[] pStepBytes)
    {
        return JNpp.checkResult(nppiMalloc_8u_C4Native(nWidthPixels, nHeightPixels, pStepBytes));
    }
    private static native TypedPointer<Npp8u> nppiMalloc_8u_C4Native(
        int nWidthPixels, 
        int nHeightPixels, 
        int[] pStepBytes);


    /**
     * <pre>
     * 16-bit unsigned image memory allocator.
     * @param nWidthPixels Image width.
     * @param nHeightPixels Image height.
     * @param pStepBytes \ref line_step.
     * @return
     *  Pointer to new image data.
     * </pre>
     */
    public static TypedPointer<Npp16u> nppiMalloc_16u_C1(
        int nWidthPixels, 
        int nHeightPixels, 
        int[] pStepBytes)
    {
        return JNpp.checkResult(nppiMalloc_16u_C1Native(nWidthPixels, nHeightPixels, pStepBytes));
    }
    private static native TypedPointer<Npp16u> nppiMalloc_16u_C1Native(
        int nWidthPixels, 
        int nHeightPixels, 
        int[] pStepBytes);


    public static TypedPointer<Npp16u> nppiMalloc_16u_C2(
        int nWidthPixels, 
        int nHeightPixels, 
        int[] pStepBytes)
    {
        return JNpp.checkResult(nppiMalloc_16u_C2Native(nWidthPixels, nHeightPixels, pStepBytes));
    }
    private static native TypedPointer<Npp16u> nppiMalloc_16u_C2Native(
        int nWidthPixels, 
        int nHeightPixels, 
        int[] pStepBytes);


    /**
     * <pre>
     * 3 channel 16-bit unsigned image memory allocator.
     * @param nWidthPixels Image width.
     * @param nHeightPixels Image height.
     * @param pStepBytes \ref line_step.
     * @return
     *  Pointer to new image data.
     * </pre>
     */
    public static TypedPointer<Npp16u> nppiMalloc_16u_C3(
        int nWidthPixels, 
        int nHeightPixels, 
        int[] pStepBytes)
    {
        return JNpp.checkResult(nppiMalloc_16u_C3Native(nWidthPixels, nHeightPixels, pStepBytes));
    }
    private static native TypedPointer<Npp16u> nppiMalloc_16u_C3Native(
        int nWidthPixels, 
        int nHeightPixels, 
        int[] pStepBytes);


    /**
     * <pre>
     * 4 channel 16-bit unsigned image memory allocator.
     * @param nWidthPixels Image width.
     * @param nHeightPixels Image height.
     * @param pStepBytes \ref line_step.
     * @return
     *  Pointer to new image data.
     * </pre>
     */
    public static TypedPointer<Npp16u> nppiMalloc_16u_C4(
        int nWidthPixels, 
        int nHeightPixels, 
        int[] pStepBytes)
    {
        return JNpp.checkResult(nppiMalloc_16u_C4Native(nWidthPixels, nHeightPixels, pStepBytes));
    }
    private static native TypedPointer<Npp16u> nppiMalloc_16u_C4Native(
        int nWidthPixels, 
        int nHeightPixels, 
        int[] pStepBytes);


    /**
     * <pre>
     * 16-bit signed image memory allocator.
     * @param nWidthPixels Image width.
     * @param nHeightPixels Image height.
     * @param pStepBytes \ref line_step.
     * @return
     *  Pointer to new image data.
     * </pre>
     */
    public static TypedPointer<Npp16s> nppiMalloc_16s_C1(
        int nWidthPixels, 
        int nHeightPixels, 
        int[] pStepBytes)
    {
        return JNpp.checkResult(nppiMalloc_16s_C1Native(nWidthPixels, nHeightPixels, pStepBytes));
    }
    private static native TypedPointer<Npp16s> nppiMalloc_16s_C1Native(
        int nWidthPixels, 
        int nHeightPixels, 
        int[] pStepBytes);


    /**
     * <pre>
     * 2 channel 16-bit signed image memory allocator.
     * @param nWidthPixels Image width.
     * @param nHeightPixels Image height.
     * @param pStepBytes \ref line_step.
     * @return
     *  Pointer to new image data.
     * </pre>
     */
    public static TypedPointer<Npp16s> nppiMalloc_16s_C2(
        int nWidthPixels, 
        int nHeightPixels, 
        int[] pStepBytes)
    {
        return JNpp.checkResult(nppiMalloc_16s_C2Native(nWidthPixels, nHeightPixels, pStepBytes));
    }
    private static native TypedPointer<Npp16s> nppiMalloc_16s_C2Native(
        int nWidthPixels, 
        int nHeightPixels, 
        int[] pStepBytes);


    /**
     * <pre>
     * 4 channel 16-bit signed image memory allocator.
     * @param nWidthPixels Image width.
     * @param nHeightPixels Image height.
     * @param pStepBytes \ref line_step.
     * @return
     *  Pointer to new image data.
     * </pre>
     */
    public static TypedPointer<Npp16s> nppiMalloc_16s_C4(
        int nWidthPixels, 
        int nHeightPixels, 
        int[] pStepBytes)
    {
        return JNpp.checkResult(nppiMalloc_16s_C4Native(nWidthPixels, nHeightPixels, pStepBytes));
    }
    private static native TypedPointer<Npp16s> nppiMalloc_16s_C4Native(
        int nWidthPixels, 
        int nHeightPixels, 
        int[] pStepBytes);


    public static TypedPointer<Npp16s> nppiMalloc_16sc_C1(
        int nWidthPixels, 
        int nHeightPixels, 
        int[] pStepBytes)
    {
        return JNpp.checkResult(nppiMalloc_16sc_C1Native(nWidthPixels, nHeightPixels, pStepBytes));
    }
    private static native TypedPointer<Npp16s> nppiMalloc_16sc_C1Native(
        int nWidthPixels, 
        int nHeightPixels, 
        int[] pStepBytes);


    /**
     * <pre>
     * 2 channel 16-bit signed complex image memory allocator.
     * @param nWidthPixels Image width.
     * @param nHeightPixels Image height.
     * @param pStepBytes \ref line_step.
     * @return
     *  Pointer to new image data.
     * </pre>
     */
    public static TypedPointer<Npp16s> nppiMalloc_16sc_C2(
        int nWidthPixels, 
        int nHeightPixels, 
        int[] pStepBytes)
    {
        return JNpp.checkResult(nppiMalloc_16sc_C2Native(nWidthPixels, nHeightPixels, pStepBytes));
    }
    private static native TypedPointer<Npp16s> nppiMalloc_16sc_C2Native(
        int nWidthPixels, 
        int nHeightPixels, 
        int[] pStepBytes);


    /**
     * <pre>
     * 3 channel 16-bit signed complex image memory allocator.
     * @param nWidthPixels Image width.
     * @param nHeightPixels Image height.
     * @param pStepBytes \ref line_step.
     * @return
     *  Pointer to new image data.
     * </pre>
     */
    public static TypedPointer<Npp16s> nppiMalloc_16sc_C3(
        int nWidthPixels, 
        int nHeightPixels, 
        int[] pStepBytes)
    {
        return JNpp.checkResult(nppiMalloc_16sc_C3Native(nWidthPixels, nHeightPixels, pStepBytes));
    }
    private static native TypedPointer<Npp16s> nppiMalloc_16sc_C3Native(
        int nWidthPixels, 
        int nHeightPixels, 
        int[] pStepBytes);


    /**
     * <pre>
     * 4 channel 16-bit signed complex image memory allocator.
     * @param nWidthPixels Image width.
     * @param nHeightPixels Image height.
     * @param pStepBytes \ref line_step.
     * @return
     *  Pointer to new image data.
     * </pre>
     */
    public static TypedPointer<Npp16s> nppiMalloc_16sc_C4(
        int nWidthPixels, 
        int nHeightPixels, 
        int[] pStepBytes)
    {
        return JNpp.checkResult(nppiMalloc_16sc_C4Native(nWidthPixels, nHeightPixels, pStepBytes));
    }
    private static native TypedPointer<Npp16s> nppiMalloc_16sc_C4Native(
        int nWidthPixels, 
        int nHeightPixels, 
        int[] pStepBytes);


    /**
     * <pre>
     * 32-bit signed image memory allocator.
     * @param nWidthPixels Image width.
     * @param nHeightPixels Image height.
     * @param pStepBytes \ref line_step.
     * @return
     *  Pointer to new image data.
     * </pre>
     */
    public static TypedPointer<Npp32s> nppiMalloc_32s_C1(
        int nWidthPixels, 
        int nHeightPixels, 
        int[] pStepBytes)
    {
        return JNpp.checkResult(nppiMalloc_32s_C1Native(nWidthPixels, nHeightPixels, pStepBytes));
    }
    private static native TypedPointer<Npp32s> nppiMalloc_32s_C1Native(
        int nWidthPixels, 
        int nHeightPixels, 
        int[] pStepBytes);


    /**
     * <pre>
     * 3 channel 32-bit signed image memory allocator.
     * @param nWidthPixels Image width.
     * @param nHeightPixels Image height.
     * @param pStepBytes \ref line_step.
     * @return
     *  Pointer to new image data.
     * </pre>
     */
    public static TypedPointer<Npp32s> nppiMalloc_32s_C3(
        int nWidthPixels, 
        int nHeightPixels, 
        int[] pStepBytes)
    {
        return JNpp.checkResult(nppiMalloc_32s_C3Native(nWidthPixels, nHeightPixels, pStepBytes));
    }
    private static native TypedPointer<Npp32s> nppiMalloc_32s_C3Native(
        int nWidthPixels, 
        int nHeightPixels, 
        int[] pStepBytes);


    public static TypedPointer<Npp32s> nppiMalloc_32s_C4(
        int nWidthPixels, 
        int nHeightPixels, 
        int[] pStepBytes)
    {
        return JNpp.checkResult(nppiMalloc_32s_C4Native(nWidthPixels, nHeightPixels, pStepBytes));
    }
    private static native TypedPointer<Npp32s> nppiMalloc_32s_C4Native(
        int nWidthPixels, 
        int nHeightPixels, 
        int[] pStepBytes);


    /**
     * <pre>
     * 32-bit integer complex image memory allocator.
     * @param nWidthPixels Image width.
     * @param nHeightPixels Image height.
     * @param pStepBytes \ref line_step.
     * @return
     *  Pointer to new image data.
     * </pre>
     */
    public static TypedPointer<Npp32s> nppiMalloc_32sc_C1(
        int nWidthPixels, 
        int nHeightPixels, 
        int[] pStepBytes)
    {
        return JNpp.checkResult(nppiMalloc_32sc_C1Native(nWidthPixels, nHeightPixels, pStepBytes));
    }
    private static native TypedPointer<Npp32s> nppiMalloc_32sc_C1Native(
        int nWidthPixels, 
        int nHeightPixels, 
        int[] pStepBytes);


    /**
     * <pre>
     * 2 channel 32-bit integer complex image memory allocator.
     * @param nWidthPixels Image width.
     * @param nHeightPixels Image height.
     * @param pStepBytes \ref line_step.
     * @return
     *  Pointer to new image data.
     * </pre>
     */
    public static TypedPointer<Npp32s> nppiMalloc_32sc_C2(
        int nWidthPixels, 
        int nHeightPixels, 
        int[] pStepBytes)
    {
        return JNpp.checkResult(nppiMalloc_32sc_C2Native(nWidthPixels, nHeightPixels, pStepBytes));
    }
    private static native TypedPointer<Npp32s> nppiMalloc_32sc_C2Native(
        int nWidthPixels, 
        int nHeightPixels, 
        int[] pStepBytes);


    /**
     * <pre>
     * 3 channel 32-bit integer complex image memory allocator.
     * @param nWidthPixels Image width.
     * @param nHeightPixels Image height.
     * @param pStepBytes \ref line_step.
     * @return
     *  Pointer to new image data.
     * </pre>
     */
    public static TypedPointer<Npp32s> nppiMalloc_32sc_C3(
        int nWidthPixels, 
        int nHeightPixels, 
        int[] pStepBytes)
    {
        return JNpp.checkResult(nppiMalloc_32sc_C3Native(nWidthPixels, nHeightPixels, pStepBytes));
    }
    private static native TypedPointer<Npp32s> nppiMalloc_32sc_C3Native(
        int nWidthPixels, 
        int nHeightPixels, 
        int[] pStepBytes);


    /**
     * <pre>
     * 4 channel 32-bit integer complex image memory allocator.
     * @param nWidthPixels Image width.
     * @param nHeightPixels Image height.
     * @param pStepBytes \ref line_step.
     * @return
     *  Pointer to new image data.
     * </pre>
     */
    public static TypedPointer<Npp32s> nppiMalloc_32sc_C4(
        int nWidthPixels, 
        int nHeightPixels, 
        int[] pStepBytes)
    {
        return JNpp.checkResult(nppiMalloc_32sc_C4Native(nWidthPixels, nHeightPixels, pStepBytes));
    }
    private static native TypedPointer<Npp32s> nppiMalloc_32sc_C4Native(
        int nWidthPixels, 
        int nHeightPixels, 
        int[] pStepBytes);


    /**
     * <pre>
     * 32-bit floating point image memory allocator.
     * @param nWidthPixels Image width.
     * @param nHeightPixels Image height.
     * @param pStepBytes \ref line_step.
     * @return
     *  Pointer to new image data.
     * </pre>
     */
    public static TypedPointer<Npp32f> nppiMalloc_32f_C1(
        int nWidthPixels, 
        int nHeightPixels, 
        int[] pStepBytes)
    {
        return JNpp.checkResult(nppiMalloc_32f_C1Native(nWidthPixels, nHeightPixels, pStepBytes));
    }
    private static native TypedPointer<Npp32f> nppiMalloc_32f_C1Native(
        int nWidthPixels, 
        int nHeightPixels, 
        int[] pStepBytes);


    /**
     * <pre>
     * 2 channel 32-bit floating point image memory allocator.
     * @param nWidthPixels Image width.
     * @param nHeightPixels Image height.
     * @param pStepBytes \ref line_step.
     * @return
     *  Pointer to new image data.
     * </pre>
     */
    public static TypedPointer<Npp32f> nppiMalloc_32f_C2(
        int nWidthPixels, 
        int nHeightPixels, 
        int[] pStepBytes)
    {
        return JNpp.checkResult(nppiMalloc_32f_C2Native(nWidthPixels, nHeightPixels, pStepBytes));
    }
    private static native TypedPointer<Npp32f> nppiMalloc_32f_C2Native(
        int nWidthPixels, 
        int nHeightPixels, 
        int[] pStepBytes);


    /**
     * <pre>
     * 3 channel 32-bit floating point image memory allocator.
     * @param nWidthPixels Image width.
     * @param nHeightPixels Image height.
     * @param pStepBytes \ref line_step.
     * @return
     *  Pointer to new image data.
     * </pre>
     */
    public static TypedPointer<Npp32f> nppiMalloc_32f_C3(
        int nWidthPixels, 
        int nHeightPixels, 
        int[] pStepBytes)
    {
        return JNpp.checkResult(nppiMalloc_32f_C3Native(nWidthPixels, nHeightPixels, pStepBytes));
    }
    private static native TypedPointer<Npp32f> nppiMalloc_32f_C3Native(
        int nWidthPixels, 
        int nHeightPixels, 
        int[] pStepBytes);


    /**
     * <pre>
     * 4 channel 32-bit floating point image memory allocator.
     * @param nWidthPixels Image width.
     * @param nHeightPixels Image height.
     * @param pStepBytes \ref line_step.
     * @return
     *  Pointer to new image data.
     * </pre>
     */
    public static TypedPointer<Npp32f> nppiMalloc_32f_C4(
        int nWidthPixels, 
        int nHeightPixels, 
        int[] pStepBytes)
    {
        return JNpp.checkResult(nppiMalloc_32f_C4Native(nWidthPixels, nHeightPixels, pStepBytes));
    }
    private static native TypedPointer<Npp32f> nppiMalloc_32f_C4Native(
        int nWidthPixels, 
        int nHeightPixels, 
        int[] pStepBytes);


    /**
     * <pre>
     * 32-bit float complex image memory allocator.
     * @param nWidthPixels Image width.
     * @param nHeightPixels Image height.
     * @param pStepBytes \ref line_step.
     * @return
     *  Pointer to new image data.
     * </pre>
     */
    public static TypedPointer<Npp32f> nppiMalloc_32fc_C1(
        int nWidthPixels, 
        int nHeightPixels, 
        int[] pStepBytes)
    {
        return JNpp.checkResult(nppiMalloc_32fc_C1Native(nWidthPixels, nHeightPixels, pStepBytes));
    }
    private static native TypedPointer<Npp32f> nppiMalloc_32fc_C1Native(
        int nWidthPixels, 
        int nHeightPixels, 
        int[] pStepBytes);


    /**
     * <pre>
     * 2 channel 32-bit float complex image memory allocator.
     * @param nWidthPixels Image width.
     * @param nHeightPixels Image height.
     * @param pStepBytes \ref line_step.
     * @return
     *  Pointer to new image data.
     * </pre>
     */
    public static TypedPointer<Npp32f> nppiMalloc_32fc_C2(
        int nWidthPixels, 
        int nHeightPixels, 
        int[] pStepBytes)
    {
        return JNpp.checkResult(nppiMalloc_32fc_C2Native(nWidthPixels, nHeightPixels, pStepBytes));
    }
    private static native TypedPointer<Npp32f> nppiMalloc_32fc_C2Native(
        int nWidthPixels, 
        int nHeightPixels, 
        int[] pStepBytes);


    public static TypedPointer<Npp32f> nppiMalloc_32fc_C3(
        int nWidthPixels, 
        int nHeightPixels, 
        int[] pStepBytes)
    {
        return JNpp.checkResult(nppiMalloc_32fc_C3Native(nWidthPixels, nHeightPixels, pStepBytes));
    }
    private static native TypedPointer<Npp32f> nppiMalloc_32fc_C3Native(
        int nWidthPixels, 
        int nHeightPixels, 
        int[] pStepBytes);


    /**
     * <pre>
     * 4 channel 32-bit float complex image memory allocator.
     * @param nWidthPixels Image width.
     * @param nHeightPixels Image height.
     * @param pStepBytes \ref line_step.
     * @return
     *  Pointer to new image data.
     * </pre>
     */
    public static TypedPointer<Npp32f> nppiMalloc_32fc_C4(
        int nWidthPixels, 
        int nHeightPixels, 
        int[] pStepBytes)
    {
        return JNpp.checkResult(nppiMalloc_32fc_C4Native(nWidthPixels, nHeightPixels, pStepBytes));
    }
    private static native TypedPointer<Npp32f> nppiMalloc_32fc_C4Native(
        int nWidthPixels, 
        int nHeightPixels, 
        int[] pStepBytes);


    /**
     * <pre>
     * Free method for any 2D allocated memory.
     * This method should be used to free memory allocated with any of the nppiMalloc_<modifier> methods.
     * @param pData A pointer to memory allocated using nppiMalloc_<modifier>.
     * </pre>
     */
    public static void nppiFree(
        Pointer pData)
    {
        nppiFreeNative(pData);
    }
    private static native void nppiFreeNative(
        Pointer pData);


    public static int nppiSet_8s_C1R(
        byte nValue, 
        TypedPointer<Npp8s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiSet_8s_C1RNative(nValue, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiSet_8s_C1RNative(
        byte nValue, 
        TypedPointer<Npp8s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    public static int nppiSet_8s_C2R(
        byte[] aValue, 
        TypedPointer<Npp8s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiSet_8s_C2RNative(aValue, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiSet_8s_C2RNative(
        byte[] aValue, 
        TypedPointer<Npp8s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    public static int nppiSet_8s_C3R(
        byte[] aValue, 
        TypedPointer<Npp8s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiSet_8s_C3RNative(aValue, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiSet_8s_C3RNative(
        byte[] aValue, 
        TypedPointer<Npp8s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 8-bit four-channel image set.
     * @param aValue The pixel value to be set.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSet_8s_C4R(
        byte[] aValue, 
        TypedPointer<Npp8s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiSet_8s_C4RNative(aValue, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiSet_8s_C4RNative(
        byte[] aValue, 
        TypedPointer<Npp8s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    public static int nppiSet_8s_AC4R(
        byte[] aValue, 
        TypedPointer<Npp8s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiSet_8s_AC4RNative(aValue, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiSet_8s_AC4RNative(
        byte[] aValue, 
        TypedPointer<Npp8s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    public static int nppiSet_8u_C1R(
        byte nValue, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiSet_8u_C1RNative(nValue, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiSet_8u_C1RNative(
        byte nValue, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    public static int nppiSet_8u_C1MR(
        byte nValue, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep)
    {
        return JNpp.checkResult(nppiSet_8u_C1MRNative(nValue, pDst, nDstStep, oSizeROI, pMask, nMaskStep));
    }
    private static native int nppiSet_8u_C1MRNative(
        byte nValue, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep);


    /**
     * <pre>
     * 4 channel 8-bit unsigned image set.
     * @param aValues Four-channel array containing the pixel-value to be set.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSet_8u_C4R(
        byte[] aValues, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiSet_8u_C4RNative(aValues, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiSet_8u_C4RNative(
        byte[] aValues, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Masked 4 channel 8-bit unsigned image set.
     * @param aValues Four-channel array containing the pixel-value to be set.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pMask Pointer to the mask image. This is a single channel 8-bit unsigned int image.
     * @param nMaskStep Number of bytes between line starts of successive lines in the mask image.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSet_8u_C4MR(
        byte[] aValues, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep)
    {
        return JNpp.checkResult(nppiSet_8u_C4MRNative(aValues, pDst, nDstStep, oSizeROI, pMask, nMaskStep));
    }
    private static native int nppiSet_8u_C4MRNative(
        byte[] aValues, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep);


    /**
     * <pre>
     * 4 channel 8-bit unsigned image set method, not affecting Alpha channel.
     * For RGBA images, this method allows setting of the RGB values without changing the contents
     * of the alpha-channel (fourth channel).
     * @param aValues Three-channel array containing the pixel-value to be set.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSet_8u_AC4R(
        byte[] aValues, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiSet_8u_AC4RNative(aValues, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiSet_8u_AC4RNative(
        byte[] aValues, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Masked 4 channel 8-bit unsigned image set method, not affecting Alpha channel.
     * For RGBA images, this method allows setting of the RGB values without changing the contents
     * of the alpha-channel (fourth channel).
     * @param aValues Three-channel array containing the pixel-value to be set.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pMask Pointer to the mask image. This is a single channel 8-bit unsigned int image.
     * @param nMaskStep Number of bytes between line starts of successive lines in the mask image.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSet_8u_AC4MR(
        byte[] aValues, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep)
    {
        return JNpp.checkResult(nppiSet_8u_AC4MRNative(aValues, pDst, nDstStep, oSizeROI, pMask, nMaskStep));
    }
    private static native int nppiSet_8u_AC4MRNative(
        byte[] aValues, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep);


    /**
     * <pre>
     * 4 channel 8-bit unsigned image set affecting only single channel.
     * For RGBA images, this method allows setting of a single of the four (RGBA) values 
     * without changing the contents of the other three channels. The channel is selected
     * via the pDst pointer. The pointer needs to point to the actual first value to be set,
     * e.g. in order to set the R-channel (first channel), one would pass pDst unmodified, since
     * its value actually points to the r channel. If one wanted to modify the B channel (second
     * channel), one would pass pDst + 2 to the function.
     * @param nValue The pixel-value to be set.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSet_8u_C4CR(
        byte nValue, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiSet_8u_C4CRNative(nValue, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiSet_8u_C4CRNative(
        byte nValue, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 16-bit unsigned image set.
     * @param nValue New pixel value.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSet_16u_C1R(
        short nValue, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiSet_16u_C1RNative(nValue, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiSet_16u_C1RNative(
        short nValue, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Masked 16-bit unsigned image set.
     * @param nValue New pixel value.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pMask Pointer to the mask image. This is a single channel 8-bit unsigned int image.
     * @param nMaskStep Number of bytes between line starts of successive lines in the mask image.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSet_16u_C1MR(
        short nValue, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep)
    {
        return JNpp.checkResult(nppiSet_16u_C1MRNative(nValue, pDst, nDstStep, oSizeROI, pMask, nMaskStep));
    }
    private static native int nppiSet_16u_C1MRNative(
        short nValue, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep);


    public static int nppiSet_16u_C2R(
        short[] aValues, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiSet_16u_C2RNative(aValues, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiSet_16u_C2RNative(
        short[] aValues, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 4 channel 16-bit unsigned image set.
     * @param aValues New pixel value.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSet_16u_C4R(
        short[] aValues, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiSet_16u_C4RNative(aValues, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiSet_16u_C4RNative(
        short[] aValues, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Masked 4 channel 16-bit unsigned image set.
     * @param aValues New pixel value.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pMask Pointer to the mask image. This is a single channel 8-bit unsigned int image.
     * @param nMaskStep Number of bytes between line starts of successive lines in the mask image.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSet_16u_C4MR(
        short[] aValues, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep)
    {
        return JNpp.checkResult(nppiSet_16u_C4MRNative(aValues, pDst, nDstStep, oSizeROI, pMask, nMaskStep));
    }
    private static native int nppiSet_16u_C4MRNative(
        short[] aValues, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep);


    public static int nppiSet_16u_AC4R(
        short[] aValues, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiSet_16u_AC4RNative(aValues, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiSet_16u_AC4RNative(
        short[] aValues, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Masked 4 channel 16-bit unsigned image set method, not affecting Alpha channel.
     * For RGBA images, this method allows setting of the RGB values without changing the contents
     * of the alpha-channel (fourth channel).
     * @param aValues Three-channel array containing the pixel-value to be set.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pMask Pointer to the mask image. This is a single channel 8-bit unsigned int image.
     * @param nMaskStep Number of bytes between line starts of successive lines in the mask image.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSet_16u_AC4MR(
        short[] aValues, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep)
    {
        return JNpp.checkResult(nppiSet_16u_AC4MRNative(aValues, pDst, nDstStep, oSizeROI, pMask, nMaskStep));
    }
    private static native int nppiSet_16u_AC4MRNative(
        short[] aValues, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep);


    /**
     * <pre>
     * 4 channel 16-bit unsigned image set affecting only single channel.
     * For RGBA images, this method allows setting of a single of the four (RGBA) values 
     * without changing the contents of the other three channels. The channel is selected
     * via the pDst pointer. The pointer needs to point to the actual first value to be set,
     * e.g. in order to set the R-channel (first channel), one would pass pDst unmodified, since
     * its value actually points to the r channel. If one wanted to modify the B channel (second
     * channel), one would pass pDst + 2 to the function.
     * @param nValue The pixel-value to be set.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSet_16u_C4CR(
        short nValue, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiSet_16u_C4CRNative(nValue, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiSet_16u_C4CRNative(
        short nValue, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 16-bit image set.
     * @param nValue New pixel value.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSet_16s_C1R(
        short nValue, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiSet_16s_C1RNative(nValue, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiSet_16s_C1RNative(
        short nValue, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Masked 16-bit image set.
     * @param nValue New pixel value.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pMask Pointer to the mask image. This is a single channel 8-bit unsigned int image.
     * @param nMaskStep Number of bytes between line starts of successive lines in the mask image.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSet_16s_C1MR(
        short nValue, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep)
    {
        return JNpp.checkResult(nppiSet_16s_C1MRNative(nValue, pDst, nDstStep, oSizeROI, pMask, nMaskStep));
    }
    private static native int nppiSet_16s_C1MRNative(
        short nValue, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep);


    /**
     * <pre>
     * 2 channel 16-bit image set.
     * @param aValues New pixel value.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSet_16s_C2R(
        short[] aValues, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiSet_16s_C2RNative(aValues, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiSet_16s_C2RNative(
        short[] aValues, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 4 channel 16-bit image set.
     * @param aValues New pixel value.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSet_16s_C4R(
        short[] aValues, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiSet_16s_C4RNative(aValues, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiSet_16s_C4RNative(
        short[] aValues, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Masked 4 channel 16-bit image set.
     * @param aValues New pixel value.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pMask Pointer to the mask image. This is a single channel 8-bit unsigned int image.
     * @param nMaskStep Number of bytes between line starts of successive lines in the mask image.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSet_16s_C4MR(
        short[] aValues, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep)
    {
        return JNpp.checkResult(nppiSet_16s_C4MRNative(aValues, pDst, nDstStep, oSizeROI, pMask, nMaskStep));
    }
    private static native int nppiSet_16s_C4MRNative(
        short[] aValues, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep);


    public static int nppiSet_16s_AC4R(
        short[] aValues, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiSet_16s_AC4RNative(aValues, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiSet_16s_AC4RNative(
        short[] aValues, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Masked 4 channel 16-bit image set method, not affecting Alpha channel.
     * For RGBA images, this method allows setting of the RGB values without changing the contents
     * of the alpha-channel (fourth channel).
     * @param aValues Three-channel array containing the pixel-value to be set.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pMask Pointer to the mask image. This is a single channel 8-bit unsigned int image.
     * @param nMaskStep Number of bytes between line starts of successive lines in the mask image.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSet_16s_AC4MR(
        short[] aValues, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep)
    {
        return JNpp.checkResult(nppiSet_16s_AC4MRNative(aValues, pDst, nDstStep, oSizeROI, pMask, nMaskStep));
    }
    private static native int nppiSet_16s_AC4MRNative(
        short[] aValues, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep);


    /**
     * <pre>
     * 4 channel 16-bit unsigned image set affecting only single channel.
     * For RGBA images, this method allows setting of a single of the four (RGBA) values 
     * without changing the contents of the other three channels. The channel is selected
     * via the pDst pointer. The pointer needs to point to the actual first value to be set,
     * e.g. in order to set the R-channel (first channel), one would pass pDst unmodified, since
     * its value actually points to the r channel. If one wanted to modify the B channel (second
     * channel), one would pass pDst + 2 to the function.
     * @param nValue The pixel-value to be set.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSet_16s_C4CR(
        short nValue, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiSet_16s_C4CRNative(nValue, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiSet_16s_C4CRNative(
        short nValue, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    public static int nppiSet_16sc_C1R(
        Npp16sc oValue, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiSet_16sc_C1RNative(oValue, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiSet_16sc_C1RNative(
        Npp16sc oValue, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 16-bit complex integer two-channel image set.
     * @param aValue New pixel value.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSet_16sc_C2R(
        Npp16sc[] aValue, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiSet_16sc_C2RNative(aValue, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiSet_16sc_C2RNative(
        Npp16sc[] aValue, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 16-bit complex integer three-channel image set.
     * @param aValue New pixel value.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSet_16sc_C3R(
        Npp16sc[] aValue, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiSet_16sc_C3RNative(aValue, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiSet_16sc_C3RNative(
        Npp16sc[] aValue, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 16-bit complex integer four-channel image set ignoring alpha.
     * @param aValue New pixel value.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSet_16sc_AC4R(
        Npp16sc[] aValue, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiSet_16sc_AC4RNative(aValue, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiSet_16sc_AC4RNative(
        Npp16sc[] aValue, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 16-bit complex integer four-channel image set.
     * @param aValue New pixel value.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSet_16sc_C4R(
        Npp16sc[] aValue, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiSet_16sc_C4RNative(aValue, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiSet_16sc_C4RNative(
        Npp16sc[] aValue, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 32-bit image set.
     * @param nValue New pixel value.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSet_32s_C1R(
        int nValue, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiSet_32s_C1RNative(nValue, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiSet_32s_C1RNative(
        int nValue, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Masked 32-bit image set.
     * @param nValue New pixel value.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pMask Pointer to the mask image. This is a single channel 8-bit unsigned int image.
     * @param nMaskStep Number of bytes between line starts of successive lines in the mask image.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSet_32s_C1MR(
        int nValue, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep)
    {
        return JNpp.checkResult(nppiSet_32s_C1MRNative(nValue, pDst, nDstStep, oSizeROI, pMask, nMaskStep));
    }
    private static native int nppiSet_32s_C1MRNative(
        int nValue, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep);


    /**
     * <pre>
     * 4 channel 32-bit image set.
     * @param aValues New pixel value.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSet_32s_C4R(
        int[] aValues, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiSet_32s_C4RNative(aValues, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiSet_32s_C4RNative(
        int[] aValues, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Masked 4 channel 32-bit image set.
     * @param aValues New pixel value.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pMask Pointer to the mask image. This is a single channel 8-bit unsigned int image.
     * @param nMaskStep Number of bytes between line starts of successive lines in the mask image.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSet_32s_C4MR(
        int[] aValues, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep)
    {
        return JNpp.checkResult(nppiSet_32s_C4MRNative(aValues, pDst, nDstStep, oSizeROI, pMask, nMaskStep));
    }
    private static native int nppiSet_32s_C4MRNative(
        int[] aValues, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep);


    /**
     * <pre>
     * 4 channel 16-bit image set method, not affecting Alpha channel.
     * For RGBA images, this method allows setting of the RGB values without changing the contents
     * of the alpha-channel (fourth channel).
     * @param aValues Three-channel array containing the pixel-value to be set.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSet_32s_AC4R(
        int[] aValues, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiSet_32s_AC4RNative(aValues, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiSet_32s_AC4RNative(
        int[] aValues, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    public static int nppiSet_32s_AC4MR(
        int[] aValues, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep)
    {
        return JNpp.checkResult(nppiSet_32s_AC4MRNative(aValues, pDst, nDstStep, oSizeROI, pMask, nMaskStep));
    }
    private static native int nppiSet_32s_AC4MRNative(
        int[] aValues, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep);


    /**
     * <pre>
     * 4 channel 32-bit unsigned image set affecting only single channel.
     * For RGBA images, this method allows setting of a single of the four (RGBA) values 
     * without changing the contents of the other three channels. The channel is selected
     * via the pDst pointer. The pointer needs to point to the actual first value to be set,
     * e.g. in order to set the R-channel (first channel), one would pass pDst unmodified, since
     * its value actually points to the r channel. If one wanted to modify the B channel (second
     * channel), one would pass pDst + 2 to the function.
     * @param nValue The pixel-value to be set.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSet_32s_C4CR(
        int nValue, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiSet_32s_C4CRNative(nValue, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiSet_32s_C4CRNative(
        int nValue, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Single channel 32-bit complex integer image set.
     * @param oValue The pixel-value to be set.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSet_32sc_C1R(
        Npp32sc oValue, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiSet_32sc_C1RNative(oValue, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiSet_32sc_C1RNative(
        Npp32sc oValue, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Two channel 32-bit complex integer image set.
     * @param aValue The pixel-value to be set.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSet_32sc_C2R(
        Npp32sc[] aValue, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiSet_32sc_C2RNative(aValue, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiSet_32sc_C2RNative(
        Npp32sc[] aValue, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three channel 32-bit complex integer image set.
     * @param aValue The pixel-value to be set.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSet_32sc_C3R(
        Npp32sc[] aValue, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiSet_32sc_C3RNative(aValue, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiSet_32sc_C3RNative(
        Npp32sc[] aValue, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four channel 32-bit complex integer image set.
     * @param aValue The pixel-value to be set.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSet_32sc_C4R(
        Npp32sc[] aValue, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiSet_32sc_C4RNative(aValue, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiSet_32sc_C4RNative(
        Npp32sc[] aValue, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 32-bit complex integer four-channel image set ignoring alpha.
     * @param aValue New pixel value.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSet_32sc_AC4R(
        Npp32sc[] aValue, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiSet_32sc_AC4RNative(aValue, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiSet_32sc_AC4RNative(
        Npp32sc[] aValue, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 32-bit floating point image set.
     * @param nValue New pixel value.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSet_32f_C1R(
        float nValue, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiSet_32f_C1RNative(nValue, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiSet_32f_C1RNative(
        float nValue, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Masked 32-bit floating point image set.
     * @param nValue New pixel value.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pMask Pointer to the mask image. This is a single channel 8-bit unsigned int image.
     * @param nMaskStep Number of bytes between line starts of successive lines in the mask image.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSet_32f_C1MR(
        float nValue, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep)
    {
        return JNpp.checkResult(nppiSet_32f_C1MRNative(nValue, pDst, nDstStep, oSizeROI, pMask, nMaskStep));
    }
    private static native int nppiSet_32f_C1MRNative(
        float nValue, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep);


    /**
     * <pre>
     * 4 channel 32-bit floating point image set.
     * @param aValues New pixel value.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSet_32f_C4R(
        float[] aValues, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiSet_32f_C4RNative(aValues, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiSet_32f_C4RNative(
        float[] aValues, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Masked 4 channel 32-bit floating point image set.
     * @param aValues New pixel value.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pMask Pointer to the mask image. This is a single channel 8-bit unsigned int image.
     * @param nMaskStep Number of bytes between line starts of successive lines in the mask image.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSet_32f_C4MR(
        float[] aValues, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep)
    {
        return JNpp.checkResult(nppiSet_32f_C4MRNative(aValues, pDst, nDstStep, oSizeROI, pMask, nMaskStep));
    }
    private static native int nppiSet_32f_C4MRNative(
        float[] aValues, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep);


    /**
     * <pre>
     * 4 channel 32-bit floating point image set method, not affecting Alpha channel.
     * For RGBA images, this method allows setting of the RGB values without changing the contents
     * of the alpha-channel (fourth channel).
     * @param aValues Three-channel array containing the pixel-value to be set.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSet_32f_AC4R(
        float[] aValues, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiSet_32f_AC4RNative(aValues, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiSet_32f_AC4RNative(
        float[] aValues, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Masked 4 channel 32-bit floating point image set method, not affecting Alpha channel.
     * For RGBA images, this method allows setting of the RGB values without changing the contents
     * of the alpha-channel (fourth channel).
     * @param aValues Three-channel array containing the pixel-value to be set.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pMask Pointer to the mask image. This is a single channel 8-bit unsigned int image.
     * @param nMaskStep Number of bytes between line starts of successive lines in the mask image.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSet_32f_AC4MR(
        float[] aValues, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep)
    {
        return JNpp.checkResult(nppiSet_32f_AC4MRNative(aValues, pDst, nDstStep, oSizeROI, pMask, nMaskStep));
    }
    private static native int nppiSet_32f_AC4MRNative(
        float[] aValues, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep);


    public static int nppiSet_32f_C4CR(
        float nValue, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiSet_32f_C4CRNative(nValue, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiSet_32f_C4CRNative(
        float nValue, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Single channel 32-bit complex image set.
     * @param oValue The pixel-value to be set.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSet_32fc_C1R(
        Npp32fc oValue, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiSet_32fc_C1RNative(oValue, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiSet_32fc_C1RNative(
        Npp32fc oValue, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Two channel 32-bit complex image set.
     * @param aValue The pixel-value to be set.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSet_32fc_C2R(
        Npp32fc[] aValue, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiSet_32fc_C2RNative(aValue, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiSet_32fc_C2RNative(
        Npp32fc[] aValue, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three channel 32-bit complex image set.
     * @param aValue The pixel-value to be set.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSet_32fc_C3R(
        Npp32fc[] aValue, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiSet_32fc_C3RNative(aValue, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiSet_32fc_C3RNative(
        Npp32fc[] aValue, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four channel 32-bit complex image set.
     * @param aValue The pixel-value to be set.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSet_32fc_C4R(
        Npp32fc[] aValue, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiSet_32fc_C4RNative(aValue, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiSet_32fc_C4RNative(
        Npp32fc[] aValue, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 32-bit complex four-channel image set ignoring alpha.
     * @param aValue New pixel value.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSet_32fc_AC4R(
        Npp32fc[] aValue, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiSet_32fc_AC4RNative(aValue, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiSet_32fc_AC4RNative(
        Npp32fc[] aValue, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 8-bit image copy.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_8s_C1R(
        TypedPointer<Npp8s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiCopy_8s_C1RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_8s_C1RNative(
        TypedPointer<Npp8s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Two-channel 8-bit image copy.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_8s_C2R(
        TypedPointer<Npp8s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiCopy_8s_C2RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_8s_C2RNative(
        TypedPointer<Npp8s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    public static int nppiCopy_8s_C3R(
        TypedPointer<Npp8s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiCopy_8s_C3RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_8s_C3RNative(
        TypedPointer<Npp8s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four-channel 8-bit image copy.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_8s_C4R(
        TypedPointer<Npp8s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiCopy_8s_C4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_8s_C4RNative(
        TypedPointer<Npp8s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four-channel 8-bit image copy, ignoring alpha channel.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_8s_AC4R(
        TypedPointer<Npp8s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiCopy_8s_AC4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_8s_AC4RNative(
        TypedPointer<Npp8s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 8-bit unsigned image copy.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_8u_C1R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiCopy_8u_C1RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_8u_C1RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 4 channel 8-bit unsigned image copy.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_8u_C4R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiCopy_8u_C4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_8u_C4RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 4 channel 8-bit unsigned image copy, not affecting Alpha channel.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_8u_AC4R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiCopy_8u_AC4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_8u_AC4RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 16-bit unsigned image copy.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_16u_C1R(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiCopy_16u_C1RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_16u_C1RNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    public static int nppiCopy_16u_C4R(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiCopy_16u_C4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_16u_C4RNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 4 channel 16-bit unsigned image copy, not affecting Alpha channel.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_16u_AC4R(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiCopy_16u_AC4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_16u_AC4RNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 16-bit image copy.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_16s_C1R(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiCopy_16s_C1RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_16s_C1RNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    public static int nppiCopy_16s_C4R(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiCopy_16s_C4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_16s_C4RNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 4 channel 16-bit image copy, not affecting Alpha.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_16s_AC4R(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiCopy_16s_AC4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_16s_AC4RNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 16-bit complex image copy.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_16sc_C1R(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiCopy_16sc_C1RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_16sc_C1RNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Two-channel 16-bit complex image copy.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_16sc_C2R(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiCopy_16sc_C2RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_16sc_C2RNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three-channel 16-bit complex image copy.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_16sc_C3R(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiCopy_16sc_C3RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_16sc_C3RNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four-channel 16-bit complex image copy.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_16sc_C4R(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiCopy_16sc_C4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_16sc_C4RNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four-channel 16-bit complex image copy, ignoring alpha.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_16sc_AC4R(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiCopy_16sc_AC4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_16sc_AC4RNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    public static int nppiCopy_32s_C1R(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiCopy_32s_C1RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_32s_C1RNative(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 4 channel 32-bit image copy.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_32s_C4R(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiCopy_32s_C4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_32s_C4RNative(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 4 channel 32-bit image copy, not affecting Alpha.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_32s_AC4R(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiCopy_32s_AC4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_32s_AC4RNative(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 32-bit complex image copy.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_32sc_C1R(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiCopy_32sc_C1RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_32sc_C1RNative(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Two-channel 32-bit complex image copy.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_32sc_C2R(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiCopy_32sc_C2RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_32sc_C2RNative(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three-channel 32-bit complex image copy.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_32sc_C3R(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiCopy_32sc_C3RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_32sc_C3RNative(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four-channel 32-bit complex image copy.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_32sc_C4R(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiCopy_32sc_C4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_32sc_C4RNative(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four-channel 32-bit complex image copy, ignoring alpha.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_32sc_AC4R(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiCopy_32sc_AC4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_32sc_AC4RNative(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 32-bit floating point image copy.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_32f_C1R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiCopy_32f_C1RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_32f_C1RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 4 channel 32-bit floating point image copy.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_32f_C4R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiCopy_32f_C4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_32f_C4RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    public static int nppiCopy_32f_AC4R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiCopy_32f_AC4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_32f_AC4RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 32-bit floating-point complex image copy.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_32fc_C1R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiCopy_32fc_C1RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_32fc_C1RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Two-channel 32-bit floating-point complex image copy.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_32fc_C2R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiCopy_32fc_C2RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_32fc_C2RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three-channel 32-bit floating-point complex image copy.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_32fc_C3R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiCopy_32fc_C3RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_32fc_C3RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    public static int nppiCopy_32fc_C4R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiCopy_32fc_C4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_32fc_C4RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four-channel 32-bit floating-point complex image copy, ignoring alpha.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_32fc_AC4R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiCopy_32fc_AC4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_32fc_AC4RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * \ref masked_operation 8-bit unsigned image copy.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param pMask \ref mask_image_pointer.
     * @param nMaskStep \ref mask_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_8u_C1MR(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep)
    {
        return JNpp.checkResult(nppiCopy_8u_C1MRNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, pMask, nMaskStep));
    }
    private static native int nppiCopy_8u_C1MRNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep);


    /**
     * <pre>
     * \ref masked_operation three channel 8-bit unsigned image copy.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param pMask \ref mask_image_pointer.
     * @param nMaskStep \ref mask_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_8u_C3MR(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep)
    {
        return JNpp.checkResult(nppiCopy_8u_C3MRNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, pMask, nMaskStep));
    }
    private static native int nppiCopy_8u_C3MRNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep);


    /**
     * <pre>
     * \ref masked_operation four channel 8-bit unsigned image copy.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param pMask \ref mask_image_pointer.
     * @param nMaskStep \ref mask_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_8u_C4MR(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep)
    {
        return JNpp.checkResult(nppiCopy_8u_C4MRNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, pMask, nMaskStep));
    }
    private static native int nppiCopy_8u_C4MRNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep);


    /**
     * <pre>
     * \ref masked_operation four channel 8-bit unsigned image copy, ignoring alpha.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param pMask \ref mask_image_pointer.
     * @param nMaskStep \ref mask_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_8u_AC4MR(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep)
    {
        return JNpp.checkResult(nppiCopy_8u_AC4MRNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, pMask, nMaskStep));
    }
    private static native int nppiCopy_8u_AC4MRNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep);


    /**
     * <pre>
     * \ref masked_operation 16-bit unsigned image copy.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param pMask \ref mask_image_pointer.
     * @param nMaskStep \ref mask_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_16u_C1MR(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep)
    {
        return JNpp.checkResult(nppiCopy_16u_C1MRNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, pMask, nMaskStep));
    }
    private static native int nppiCopy_16u_C1MRNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep);


    /**
     * <pre>
     * \ref masked_operation three channel 16-bit unsigned image copy.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param pMask \ref mask_image_pointer.
     * @param nMaskStep \ref mask_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_16u_C3MR(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep)
    {
        return JNpp.checkResult(nppiCopy_16u_C3MRNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, pMask, nMaskStep));
    }
    private static native int nppiCopy_16u_C3MRNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep);


    /**
     * <pre>
     * \ref masked_operation four channel 16-bit unsigned image copy.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param pMask \ref mask_image_pointer.
     * @param nMaskStep \ref mask_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_16u_C4MR(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep)
    {
        return JNpp.checkResult(nppiCopy_16u_C4MRNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, pMask, nMaskStep));
    }
    private static native int nppiCopy_16u_C4MRNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep);


    /**
     * <pre>
     * \ref masked_operation four channel 16-bit unsigned image copy, ignoring alpha.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param pMask \ref mask_image_pointer.
     * @param nMaskStep \ref mask_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_16u_AC4MR(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep)
    {
        return JNpp.checkResult(nppiCopy_16u_AC4MRNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, pMask, nMaskStep));
    }
    private static native int nppiCopy_16u_AC4MRNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep);


    /**
     * <pre>
     * \ref masked_operation 16-bit signed image copy.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param pMask \ref mask_image_pointer.
     * @param nMaskStep \ref mask_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_16s_C1MR(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep)
    {
        return JNpp.checkResult(nppiCopy_16s_C1MRNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, pMask, nMaskStep));
    }
    private static native int nppiCopy_16s_C1MRNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep);


    /**
     * <pre>
     * \ref masked_operation three channel 16-bit signed image copy.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param pMask \ref mask_image_pointer.
     * @param nMaskStep \ref mask_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_16s_C3MR(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep)
    {
        return JNpp.checkResult(nppiCopy_16s_C3MRNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, pMask, nMaskStep));
    }
    private static native int nppiCopy_16s_C3MRNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep);


    /**
     * <pre>
     * \ref masked_operation four channel 16-bit signed image copy.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param pMask \ref mask_image_pointer.
     * @param nMaskStep \ref mask_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_16s_C4MR(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep)
    {
        return JNpp.checkResult(nppiCopy_16s_C4MRNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, pMask, nMaskStep));
    }
    private static native int nppiCopy_16s_C4MRNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep);


    /**
     * <pre>
     * \ref masked_operation four channel 16-bit signed image copy, ignoring alpha.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param pMask \ref mask_image_pointer.
     * @param nMaskStep \ref mask_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_16s_AC4MR(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep)
    {
        return JNpp.checkResult(nppiCopy_16s_AC4MRNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, pMask, nMaskStep));
    }
    private static native int nppiCopy_16s_AC4MRNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep);


    /**
     * <pre>
     * \ref masked_operation 32-bit signed image copy.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param pMask \ref mask_image_pointer.
     * @param nMaskStep \ref mask_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_32s_C1MR(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep)
    {
        return JNpp.checkResult(nppiCopy_32s_C1MRNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, pMask, nMaskStep));
    }
    private static native int nppiCopy_32s_C1MRNative(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep);


    /**
     * <pre>
     * \ref masked_operation three channel 32-bit signed image copy.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param pMask \ref mask_image_pointer.
     * @param nMaskStep \ref mask_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_32s_C3MR(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep)
    {
        return JNpp.checkResult(nppiCopy_32s_C3MRNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, pMask, nMaskStep));
    }
    private static native int nppiCopy_32s_C3MRNative(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep);


    /**
     * <pre>
     * \ref masked_operation four channel 32-bit signed image copy.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param pMask \ref mask_image_pointer.
     * @param nMaskStep \ref mask_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_32s_C4MR(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep)
    {
        return JNpp.checkResult(nppiCopy_32s_C4MRNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, pMask, nMaskStep));
    }
    private static native int nppiCopy_32s_C4MRNative(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep);


    /**
     * <pre>
     * \ref masked_operation four channel 32-bit signed image copy, ignoring alpha.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param pMask \ref mask_image_pointer.
     * @param nMaskStep \ref mask_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_32s_AC4MR(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep)
    {
        return JNpp.checkResult(nppiCopy_32s_AC4MRNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, pMask, nMaskStep));
    }
    private static native int nppiCopy_32s_AC4MRNative(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep);


    /**
     * <pre>
     * \ref masked_operation 32-bit float image copy.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param pMask \ref mask_image_pointer.
     * @param nMaskStep \ref mask_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_32f_C1MR(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep)
    {
        return JNpp.checkResult(nppiCopy_32f_C1MRNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, pMask, nMaskStep));
    }
    private static native int nppiCopy_32f_C1MRNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep);


    /**
     * <pre>
     * \ref masked_operation three channel 32-bit float image copy.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param pMask \ref mask_image_pointer.
     * @param nMaskStep \ref mask_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_32f_C3MR(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep)
    {
        return JNpp.checkResult(nppiCopy_32f_C3MRNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, pMask, nMaskStep));
    }
    private static native int nppiCopy_32f_C3MRNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep);


    /**
     * <pre>
     * \ref masked_operation four channel 32-bit float image copy.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param pMask \ref mask_image_pointer.
     * @param nMaskStep \ref mask_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_32f_C4MR(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep)
    {
        return JNpp.checkResult(nppiCopy_32f_C4MRNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, pMask, nMaskStep));
    }
    private static native int nppiCopy_32f_C4MRNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep);


    /**
     * <pre>
     * \ref masked_operation four channel 32-bit float image copy, ignoring alpha.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param pMask \ref mask_image_pointer.
     * @param nMaskStep \ref mask_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_32f_AC4MR(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep)
    {
        return JNpp.checkResult(nppiCopy_32f_AC4MRNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, pMask, nMaskStep));
    }
    private static native int nppiCopy_32f_AC4MRNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep);


    public static int nppiCopy_8u_C3CR(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiCopy_8u_C3CRNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_8u_C3CRNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Select-channel 8-bit unsigned image copy for four-channel images.
     * @param pSrc \ref select_source_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref select_destination_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_8u_C4CR(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiCopy_8u_C4CRNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_8u_C4CRNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    public static int nppiCopy_16s_C3CR(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiCopy_16s_C3CRNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_16s_C3CRNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Select-channel 16-bit signed image copy for four-channel images.
     * @param pSrc \ref select_source_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref select_destination_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_16s_C4CR(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiCopy_16s_C4CRNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_16s_C4CRNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Select-channel 16-bit unsigned image copy for three-channel images.
     * @param pSrc \ref select_source_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref select_destination_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_16u_C3CR(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiCopy_16u_C3CRNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_16u_C3CRNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Select-channel 16-bit unsigned image copy for four-channel images.
     * @param pSrc \ref select_source_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref select_destination_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_16u_C4CR(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiCopy_16u_C4CRNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_16u_C4CRNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Select-channel 32-bit signed image copy for three-channel images.
     * @param pSrc \ref select_source_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref select_destination_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_32s_C3CR(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiCopy_32s_C3CRNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_32s_C3CRNative(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Select-channel 32-bit signed image copy for four-channel images.
     * @param pSrc \ref select_source_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref select_destination_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_32s_C4CR(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiCopy_32s_C4CRNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_32s_C4CRNative(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Select-channel 32-bit float image copy for three-channel images.
     * @param pSrc \ref select_source_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref select_destination_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_32f_C3CR(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiCopy_32f_C3CRNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_32f_C3CRNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Select-channel 32-bit float image copy for four-channel images.
     * @param pSrc \ref select_source_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref select_destination_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_32f_C4CR(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiCopy_32f_C4CRNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_32f_C4CRNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three-channel to single-channel 8-bit unsigned image copy.
     * @param pSrc \ref select_source_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_8u_C3C1R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiCopy_8u_C3C1RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_8u_C3C1RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    public static int nppiCopy_8u_C4C1R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiCopy_8u_C4C1RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_8u_C4C1RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three-channel to single-channel 16-bit signed image copy.
     * @param pSrc \ref select_source_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_16s_C3C1R(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiCopy_16s_C3C1RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_16s_C3C1RNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four-channel to single-channel 16-bit signed image copy.
     * @param pSrc \ref select_source_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_16s_C4C1R(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiCopy_16s_C4C1RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_16s_C4C1RNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three-channel to single-channel 16-bit unsigned image copy.
     * @param pSrc \ref select_source_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_16u_C3C1R(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiCopy_16u_C3C1RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_16u_C3C1RNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four-channel to single-channel 16-bit unsigned image copy.
     * @param pSrc \ref select_source_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_16u_C4C1R(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiCopy_16u_C4C1RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_16u_C4C1RNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three-channel to single-channel 32-bit signed image copy.
     * @param pSrc \ref select_source_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_32s_C3C1R(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiCopy_32s_C3C1RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_32s_C3C1RNative(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four-channel to single-channel 32-bit signed image copy.
     * @param pSrc \ref select_source_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_32s_C4C1R(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiCopy_32s_C4C1RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_32s_C4C1RNative(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three-channel to single-channel 32-bit float image copy.
     * @param pSrc \ref select_source_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_32f_C3C1R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiCopy_32f_C3C1RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_32f_C3C1RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four-channel to single-channel 32-bit float image copy.
     * @param pSrc \ref select_source_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_32f_C4C1R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiCopy_32f_C4C1RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_32f_C4C1RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Single-channel to three-channel 8-bit unsigned image copy.
     * @param pSrc \ref select_source_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_8u_C1C3R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiCopy_8u_C1C3RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_8u_C1C3RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Single-channel to four-channel 8-bit unsigned image copy.
     * @param pSrc \ref select_source_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_8u_C1C4R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiCopy_8u_C1C4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_8u_C1C4RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Single-channel to three-channel 16-bit signed image copy.
     * @param pSrc \ref select_source_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_16s_C1C3R(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiCopy_16s_C1C3RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_16s_C1C3RNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Single-channel to four-channel 16-bit signed image copy.
     * @param pSrc \ref select_source_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_16s_C1C4R(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiCopy_16s_C1C4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_16s_C1C4RNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Single-channel to three-channel 16-bit unsigned image copy.
     * @param pSrc \ref select_source_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_16u_C1C3R(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiCopy_16u_C1C3RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_16u_C1C3RNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Single-channel to four-channel 16-bit unsigned image copy.
     * @param pSrc \ref select_source_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_16u_C1C4R(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiCopy_16u_C1C4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_16u_C1C4RNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Single-channel to three-channel 32-bit signed image copy.
     * @param pSrc \ref select_source_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_32s_C1C3R(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiCopy_32s_C1C3RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_32s_C1C3RNative(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Single-channel to four-channel 32-bit signed image copy.
     * @param pSrc \ref select_source_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_32s_C1C4R(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiCopy_32s_C1C4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_32s_C1C4RNative(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Single-channel to three-channel 32-bit float image copy.
     * @param pSrc \ref select_source_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_32f_C1C3R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiCopy_32f_C1C3RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_32f_C1C3RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Single-channel to four-channel 32-bit float image copy.
     * @param pSrc \ref select_source_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_32f_C1C4R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiCopy_32f_C1C4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_32f_C1C4RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    public static int nppiCopy_8u_C3P3R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u>[] aDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiCopy_8u_C3P3RNative(pSrc, nSrcStep, aDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_8u_C3P3RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u>[] aDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four-channel 8-bit unsigned packed to planar image copy.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param aDst Planar \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_8u_C4P4R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u>[] aDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiCopy_8u_C4P4RNative(pSrc, nSrcStep, aDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_8u_C4P4RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u>[] aDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three-channel 16-bit signed packed to planar image copy.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param aDst Planar \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_16s_C3P3R(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s>[] aDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiCopy_16s_C3P3RNative(pSrc, nSrcStep, aDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_16s_C3P3RNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s>[] aDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four-channel 16-bit signed packed to planar image copy.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param aDst Planar \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_16s_C4P4R(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s>[] aDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiCopy_16s_C4P4RNative(pSrc, nSrcStep, aDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_16s_C4P4RNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s>[] aDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three-channel 16-bit unsigned packed to planar image copy.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param aDst Planar \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_16u_C3P3R(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u>[] aDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiCopy_16u_C3P3RNative(pSrc, nSrcStep, aDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_16u_C3P3RNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u>[] aDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    public static int nppiCopy_16u_C4P4R(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u>[] aDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiCopy_16u_C4P4RNative(pSrc, nSrcStep, aDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_16u_C4P4RNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u>[] aDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three-channel 32-bit signed packed to planar image copy.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param aDst Planar \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_32s_C3P3R(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s>[] aDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiCopy_32s_C3P3RNative(pSrc, nSrcStep, aDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_32s_C3P3RNative(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s>[] aDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    public static int nppiCopy_32s_C4P4R(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s>[] aDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiCopy_32s_C4P4RNative(pSrc, nSrcStep, aDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_32s_C4P4RNative(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s>[] aDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three-channel 32-bit float packed to planar image copy.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param aDst Planar \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_32f_C3P3R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f>[] aDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiCopy_32f_C3P3RNative(pSrc, nSrcStep, aDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_32f_C3P3RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f>[] aDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four-channel 32-bit float packed to planar image copy.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param aDst Planar \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_32f_C4P4R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f>[] aDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiCopy_32f_C4P4RNative(pSrc, nSrcStep, aDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_32f_C4P4RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f>[] aDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three-channel 8-bit unsigned planar to packed image copy.
     * @param aSrc Planar \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_8u_P3C3R(
        TypedPointer<Npp8u>[] aSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiCopy_8u_P3C3RNative(aSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_8u_P3C3RNative(
        TypedPointer<Npp8u>[] aSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four-channel 8-bit unsigned planar to packed image copy.
     * @param aSrc Planar \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_8u_P4C4R(
        TypedPointer<Npp8u>[] aSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiCopy_8u_P4C4RNative(aSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_8u_P4C4RNative(
        TypedPointer<Npp8u>[] aSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three-channel 16-bit unsigned planar to packed image copy.
     * @param aSrc Planar \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_16u_P3C3R(
        TypedPointer<Npp16u>[] aSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiCopy_16u_P3C3RNative(aSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_16u_P3C3RNative(
        TypedPointer<Npp16u>[] aSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four-channel 16-bit unsigned planar to packed image copy.
     * @param aSrc Planar \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_16u_P4C4R(
        TypedPointer<Npp16u>[] aSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiCopy_16u_P4C4RNative(aSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_16u_P4C4RNative(
        TypedPointer<Npp16u>[] aSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    public static int nppiCopy_16s_P3C3R(
        TypedPointer<Npp16s>[] aSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiCopy_16s_P3C3RNative(aSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_16s_P3C3RNative(
        TypedPointer<Npp16s>[] aSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four-channel 16-bit signed planar to packed image copy.
     * @param aSrc Planar \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_16s_P4C4R(
        TypedPointer<Npp16s>[] aSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiCopy_16s_P4C4RNative(aSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_16s_P4C4RNative(
        TypedPointer<Npp16s>[] aSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three-channel 32-bit signed planar to packed image copy.
     * @param aSrc Planar \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_32s_P3C3R(
        TypedPointer<Npp32s>[] aSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiCopy_32s_P3C3RNative(aSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_32s_P3C3RNative(
        TypedPointer<Npp32s>[] aSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four-channel 32-bit signed planar to packed image copy.
     * @param aSrc Planar \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_32s_P4C4R(
        TypedPointer<Npp32s>[] aSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiCopy_32s_P4C4RNative(aSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_32s_P4C4RNative(
        TypedPointer<Npp32s>[] aSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three-channel 32-bit float planar to packed image copy.
     * @param aSrc Planar \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_32f_P3C3R(
        TypedPointer<Npp32f>[] aSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiCopy_32f_P3C3RNative(aSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_32f_P3C3RNative(
        TypedPointer<Npp32f>[] aSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four-channel 32-bit float planar to packed image copy.
     * @param aSrc Planar \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_32f_P4C4R(
        TypedPointer<Npp32f>[] aSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiCopy_32f_P4C4RNative(aSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_32f_P4C4RNative(
        TypedPointer<Npp32f>[] aSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Single channel 8-bit unsigned to 16-bit unsigned conversion.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiConvert_8u16u_C1R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiConvert_8u16u_C1RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiConvert_8u16u_C1RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three channel 8-bit unsigned to 16-bit unsigned  conversion.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiConvert_8u16u_C3R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiConvert_8u16u_C3RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiConvert_8u16u_C3RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four channel 8-bit unsigned to 16-bit unsigned  conversion.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiConvert_8u16u_C4R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiConvert_8u16u_C4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiConvert_8u16u_C4RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four channel 8-bit unsigned to 16-bit unsigned conversion, not affecting Alpha.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiConvert_8u16u_AC4R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiConvert_8u16u_AC4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiConvert_8u16u_AC4RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Single channel 8-bit unsigned to 16-bit signed conversion.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiConvert_8u16s_C1R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiConvert_8u16s_C1RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiConvert_8u16s_C1RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three channel 8-bit unsigned to 16-bit signed conversion.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiConvert_8u16s_C3R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiConvert_8u16s_C3RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiConvert_8u16s_C3RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four channel 8-bit unsigned to 16-bit signed conversion.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiConvert_8u16s_C4R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiConvert_8u16s_C4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiConvert_8u16s_C4RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four channel 8-bit unsigned to 16-bit signed conversion, not affecting Alpha.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiConvert_8u16s_AC4R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiConvert_8u16s_AC4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiConvert_8u16s_AC4RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Single channel 8-bit unsigned to 32-bit signed conversion.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiConvert_8u32s_C1R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiConvert_8u32s_C1RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiConvert_8u32s_C1RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three channel 8-bit unsigned to 32-bit signed conversion.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiConvert_8u32s_C3R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiConvert_8u32s_C3RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiConvert_8u32s_C3RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    public static int nppiConvert_8u32s_C4R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiConvert_8u32s_C4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiConvert_8u32s_C4RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four channel 8-bit unsigned to 32-bit signed conversion, not affecting Alpha.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiConvert_8u32s_AC4R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiConvert_8u32s_AC4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiConvert_8u32s_AC4RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Single channel 8-bit unsigned to 32-bit floating-point conversion.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiConvert_8u32f_C1R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiConvert_8u32f_C1RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiConvert_8u32f_C1RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three channel 8-bit unsigned to 32-bit floating-point conversion.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiConvert_8u32f_C3R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiConvert_8u32f_C3RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiConvert_8u32f_C3RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four channel 8-bit unsigned to 32-bit floating-point conversion.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiConvert_8u32f_C4R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiConvert_8u32f_C4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiConvert_8u32f_C4RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    public static int nppiConvert_8u32f_AC4R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiConvert_8u32f_AC4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiConvert_8u32f_AC4RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Single channel 8-bit signed to 32-bit signed conversion.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiConvert_8s32s_C1R(
        TypedPointer<Npp8s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiConvert_8s32s_C1RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiConvert_8s32s_C1RNative(
        TypedPointer<Npp8s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three channel 8-bit signed to 32-bit signed conversion.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiConvert_8s32s_C3R(
        TypedPointer<Npp8s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiConvert_8s32s_C3RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiConvert_8s32s_C3RNative(
        TypedPointer<Npp8s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    public static int nppiConvert_8s32s_C4R(
        TypedPointer<Npp8s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiConvert_8s32s_C4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiConvert_8s32s_C4RNative(
        TypedPointer<Npp8s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    public static int nppiConvert_8s32s_AC4R(
        TypedPointer<Npp8s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiConvert_8s32s_AC4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiConvert_8s32s_AC4RNative(
        TypedPointer<Npp8s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Single channel 8-bit signed to 32-bit floating-point conversion.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiConvert_8s32f_C1R(
        TypedPointer<Npp8s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiConvert_8s32f_C1RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiConvert_8s32f_C1RNative(
        TypedPointer<Npp8s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    public static int nppiConvert_8s32f_C3R(
        TypedPointer<Npp8s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiConvert_8s32f_C3RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiConvert_8s32f_C3RNative(
        TypedPointer<Npp8s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four channel 8-bit signed to 32-bit floating-point conversion.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiConvert_8s32f_C4R(
        TypedPointer<Npp8s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiConvert_8s32f_C4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiConvert_8s32f_C4RNative(
        TypedPointer<Npp8s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four channel 8-bit signed to 32-bit floating-point conversion, not affecting Alpha.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiConvert_8s32f_AC4R(
        TypedPointer<Npp8s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiConvert_8s32f_AC4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiConvert_8s32f_AC4RNative(
        TypedPointer<Npp8s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Single channel 16-bit unsigned to 32-bit signed conversion.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiConvert_16u32s_C1R(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiConvert_16u32s_C1RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiConvert_16u32s_C1RNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three channel 16-bit unsigned to 32-bit signed conversion.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiConvert_16u32s_C3R(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiConvert_16u32s_C3RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiConvert_16u32s_C3RNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four channel 16-bit unsigned to 32-bit signed conversion.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiConvert_16u32s_C4R(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiConvert_16u32s_C4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiConvert_16u32s_C4RNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four channel 16-bit unsigned to 32-bit signed conversion, not affecting Alpha.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiConvert_16u32s_AC4R(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiConvert_16u32s_AC4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiConvert_16u32s_AC4RNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    public static int nppiConvert_16u32f_C1R(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiConvert_16u32f_C1RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiConvert_16u32f_C1RNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three channel 16-bit unsigned to 32-bit floating-point conversion.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiConvert_16u32f_C3R(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiConvert_16u32f_C3RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiConvert_16u32f_C3RNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four channel 16-bit unsigned to 32-bit floating-point conversion.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiConvert_16u32f_C4R(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiConvert_16u32f_C4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiConvert_16u32f_C4RNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four channel 16-bit unsigned to 32-bit floating-point conversion, not affecting Alpha.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiConvert_16u32f_AC4R(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiConvert_16u32f_AC4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiConvert_16u32f_AC4RNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Single channel 16-bit signed to 32-bit signed conversion.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiConvert_16s32s_C1R(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiConvert_16s32s_C1RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiConvert_16s32s_C1RNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three channel 16-bit signed to 32-bit signed conversion.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiConvert_16s32s_C3R(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiConvert_16s32s_C3RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiConvert_16s32s_C3RNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four channel 16-bit signed to 32-bit signed conversion.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiConvert_16s32s_C4R(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiConvert_16s32s_C4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiConvert_16s32s_C4RNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four channel 16-bit signed to 32-bit signed conversion, not affecting Alpha.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiConvert_16s32s_AC4R(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiConvert_16s32s_AC4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiConvert_16s32s_AC4RNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Single channel 16-bit signed to 32-bit floating-point conversion.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiConvert_16s32f_C1R(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiConvert_16s32f_C1RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiConvert_16s32f_C1RNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three channel 16-bit signed to 32-bit floating-point conversion.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiConvert_16s32f_C3R(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiConvert_16s32f_C3RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiConvert_16s32f_C3RNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four channel 16-bit signed to 32-bit floating-point conversion.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiConvert_16s32f_C4R(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiConvert_16s32f_C4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiConvert_16s32f_C4RNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four channel 16-bit signed to 32-bit floating-point conversion, not affecting Alpha.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiConvert_16s32f_AC4R(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiConvert_16s32f_AC4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiConvert_16s32f_AC4RNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Single channel 8-bit signed to 8-bit unsigned conversion with saturation.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiConvert_8s8u_C1Rs(
        TypedPointer<Npp8s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiConvert_8s8u_C1RsNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiConvert_8s8u_C1RsNative(
        TypedPointer<Npp8s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Single channel 8-bit signed to 16-bit unsigned conversion with saturation.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiConvert_8s16u_C1Rs(
        TypedPointer<Npp8s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiConvert_8s16u_C1RsNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiConvert_8s16u_C1RsNative(
        TypedPointer<Npp8s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Single channel 8-bit signed to 16-bit signed conversion.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiConvert_8s16s_C1R(
        TypedPointer<Npp8s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiConvert_8s16s_C1RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiConvert_8s16s_C1RNative(
        TypedPointer<Npp8s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Single channel 8-bit signed to 32-bit unsigned conversion with saturation.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiConvert_8s32u_C1Rs(
        TypedPointer<Npp8s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiConvert_8s32u_C1RsNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiConvert_8s32u_C1RsNative(
        TypedPointer<Npp8s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Single channel 16-bit signed to 16-bit unsigned conversion with saturation.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiConvert_16s16u_C1Rs(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiConvert_16s16u_C1RsNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiConvert_16s16u_C1RsNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Single channel 16-bit signed to 32-bit unsigned conversion with saturation.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiConvert_16s32u_C1Rs(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiConvert_16s32u_C1RsNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiConvert_16s32u_C1RsNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Single channel 16-bit unsigned to 32-bit unsigned conversion.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiConvert_16u32u_C1R(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiConvert_16u32u_C1RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiConvert_16u32u_C1RNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Single channel 32-bit signed to 32-bit unsigned conversion with saturation.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiConvert_32s32u_C1Rs(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiConvert_32s32u_C1RsNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiConvert_32s32u_C1RsNative(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Single channel 32-bit signed to 32-bit floating-point conversion.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiConvert_32s32f_C1R(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiConvert_32s32f_C1RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiConvert_32s32f_C1RNative(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Single channel 32-bit unsigned to 32-bit floating-point conversion.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiConvert_32u32f_C1R(
        TypedPointer<Npp32u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiConvert_32u32f_C1RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiConvert_32u32f_C1RNative(
        TypedPointer<Npp32u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Single channel 16-bit unsigned to 8-bit unsigned conversion.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiConvert_16u8u_C1R(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiConvert_16u8u_C1RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiConvert_16u8u_C1RNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three channel 16-bit unsigned to 8-bit unsigned conversion.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiConvert_16u8u_C3R(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiConvert_16u8u_C3RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiConvert_16u8u_C3RNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    public static int nppiConvert_16u8u_C4R(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiConvert_16u8u_C4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiConvert_16u8u_C4RNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four channel 16-bit unsigned to 8-bit unsigned conversion, not affecting Alpha.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiConvert_16u8u_AC4R(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiConvert_16u8u_AC4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiConvert_16u8u_AC4RNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Single channel 16-bit signed to 8-bit unsigned conversion.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiConvert_16s8u_C1R(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiConvert_16s8u_C1RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiConvert_16s8u_C1RNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three channel 16-bit signed to 8-bit unsigned conversion.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiConvert_16s8u_C3R(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiConvert_16s8u_C3RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiConvert_16s8u_C3RNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four channel 16-bit signed to 8-bit unsigned conversion.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiConvert_16s8u_C4R(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiConvert_16s8u_C4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiConvert_16s8u_C4RNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four channel 16-bit signed to 8-bit unsigned conversion, not affecting Alpha.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiConvert_16s8u_AC4R(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiConvert_16s8u_AC4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiConvert_16s8u_AC4RNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    public static int nppiConvert_32s8u_C1R(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiConvert_32s8u_C1RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiConvert_32s8u_C1RNative(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three channel 32-bit signed to 8-bit unsigned conversion.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiConvert_32s8u_C3R(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiConvert_32s8u_C3RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiConvert_32s8u_C3RNative(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four channel 32-bit signed to 8-bit unsigned conversion.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiConvert_32s8u_C4R(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiConvert_32s8u_C4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiConvert_32s8u_C4RNative(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    public static int nppiConvert_32s8u_AC4R(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiConvert_32s8u_AC4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiConvert_32s8u_AC4RNative(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Single channel 32-bit signed to 8-bit signed conversion.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiConvert_32s8s_C1R(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiConvert_32s8s_C1RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiConvert_32s8s_C1RNative(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three channel 32-bit signed to 8-bit signed conversion.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiConvert_32s8s_C3R(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiConvert_32s8s_C3RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiConvert_32s8s_C3RNative(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four channel 32-bit signed to 8-bit signed conversion.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiConvert_32s8s_C4R(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiConvert_32s8s_C4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiConvert_32s8s_C4RNative(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four channel 32-bit signed to 8-bit signed conversion, not affecting Alpha.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiConvert_32s8s_AC4R(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiConvert_32s8s_AC4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiConvert_32s8s_AC4RNative(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    public static int nppiConvert_8u8s_C1RSfs(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eRoundMode, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiConvert_8u8s_C1RSfsNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, eRoundMode, nScaleFactor));
    }
    private static native int nppiConvert_8u8s_C1RSfsNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eRoundMode, 
        int nScaleFactor);


    public static int nppiConvert_16u8s_C1RSfs(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eRoundMode, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiConvert_16u8s_C1RSfsNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, eRoundMode, nScaleFactor));
    }
    private static native int nppiConvert_16u8s_C1RSfsNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eRoundMode, 
        int nScaleFactor);


    public static int nppiConvert_16s8s_C1RSfs(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eRoundMode, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiConvert_16s8s_C1RSfsNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, eRoundMode, nScaleFactor));
    }
    private static native int nppiConvert_16s8s_C1RSfsNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eRoundMode, 
        int nScaleFactor);


    public static int nppiConvert_16u16s_C1RSfs(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eRoundMode, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiConvert_16u16s_C1RSfsNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, eRoundMode, nScaleFactor));
    }
    private static native int nppiConvert_16u16s_C1RSfsNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eRoundMode, 
        int nScaleFactor);


    public static int nppiConvert_32u8u_C1RSfs(
        TypedPointer<Npp32u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eRoundMode, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiConvert_32u8u_C1RSfsNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, eRoundMode, nScaleFactor));
    }
    private static native int nppiConvert_32u8u_C1RSfsNative(
        TypedPointer<Npp32u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eRoundMode, 
        int nScaleFactor);


    public static int nppiConvert_32u8s_C1RSfs(
        TypedPointer<Npp32u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eRoundMode, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiConvert_32u8s_C1RSfsNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, eRoundMode, nScaleFactor));
    }
    private static native int nppiConvert_32u8s_C1RSfsNative(
        TypedPointer<Npp32u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eRoundMode, 
        int nScaleFactor);


    public static int nppiConvert_32u16u_C1RSfs(
        TypedPointer<Npp32u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eRoundMode, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiConvert_32u16u_C1RSfsNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, eRoundMode, nScaleFactor));
    }
    private static native int nppiConvert_32u16u_C1RSfsNative(
        TypedPointer<Npp32u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eRoundMode, 
        int nScaleFactor);


    public static int nppiConvert_32u16s_C1RSfs(
        TypedPointer<Npp32u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eRoundMode, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiConvert_32u16s_C1RSfsNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, eRoundMode, nScaleFactor));
    }
    private static native int nppiConvert_32u16s_C1RSfsNative(
        TypedPointer<Npp32u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eRoundMode, 
        int nScaleFactor);


    public static int nppiConvert_32u32s_C1RSfs(
        TypedPointer<Npp32u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eRoundMode, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiConvert_32u32s_C1RSfsNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, eRoundMode, nScaleFactor));
    }
    private static native int nppiConvert_32u32s_C1RSfsNative(
        TypedPointer<Npp32u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eRoundMode, 
        int nScaleFactor);


    public static int nppiConvert_32s16u_C1RSfs(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eRoundMode, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiConvert_32s16u_C1RSfsNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, eRoundMode, nScaleFactor));
    }
    private static native int nppiConvert_32s16u_C1RSfsNative(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eRoundMode, 
        int nScaleFactor);


    public static int nppiConvert_32s16s_C1RSfs(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eRoundMode, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiConvert_32s16s_C1RSfsNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, eRoundMode, nScaleFactor));
    }
    private static native int nppiConvert_32s16s_C1RSfsNative(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eRoundMode, 
        int nScaleFactor);


    /**
     * <pre>
     * Single channel 32-bit floating point to 8-bit unsigned conversion.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param eRoundMode Flag specifying how fractional float values are rounded to integer values.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiConvert_32f8u_C1R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eRoundMode)
    {
        return JNpp.checkResult(nppiConvert_32f8u_C1RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, eRoundMode));
    }
    private static native int nppiConvert_32f8u_C1RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eRoundMode);


    /**
     * <pre>
     * Three channel 32-bit floating point to 8-bit unsigned conversion.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param eRoundMode Flag specifying how fractional float values are rounded to integer values.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiConvert_32f8u_C3R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eRoundMode)
    {
        return JNpp.checkResult(nppiConvert_32f8u_C3RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, eRoundMode));
    }
    private static native int nppiConvert_32f8u_C3RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eRoundMode);


    /**
     * <pre>
     * Four channel 32-bit floating point to 8-bit unsigned conversion.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param eRoundMode Flag specifying how fractional float values are rounded to integer values.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiConvert_32f8u_C4R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eRoundMode)
    {
        return JNpp.checkResult(nppiConvert_32f8u_C4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, eRoundMode));
    }
    private static native int nppiConvert_32f8u_C4RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eRoundMode);


    /**
     * <pre>
     * Four channel 32-bit floating point to 8-bit unsigned conversion, not affecting Alpha.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param eRoundMode Flag specifying how fractional float values are rounded to integer values.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiConvert_32f8u_AC4R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eRoundMode)
    {
        return JNpp.checkResult(nppiConvert_32f8u_AC4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, eRoundMode));
    }
    private static native int nppiConvert_32f8u_AC4RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eRoundMode);


    /**
     * <pre>
     * Single channel 32-bit floating point to 8-bit signed conversion.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param eRoundMode Flag specifying how fractional float values are rounded to integer values.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiConvert_32f8s_C1R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eRoundMode)
    {
        return JNpp.checkResult(nppiConvert_32f8s_C1RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, eRoundMode));
    }
    private static native int nppiConvert_32f8s_C1RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eRoundMode);


    /**
     * <pre>
     * Three channel 32-bit floating point to 8-bit signed conversion.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param eRoundMode Flag specifying how fractional float values are rounded to integer values.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiConvert_32f8s_C3R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eRoundMode)
    {
        return JNpp.checkResult(nppiConvert_32f8s_C3RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, eRoundMode));
    }
    private static native int nppiConvert_32f8s_C3RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eRoundMode);


    /**
     * <pre>
     * Four channel 32-bit floating point to 8-bit signed conversion.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param eRoundMode Flag specifying how fractional float values are rounded to integer values.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiConvert_32f8s_C4R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eRoundMode)
    {
        return JNpp.checkResult(nppiConvert_32f8s_C4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, eRoundMode));
    }
    private static native int nppiConvert_32f8s_C4RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eRoundMode);


    /**
     * <pre>
     * Four channel 32-bit floating point to 8-bit signed conversion, not affecting Alpha.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param eRoundMode Flag specifying how fractional float values are rounded to integer values.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiConvert_32f8s_AC4R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eRoundMode)
    {
        return JNpp.checkResult(nppiConvert_32f8s_AC4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, eRoundMode));
    }
    private static native int nppiConvert_32f8s_AC4RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eRoundMode);


    public static int nppiConvert_32f16u_C1R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eRoundMode)
    {
        return JNpp.checkResult(nppiConvert_32f16u_C1RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, eRoundMode));
    }
    private static native int nppiConvert_32f16u_C1RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eRoundMode);


    /**
     * <pre>
     * Three channel 32-bit floating point to 16-bit unsigned conversion.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param eRoundMode Flag specifying how fractional float values are rounded to integer values.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiConvert_32f16u_C3R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eRoundMode)
    {
        return JNpp.checkResult(nppiConvert_32f16u_C3RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, eRoundMode));
    }
    private static native int nppiConvert_32f16u_C3RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eRoundMode);


    /**
     * <pre>
     * Four channel 32-bit floating point to 16-bit unsigned conversion.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param eRoundMode Flag specifying how fractional float values are rounded to integer values.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiConvert_32f16u_C4R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eRoundMode)
    {
        return JNpp.checkResult(nppiConvert_32f16u_C4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, eRoundMode));
    }
    private static native int nppiConvert_32f16u_C4RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eRoundMode);


    /**
     * <pre>
     * Four channel 32-bit floating point to 16-bit unsigned conversion, not affecting Alpha.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param eRoundMode Flag specifying how fractional float values are rounded to integer values.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiConvert_32f16u_AC4R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eRoundMode)
    {
        return JNpp.checkResult(nppiConvert_32f16u_AC4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, eRoundMode));
    }
    private static native int nppiConvert_32f16u_AC4RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eRoundMode);


    /**
     * <pre>
     * Single channel 32-bit floating point to 16-bit signed conversion.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param eRoundMode Flag specifying how fractional float values are rounded to integer values.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiConvert_32f16s_C1R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eRoundMode)
    {
        return JNpp.checkResult(nppiConvert_32f16s_C1RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, eRoundMode));
    }
    private static native int nppiConvert_32f16s_C1RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eRoundMode);


    public static int nppiConvert_32f16s_C3R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eRoundMode)
    {
        return JNpp.checkResult(nppiConvert_32f16s_C3RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, eRoundMode));
    }
    private static native int nppiConvert_32f16s_C3RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eRoundMode);


    /**
     * <pre>
     * Four channel 32-bit floating point to 16-bit signed conversion.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param eRoundMode Flag specifying how fractional float values are rounded to integer values.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiConvert_32f16s_C4R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eRoundMode)
    {
        return JNpp.checkResult(nppiConvert_32f16s_C4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, eRoundMode));
    }
    private static native int nppiConvert_32f16s_C4RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eRoundMode);


    /**
     * <pre>
     * Four channel 32-bit floating point to 16-bit signed conversion.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param eRoundMode Flag specifying how fractional float values are rounded to integer values.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiConvert_32f16s_AC4R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eRoundMode)
    {
        return JNpp.checkResult(nppiConvert_32f16s_AC4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, eRoundMode));
    }
    private static native int nppiConvert_32f16s_AC4RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eRoundMode);


    public static int nppiConvert_32f8u_C1RSfs(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eRoundMode, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiConvert_32f8u_C1RSfsNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, eRoundMode, nScaleFactor));
    }
    private static native int nppiConvert_32f8u_C1RSfsNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eRoundMode, 
        int nScaleFactor);


    /**
     * <pre>
     * Single channel 32-bit floating point to 8-bit signed conversion.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param eRoundMode Flag specifying how fractional float values are rounded to integer values.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiConvert_32f8s_C1RSfs(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eRoundMode, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiConvert_32f8s_C1RSfsNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, eRoundMode, nScaleFactor));
    }
    private static native int nppiConvert_32f8s_C1RSfsNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eRoundMode, 
        int nScaleFactor);


    /**
     * <pre>
     * Single channel 32-bit floating point to 16-bit unsigned conversion.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param eRoundMode Flag specifying how fractional float values are rounded to integer values.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiConvert_32f16u_C1RSfs(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eRoundMode, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiConvert_32f16u_C1RSfsNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, eRoundMode, nScaleFactor));
    }
    private static native int nppiConvert_32f16u_C1RSfsNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eRoundMode, 
        int nScaleFactor);


    /**
     * <pre>
     * Single channel 32-bit floating point to 16-bit signed conversion.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param eRoundMode Flag specifying how fractional float values are rounded to integer values.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiConvert_32f16s_C1RSfs(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eRoundMode, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiConvert_32f16s_C1RSfsNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, eRoundMode, nScaleFactor));
    }
    private static native int nppiConvert_32f16s_C1RSfsNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eRoundMode, 
        int nScaleFactor);


    /**
     * <pre>
     * Single channel 32-bit floating point to 32-bit unsigned conversion.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param eRoundMode Flag specifying how fractional float values are rounded to integer values.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiConvert_32f32u_C1RSfs(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eRoundMode, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiConvert_32f32u_C1RSfsNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, eRoundMode, nScaleFactor));
    }
    private static native int nppiConvert_32f32u_C1RSfsNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eRoundMode, 
        int nScaleFactor);


    public static int nppiConvert_32f32s_C1RSfs(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eRoundMode, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiConvert_32f32s_C1RSfsNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, eRoundMode, nScaleFactor));
    }
    private static native int nppiConvert_32f32s_C1RSfsNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eRoundMode, 
        int nScaleFactor);


    /**
     * <pre>
     * 8-bit unsigned image copy width constant border color.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcSizeROI Size of the source region of pixels.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstSizeROI Size (width, height) of the destination region, i.e. the region that gets filled with
     *      data from the source image (inner part) and constant border color (outer part).
     * @param nTopBorderHeight Height (in pixels) of the top border. The height of the border at the bottom of the
     *      destination ROI is implicitly defined by the size of the source ROI: 
     *      nBottomBorderHeight = oDstSizeROI.height - nTopBorderHeight - oSrcSizeROI.height.
     * @param nLeftBorderWidth Width (in pixels) of the left border. The width of the border at the right side of the
     *      destination ROI is implicitly defined by the size of the source ROI:
     *      nRightBorderWidth = oDstSizeROI.width - nLeftBorderWidth - oSrcSizeROI.width.
     * @param nValue The pixel value to be set for border pixels.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopyConstBorder_8u_C1R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSrcSizeROI, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oDstSizeROI, 
        int nTopBorderHeight, 
        int nLeftBorderWidth, 
        byte nValue)
    {
        return JNpp.checkResult(nppiCopyConstBorder_8u_C1RNative(pSrc, nSrcStep, oSrcSizeROI, pDst, nDstStep, oDstSizeROI, nTopBorderHeight, nLeftBorderWidth, nValue));
    }
    private static native int nppiCopyConstBorder_8u_C1RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSrcSizeROI, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oDstSizeROI, 
        int nTopBorderHeight, 
        int nLeftBorderWidth, 
        byte nValue);


    /**
     * <pre>
     * 4channel 8-bit unsigned image copy with constant border color.
     * See nppiCopyConstBorder_8u_C1R() for detailed documentation.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcSizeROI Size of the source region-of-interest.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstSizeROI Size of the destination region-of-interest.
     * @param nTopBorderHeight Height of top border.
     * @param nLeftBorderWidth Width of left border.
     * @param aValue Vector of the RGBA values of the border pixels to be set.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopyConstBorder_8u_C4R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSrcSizeROI, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oDstSizeROI, 
        int nTopBorderHeight, 
        int nLeftBorderWidth, 
        byte[] aValue)
    {
        return JNpp.checkResult(nppiCopyConstBorder_8u_C4RNative(pSrc, nSrcStep, oSrcSizeROI, pDst, nDstStep, oDstSizeROI, nTopBorderHeight, nLeftBorderWidth, aValue));
    }
    private static native int nppiCopyConstBorder_8u_C4RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSrcSizeROI, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oDstSizeROI, 
        int nTopBorderHeight, 
        int nLeftBorderWidth, 
        byte[] aValue);


    /**
     * <pre>
     * 4 channel 8-bit unsigned image copy with constant border color.
     * See nppiCopyConstBorder_8u_C1R() for detailed documentation.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcSizeROI Size of the source region-of-interest.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstSizeROI Size of the destination region-of-interest.
     * @param nTopBorderHeight Height of top border.
     * @param nLeftBorderWidth Width of left border.
     * @param aValue Vector of the RGB values of the border pixels. Because this method does not
     *      affect the destination image's alpha channel, only three components of the border color
     *      are needed.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopyConstBorder_8u_AC4R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSrcSizeROI, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oDstSizeROI, 
        int nTopBorderHeight, 
        int nLeftBorderWidth, 
        byte[] aValue)
    {
        return JNpp.checkResult(nppiCopyConstBorder_8u_AC4RNative(pSrc, nSrcStep, oSrcSizeROI, pDst, nDstStep, oDstSizeROI, nTopBorderHeight, nLeftBorderWidth, aValue));
    }
    private static native int nppiCopyConstBorder_8u_AC4RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSrcSizeROI, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oDstSizeROI, 
        int nTopBorderHeight, 
        int nLeftBorderWidth, 
        byte[] aValue);


    /**
     * <pre>
     * 32-bit image copy with constant border color.
     * See nppiCopyConstBorder_8u_C1R() for detailed documentation.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcSizeROI Size of the source region-of-interest.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstSizeROI Size of the destination region-of-interest.
     * @param nTopBorderHeight Height of top border.
     * @param nLeftBorderWidth Width of left border.
     * @param nValue Border luminance value.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopyConstBorder_32s_C1R(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        NppiSize oSrcSizeROI, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oDstSizeROI, 
        int nTopBorderHeight, 
        int nLeftBorderWidth, 
        int nValue)
    {
        return JNpp.checkResult(nppiCopyConstBorder_32s_C1RNative(pSrc, nSrcStep, oSrcSizeROI, pDst, nDstStep, oDstSizeROI, nTopBorderHeight, nLeftBorderWidth, nValue));
    }
    private static native int nppiCopyConstBorder_32s_C1RNative(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        NppiSize oSrcSizeROI, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oDstSizeROI, 
        int nTopBorderHeight, 
        int nLeftBorderWidth, 
        int nValue);


    /**
     * <pre>
     * 8-bit image transpose.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst Pointer to the destination ROI.
     * @param nDstStep \ref destination_image_line_step.
     * @param oROI \ref roi_specification.
     *
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiTranspose_8u_C1R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oROI)
    {
        return JNpp.checkResult(nppiTranspose_8u_C1RNative(pSrc, nSrcStep, pDst, nDstStep, oROI));
    }
    private static native int nppiTranspose_8u_C1RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oROI);


    public static int nppiSwapChannels_8u_C4IR(
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int[] aDstOrder)
    {
        return JNpp.checkResult(nppiSwapChannels_8u_C4IRNative(pSrcDst, nSrcDstStep, oSizeROI, aDstOrder));
    }
    private static native int nppiSwapChannels_8u_C4IRNative(
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int[] aDstOrder);


    /**
     * <pre>
     * One 8-bit unsigned char channel image add constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nConstant Constant.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAddC_8u_C1RSfs(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        byte nConstant, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiAddC_8u_C1RSfsNative(pSrc1, nSrc1Step, nConstant, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAddC_8u_C1RSfsNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        byte nConstant, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    public static int nppiAddC_8u_C1IRSfs(
        byte nConstant, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiAddC_8u_C1IRSfsNative(nConstant, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAddC_8u_C1IRSfsNative(
        byte nConstant, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    public static int nppiAddC_8u_C3RSfs(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        byte[] aConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiAddC_8u_C3RSfsNative(pSrc1, nSrc1Step, aConstants, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAddC_8u_C3RSfsNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        byte[] aConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 8-bit unsigned char channel 8-bit unsigned char in place image add constant, scale, then clamp to saturated value.
     * @param aConstants fixed size array of constant values, one per channel..
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAddC_8u_C3IRSfs(
        byte[] aConstants, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiAddC_8u_C3IRSfsNative(aConstants, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAddC_8u_C3IRSfsNative(
        byte[] aConstants, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 8-bit unsigned char channel with unmodified alpha image add constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param aConstants fixed size array of constant values, one per channel..
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAddC_8u_AC4RSfs(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        byte[] aConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiAddC_8u_AC4RSfsNative(pSrc1, nSrc1Step, aConstants, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAddC_8u_AC4RSfsNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        byte[] aConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    public static int nppiAddC_8u_AC4IRSfs(
        byte[] aConstants, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiAddC_8u_AC4IRSfsNative(aConstants, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAddC_8u_AC4IRSfsNative(
        byte[] aConstants, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    public static int nppiAddC_8u_C4RSfs(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        byte[] aConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiAddC_8u_C4RSfsNative(pSrc1, nSrc1Step, aConstants, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAddC_8u_C4RSfsNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        byte[] aConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 8-bit unsigned char channel in place image add constant, scale, then clamp to saturated value.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAddC_8u_C4IRSfs(
        byte[] aConstants, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiAddC_8u_C4IRSfsNative(aConstants, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAddC_8u_C4IRSfsNative(
        byte[] aConstants, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    public static int nppiAddC_16u_C1RSfs(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        short nConstant, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiAddC_16u_C1RSfsNative(pSrc1, nSrc1Step, nConstant, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAddC_16u_C1RSfsNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        short nConstant, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    public static int nppiAddC_16u_C1IRSfs(
        short nConstant, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiAddC_16u_C1IRSfsNative(nConstant, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAddC_16u_C1IRSfsNative(
        short nConstant, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 16-bit unsigned short channel image add constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAddC_16u_C3RSfs(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        short[] aConstants, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiAddC_16u_C3RSfsNative(pSrc1, nSrc1Step, aConstants, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAddC_16u_C3RSfsNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        short[] aConstants, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 16-bit unsigned short channel in place image add constant, scale, then clamp to saturated value.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAddC_16u_C3IRSfs(
        short[] aConstants, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiAddC_16u_C3IRSfsNative(aConstants, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAddC_16u_C3IRSfsNative(
        short[] aConstants, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit unsigned short channel with unmodified alpha image add constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAddC_16u_AC4RSfs(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        short[] aConstants, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiAddC_16u_AC4RSfsNative(pSrc1, nSrc1Step, aConstants, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAddC_16u_AC4RSfsNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        short[] aConstants, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    public static int nppiAddC_16u_AC4IRSfs(
        short[] aConstants, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiAddC_16u_AC4IRSfsNative(aConstants, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAddC_16u_AC4IRSfsNative(
        short[] aConstants, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    public static int nppiAddC_16u_C4RSfs(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        short[] aConstants, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiAddC_16u_C4RSfsNative(pSrc1, nSrc1Step, aConstants, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAddC_16u_C4RSfsNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        short[] aConstants, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit unsigned short channel in place image add constant, scale, then clamp to saturated value.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAddC_16u_C4IRSfs(
        short[] aConstants, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiAddC_16u_C4IRSfsNative(aConstants, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAddC_16u_C4IRSfsNative(
        short[] aConstants, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    public static int nppiAddC_16s_C1RSfs(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        short nConstant, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiAddC_16s_C1RSfsNative(pSrc1, nSrc1Step, nConstant, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAddC_16s_C1RSfsNative(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        short nConstant, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    public static int nppiAddC_16s_C1IRSfs(
        short nConstant, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiAddC_16s_C1IRSfsNative(nConstant, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAddC_16s_C1IRSfsNative(
        short nConstant, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    public static int nppiAddC_16s_C3RSfs(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        short[] aConstants, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiAddC_16s_C3RSfsNative(pSrc1, nSrc1Step, aConstants, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAddC_16s_C3RSfsNative(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        short[] aConstants, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 16-bit signed short channel in place image add constant, scale, then clamp to saturated value.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAddC_16s_C3IRSfs(
        short[] aConstants, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiAddC_16s_C3IRSfsNative(aConstants, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAddC_16s_C3IRSfsNative(
        short[] aConstants, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit signed short channel with unmodified alpha image add constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAddC_16s_AC4RSfs(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        short[] aConstants, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiAddC_16s_AC4RSfsNative(pSrc1, nSrc1Step, aConstants, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAddC_16s_AC4RSfsNative(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        short[] aConstants, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit signed short channel with unmodified alpha in place image add constant, scale, then clamp to saturated value.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAddC_16s_AC4IRSfs(
        short[] aConstants, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiAddC_16s_AC4IRSfsNative(aConstants, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAddC_16s_AC4IRSfsNative(
        short[] aConstants, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit signed short channel image add constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAddC_16s_C4RSfs(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        short[] aConstants, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiAddC_16s_C4RSfsNative(pSrc1, nSrc1Step, aConstants, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAddC_16s_C4RSfsNative(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        short[] aConstants, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit signed short channel in place image add constant, scale, then clamp to saturated value.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAddC_16s_C4IRSfs(
        short[] aConstants, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiAddC_16s_C4IRSfsNative(aConstants, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAddC_16s_C4IRSfsNative(
        short[] aConstants, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit signed short complex number (16-bit real, 16-bit imaginary) channel image add constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nConstant Constant.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAddC_16sc_C1RSfs(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        Npp16sc nConstant, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiAddC_16sc_C1RSfsNative(pSrc1, nSrc1Step, nConstant, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAddC_16sc_C1RSfsNative(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        Npp16sc nConstant, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit signed short complex number (16-bit real, 16-bit imaginary) channel in place image add constant, scale, then clamp to saturated value.
     * @param nConstant Constant.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAddC_16sc_C1IRSfs(
        Npp16sc nConstant, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiAddC_16sc_C1IRSfsNative(nConstant, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAddC_16sc_C1IRSfsNative(
        Npp16sc nConstant, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 16-bit signed short complex number (16-bit real, 16-bit imaginary) channel image add constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAddC_16sc_C3RSfs(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        Npp16sc[] aConstants, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiAddC_16sc_C3RSfsNative(pSrc1, nSrc1Step, aConstants, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAddC_16sc_C3RSfsNative(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        Npp16sc[] aConstants, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 16-bit signed short complex number (16-bit real, 16-bit imaginary) channel in place image add constant, scale, then clamp to saturated value.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAddC_16sc_C3IRSfs(
        Npp16sc[] aConstants, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiAddC_16sc_C3IRSfsNative(aConstants, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAddC_16sc_C3IRSfsNative(
        Npp16sc[] aConstants, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit signed short complex number (16-bit real, 16-bit imaginary) channel with unmodified alpha image add constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAddC_16sc_AC4RSfs(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        Npp16sc[] aConstants, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiAddC_16sc_AC4RSfsNative(pSrc1, nSrc1Step, aConstants, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAddC_16sc_AC4RSfsNative(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        Npp16sc[] aConstants, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit signed short complex number (16-bit real, 16-bit imaginary) channel with unmodified alpha in place image add constant, scale, then clamp to saturated value.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAddC_16sc_AC4IRSfs(
        Npp16sc[] aConstants, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiAddC_16sc_AC4IRSfsNative(aConstants, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAddC_16sc_AC4IRSfsNative(
        Npp16sc[] aConstants, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 32-bit signed integer channel image add constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nConstant Constant.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAddC_32s_C1RSfs(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        int nConstant, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiAddC_32s_C1RSfsNative(pSrc1, nSrc1Step, nConstant, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAddC_32s_C1RSfsNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        int nConstant, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 32-bit signed integer channel in place image add constant, scale, then clamp to saturated value.
     * @param nConstant Constant.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAddC_32s_C1IRSfs(
        int nConstant, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiAddC_32s_C1IRSfsNative(nConstant, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAddC_32s_C1IRSfsNative(
        int nConstant, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 32-bit signed integer channel image add constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAddC_32s_C3RSfs(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        int[] aConstants, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiAddC_32s_C3RSfsNative(pSrc1, nSrc1Step, aConstants, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAddC_32s_C3RSfsNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        int[] aConstants, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 32-bit signed integer channel in place image add constant, scale, then clamp to saturated value.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAddC_32s_C3IRSfs(
        int[] aConstants, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiAddC_32s_C3IRSfsNative(aConstants, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAddC_32s_C3IRSfsNative(
        int[] aConstants, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 32-bit signed complex integer (32-bit real, 32-bit imaginary) channel image add constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nConstant Constant.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAddC_32sc_C1RSfs(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        Npp32sc nConstant, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiAddC_32sc_C1RSfsNative(pSrc1, nSrc1Step, nConstant, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAddC_32sc_C1RSfsNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        Npp32sc nConstant, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 32-bit signed complex integer (32-bit real, 32-bit imaginary) channel in place image add constant, scale, then clamp to saturated value.
     * @param nConstant Constant.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAddC_32sc_C1IRSfs(
        Npp32sc nConstant, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiAddC_32sc_C1IRSfsNative(nConstant, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAddC_32sc_C1IRSfsNative(
        Npp32sc nConstant, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 32-bit signed complex integer (32-bit real, 32-bit imaginary) channel image add constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAddC_32sc_C3RSfs(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        Npp32sc[] aConstants, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiAddC_32sc_C3RSfsNative(pSrc1, nSrc1Step, aConstants, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAddC_32sc_C3RSfsNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        Npp32sc[] aConstants, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 32-bit signed complex integer (32-bit real, 32-bit imaginary) channel in place image add constant, scale, then clamp to saturated value.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAddC_32sc_C3IRSfs(
        Npp32sc[] aConstants, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiAddC_32sc_C3IRSfsNative(aConstants, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAddC_32sc_C3IRSfsNative(
        Npp32sc[] aConstants, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 32-bit signed complex integer (32-bit real, 32-bit imaginary) channel with unmodified alpha image add constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAddC_32sc_AC4RSfs(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        Npp32sc[] aConstants, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiAddC_32sc_AC4RSfsNative(pSrc1, nSrc1Step, aConstants, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAddC_32sc_AC4RSfsNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        Npp32sc[] aConstants, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 32-bit signed complex integer (32-bit real, 32-bit imaginary) channel with unmodified alpha in place image add constant, scale, then clamp to saturated value.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAddC_32sc_AC4IRSfs(
        Npp32sc[] aConstants, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiAddC_32sc_AC4IRSfsNative(aConstants, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAddC_32sc_AC4IRSfsNative(
        Npp32sc[] aConstants, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 32-bit floating point channel image add constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nConstant Constant.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAddC_32f_C1R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        float nConstant, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiAddC_32f_C1RNative(pSrc1, nSrc1Step, nConstant, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiAddC_32f_C1RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        float nConstant, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 32-bit floating point channel in place image add constant.
     * @param nConstant Constant.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAddC_32f_C1IR(
        float nConstant, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiAddC_32f_C1IRNative(nConstant, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiAddC_32f_C1IRNative(
        float nConstant, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 32-bit floating point channel image add constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAddC_32f_C3R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        float[] aConstants, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiAddC_32f_C3RNative(pSrc1, nSrc1Step, aConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiAddC_32f_C3RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        float[] aConstants, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 32-bit floating point channel in place image add constant.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAddC_32f_C3IR(
        float[] aConstants, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiAddC_32f_C3IRNative(aConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiAddC_32f_C3IRNative(
        float[] aConstants, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit floating point channel with unmodified alpha image add constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAddC_32f_AC4R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        float[] aConstants, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiAddC_32f_AC4RNative(pSrc1, nSrc1Step, aConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiAddC_32f_AC4RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        float[] aConstants, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit floating point channel with unmodified alpha in place image add constant.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAddC_32f_AC4IR(
        float[] aConstants, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiAddC_32f_AC4IRNative(aConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiAddC_32f_AC4IRNative(
        float[] aConstants, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit floating point channel image add constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAddC_32f_C4R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        float[] aConstants, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiAddC_32f_C4RNative(pSrc1, nSrc1Step, aConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiAddC_32f_C4RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        float[] aConstants, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit floating point channel in place image add constant.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAddC_32f_C4IR(
        float[] aConstants, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiAddC_32f_C4IRNative(aConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiAddC_32f_C4IRNative(
        float[] aConstants, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 32-bit complex floating point (32-bit floating point real, 32-bit floating point imaginary) channel image add constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nConstant Constant.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAddC_32fc_C1R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        Npp32fc nConstant, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiAddC_32fc_C1RNative(pSrc1, nSrc1Step, nConstant, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiAddC_32fc_C1RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        Npp32fc nConstant, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 32-bit complex floating point (32-bit floating point real, 32-bit floating point imaginary) channel in place image add constant.
     * @param nConstant Constant.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAddC_32fc_C1IR(
        Npp32fc nConstant, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiAddC_32fc_C1IRNative(nConstant, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiAddC_32fc_C1IRNative(
        Npp32fc nConstant, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 32-bit complex floating point (32-bit floating point real, 32-bit floating point imaginary) channel image add constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAddC_32fc_C3R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        Npp32fc[] aConstants, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiAddC_32fc_C3RNative(pSrc1, nSrc1Step, aConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiAddC_32fc_C3RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        Npp32fc[] aConstants, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 32-bit complex floating point (32-bit floating point real, 32-bit floating point imaginary) channel in place image add constant.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAddC_32fc_C3IR(
        Npp32fc[] aConstants, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiAddC_32fc_C3IRNative(aConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiAddC_32fc_C3IRNative(
        Npp32fc[] aConstants, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit complex floating point (32-bit floating point real, 32-bit floating point imaginary) channel with unmodified alpha image add constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAddC_32fc_AC4R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        Npp32fc[] aConstants, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiAddC_32fc_AC4RNative(pSrc1, nSrc1Step, aConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiAddC_32fc_AC4RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        Npp32fc[] aConstants, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit complex floating point (32-bit floating point real, 32-bit floating point imaginary) channel with unmodified alpha in place image add constant.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAddC_32fc_AC4IR(
        Npp32fc[] aConstants, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiAddC_32fc_AC4IRNative(aConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiAddC_32fc_AC4IRNative(
        Npp32fc[] aConstants, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit complex floating point (32-bit floating point real, 32-bit floating point imaginary) channel image add constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAddC_32fc_C4R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        Npp32fc[] aConstants, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiAddC_32fc_C4RNative(pSrc1, nSrc1Step, aConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiAddC_32fc_C4RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        Npp32fc[] aConstants, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit complex floating point (32-bit floating point real, 32-bit floating point imaginary) channel in place image add constant.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAddC_32fc_C4IR(
        Npp32fc[] aConstants, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiAddC_32fc_C4IRNative(aConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiAddC_32fc_C4IRNative(
        Npp32fc[] aConstants, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 8-bit unsigned char channel image multiply by constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nConstant Constant.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulC_8u_C1RSfs(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        byte nConstant, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiMulC_8u_C1RSfsNative(pSrc1, nSrc1Step, nConstant, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMulC_8u_C1RSfsNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        byte nConstant, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 8-bit unsigned char channel in place image multiply by constant, scale, then clamp to saturated value.
     * @param nConstant Constant.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulC_8u_C1IRSfs(
        byte nConstant, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiMulC_8u_C1IRSfsNative(nConstant, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMulC_8u_C1IRSfsNative(
        byte nConstant, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 8-bit unsigned char channel image multiply by constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulC_8u_C3RSfs(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        byte[] aConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiMulC_8u_C3RSfsNative(pSrc1, nSrc1Step, aConstants, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMulC_8u_C3RSfsNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        byte[] aConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 8-bit unsigned char channel 8-bit unsigned char in place image multiply by constant, scale, then clamp to saturated value.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulC_8u_C3IRSfs(
        byte[] aConstants, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiMulC_8u_C3IRSfsNative(aConstants, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMulC_8u_C3IRSfsNative(
        byte[] aConstants, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 8-bit unsigned char channel with unmodified alpha image multiply by constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulC_8u_AC4RSfs(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        byte[] aConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiMulC_8u_AC4RSfsNative(pSrc1, nSrc1Step, aConstants, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMulC_8u_AC4RSfsNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        byte[] aConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 8-bit unsigned char channel with unmodified alpha in place image multiply by constant, scale, then clamp to saturated value.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulC_8u_AC4IRSfs(
        byte[] aConstants, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiMulC_8u_AC4IRSfsNative(aConstants, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMulC_8u_AC4IRSfsNative(
        byte[] aConstants, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 8-bit unsigned char channel image multiply by constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulC_8u_C4RSfs(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        byte[] aConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiMulC_8u_C4RSfsNative(pSrc1, nSrc1Step, aConstants, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMulC_8u_C4RSfsNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        byte[] aConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 8-bit unsigned char channel in place image multiply by constant, scale, then clamp to saturated value.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulC_8u_C4IRSfs(
        byte[] aConstants, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiMulC_8u_C4IRSfsNative(aConstants, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMulC_8u_C4IRSfsNative(
        byte[] aConstants, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit unsigned short channel image multiply by constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nConstant Constant.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulC_16u_C1RSfs(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        short nConstant, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiMulC_16u_C1RSfsNative(pSrc1, nSrc1Step, nConstant, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMulC_16u_C1RSfsNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        short nConstant, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit unsigned short channel in place image multiply by constant, scale, then clamp to saturated value.
     * @param nConstant Constant.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulC_16u_C1IRSfs(
        short nConstant, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiMulC_16u_C1IRSfsNative(nConstant, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMulC_16u_C1IRSfsNative(
        short nConstant, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    public static int nppiMulC_16u_C3RSfs(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        short[] aConstants, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiMulC_16u_C3RSfsNative(pSrc1, nSrc1Step, aConstants, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMulC_16u_C3RSfsNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        short[] aConstants, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 16-bit unsigned short channel in place image multiply by constant, scale, then clamp to saturated value.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulC_16u_C3IRSfs(
        short[] aConstants, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiMulC_16u_C3IRSfsNative(aConstants, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMulC_16u_C3IRSfsNative(
        short[] aConstants, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit unsigned short channel with unmodified alpha image multiply by constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulC_16u_AC4RSfs(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        short[] aConstants, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiMulC_16u_AC4RSfsNative(pSrc1, nSrc1Step, aConstants, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMulC_16u_AC4RSfsNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        short[] aConstants, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit unsigned short channel with unmodified alpha in place image multiply by constant, scale, then clamp to saturated value.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulC_16u_AC4IRSfs(
        short[] aConstants, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiMulC_16u_AC4IRSfsNative(aConstants, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMulC_16u_AC4IRSfsNative(
        short[] aConstants, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit unsigned short channel image multiply by constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulC_16u_C4RSfs(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        short[] aConstants, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiMulC_16u_C4RSfsNative(pSrc1, nSrc1Step, aConstants, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMulC_16u_C4RSfsNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        short[] aConstants, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit unsigned short channel in place image multiply by constant, scale, then clamp to saturated value.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulC_16u_C4IRSfs(
        short[] aConstants, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiMulC_16u_C4IRSfsNative(aConstants, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMulC_16u_C4IRSfsNative(
        short[] aConstants, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit signed short channel image multiply by constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nConstant Constant.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulC_16s_C1RSfs(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        short nConstant, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiMulC_16s_C1RSfsNative(pSrc1, nSrc1Step, nConstant, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMulC_16s_C1RSfsNative(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        short nConstant, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit signed short channel in place image multiply by constant, scale, then clamp to saturated value.
     * @param nConstant Constant.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulC_16s_C1IRSfs(
        short nConstant, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiMulC_16s_C1IRSfsNative(nConstant, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMulC_16s_C1IRSfsNative(
        short nConstant, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    public static int nppiMulC_16s_C3RSfs(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        short[] aConstants, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiMulC_16s_C3RSfsNative(pSrc1, nSrc1Step, aConstants, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMulC_16s_C3RSfsNative(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        short[] aConstants, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 16-bit signed short channel in place image multiply by constant, scale, then clamp to saturated value.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulC_16s_C3IRSfs(
        short[] aConstants, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiMulC_16s_C3IRSfsNative(aConstants, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMulC_16s_C3IRSfsNative(
        short[] aConstants, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit signed short channel with unmodified alpha image multiply by constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulC_16s_AC4RSfs(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        short[] aConstants, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiMulC_16s_AC4RSfsNative(pSrc1, nSrc1Step, aConstants, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMulC_16s_AC4RSfsNative(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        short[] aConstants, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit signed short channel with unmodified alpha in place image multiply by constant, scale, then clamp to saturated value.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulC_16s_AC4IRSfs(
        short[] aConstants, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiMulC_16s_AC4IRSfsNative(aConstants, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMulC_16s_AC4IRSfsNative(
        short[] aConstants, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    public static int nppiMulC_16s_C4RSfs(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        short[] aConstants, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiMulC_16s_C4RSfsNative(pSrc1, nSrc1Step, aConstants, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMulC_16s_C4RSfsNative(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        short[] aConstants, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit signed short channel in place image multiply by constant, scale, then clamp to saturated value.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulC_16s_C4IRSfs(
        short[] aConstants, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiMulC_16s_C4IRSfsNative(aConstants, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMulC_16s_C4IRSfsNative(
        short[] aConstants, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit signed short complex number (16-bit real, 16-bit imaginary) channel image multiply by constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nConstant Constant.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulC_16sc_C1RSfs(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        Npp16sc nConstant, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiMulC_16sc_C1RSfsNative(pSrc1, nSrc1Step, nConstant, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMulC_16sc_C1RSfsNative(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        Npp16sc nConstant, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit signed short complex number (16-bit real, 16-bit imaginary) channel in place image multiply by constant, scale, then clamp to saturated value.
     * @param nConstant Constant.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulC_16sc_C1IRSfs(
        Npp16sc nConstant, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiMulC_16sc_C1IRSfsNative(nConstant, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMulC_16sc_C1IRSfsNative(
        Npp16sc nConstant, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    public static int nppiMulC_16sc_C3RSfs(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        Npp16sc[] aConstants, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiMulC_16sc_C3RSfsNative(pSrc1, nSrc1Step, aConstants, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMulC_16sc_C3RSfsNative(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        Npp16sc[] aConstants, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 16-bit signed short complex number (16-bit real, 16-bit imaginary) channel in place image multiply by constant, scale, then clamp to saturated value.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulC_16sc_C3IRSfs(
        Npp16sc[] aConstants, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiMulC_16sc_C3IRSfsNative(aConstants, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMulC_16sc_C3IRSfsNative(
        Npp16sc[] aConstants, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    public static int nppiMulC_16sc_AC4RSfs(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        Npp16sc[] aConstants, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiMulC_16sc_AC4RSfsNative(pSrc1, nSrc1Step, aConstants, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMulC_16sc_AC4RSfsNative(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        Npp16sc[] aConstants, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit signed short complex number (16-bit real, 16-bit imaginary) channel with unmodified alpha in place image multiply by constant, scale, then clamp to saturated value.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulC_16sc_AC4IRSfs(
        Npp16sc[] aConstants, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiMulC_16sc_AC4IRSfsNative(aConstants, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMulC_16sc_AC4IRSfsNative(
        Npp16sc[] aConstants, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 32-bit signed integer channel image multiply by constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nConstant Constant.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulC_32s_C1RSfs(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        int nConstant, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiMulC_32s_C1RSfsNative(pSrc1, nSrc1Step, nConstant, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMulC_32s_C1RSfsNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        int nConstant, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 32-bit signed integer channel in place image multiply by constant, scale, then clamp to saturated value.
     * @param nConstant Constant.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulC_32s_C1IRSfs(
        int nConstant, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiMulC_32s_C1IRSfsNative(nConstant, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMulC_32s_C1IRSfsNative(
        int nConstant, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 32-bit signed integer channel image multiply by constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulC_32s_C3RSfs(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        int[] aConstants, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiMulC_32s_C3RSfsNative(pSrc1, nSrc1Step, aConstants, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMulC_32s_C3RSfsNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        int[] aConstants, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 32-bit signed integer channel in place image multiply by constant, scale, then clamp to saturated value.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulC_32s_C3IRSfs(
        int[] aConstants, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiMulC_32s_C3IRSfsNative(aConstants, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMulC_32s_C3IRSfsNative(
        int[] aConstants, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 32-bit signed complex integer (32-bit real, 32-bit imaginary) channel image multiply by constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nConstant Constant.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulC_32sc_C1RSfs(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        Npp32sc nConstant, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiMulC_32sc_C1RSfsNative(pSrc1, nSrc1Step, nConstant, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMulC_32sc_C1RSfsNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        Npp32sc nConstant, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 32-bit signed complex integer (32-bit real, 32-bit imaginary) channel in place image multiply by constant, scale, then clamp to saturated value.
     * @param nConstant Constant.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulC_32sc_C1IRSfs(
        Npp32sc nConstant, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiMulC_32sc_C1IRSfsNative(nConstant, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMulC_32sc_C1IRSfsNative(
        Npp32sc nConstant, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 32-bit signed complex integer (32-bit real, 32-bit imaginary) channel image multiply by constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulC_32sc_C3RSfs(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        Npp32sc[] aConstants, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiMulC_32sc_C3RSfsNative(pSrc1, nSrc1Step, aConstants, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMulC_32sc_C3RSfsNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        Npp32sc[] aConstants, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 32-bit signed complex integer (32-bit real, 32-bit imaginary) channel in place image multiply by constant, scale, then clamp to saturated value.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulC_32sc_C3IRSfs(
        Npp32sc[] aConstants, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiMulC_32sc_C3IRSfsNative(aConstants, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMulC_32sc_C3IRSfsNative(
        Npp32sc[] aConstants, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 32-bit signed complex integer (32-bit real, 32-bit imaginary) channel with unmodified alpha image multiply by constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulC_32sc_AC4RSfs(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        Npp32sc[] aConstants, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiMulC_32sc_AC4RSfsNative(pSrc1, nSrc1Step, aConstants, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMulC_32sc_AC4RSfsNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        Npp32sc[] aConstants, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 32-bit signed complex integer (32-bit real, 32-bit imaginary) channel with unmodified alpha in place image multiply by constant, scale, then clamp to saturated value.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulC_32sc_AC4IRSfs(
        Npp32sc[] aConstants, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiMulC_32sc_AC4IRSfsNative(aConstants, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMulC_32sc_AC4IRSfsNative(
        Npp32sc[] aConstants, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 32-bit floating point channel image multiply by constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nConstant Constant.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulC_32f_C1R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        float nConstant, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiMulC_32f_C1RNative(pSrc1, nSrc1Step, nConstant, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiMulC_32f_C1RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        float nConstant, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 32-bit floating point channel in place image multiply by constant.
     * @param nConstant Constant.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulC_32f_C1IR(
        float nConstant, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiMulC_32f_C1IRNative(nConstant, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiMulC_32f_C1IRNative(
        float nConstant, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 32-bit floating point channel image multiply by constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulC_32f_C3R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        float[] aConstants, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiMulC_32f_C3RNative(pSrc1, nSrc1Step, aConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiMulC_32f_C3RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        float[] aConstants, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 32-bit floating point channel in place image multiply by constant.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulC_32f_C3IR(
        float[] aConstants, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiMulC_32f_C3IRNative(aConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiMulC_32f_C3IRNative(
        float[] aConstants, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit floating point channel with unmodified alpha image multiply by constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulC_32f_AC4R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        float[] aConstants, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiMulC_32f_AC4RNative(pSrc1, nSrc1Step, aConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiMulC_32f_AC4RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        float[] aConstants, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit floating point channel with unmodified alpha in place image multiply by constant.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulC_32f_AC4IR(
        float[] aConstants, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiMulC_32f_AC4IRNative(aConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiMulC_32f_AC4IRNative(
        float[] aConstants, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    public static int nppiMulC_32f_C4R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        float[] aConstants, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiMulC_32f_C4RNative(pSrc1, nSrc1Step, aConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiMulC_32f_C4RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        float[] aConstants, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit floating point channel in place image multiply by constant.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulC_32f_C4IR(
        float[] aConstants, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiMulC_32f_C4IRNative(aConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiMulC_32f_C4IRNative(
        float[] aConstants, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 32-bit complex floating point (32-bit floating point real, 32-bit floating point imaginary) channel image multiply by constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nConstant Constant.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulC_32fc_C1R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        Npp32fc nConstant, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiMulC_32fc_C1RNative(pSrc1, nSrc1Step, nConstant, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiMulC_32fc_C1RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        Npp32fc nConstant, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 32-bit complex floating point (32-bit floating point real, 32-bit floating point imaginary) channel in place image multiply by constant.
     * @param nConstant Constant.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulC_32fc_C1IR(
        Npp32fc nConstant, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiMulC_32fc_C1IRNative(nConstant, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiMulC_32fc_C1IRNative(
        Npp32fc nConstant, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 32-bit complex floating point (32-bit floating point real, 32-bit floating point imaginary) channel image multiply by constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulC_32fc_C3R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        Npp32fc[] aConstants, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiMulC_32fc_C3RNative(pSrc1, nSrc1Step, aConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiMulC_32fc_C3RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        Npp32fc[] aConstants, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 32-bit complex floating point (32-bit floating point real, 32-bit floating point imaginary) channel in place image multiply by constant.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulC_32fc_C3IR(
        Npp32fc[] aConstants, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiMulC_32fc_C3IRNative(aConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiMulC_32fc_C3IRNative(
        Npp32fc[] aConstants, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    public static int nppiMulC_32fc_AC4R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        Npp32fc[] aConstants, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiMulC_32fc_AC4RNative(pSrc1, nSrc1Step, aConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiMulC_32fc_AC4RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        Npp32fc[] aConstants, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit complex floating point (32-bit floating point real, 32-bit floating point imaginary) channel with unmodified alpha in place image multiply by constant.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulC_32fc_AC4IR(
        Npp32fc[] aConstants, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiMulC_32fc_AC4IRNative(aConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiMulC_32fc_AC4IRNative(
        Npp32fc[] aConstants, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit complex floating point (32-bit floating point real, 32-bit floating point imaginary) channel image multiply by constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulC_32fc_C4R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        Npp32fc[] aConstants, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiMulC_32fc_C4RNative(pSrc1, nSrc1Step, aConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiMulC_32fc_C4RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        Npp32fc[] aConstants, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit complex floating point (32-bit floating point real, 32-bit floating point imaginary) channel in place image multiply by constant.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulC_32fc_C4IR(
        Npp32fc[] aConstants, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiMulC_32fc_C4IRNative(aConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiMulC_32fc_C4IRNative(
        Npp32fc[] aConstants, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 8-bit unsigned char channel image multiply by constant and scale by max bit width value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nConstant Constant.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulCScale_8u_C1R(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        byte nConstant, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiMulCScale_8u_C1RNative(pSrc1, nSrc1Step, nConstant, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiMulCScale_8u_C1RNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        byte nConstant, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 8-bit unsigned char channel in place image multiply by constant and scale by max bit width value.
     * @param nConstant Constant.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulCScale_8u_C1IR(
        byte nConstant, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiMulCScale_8u_C1IRNative(nConstant, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiMulCScale_8u_C1IRNative(
        byte nConstant, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 8-bit unsigned char channel image multiply by constant and scale by max bit width value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulCScale_8u_C3R(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        byte[] aConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiMulCScale_8u_C3RNative(pSrc1, nSrc1Step, aConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiMulCScale_8u_C3RNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        byte[] aConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 8-bit unsigned char channel 8-bit unsigned char in place image multiply by constant and scale by max bit width value.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulCScale_8u_C3IR(
        byte[] aConstants, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiMulCScale_8u_C3IRNative(aConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiMulCScale_8u_C3IRNative(
        byte[] aConstants, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 8-bit unsigned char channel with unmodified alpha image multiply by constant and scale by max bit width value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulCScale_8u_AC4R(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        byte[] aConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiMulCScale_8u_AC4RNative(pSrc1, nSrc1Step, aConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiMulCScale_8u_AC4RNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        byte[] aConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 8-bit unsigned char channel with unmodified alpha in place image multiply by constant, scale and scale by max bit width value.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulCScale_8u_AC4IR(
        byte[] aConstants, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiMulCScale_8u_AC4IRNative(aConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiMulCScale_8u_AC4IRNative(
        byte[] aConstants, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 8-bit unsigned char channel image multiply by constant and scale by max bit width value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulCScale_8u_C4R(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        byte[] aConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiMulCScale_8u_C4RNative(pSrc1, nSrc1Step, aConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiMulCScale_8u_C4RNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        byte[] aConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 8-bit unsigned char channel in place image multiply by constant and scale by max bit width value.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulCScale_8u_C4IR(
        byte[] aConstants, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiMulCScale_8u_C4IRNative(aConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiMulCScale_8u_C4IRNative(
        byte[] aConstants, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 16-bit unsigned short channel image multiply by constant and scale by max bit width value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nConstant Constant.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulCScale_16u_C1R(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        short nConstant, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiMulCScale_16u_C1RNative(pSrc1, nSrc1Step, nConstant, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiMulCScale_16u_C1RNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        short nConstant, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 16-bit unsigned short channel in place image multiply by constant and scale by max bit width value.
     * @param nConstant Constant.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulCScale_16u_C1IR(
        short nConstant, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiMulCScale_16u_C1IRNative(nConstant, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiMulCScale_16u_C1IRNative(
        short nConstant, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    public static int nppiMulCScale_16u_C3R(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        short[] aConstants, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiMulCScale_16u_C3RNative(pSrc1, nSrc1Step, aConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiMulCScale_16u_C3RNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        short[] aConstants, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 16-bit unsigned short channel in place image multiply by constant and scale by max bit width value.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulCScale_16u_C3IR(
        short[] aConstants, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiMulCScale_16u_C3IRNative(aConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiMulCScale_16u_C3IRNative(
        short[] aConstants, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 16-bit unsigned short channel with unmodified alpha image multiply by constant and scale by max bit width value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulCScale_16u_AC4R(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        short[] aConstants, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiMulCScale_16u_AC4RNative(pSrc1, nSrc1Step, aConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiMulCScale_16u_AC4RNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        short[] aConstants, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 16-bit unsigned short channel with unmodified alpha in place image multiply by constant and scale by max bit width value.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulCScale_16u_AC4IR(
        short[] aConstants, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiMulCScale_16u_AC4IRNative(aConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiMulCScale_16u_AC4IRNative(
        short[] aConstants, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 16-bit unsigned short channel image multiply by constant and scale by max bit width value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulCScale_16u_C4R(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        short[] aConstants, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiMulCScale_16u_C4RNative(pSrc1, nSrc1Step, aConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiMulCScale_16u_C4RNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        short[] aConstants, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 16-bit unsigned short channel in place image multiply by constant and scale by max bit width value.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulCScale_16u_C4IR(
        short[] aConstants, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiMulCScale_16u_C4IRNative(aConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiMulCScale_16u_C4IRNative(
        short[] aConstants, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 8-bit unsigned char channel image subtract constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nConstant Constant.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSubC_8u_C1RSfs(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        byte nConstant, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiSubC_8u_C1RSfsNative(pSrc1, nSrc1Step, nConstant, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSubC_8u_C1RSfsNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        byte nConstant, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 8-bit unsigned char channel in place image subtract constant, scale, then clamp to saturated value.
     * @param nConstant Constant.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSubC_8u_C1IRSfs(
        byte nConstant, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiSubC_8u_C1IRSfsNative(nConstant, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSubC_8u_C1IRSfsNative(
        byte nConstant, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 8-bit unsigned char channel image subtract constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSubC_8u_C3RSfs(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        byte[] aConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiSubC_8u_C3RSfsNative(pSrc1, nSrc1Step, aConstants, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSubC_8u_C3RSfsNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        byte[] aConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 8-bit unsigned char channel 8-bit unsigned char in place image subtract constant, scale, then clamp to saturated value.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSubC_8u_C3IRSfs(
        byte[] aConstants, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiSubC_8u_C3IRSfsNative(aConstants, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSubC_8u_C3IRSfsNative(
        byte[] aConstants, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    public static int nppiSubC_8u_AC4RSfs(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        byte[] aConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiSubC_8u_AC4RSfsNative(pSrc1, nSrc1Step, aConstants, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSubC_8u_AC4RSfsNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        byte[] aConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 8-bit unsigned char channel with unmodified alpha in place image subtract constant, scale, then clamp to saturated value.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSubC_8u_AC4IRSfs(
        byte[] aConstants, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiSubC_8u_AC4IRSfsNative(aConstants, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSubC_8u_AC4IRSfsNative(
        byte[] aConstants, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 8-bit unsigned char channel image subtract constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSubC_8u_C4RSfs(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        byte[] aConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiSubC_8u_C4RSfsNative(pSrc1, nSrc1Step, aConstants, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSubC_8u_C4RSfsNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        byte[] aConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 8-bit unsigned char channel in place image subtract constant, scale, then clamp to saturated value.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSubC_8u_C4IRSfs(
        byte[] aConstants, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiSubC_8u_C4IRSfsNative(aConstants, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSubC_8u_C4IRSfsNative(
        byte[] aConstants, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit unsigned short channel image subtract constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nConstant Constant.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSubC_16u_C1RSfs(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        short nConstant, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiSubC_16u_C1RSfsNative(pSrc1, nSrc1Step, nConstant, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSubC_16u_C1RSfsNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        short nConstant, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit unsigned short channel in place image subtract constant, scale, then clamp to saturated value.
     * @param nConstant Constant.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSubC_16u_C1IRSfs(
        short nConstant, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiSubC_16u_C1IRSfsNative(nConstant, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSubC_16u_C1IRSfsNative(
        short nConstant, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 16-bit unsigned short channel image subtract constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSubC_16u_C3RSfs(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        short[] aConstants, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiSubC_16u_C3RSfsNative(pSrc1, nSrc1Step, aConstants, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSubC_16u_C3RSfsNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        short[] aConstants, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 16-bit unsigned short channel in place image subtract constant, scale, then clamp to saturated value.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSubC_16u_C3IRSfs(
        short[] aConstants, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiSubC_16u_C3IRSfsNative(aConstants, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSubC_16u_C3IRSfsNative(
        short[] aConstants, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit unsigned short channel with unmodified alpha image subtract constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSubC_16u_AC4RSfs(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        short[] aConstants, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiSubC_16u_AC4RSfsNative(pSrc1, nSrc1Step, aConstants, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSubC_16u_AC4RSfsNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        short[] aConstants, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit unsigned short channel with unmodified alpha in place image subtract constant, scale, then clamp to saturated value.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSubC_16u_AC4IRSfs(
        short[] aConstants, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiSubC_16u_AC4IRSfsNative(aConstants, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSubC_16u_AC4IRSfsNative(
        short[] aConstants, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit unsigned short channel image subtract constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSubC_16u_C4RSfs(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        short[] aConstants, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiSubC_16u_C4RSfsNative(pSrc1, nSrc1Step, aConstants, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSubC_16u_C4RSfsNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        short[] aConstants, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit unsigned short channel in place image subtract constant, scale, then clamp to saturated value.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSubC_16u_C4IRSfs(
        short[] aConstants, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiSubC_16u_C4IRSfsNative(aConstants, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSubC_16u_C4IRSfsNative(
        short[] aConstants, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit signed short channel image subtract constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nConstant Constant.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSubC_16s_C1RSfs(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        short nConstant, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiSubC_16s_C1RSfsNative(pSrc1, nSrc1Step, nConstant, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSubC_16s_C1RSfsNative(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        short nConstant, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    public static int nppiSubC_16s_C1IRSfs(
        short nConstant, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiSubC_16s_C1IRSfsNative(nConstant, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSubC_16s_C1IRSfsNative(
        short nConstant, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 16-bit signed short channel image subtract constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSubC_16s_C3RSfs(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        short[] aConstants, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiSubC_16s_C3RSfsNative(pSrc1, nSrc1Step, aConstants, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSubC_16s_C3RSfsNative(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        short[] aConstants, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 16-bit signed short channel in place image subtract constant, scale, then clamp to saturated value.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSubC_16s_C3IRSfs(
        short[] aConstants, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiSubC_16s_C3IRSfsNative(aConstants, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSubC_16s_C3IRSfsNative(
        short[] aConstants, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit signed short channel with unmodified alpha image subtract constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSubC_16s_AC4RSfs(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        short[] aConstants, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiSubC_16s_AC4RSfsNative(pSrc1, nSrc1Step, aConstants, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSubC_16s_AC4RSfsNative(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        short[] aConstants, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    public static int nppiSubC_16s_AC4IRSfs(
        short[] aConstants, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiSubC_16s_AC4IRSfsNative(aConstants, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSubC_16s_AC4IRSfsNative(
        short[] aConstants, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit signed short channel image subtract constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSubC_16s_C4RSfs(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        short[] aConstants, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiSubC_16s_C4RSfsNative(pSrc1, nSrc1Step, aConstants, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSubC_16s_C4RSfsNative(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        short[] aConstants, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    public static int nppiSubC_16s_C4IRSfs(
        short[] aConstants, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiSubC_16s_C4IRSfsNative(aConstants, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSubC_16s_C4IRSfsNative(
        short[] aConstants, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit signed short complex number (16-bit real, 16-bit imaginary) channel image subtract constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nConstant Constant.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSubC_16sc_C1RSfs(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        Npp16sc nConstant, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiSubC_16sc_C1RSfsNative(pSrc1, nSrc1Step, nConstant, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSubC_16sc_C1RSfsNative(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        Npp16sc nConstant, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit signed short complex number (16-bit real, 16-bit imaginary) channel in place image subtract constant, scale, then clamp to saturated value.
     * @param nConstant Constant.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSubC_16sc_C1IRSfs(
        Npp16sc nConstant, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiSubC_16sc_C1IRSfsNative(nConstant, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSubC_16sc_C1IRSfsNative(
        Npp16sc nConstant, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 16-bit signed short complex number (16-bit real, 16-bit imaginary) channel image subtract constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSubC_16sc_C3RSfs(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        Npp16sc[] aConstants, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiSubC_16sc_C3RSfsNative(pSrc1, nSrc1Step, aConstants, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSubC_16sc_C3RSfsNative(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        Npp16sc[] aConstants, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    public static int nppiSubC_16sc_C3IRSfs(
        Npp16sc[] aConstants, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiSubC_16sc_C3IRSfsNative(aConstants, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSubC_16sc_C3IRSfsNative(
        Npp16sc[] aConstants, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit signed short complex number (16-bit real, 16-bit imaginary) channel with unmodified alpha image subtract constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSubC_16sc_AC4RSfs(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        Npp16sc[] aConstants, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiSubC_16sc_AC4RSfsNative(pSrc1, nSrc1Step, aConstants, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSubC_16sc_AC4RSfsNative(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        Npp16sc[] aConstants, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit signed short complex number (16-bit real, 16-bit imaginary) channel with unmodified alpha in place image subtract constant, scale, then clamp to saturated value.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSubC_16sc_AC4IRSfs(
        Npp16sc[] aConstants, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiSubC_16sc_AC4IRSfsNative(aConstants, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSubC_16sc_AC4IRSfsNative(
        Npp16sc[] aConstants, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 32-bit signed integer channel image subtract constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nConstant Constant.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSubC_32s_C1RSfs(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        int nConstant, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiSubC_32s_C1RSfsNative(pSrc1, nSrc1Step, nConstant, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSubC_32s_C1RSfsNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        int nConstant, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 32-bit signed integer channel in place image subtract constant, scale, then clamp to saturated value.
     * @param nConstant Constant.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSubC_32s_C1IRSfs(
        int nConstant, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiSubC_32s_C1IRSfsNative(nConstant, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSubC_32s_C1IRSfsNative(
        int nConstant, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 32-bit signed integer channel image subtract constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSubC_32s_C3RSfs(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        int[] aConstants, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiSubC_32s_C3RSfsNative(pSrc1, nSrc1Step, aConstants, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSubC_32s_C3RSfsNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        int[] aConstants, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 32-bit signed integer channel in place image subtract constant, scale, then clamp to saturated value.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSubC_32s_C3IRSfs(
        int[] aConstants, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiSubC_32s_C3IRSfsNative(aConstants, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSubC_32s_C3IRSfsNative(
        int[] aConstants, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 32-bit signed complex integer (32-bit real, 32-bit imaginary) channel image subtract constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nConstant Constant.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSubC_32sc_C1RSfs(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        Npp32sc nConstant, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiSubC_32sc_C1RSfsNative(pSrc1, nSrc1Step, nConstant, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSubC_32sc_C1RSfsNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        Npp32sc nConstant, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 32-bit signed complex integer (32-bit real, 32-bit imaginary) channel in place image subtract constant, scale, then clamp to saturated value.
     * @param nConstant Constant.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSubC_32sc_C1IRSfs(
        Npp32sc nConstant, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiSubC_32sc_C1IRSfsNative(nConstant, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSubC_32sc_C1IRSfsNative(
        Npp32sc nConstant, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 32-bit signed complex integer (32-bit real, 32-bit imaginary) channel image subtract constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSubC_32sc_C3RSfs(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        Npp32sc[] aConstants, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiSubC_32sc_C3RSfsNative(pSrc1, nSrc1Step, aConstants, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSubC_32sc_C3RSfsNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        Npp32sc[] aConstants, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 32-bit signed complex integer (32-bit real, 32-bit imaginary) channel in place image subtract constant, scale, then clamp to saturated value.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSubC_32sc_C3IRSfs(
        Npp32sc[] aConstants, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiSubC_32sc_C3IRSfsNative(aConstants, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSubC_32sc_C3IRSfsNative(
        Npp32sc[] aConstants, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 32-bit signed complex integer (32-bit real, 32-bit imaginary) channel with unmodified alpha image subtract constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSubC_32sc_AC4RSfs(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        Npp32sc[] aConstants, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiSubC_32sc_AC4RSfsNative(pSrc1, nSrc1Step, aConstants, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSubC_32sc_AC4RSfsNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        Npp32sc[] aConstants, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 32-bit signed complex integer (32-bit real, 32-bit imaginary) channel with unmodified alpha in place image subtract constant, scale, then clamp to saturated value.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSubC_32sc_AC4IRSfs(
        Npp32sc[] aConstants, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiSubC_32sc_AC4IRSfsNative(aConstants, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSubC_32sc_AC4IRSfsNative(
        Npp32sc[] aConstants, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 32-bit floating point channel image subtract constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nConstant Constant.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSubC_32f_C1R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        float nConstant, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiSubC_32f_C1RNative(pSrc1, nSrc1Step, nConstant, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiSubC_32f_C1RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        float nConstant, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 32-bit floating point channel in place image subtract constant.
     * @param nConstant Constant.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSubC_32f_C1IR(
        float nConstant, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiSubC_32f_C1IRNative(nConstant, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiSubC_32f_C1IRNative(
        float nConstant, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 32-bit floating point channel image subtract constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSubC_32f_C3R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        float[] aConstants, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiSubC_32f_C3RNative(pSrc1, nSrc1Step, aConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiSubC_32f_C3RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        float[] aConstants, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 32-bit floating point channel in place image subtract constant.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSubC_32f_C3IR(
        float[] aConstants, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiSubC_32f_C3IRNative(aConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiSubC_32f_C3IRNative(
        float[] aConstants, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit floating point channel with unmodified alpha image subtract constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSubC_32f_AC4R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        float[] aConstants, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiSubC_32f_AC4RNative(pSrc1, nSrc1Step, aConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiSubC_32f_AC4RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        float[] aConstants, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit floating point channel with unmodified alpha in place image subtract constant.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSubC_32f_AC4IR(
        float[] aConstants, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiSubC_32f_AC4IRNative(aConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiSubC_32f_AC4IRNative(
        float[] aConstants, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit floating point channel image subtract constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSubC_32f_C4R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        float[] aConstants, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiSubC_32f_C4RNative(pSrc1, nSrc1Step, aConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiSubC_32f_C4RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        float[] aConstants, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit floating point channel in place image subtract constant.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSubC_32f_C4IR(
        float[] aConstants, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiSubC_32f_C4IRNative(aConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiSubC_32f_C4IRNative(
        float[] aConstants, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 32-bit complex floating point (32-bit floating point real, 32-bit floating point imaginary) channel image subtract constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nConstant Constant.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSubC_32fc_C1R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        Npp32fc nConstant, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiSubC_32fc_C1RNative(pSrc1, nSrc1Step, nConstant, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiSubC_32fc_C1RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        Npp32fc nConstant, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 32-bit complex floating point (32-bit floating point real, 32-bit floating point imaginary) channel in place image subtract constant.
     * @param nConstant Constant.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSubC_32fc_C1IR(
        Npp32fc nConstant, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiSubC_32fc_C1IRNative(nConstant, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiSubC_32fc_C1IRNative(
        Npp32fc nConstant, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    public static int nppiSubC_32fc_C3R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        Npp32fc[] aConstants, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiSubC_32fc_C3RNative(pSrc1, nSrc1Step, aConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiSubC_32fc_C3RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        Npp32fc[] aConstants, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 32-bit complex floating point (32-bit floating point real, 32-bit floating point imaginary) channel in place image subtract constant.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSubC_32fc_C3IR(
        Npp32fc[] aConstants, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiSubC_32fc_C3IRNative(aConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiSubC_32fc_C3IRNative(
        Npp32fc[] aConstants, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit complex floating point (32-bit floating point real, 32-bit floating point imaginary) channel with unmodified alpha image subtract constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSubC_32fc_AC4R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        Npp32fc[] aConstants, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiSubC_32fc_AC4RNative(pSrc1, nSrc1Step, aConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiSubC_32fc_AC4RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        Npp32fc[] aConstants, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit complex floating point (32-bit floating point real, 32-bit floating point imaginary) channel with unmodified alpha in place image subtract constant.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSubC_32fc_AC4IR(
        Npp32fc[] aConstants, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiSubC_32fc_AC4IRNative(aConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiSubC_32fc_AC4IRNative(
        Npp32fc[] aConstants, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit complex floating point (32-bit floating point real, 32-bit floating point imaginary) channel image subtract constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSubC_32fc_C4R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        Npp32fc[] aConstants, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiSubC_32fc_C4RNative(pSrc1, nSrc1Step, aConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiSubC_32fc_C4RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        Npp32fc[] aConstants, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit complex floating point (32-bit floating point real, 32-bit floating point imaginary) channel in place image subtract constant.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSubC_32fc_C4IR(
        Npp32fc[] aConstants, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiSubC_32fc_C4IRNative(aConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiSubC_32fc_C4IRNative(
        Npp32fc[] aConstants, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 8-bit unsigned char channel image divided by constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nConstant Constant.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDivC_8u_C1RSfs(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        byte nConstant, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiDivC_8u_C1RSfsNative(pSrc1, nSrc1Step, nConstant, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDivC_8u_C1RSfsNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        byte nConstant, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    public static int nppiDivC_8u_C1IRSfs(
        byte nConstant, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiDivC_8u_C1IRSfsNative(nConstant, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDivC_8u_C1IRSfsNative(
        byte nConstant, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 8-bit unsigned char channel image divided by constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDivC_8u_C3RSfs(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        byte[] aConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiDivC_8u_C3RSfsNative(pSrc1, nSrc1Step, aConstants, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDivC_8u_C3RSfsNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        byte[] aConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 8-bit unsigned char channel 8-bit unsigned char in place image divided by constant, scale, then clamp to saturated value.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDivC_8u_C3IRSfs(
        byte[] aConstants, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiDivC_8u_C3IRSfsNative(aConstants, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDivC_8u_C3IRSfsNative(
        byte[] aConstants, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 8-bit unsigned char channel with unmodified alpha image divided by constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDivC_8u_AC4RSfs(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        byte[] aConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiDivC_8u_AC4RSfsNative(pSrc1, nSrc1Step, aConstants, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDivC_8u_AC4RSfsNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        byte[] aConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    public static int nppiDivC_8u_AC4IRSfs(
        byte[] aConstants, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiDivC_8u_AC4IRSfsNative(aConstants, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDivC_8u_AC4IRSfsNative(
        byte[] aConstants, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 8-bit unsigned char channel image divided by constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDivC_8u_C4RSfs(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        byte[] aConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiDivC_8u_C4RSfsNative(pSrc1, nSrc1Step, aConstants, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDivC_8u_C4RSfsNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        byte[] aConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 8-bit unsigned char channel in place image divided by constant, scale, then clamp to saturated value.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDivC_8u_C4IRSfs(
        byte[] aConstants, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiDivC_8u_C4IRSfsNative(aConstants, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDivC_8u_C4IRSfsNative(
        byte[] aConstants, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit unsigned short channel image divided by constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nConstant Constant.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDivC_16u_C1RSfs(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        short nConstant, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiDivC_16u_C1RSfsNative(pSrc1, nSrc1Step, nConstant, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDivC_16u_C1RSfsNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        short nConstant, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit unsigned short channel in place image divided by constant, scale, then clamp to saturated value.
     * @param nConstant Constant.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDivC_16u_C1IRSfs(
        short nConstant, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiDivC_16u_C1IRSfsNative(nConstant, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDivC_16u_C1IRSfsNative(
        short nConstant, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 16-bit unsigned short channel image divided by constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDivC_16u_C3RSfs(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        short[] aConstants, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiDivC_16u_C3RSfsNative(pSrc1, nSrc1Step, aConstants, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDivC_16u_C3RSfsNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        short[] aConstants, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 16-bit unsigned short channel in place image divided by constant, scale, then clamp to saturated value.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDivC_16u_C3IRSfs(
        short[] aConstants, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiDivC_16u_C3IRSfsNative(aConstants, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDivC_16u_C3IRSfsNative(
        short[] aConstants, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    public static int nppiDivC_16u_AC4RSfs(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        short[] aConstants, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiDivC_16u_AC4RSfsNative(pSrc1, nSrc1Step, aConstants, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDivC_16u_AC4RSfsNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        short[] aConstants, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit unsigned short channel with unmodified alpha in place image divided by constant, scale, then clamp to saturated value.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDivC_16u_AC4IRSfs(
        short[] aConstants, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiDivC_16u_AC4IRSfsNative(aConstants, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDivC_16u_AC4IRSfsNative(
        short[] aConstants, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit unsigned short channel image divided by constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDivC_16u_C4RSfs(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        short[] aConstants, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiDivC_16u_C4RSfsNative(pSrc1, nSrc1Step, aConstants, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDivC_16u_C4RSfsNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        short[] aConstants, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    public static int nppiDivC_16u_C4IRSfs(
        short[] aConstants, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiDivC_16u_C4IRSfsNative(aConstants, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDivC_16u_C4IRSfsNative(
        short[] aConstants, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit signed short channel image divided by constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nConstant Constant.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDivC_16s_C1RSfs(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        short nConstant, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiDivC_16s_C1RSfsNative(pSrc1, nSrc1Step, nConstant, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDivC_16s_C1RSfsNative(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        short nConstant, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit signed short channel in place image divided by constant, scale, then clamp to saturated value.
     * @param nConstant Constant.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDivC_16s_C1IRSfs(
        short nConstant, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiDivC_16s_C1IRSfsNative(nConstant, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDivC_16s_C1IRSfsNative(
        short nConstant, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 16-bit signed short channel image divided by constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDivC_16s_C3RSfs(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        short[] aConstants, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiDivC_16s_C3RSfsNative(pSrc1, nSrc1Step, aConstants, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDivC_16s_C3RSfsNative(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        short[] aConstants, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 16-bit signed short channel in place image divided by constant, scale, then clamp to saturated value.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDivC_16s_C3IRSfs(
        short[] aConstants, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiDivC_16s_C3IRSfsNative(aConstants, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDivC_16s_C3IRSfsNative(
        short[] aConstants, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    public static int nppiDivC_16s_AC4RSfs(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        short[] aConstants, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiDivC_16s_AC4RSfsNative(pSrc1, nSrc1Step, aConstants, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDivC_16s_AC4RSfsNative(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        short[] aConstants, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit signed short channel with unmodified alpha in place image divided by constant, scale, then clamp to saturated value.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDivC_16s_AC4IRSfs(
        short[] aConstants, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiDivC_16s_AC4IRSfsNative(aConstants, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDivC_16s_AC4IRSfsNative(
        short[] aConstants, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit signed short channel image divided by constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDivC_16s_C4RSfs(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        short[] aConstants, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiDivC_16s_C4RSfsNative(pSrc1, nSrc1Step, aConstants, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDivC_16s_C4RSfsNative(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        short[] aConstants, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit signed short channel in place image divided by constant, scale, then clamp to saturated value.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDivC_16s_C4IRSfs(
        short[] aConstants, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiDivC_16s_C4IRSfsNative(aConstants, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDivC_16s_C4IRSfsNative(
        short[] aConstants, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit signed short complex number (16-bit real, 16-bit imaginary) channel image divided by constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nConstant Constant.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDivC_16sc_C1RSfs(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        Npp16sc nConstant, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiDivC_16sc_C1RSfsNative(pSrc1, nSrc1Step, nConstant, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDivC_16sc_C1RSfsNative(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        Npp16sc nConstant, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit signed short complex number (16-bit real, 16-bit imaginary) channel in place image divided by constant, scale, then clamp to saturated value.
     * @param nConstant Constant.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDivC_16sc_C1IRSfs(
        Npp16sc nConstant, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiDivC_16sc_C1IRSfsNative(nConstant, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDivC_16sc_C1IRSfsNative(
        Npp16sc nConstant, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 16-bit signed short complex number (16-bit real, 16-bit imaginary) channel image divided by constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDivC_16sc_C3RSfs(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        Npp16sc[] aConstants, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiDivC_16sc_C3RSfsNative(pSrc1, nSrc1Step, aConstants, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDivC_16sc_C3RSfsNative(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        Npp16sc[] aConstants, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 16-bit signed short complex number (16-bit real, 16-bit imaginary) channel in place image divided by constant, scale, then clamp to saturated value.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDivC_16sc_C3IRSfs(
        Npp16sc[] aConstants, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiDivC_16sc_C3IRSfsNative(aConstants, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDivC_16sc_C3IRSfsNative(
        Npp16sc[] aConstants, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit signed short complex number (16-bit real, 16-bit imaginary) channel with unmodified alpha image divided by constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDivC_16sc_AC4RSfs(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        Npp16sc[] aConstants, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiDivC_16sc_AC4RSfsNative(pSrc1, nSrc1Step, aConstants, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDivC_16sc_AC4RSfsNative(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        Npp16sc[] aConstants, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit signed short complex number (16-bit real, 16-bit imaginary) channel with unmodified alpha in place image divided by constant, scale, then clamp to saturated value.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDivC_16sc_AC4IRSfs(
        Npp16sc[] aConstants, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiDivC_16sc_AC4IRSfsNative(aConstants, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDivC_16sc_AC4IRSfsNative(
        Npp16sc[] aConstants, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    public static int nppiDivC_32s_C1RSfs(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        int nConstant, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiDivC_32s_C1RSfsNative(pSrc1, nSrc1Step, nConstant, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDivC_32s_C1RSfsNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        int nConstant, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 32-bit signed integer channel in place image divided by constant, scale, then clamp to saturated value.
     * @param nConstant Constant.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDivC_32s_C1IRSfs(
        int nConstant, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiDivC_32s_C1IRSfsNative(nConstant, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDivC_32s_C1IRSfsNative(
        int nConstant, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 32-bit signed integer channel image divided by constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDivC_32s_C3RSfs(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        int[] aConstants, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiDivC_32s_C3RSfsNative(pSrc1, nSrc1Step, aConstants, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDivC_32s_C3RSfsNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        int[] aConstants, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 32-bit signed integer channel in place image divided by constant, scale, then clamp to saturated value.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDivC_32s_C3IRSfs(
        int[] aConstants, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiDivC_32s_C3IRSfsNative(aConstants, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDivC_32s_C3IRSfsNative(
        int[] aConstants, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 32-bit signed complex integer (32-bit real, 32-bit imaginary) channel image divided by constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nConstant Constant.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDivC_32sc_C1RSfs(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        Npp32sc nConstant, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiDivC_32sc_C1RSfsNative(pSrc1, nSrc1Step, nConstant, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDivC_32sc_C1RSfsNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        Npp32sc nConstant, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 32-bit signed complex integer (32-bit real, 32-bit imaginary) channel in place image divided by constant, scale, then clamp to saturated value.
     * @param nConstant Constant.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDivC_32sc_C1IRSfs(
        Npp32sc nConstant, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiDivC_32sc_C1IRSfsNative(nConstant, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDivC_32sc_C1IRSfsNative(
        Npp32sc nConstant, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 32-bit signed complex integer (32-bit real, 32-bit imaginary) channel image divided by constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDivC_32sc_C3RSfs(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        Npp32sc[] aConstants, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiDivC_32sc_C3RSfsNative(pSrc1, nSrc1Step, aConstants, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDivC_32sc_C3RSfsNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        Npp32sc[] aConstants, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 32-bit signed complex integer (32-bit real, 32-bit imaginary) channel in place image divided by constant, scale, then clamp to saturated value.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDivC_32sc_C3IRSfs(
        Npp32sc[] aConstants, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiDivC_32sc_C3IRSfsNative(aConstants, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDivC_32sc_C3IRSfsNative(
        Npp32sc[] aConstants, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 32-bit signed complex integer (32-bit real, 32-bit imaginary) channel with unmodified alpha image divided by constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDivC_32sc_AC4RSfs(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        Npp32sc[] aConstants, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiDivC_32sc_AC4RSfsNative(pSrc1, nSrc1Step, aConstants, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDivC_32sc_AC4RSfsNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        Npp32sc[] aConstants, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 32-bit signed complex integer (32-bit real, 32-bit imaginary) channel with unmodified alpha in place image divided by constant, scale, then clamp to saturated value.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDivC_32sc_AC4IRSfs(
        Npp32sc[] aConstants, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiDivC_32sc_AC4IRSfsNative(aConstants, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDivC_32sc_AC4IRSfsNative(
        Npp32sc[] aConstants, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 32-bit floating point channel image divided by constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nConstant Constant.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDivC_32f_C1R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        float nConstant, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiDivC_32f_C1RNative(pSrc1, nSrc1Step, nConstant, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiDivC_32f_C1RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        float nConstant, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    public static int nppiDivC_32f_C1IR(
        float nConstant, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiDivC_32f_C1IRNative(nConstant, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiDivC_32f_C1IRNative(
        float nConstant, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 32-bit floating point channel image divided by constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDivC_32f_C3R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        float[] aConstants, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiDivC_32f_C3RNative(pSrc1, nSrc1Step, aConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiDivC_32f_C3RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        float[] aConstants, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 32-bit floating point channel in place image divided by constant.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDivC_32f_C3IR(
        float[] aConstants, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiDivC_32f_C3IRNative(aConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiDivC_32f_C3IRNative(
        float[] aConstants, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit floating point channel with unmodified alpha image divided by constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDivC_32f_AC4R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        float[] aConstants, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiDivC_32f_AC4RNative(pSrc1, nSrc1Step, aConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiDivC_32f_AC4RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        float[] aConstants, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit floating point channel with unmodified alpha in place image divided by constant.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDivC_32f_AC4IR(
        float[] aConstants, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiDivC_32f_AC4IRNative(aConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiDivC_32f_AC4IRNative(
        float[] aConstants, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit floating point channel image divided by constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDivC_32f_C4R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        float[] aConstants, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiDivC_32f_C4RNative(pSrc1, nSrc1Step, aConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiDivC_32f_C4RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        float[] aConstants, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit floating point channel in place image divided by constant.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDivC_32f_C4IR(
        float[] aConstants, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiDivC_32f_C4IRNative(aConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiDivC_32f_C4IRNative(
        float[] aConstants, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 32-bit complex floating point (32-bit floating point real, 32-bit floating point imaginary) channel image divided by constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nConstant Constant.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDivC_32fc_C1R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        Npp32fc nConstant, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiDivC_32fc_C1RNative(pSrc1, nSrc1Step, nConstant, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiDivC_32fc_C1RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        Npp32fc nConstant, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 32-bit complex floating point (32-bit floating point real, 32-bit floating point imaginary) channel in place image divided by constant.
     * @param nConstant Constant.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDivC_32fc_C1IR(
        Npp32fc nConstant, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiDivC_32fc_C1IRNative(nConstant, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiDivC_32fc_C1IRNative(
        Npp32fc nConstant, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 32-bit complex floating point (32-bit floating point real, 32-bit floating point imaginary) channel image divided by constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDivC_32fc_C3R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        Npp32fc[] aConstants, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiDivC_32fc_C3RNative(pSrc1, nSrc1Step, aConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiDivC_32fc_C3RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        Npp32fc[] aConstants, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 32-bit complex floating point (32-bit floating point real, 32-bit floating point imaginary) channel in place image divided by constant.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDivC_32fc_C3IR(
        Npp32fc[] aConstants, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiDivC_32fc_C3IRNative(aConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiDivC_32fc_C3IRNative(
        Npp32fc[] aConstants, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit complex floating point (32-bit floating point real, 32-bit floating point imaginary) channel with unmodified alpha image divided by constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDivC_32fc_AC4R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        Npp32fc[] aConstants, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiDivC_32fc_AC4RNative(pSrc1, nSrc1Step, aConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiDivC_32fc_AC4RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        Npp32fc[] aConstants, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit complex floating point (32-bit floating point real, 32-bit floating point imaginary) channel with unmodified alpha in place image divided by constant.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDivC_32fc_AC4IR(
        Npp32fc[] aConstants, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiDivC_32fc_AC4IRNative(aConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiDivC_32fc_AC4IRNative(
        Npp32fc[] aConstants, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit complex floating point (32-bit floating point real, 32-bit floating point imaginary) channel image divided by constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDivC_32fc_C4R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        Npp32fc[] aConstants, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiDivC_32fc_C4RNative(pSrc1, nSrc1Step, aConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiDivC_32fc_C4RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        Npp32fc[] aConstants, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit complex floating point (32-bit floating point real, 32-bit floating point imaginary) channel in place image divided by constant.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDivC_32fc_C4IR(
        Npp32fc[] aConstants, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiDivC_32fc_C4IRNative(aConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiDivC_32fc_C4IRNative(
        Npp32fc[] aConstants, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 8-bit unsigned char channel image absolute difference with constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nConstant Constant.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAbsDiffC_8u_C1R(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        byte nConstant)
    {
        return JNpp.checkResult(nppiAbsDiffC_8u_C1RNative(pSrc1, nSrc1Step, pDst, nDstStep, oSizeROI, nConstant));
    }
    private static native int nppiAbsDiffC_8u_C1RNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        byte nConstant);


    /**
     * <pre>
     * One 16-bit unsigned short channel image absolute difference with constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nConstant Constant.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAbsDiffC_16u_C1R(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        short nConstant)
    {
        return JNpp.checkResult(nppiAbsDiffC_16u_C1RNative(pSrc1, nSrc1Step, pDst, nDstStep, oSizeROI, nConstant));
    }
    private static native int nppiAbsDiffC_16u_C1RNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        short nConstant);


    /**
     * <pre>
     * One 32-bit floating point channel image absolute difference with constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nConstant Constant.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAbsDiffC_32f_C1R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        float nConstant)
    {
        return JNpp.checkResult(nppiAbsDiffC_32f_C1RNative(pSrc1, nSrc1Step, pDst, nDstStep, oSizeROI, nConstant));
    }
    private static native int nppiAbsDiffC_32f_C1RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        float nConstant);


    /**
     * <pre>
     * One 8-bit unsigned char channel image addition, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAdd_8u_C1RSfs(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiAdd_8u_C1RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAdd_8u_C1RSfsNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 8-bit unsigned char channel in place image addition, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAdd_8u_C1IRSfs(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiAdd_8u_C1IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAdd_8u_C1IRSfsNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 8-bit unsigned char channel image addition, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAdd_8u_C3RSfs(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiAdd_8u_C3RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAdd_8u_C3RSfsNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 8-bit unsigned char channel in place image addition, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAdd_8u_C3IRSfs(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiAdd_8u_C3IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAdd_8u_C3IRSfsNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 8-bit unsigned char channel with unmodified alpha image addition, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAdd_8u_AC4RSfs(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiAdd_8u_AC4RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAdd_8u_AC4RSfsNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 8-bit unsigned char channel with unmodified alpha in place image addition, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAdd_8u_AC4IRSfs(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiAdd_8u_AC4IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAdd_8u_AC4IRSfsNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 8-bit unsigned char channel image addition, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAdd_8u_C4RSfs(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiAdd_8u_C4RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAdd_8u_C4RSfsNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 8-bit unsigned char channel in place image addition, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAdd_8u_C4IRSfs(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiAdd_8u_C4IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAdd_8u_C4IRSfsNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    public static int nppiAdd_16u_C1RSfs(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiAdd_16u_C1RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAdd_16u_C1RSfsNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit unsigned short channel in place image addition, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAdd_16u_C1IRSfs(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiAdd_16u_C1IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAdd_16u_C1IRSfsNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 16-bit unsigned short channel image addition, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAdd_16u_C3RSfs(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiAdd_16u_C3RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAdd_16u_C3RSfsNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit unsigned short channel in place image addition, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAdd_16u_C3IRSfs(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiAdd_16u_C3IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAdd_16u_C3IRSfsNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit unsigned short channel with unmodified alpha image addition, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAdd_16u_AC4RSfs(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiAdd_16u_AC4RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAdd_16u_AC4RSfsNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit unsigned short channel with unmodified alpha in place image addition, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAdd_16u_AC4IRSfs(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiAdd_16u_AC4IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAdd_16u_AC4IRSfsNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit unsigned short channel image addition, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAdd_16u_C4RSfs(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiAdd_16u_C4RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAdd_16u_C4RSfsNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit unsigned short channel in place image addition, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAdd_16u_C4IRSfs(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiAdd_16u_C4IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAdd_16u_C4IRSfsNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    public static int nppiAdd_16s_C1RSfs(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiAdd_16s_C1RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAdd_16s_C1RSfsNative(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit signed short channel in place image addition, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAdd_16s_C1IRSfs(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiAdd_16s_C1IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAdd_16s_C1IRSfsNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    public static int nppiAdd_16s_C3RSfs(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiAdd_16s_C3RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAdd_16s_C3RSfsNative(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit signed short channel in place image addition, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAdd_16s_C3IRSfs(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiAdd_16s_C3IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAdd_16s_C3IRSfsNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit signed short channel with unmodified alpha image addition, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAdd_16s_AC4RSfs(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiAdd_16s_AC4RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAdd_16s_AC4RSfsNative(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit signed short channel with unmodified alpha in place image addition, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAdd_16s_AC4IRSfs(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiAdd_16s_AC4IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAdd_16s_AC4IRSfsNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit signed short channel image addition, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAdd_16s_C4RSfs(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiAdd_16s_C4RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAdd_16s_C4RSfsNative(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    public static int nppiAdd_16s_C4IRSfs(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiAdd_16s_C4IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAdd_16s_C4IRSfsNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit signed short complex number (16-bit real, 16-bit imaginary) channel image addition, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAdd_16sc_C1RSfs(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiAdd_16sc_C1RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAdd_16sc_C1RSfsNative(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit signed short complex number (16-bit real, 16-bit imaginary) channel in place image addition, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAdd_16sc_C1IRSfs(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiAdd_16sc_C1IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAdd_16sc_C1IRSfsNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 16-bit signed short complex number (16-bit real, 16-bit imaginary) channel image addition, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAdd_16sc_C3RSfs(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiAdd_16sc_C3RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAdd_16sc_C3RSfsNative(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    public static int nppiAdd_16sc_C3IRSfs(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiAdd_16sc_C3IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAdd_16sc_C3IRSfsNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit signed short complex number (16-bit real, 16-bit imaginary) channel with unmodified alpha image addition, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAdd_16sc_AC4RSfs(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiAdd_16sc_AC4RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAdd_16sc_AC4RSfsNative(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit signed short complex number (16-bit real, 16-bit imaginary) channel with unmodified alpha in place image addition, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAdd_16sc_AC4IRSfs(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiAdd_16sc_AC4IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAdd_16sc_AC4IRSfsNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 32-bit signed integer channel image addition, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAdd_32s_C1RSfs(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiAdd_32s_C1RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAdd_32s_C1RSfsNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Note: This function is to be deprecated in future NPP releases, use the function above with a scale factor of 0 instead. 
     * 32-bit image add.
     * Add the pixel values of corresponding pixels in the ROI and write them to the output image.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAdd_32s_C1R(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiAdd_32s_C1RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiAdd_32s_C1RNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 32-bit signed integer channel in place image addition, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAdd_32s_C1IRSfs(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiAdd_32s_C1IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAdd_32s_C1IRSfsNative(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 32-bit signed integer channel image addition, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAdd_32s_C3RSfs(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiAdd_32s_C3RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAdd_32s_C3RSfsNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 32-bit signed integer channel in place image addition, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAdd_32s_C3IRSfs(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiAdd_32s_C3IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAdd_32s_C3IRSfsNative(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 32-bit signed integer complex number (32-bit real, 32-bit imaginary) channel image addition, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAdd_32sc_C1RSfs(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiAdd_32sc_C1RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAdd_32sc_C1RSfsNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 32-bit signed integer complex number (32-bit real, 32-bit imaginary) channel in place image addition, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAdd_32sc_C1IRSfs(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiAdd_32sc_C1IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAdd_32sc_C1IRSfsNative(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 32-bit signed integer complex number (32-bit real, 32-bit imaginary) channel image addition, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAdd_32sc_C3RSfs(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiAdd_32sc_C3RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAdd_32sc_C3RSfsNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 32-bit signed integer complex number (32-bit real, 32-bit imaginary) channel in place image addition, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAdd_32sc_C3IRSfs(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiAdd_32sc_C3IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAdd_32sc_C3IRSfsNative(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 32-bit signed integer complex number (32-bit real, 32-bit imaginary) channel with unmodified alpha image addition, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAdd_32sc_AC4RSfs(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiAdd_32sc_AC4RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAdd_32sc_AC4RSfsNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 32-bit signed integer complex number (32-bit real, 32-bit imaginary) channel with unmodified alpha in place image addition, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAdd_32sc_AC4IRSfs(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiAdd_32sc_AC4IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAdd_32sc_AC4IRSfsNative(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 32-bit floating point channel image addition.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAdd_32f_C1R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiAdd_32f_C1RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiAdd_32f_C1RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 32-bit floating point channel in place image addition.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAdd_32f_C1IR(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiAdd_32f_C1IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiAdd_32f_C1IRNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 32-bit floating point channel image addition.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAdd_32f_C3R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiAdd_32f_C3RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiAdd_32f_C3RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    public static int nppiAdd_32f_C3IR(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiAdd_32f_C3IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiAdd_32f_C3IRNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit floating point channel with unmodified alpha image addition.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAdd_32f_AC4R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiAdd_32f_AC4RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiAdd_32f_AC4RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit floating point channel with unmodified alpha in place image addition.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAdd_32f_AC4IR(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiAdd_32f_AC4IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiAdd_32f_AC4IRNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit floating point channel image addition.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAdd_32f_C4R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiAdd_32f_C4RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiAdd_32f_C4RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit floating point channel in place image addition.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAdd_32f_C4IR(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiAdd_32f_C4IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiAdd_32f_C4IRNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 32-bit floating point complex number (32-bit real, 32-bit imaginary) channel image addition.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAdd_32fc_C1R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiAdd_32fc_C1RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiAdd_32fc_C1RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 32-bit floating point complex number (32-bit real, 32-bit imaginary) channel in place image addition.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAdd_32fc_C1IR(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiAdd_32fc_C1IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiAdd_32fc_C1IRNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 32-bit floating point complex number (32-bit real, 32-bit imaginary) channel image addition.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAdd_32fc_C3R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiAdd_32fc_C3RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiAdd_32fc_C3RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 32-bit floating point complex number (32-bit real, 32-bit imaginary) channel in place image addition.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAdd_32fc_C3IR(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiAdd_32fc_C3IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiAdd_32fc_C3IRNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit floating point complex number (32-bit real, 32-bit imaginary) channel with unmodified alpha image addition.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAdd_32fc_AC4R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiAdd_32fc_AC4RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiAdd_32fc_AC4RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit floating point complex number (32-bit real, 32-bit imaginary) channel with unmodified alpha in place image addition.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAdd_32fc_AC4IR(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiAdd_32fc_AC4IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiAdd_32fc_AC4IRNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit floating point complex number (32-bit real, 32-bit imaginary) channel image addition.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAdd_32fc_C4R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiAdd_32fc_C4RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiAdd_32fc_C4RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit floating point complex number (32-bit real, 32-bit imaginary) channel in place image addition.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAdd_32fc_C4IR(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiAdd_32fc_C4IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiAdd_32fc_C4IRNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 8-bit unsigned char channel image squared then added to in place floating point destination image using filter mask (updates destination when mask is non-zero).
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pMask \ref mask_image_pointer.
     * @param nMaskStep \ref mask_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAddSquare_8u32f_C1IMR(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiAddSquare_8u32f_C1IMRNative(pSrc, nSrcStep, pMask, nMaskStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiAddSquare_8u32f_C1IMRNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 8-bit unsigned char channel image squared then added to in place floating point destination image.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAddSquare_8u32f_C1IR(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiAddSquare_8u32f_C1IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiAddSquare_8u32f_C1IRNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 16-bit unsigned short channel image squared then added to in place floating point destination image using filter mask (updates destination when mask is non-zero).
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pMask \ref mask_image_pointer.
     * @param nMaskStep \ref mask_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAddSquare_16u32f_C1IMR(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiAddSquare_16u32f_C1IMRNative(pSrc, nSrcStep, pMask, nMaskStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiAddSquare_16u32f_C1IMRNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 16-bit unsigned short channel image squared then added to in place floating point destination image.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAddSquare_16u32f_C1IR(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiAddSquare_16u32f_C1IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiAddSquare_16u32f_C1IRNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 32-bit floating point channel image squared then added to in place floating point destination image using filter mask (updates destination when mask is non-zero).
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pMask \ref mask_image_pointer.
     * @param nMaskStep \ref mask_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAddSquare_32f_C1IMR(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiAddSquare_32f_C1IMRNative(pSrc, nSrcStep, pMask, nMaskStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiAddSquare_32f_C1IMRNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 32-bit floating point channel image squared then added to in place floating point destination image.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAddSquare_32f_C1IR(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiAddSquare_32f_C1IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiAddSquare_32f_C1IRNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 8-bit unsigned char channel image product added to in place floating point destination image using filter mask (updates destination when mask is non-zero).
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pMask \ref mask_image_pointer.
     * @param nMaskStep \ref mask_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAddProduct_8u32f_C1IMR(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiAddProduct_8u32f_C1IMRNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pMask, nMaskStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiAddProduct_8u32f_C1IMRNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 8-bit unsigned char channel image product added to in place floating point destination image.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAddProduct_8u32f_C1IR(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiAddProduct_8u32f_C1IRNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiAddProduct_8u32f_C1IRNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 16-bit unsigned short channel image product added to in place floating point destination image using filter mask (updates destination when mask is non-zero).
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pMask \ref mask_image_pointer.
     * @param nMaskStep \ref mask_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAddProduct_16u32f_C1IMR(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiAddProduct_16u32f_C1IMRNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pMask, nMaskStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiAddProduct_16u32f_C1IMRNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 16-bit unsigned short channel image product added to in place floating point destination image.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAddProduct_16u32f_C1IR(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiAddProduct_16u32f_C1IRNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiAddProduct_16u32f_C1IRNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 32-bit floating point channel image product added to in place floating point destination image using filter mask (updates destination when mask is non-zero).
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pMask \ref mask_image_pointer.
     * @param nMaskStep \ref mask_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAddProduct_32f_C1IMR(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiAddProduct_32f_C1IMRNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pMask, nMaskStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiAddProduct_32f_C1IMRNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 32-bit floating point channel image product added to in place floating point destination image.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAddProduct_32f_C1IR(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiAddProduct_32f_C1IRNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiAddProduct_32f_C1IRNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 8-bit unsigned char channel alpha weighted image added to in place floating point destination image using filter mask (updates destination when mask is non-zero).
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pMask \ref mask_image_pointer.
     * @param nMaskStep \ref mask_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nAlpha Alpha weight to be applied to source image pixels (0.0F to 1.0F)
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAddWeighted_8u32f_C1IMR(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        float nAlpha)
    {
        return JNpp.checkResult(nppiAddWeighted_8u32f_C1IMRNative(pSrc, nSrcStep, pMask, nMaskStep, pSrcDst, nSrcDstStep, oSizeROI, nAlpha));
    }
    private static native int nppiAddWeighted_8u32f_C1IMRNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        float nAlpha);


    /**
     * <pre>
     * One 8-bit unsigned char channel alpha weighted image added to in place floating point destination image.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nAlpha Alpha weight to be applied to source image pixels (0.0F to 1.0F)
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAddWeighted_8u32f_C1IR(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        float nAlpha)
    {
        return JNpp.checkResult(nppiAddWeighted_8u32f_C1IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nAlpha));
    }
    private static native int nppiAddWeighted_8u32f_C1IRNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        float nAlpha);


    /**
     * <pre>
     * One 16-bit unsigned short channel alpha weighted image added to in place floating point destination image using filter mask (updates destination when mask is non-zero).
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pMask \ref mask_image_pointer.
     * @param nMaskStep \ref mask_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nAlpha Alpha weight to be applied to source image pixels (0.0F to 1.0F)
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAddWeighted_16u32f_C1IMR(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        float nAlpha)
    {
        return JNpp.checkResult(nppiAddWeighted_16u32f_C1IMRNative(pSrc, nSrcStep, pMask, nMaskStep, pSrcDst, nSrcDstStep, oSizeROI, nAlpha));
    }
    private static native int nppiAddWeighted_16u32f_C1IMRNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        float nAlpha);


    /**
     * <pre>
     * One 16-bit unsigned short channel alpha weighted image added to in place floating point destination image.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nAlpha Alpha weight to be applied to source image pixels (0.0F to 1.0F)
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAddWeighted_16u32f_C1IR(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        float nAlpha)
    {
        return JNpp.checkResult(nppiAddWeighted_16u32f_C1IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nAlpha));
    }
    private static native int nppiAddWeighted_16u32f_C1IRNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        float nAlpha);


    /**
     * <pre>
     * One 32-bit floating point channel alpha weighted image added to in place floating point destination image using filter mask (updates destination when mask is non-zero).
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pMask \ref mask_image_pointer.
     * @param nMaskStep \ref mask_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nAlpha Alpha weight to be applied to source image pixels (0.0F to 1.0F)
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAddWeighted_32f_C1IMR(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        float nAlpha)
    {
        return JNpp.checkResult(nppiAddWeighted_32f_C1IMRNative(pSrc, nSrcStep, pMask, nMaskStep, pSrcDst, nSrcDstStep, oSizeROI, nAlpha));
    }
    private static native int nppiAddWeighted_32f_C1IMRNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        float nAlpha);


    /**
     * <pre>
     * One 32-bit floating point channel alpha weighted image added to in place floating point destination image.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nAlpha Alpha weight to be applied to source image pixels (0.0F to 1.0F)
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAddWeighted_32f_C1IR(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        float nAlpha)
    {
        return JNpp.checkResult(nppiAddWeighted_32f_C1IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nAlpha));
    }
    private static native int nppiAddWeighted_32f_C1IRNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        float nAlpha);


    /**
     * <pre>
     * One 8-bit unsigned char channel image multiplication, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMul_8u_C1RSfs(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiMul_8u_C1RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMul_8u_C1RSfsNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 8-bit unsigned char channel in place image multiplication, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMul_8u_C1IRSfs(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiMul_8u_C1IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMul_8u_C1IRSfsNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 8-bit unsigned char channel image multiplication, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMul_8u_C3RSfs(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiMul_8u_C3RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMul_8u_C3RSfsNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 8-bit unsigned char channel in place image multiplication, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMul_8u_C3IRSfs(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiMul_8u_C3IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMul_8u_C3IRSfsNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 8-bit unsigned char channel with unmodified alpha image multiplication, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMul_8u_AC4RSfs(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiMul_8u_AC4RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMul_8u_AC4RSfsNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 8-bit unsigned char channel with unmodified alpha in place image multiplication, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMul_8u_AC4IRSfs(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiMul_8u_AC4IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMul_8u_AC4IRSfsNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 8-bit unsigned char channel image multiplication, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMul_8u_C4RSfs(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiMul_8u_C4RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMul_8u_C4RSfsNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 8-bit unsigned char channel in place image multiplication, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMul_8u_C4IRSfs(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiMul_8u_C4IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMul_8u_C4IRSfsNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit unsigned short channel image multiplication, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMul_16u_C1RSfs(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiMul_16u_C1RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMul_16u_C1RSfsNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit unsigned short channel in place image multiplication, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMul_16u_C1IRSfs(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiMul_16u_C1IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMul_16u_C1IRSfsNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 16-bit unsigned short channel image multiplication, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMul_16u_C3RSfs(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiMul_16u_C3RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMul_16u_C3RSfsNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit unsigned short channel in place image multiplication, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMul_16u_C3IRSfs(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiMul_16u_C3IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMul_16u_C3IRSfsNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit unsigned short channel with unmodified alpha image multiplication, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMul_16u_AC4RSfs(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiMul_16u_AC4RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMul_16u_AC4RSfsNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit unsigned short channel with unmodified alpha in place image multiplication, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMul_16u_AC4IRSfs(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiMul_16u_AC4IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMul_16u_AC4IRSfsNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit unsigned short channel image multiplication, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMul_16u_C4RSfs(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiMul_16u_C4RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMul_16u_C4RSfsNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit unsigned short channel in place image multiplication, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMul_16u_C4IRSfs(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiMul_16u_C4IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMul_16u_C4IRSfsNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit signed short channel image multiplication, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMul_16s_C1RSfs(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiMul_16s_C1RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMul_16s_C1RSfsNative(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit signed short channel in place image multiplication, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMul_16s_C1IRSfs(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiMul_16s_C1IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMul_16s_C1IRSfsNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 16-bit signed short channel image multiplication, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMul_16s_C3RSfs(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiMul_16s_C3RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMul_16s_C3RSfsNative(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit signed short channel in place image multiplication, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMul_16s_C3IRSfs(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiMul_16s_C3IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMul_16s_C3IRSfsNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit signed short channel with unmodified alpha image multiplication, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMul_16s_AC4RSfs(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiMul_16s_AC4RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMul_16s_AC4RSfsNative(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit signed short channel with unmodified alpha in place image multiplication, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMul_16s_AC4IRSfs(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiMul_16s_AC4IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMul_16s_AC4IRSfsNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit signed short channel image multiplication, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMul_16s_C4RSfs(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiMul_16s_C4RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMul_16s_C4RSfsNative(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit signed short channel in place image multiplication, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMul_16s_C4IRSfs(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiMul_16s_C4IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMul_16s_C4IRSfsNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit signed short complex number (16-bit real, 16-bit imaginary) channel image multiplication, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMul_16sc_C1RSfs(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiMul_16sc_C1RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMul_16sc_C1RSfsNative(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit signed short complex number (16-bit real, 16-bit imaginary) channel in place image multiplication, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMul_16sc_C1IRSfs(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiMul_16sc_C1IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMul_16sc_C1IRSfsNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 16-bit signed short complex number (16-bit real, 16-bit imaginary) channel image multiplication, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMul_16sc_C3RSfs(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiMul_16sc_C3RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMul_16sc_C3RSfsNative(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit signed short complex number (16-bit real, 16-bit imaginary) channel in place image multiplication, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMul_16sc_C3IRSfs(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiMul_16sc_C3IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMul_16sc_C3IRSfsNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit signed short complex number (16-bit real, 16-bit imaginary) channel with unmodified alpha image multiplication, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMul_16sc_AC4RSfs(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiMul_16sc_AC4RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMul_16sc_AC4RSfsNative(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit signed short complex number (16-bit real, 16-bit imaginary) channel with unmodified alpha in place image multiplication, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMul_16sc_AC4IRSfs(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiMul_16sc_AC4IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMul_16sc_AC4IRSfsNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 32-bit signed integer channel image multiplication, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMul_32s_C1RSfs(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiMul_32s_C1RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMul_32s_C1RSfsNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Note: This function is to be deprecated in future NPP releases, use the function above with a scale factor of 0 instead.
     * 1 channel 32-bit image multiplication.
     * Multiply corresponding pixels in ROI. 
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMul_32s_C1R(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiMul_32s_C1RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiMul_32s_C1RNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 32-bit signed integer channel in place image multiplication, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMul_32s_C1IRSfs(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiMul_32s_C1IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMul_32s_C1IRSfsNative(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 32-bit signed integer channel image multiplication, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMul_32s_C3RSfs(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiMul_32s_C3RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMul_32s_C3RSfsNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 32-bit signed integer channel in place image multiplication, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMul_32s_C3IRSfs(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiMul_32s_C3IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMul_32s_C3IRSfsNative(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 32-bit signed integer complex number (32-bit real, 32-bit imaginary) channel image multiplication, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMul_32sc_C1RSfs(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiMul_32sc_C1RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMul_32sc_C1RSfsNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 32-bit signed integer complex number (32-bit real, 32-bit imaginary) channel in place image multiplication, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMul_32sc_C1IRSfs(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiMul_32sc_C1IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMul_32sc_C1IRSfsNative(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 32-bit signed integer complex number (32-bit real, 32-bit imaginary) channel image multiplication, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMul_32sc_C3RSfs(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiMul_32sc_C3RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMul_32sc_C3RSfsNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 32-bit signed integer complex number (32-bit real, 32-bit imaginary) channel in place image multiplication, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMul_32sc_C3IRSfs(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiMul_32sc_C3IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMul_32sc_C3IRSfsNative(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 32-bit signed integer complex number (32-bit real, 32-bit imaginary) channel with unmodified alpha image multiplication, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMul_32sc_AC4RSfs(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiMul_32sc_AC4RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMul_32sc_AC4RSfsNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 32-bit signed integer complex number (32-bit real, 32-bit imaginary) channel with unmodified alpha in place image multiplication, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMul_32sc_AC4IRSfs(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiMul_32sc_AC4IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMul_32sc_AC4IRSfsNative(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 32-bit floating point channel image multiplication.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMul_32f_C1R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiMul_32f_C1RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiMul_32f_C1RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 32-bit floating point channel in place image multiplication.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMul_32f_C1IR(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiMul_32f_C1IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiMul_32f_C1IRNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 32-bit floating point channel image multiplication.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMul_32f_C3R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiMul_32f_C3RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiMul_32f_C3RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 32-bit floating point channel in place image multiplication.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMul_32f_C3IR(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiMul_32f_C3IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiMul_32f_C3IRNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit floating point channel with unmodified alpha image multiplication.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMul_32f_AC4R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiMul_32f_AC4RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiMul_32f_AC4RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit floating point channel with unmodified alpha in place image multiplication.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMul_32f_AC4IR(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiMul_32f_AC4IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiMul_32f_AC4IRNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit floating point channel image multiplication.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMul_32f_C4R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiMul_32f_C4RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiMul_32f_C4RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit floating point channel in place image multiplication.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMul_32f_C4IR(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiMul_32f_C4IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiMul_32f_C4IRNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 32-bit floating point complex number (32-bit real, 32-bit imaginary) channel image multiplication.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMul_32fc_C1R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiMul_32fc_C1RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiMul_32fc_C1RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 32-bit floating point complex number (32-bit real, 32-bit imaginary) channel in place image multiplication.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMul_32fc_C1IR(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiMul_32fc_C1IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiMul_32fc_C1IRNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 32-bit floating point complex number (32-bit real, 32-bit imaginary) channel image multiplication.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMul_32fc_C3R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiMul_32fc_C3RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiMul_32fc_C3RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 32-bit floating point complex number (32-bit real, 32-bit imaginary) channel in place image multiplication.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMul_32fc_C3IR(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiMul_32fc_C3IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiMul_32fc_C3IRNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit floating point complex number (32-bit real, 32-bit imaginary) channel with unmodified alpha image multiplication.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMul_32fc_AC4R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiMul_32fc_AC4RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiMul_32fc_AC4RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit floating point complex number (32-bit real, 32-bit imaginary) channel with unmodified alpha in place image multiplication.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMul_32fc_AC4IR(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiMul_32fc_AC4IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiMul_32fc_AC4IRNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit floating point complex number (32-bit real, 32-bit imaginary) channel image multiplication.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMul_32fc_C4R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiMul_32fc_C4RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiMul_32fc_C4RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit floating point complex number (32-bit real, 32-bit imaginary) channel in place image multiplication.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMul_32fc_C4IR(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiMul_32fc_C4IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiMul_32fc_C4IRNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 8-bit unsigned char channel image multiplication then scale by maximum value for pixel bit width.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulScale_8u_C1R(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiMulScale_8u_C1RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiMulScale_8u_C1RNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 8-bit unsigned char channel in place image multiplication then scale by maximum value for pixel bit width.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulScale_8u_C1IR(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiMulScale_8u_C1IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiMulScale_8u_C1IRNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 8-bit unsigned char channel image multiplication then scale by maximum value for pixel bit width.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulScale_8u_C3R(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiMulScale_8u_C3RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiMulScale_8u_C3RNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 8-bit unsigned char channel in place image multiplication then scale by maximum value for pixel bit width.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulScale_8u_C3IR(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiMulScale_8u_C3IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiMulScale_8u_C3IRNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 8-bit unsigned char channel with unmodified alpha image multiplication then scale by maximum value for pixel bit width.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulScale_8u_AC4R(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiMulScale_8u_AC4RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiMulScale_8u_AC4RNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 8-bit unsigned char channel with unmodified alpha in place image multiplication then scale by maximum value for pixel bit width.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulScale_8u_AC4IR(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiMulScale_8u_AC4IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiMulScale_8u_AC4IRNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 8-bit unsigned char channel image multiplication then scale by maximum value for pixel bit width.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulScale_8u_C4R(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiMulScale_8u_C4RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiMulScale_8u_C4RNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 8-bit unsigned char channel in place image multiplication then scale by maximum value for pixel bit width.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulScale_8u_C4IR(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiMulScale_8u_C4IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiMulScale_8u_C4IRNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 16-bit unsigned short channel image multiplication then scale by maximum value for pixel bit width.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulScale_16u_C1R(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiMulScale_16u_C1RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiMulScale_16u_C1RNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 16-bit unsigned short channel in place image multiplication then scale by maximum value for pixel bit width.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulScale_16u_C1IR(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiMulScale_16u_C1IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiMulScale_16u_C1IRNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 16-bit unsigned short channel image multiplication then scale by maximum value for pixel bit width.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulScale_16u_C3R(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiMulScale_16u_C3RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiMulScale_16u_C3RNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 16-bit unsigned short channel in place image multiplication then scale by maximum value for pixel bit width.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulScale_16u_C3IR(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiMulScale_16u_C3IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiMulScale_16u_C3IRNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 16-bit unsigned short channel with unmodified alpha image multiplication then scale by maximum value for pixel bit width.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulScale_16u_AC4R(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiMulScale_16u_AC4RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiMulScale_16u_AC4RNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 16-bit unsigned short channel with unmodified alpha in place image multiplication then scale by maximum value for pixel bit width.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulScale_16u_AC4IR(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiMulScale_16u_AC4IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiMulScale_16u_AC4IRNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 16-bit unsigned short channel image multiplication then scale by maximum value for pixel bit width.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulScale_16u_C4R(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiMulScale_16u_C4RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiMulScale_16u_C4RNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 16-bit unsigned short channel in place image multiplication then scale by maximum value for pixel bit width.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulScale_16u_C4IR(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiMulScale_16u_C4IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiMulScale_16u_C4IRNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 8-bit unsigned char channel image subtraction, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSub_8u_C1RSfs(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiSub_8u_C1RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSub_8u_C1RSfsNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 8-bit unsigned char channel in place image subtraction, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSub_8u_C1IRSfs(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiSub_8u_C1IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSub_8u_C1IRSfsNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 8-bit unsigned char channel image subtraction, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSub_8u_C3RSfs(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiSub_8u_C3RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSub_8u_C3RSfsNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 8-bit unsigned char channel in place image subtraction, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSub_8u_C3IRSfs(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiSub_8u_C3IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSub_8u_C3IRSfsNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 8-bit unsigned char channel with unmodified alpha image subtraction, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSub_8u_AC4RSfs(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiSub_8u_AC4RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSub_8u_AC4RSfsNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 8-bit unsigned char channel with unmodified alpha in place image subtraction, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSub_8u_AC4IRSfs(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiSub_8u_AC4IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSub_8u_AC4IRSfsNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 8-bit unsigned char channel image subtraction, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSub_8u_C4RSfs(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiSub_8u_C4RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSub_8u_C4RSfsNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 8-bit unsigned char channel in place image subtraction, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSub_8u_C4IRSfs(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiSub_8u_C4IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSub_8u_C4IRSfsNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit unsigned short channel image subtraction, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSub_16u_C1RSfs(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiSub_16u_C1RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSub_16u_C1RSfsNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit unsigned short channel in place image subtraction, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSub_16u_C1IRSfs(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiSub_16u_C1IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSub_16u_C1IRSfsNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 16-bit unsigned short channel image subtraction, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSub_16u_C3RSfs(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiSub_16u_C3RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSub_16u_C3RSfsNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit unsigned short channel in place image subtraction, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSub_16u_C3IRSfs(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiSub_16u_C3IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSub_16u_C3IRSfsNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit unsigned short channel with unmodified alpha image subtraction, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSub_16u_AC4RSfs(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiSub_16u_AC4RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSub_16u_AC4RSfsNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit unsigned short channel with unmodified alpha in place image subtraction, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSub_16u_AC4IRSfs(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiSub_16u_AC4IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSub_16u_AC4IRSfsNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit unsigned short channel image subtraction, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSub_16u_C4RSfs(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiSub_16u_C4RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSub_16u_C4RSfsNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit unsigned short channel in place image subtraction, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSub_16u_C4IRSfs(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiSub_16u_C4IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSub_16u_C4IRSfsNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit signed short channel image subtraction, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSub_16s_C1RSfs(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiSub_16s_C1RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSub_16s_C1RSfsNative(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit signed short channel in place image subtraction, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSub_16s_C1IRSfs(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiSub_16s_C1IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSub_16s_C1IRSfsNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 16-bit signed short channel image subtraction, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSub_16s_C3RSfs(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiSub_16s_C3RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSub_16s_C3RSfsNative(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit signed short channel in place image subtraction, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSub_16s_C3IRSfs(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiSub_16s_C3IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSub_16s_C3IRSfsNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit signed short channel with unmodified alpha image subtraction, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSub_16s_AC4RSfs(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiSub_16s_AC4RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSub_16s_AC4RSfsNative(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit signed short channel with unmodified alpha in place image subtraction, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSub_16s_AC4IRSfs(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiSub_16s_AC4IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSub_16s_AC4IRSfsNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit signed short channel image subtraction, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSub_16s_C4RSfs(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiSub_16s_C4RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSub_16s_C4RSfsNative(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit signed short channel in place image subtraction, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSub_16s_C4IRSfs(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiSub_16s_C4IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSub_16s_C4IRSfsNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit signed short complex number (16-bit real, 16-bit imaginary) channel image subtraction, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSub_16sc_C1RSfs(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiSub_16sc_C1RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSub_16sc_C1RSfsNative(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit signed short complex number (16-bit real, 16-bit imaginary) channel in place image subtraction, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSub_16sc_C1IRSfs(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiSub_16sc_C1IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSub_16sc_C1IRSfsNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 16-bit signed short complex number (16-bit real, 16-bit imaginary) channel image subtraction, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSub_16sc_C3RSfs(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiSub_16sc_C3RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSub_16sc_C3RSfsNative(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit signed short complex number (16-bit real, 16-bit imaginary) channel in place image subtraction, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSub_16sc_C3IRSfs(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiSub_16sc_C3IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSub_16sc_C3IRSfsNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit signed short complex number (16-bit real, 16-bit imaginary) channel with unmodified alpha image subtraction, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSub_16sc_AC4RSfs(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiSub_16sc_AC4RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSub_16sc_AC4RSfsNative(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit signed short complex number (16-bit real, 16-bit imaginary) channel with unmodified alpha in place image subtraction, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSub_16sc_AC4IRSfs(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiSub_16sc_AC4IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSub_16sc_AC4IRSfsNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 32-bit signed integer channel image subtraction, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSub_32s_C1RSfs(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiSub_32s_C1RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSub_32s_C1RSfsNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Note: This function is to be deprecated in future NPP releases, use the function above with a scale factor of 0 instead. 
     * 32-bit image subtraction.
     * Subtract pSrc1's pixels from corresponding pixels in pSrc2. 
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSub_32s_C1R(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiSub_32s_C1RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiSub_32s_C1RNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 32-bit signed integer channel in place image subtraction, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSub_32s_C1IRSfs(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiSub_32s_C1IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSub_32s_C1IRSfsNative(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 32-bit signed integer channel image subtraction, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSub_32s_C3RSfs(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiSub_32s_C3RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSub_32s_C3RSfsNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 32-bit signed integer channel in place image subtraction, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSub_32s_C3IRSfs(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiSub_32s_C3IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSub_32s_C3IRSfsNative(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 32-bit signed integer channel image subtraction, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSub_32s_C4RSfs(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiSub_32s_C4RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSub_32s_C4RSfsNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 32-bit signed integer channel in place image subtraction, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSub_32s_C4IRSfs(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiSub_32s_C4IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSub_32s_C4IRSfsNative(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 32-bit signed integer complex number (32-bit real, 32-bit imaginary) channel image subtraction, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSub_32sc_C1RSfs(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiSub_32sc_C1RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSub_32sc_C1RSfsNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 32-bit signed integer complex number (32-bit real, 32-bit imaginary) channel in place image subtraction, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSub_32sc_C1IRSfs(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiSub_32sc_C1IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSub_32sc_C1IRSfsNative(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 32-bit signed integer complex number (32-bit real, 32-bit imaginary) channel image subtraction, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSub_32sc_C3RSfs(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiSub_32sc_C3RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSub_32sc_C3RSfsNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 32-bit signed integer complex number (32-bit real, 32-bit imaginary) channel in place image subtraction, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSub_32sc_C3IRSfs(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiSub_32sc_C3IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSub_32sc_C3IRSfsNative(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 32-bit signed integer complex number (32-bit real, 32-bit imaginary) channel with unmodified alpha image subtraction, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSub_32sc_AC4RSfs(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiSub_32sc_AC4RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSub_32sc_AC4RSfsNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 32-bit signed integer complex number (32-bit real, 32-bit imaginary) channel with unmodified alpha in place image subtraction, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSub_32sc_AC4IRSfs(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiSub_32sc_AC4IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSub_32sc_AC4IRSfsNative(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 32-bit floating point channel image subtraction.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSub_32f_C1R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiSub_32f_C1RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiSub_32f_C1RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 32-bit floating point channel in place image subtraction.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSub_32f_C1IR(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiSub_32f_C1IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiSub_32f_C1IRNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 32-bit floating point channel image subtraction.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSub_32f_C3R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiSub_32f_C3RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiSub_32f_C3RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 32-bit floating point channel in place image subtraction.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSub_32f_C3IR(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiSub_32f_C3IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiSub_32f_C3IRNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit floating point channel with unmodified alpha image subtraction.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSub_32f_AC4R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiSub_32f_AC4RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiSub_32f_AC4RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit floating point channel with unmodified alpha in place image subtraction.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSub_32f_AC4IR(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiSub_32f_AC4IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiSub_32f_AC4IRNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit floating point channel image subtraction.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSub_32f_C4R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiSub_32f_C4RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiSub_32f_C4RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit floating point channel in place image subtraction.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSub_32f_C4IR(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiSub_32f_C4IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiSub_32f_C4IRNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 32-bit floating point complex number (32-bit real, 32-bit imaginary) channel image subtraction.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSub_32fc_C1R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiSub_32fc_C1RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiSub_32fc_C1RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 32-bit floating point complex number (32-bit real, 32-bit imaginary) channel in place image subtraction.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSub_32fc_C1IR(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiSub_32fc_C1IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiSub_32fc_C1IRNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 32-bit floating point complex number (32-bit real, 32-bit imaginary) channel image subtraction.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSub_32fc_C3R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiSub_32fc_C3RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiSub_32fc_C3RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 32-bit floating point complex number (32-bit real, 32-bit imaginary) channel in place image subtraction.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSub_32fc_C3IR(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiSub_32fc_C3IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiSub_32fc_C3IRNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit floating point complex number (32-bit real, 32-bit imaginary) channel with unmodified alpha image subtraction.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSub_32fc_AC4R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiSub_32fc_AC4RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiSub_32fc_AC4RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit floating point complex number (32-bit real, 32-bit imaginary) channel with unmodified alpha in place image subtraction.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSub_32fc_AC4IR(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiSub_32fc_AC4IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiSub_32fc_AC4IRNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit floating point complex number (32-bit real, 32-bit imaginary) channel image subtraction.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSub_32fc_C4R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiSub_32fc_C4RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiSub_32fc_C4RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit floating point complex number (32-bit real, 32-bit imaginary) channel in place image subtraction.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSub_32fc_C4IR(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiSub_32fc_C4IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiSub_32fc_C4IRNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 8-bit unsigned char channel image division, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_8u_C1RSfs(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiDiv_8u_C1RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDiv_8u_C1RSfsNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 8-bit unsigned char channel in place image division, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_8u_C1IRSfs(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiDiv_8u_C1IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDiv_8u_C1IRSfsNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 8-bit unsigned char channel image division, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_8u_C3RSfs(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiDiv_8u_C3RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDiv_8u_C3RSfsNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 8-bit unsigned char channel in place image division, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_8u_C3IRSfs(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiDiv_8u_C3IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDiv_8u_C3IRSfsNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 8-bit unsigned char channel with unmodified alpha image division, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_8u_AC4RSfs(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiDiv_8u_AC4RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDiv_8u_AC4RSfsNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 8-bit unsigned char channel with unmodified alpha in place image division, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_8u_AC4IRSfs(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiDiv_8u_AC4IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDiv_8u_AC4IRSfsNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 8-bit unsigned char channel image division, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_8u_C4RSfs(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiDiv_8u_C4RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDiv_8u_C4RSfsNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 8-bit unsigned char channel in place image division, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_8u_C4IRSfs(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiDiv_8u_C4IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDiv_8u_C4IRSfsNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit unsigned short channel image division, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_16u_C1RSfs(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiDiv_16u_C1RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDiv_16u_C1RSfsNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit unsigned short channel in place image division, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_16u_C1IRSfs(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiDiv_16u_C1IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDiv_16u_C1IRSfsNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 16-bit unsigned short channel image division, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_16u_C3RSfs(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiDiv_16u_C3RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDiv_16u_C3RSfsNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit unsigned short channel in place image division, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_16u_C3IRSfs(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiDiv_16u_C3IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDiv_16u_C3IRSfsNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit unsigned short channel with unmodified alpha image division, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_16u_AC4RSfs(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiDiv_16u_AC4RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDiv_16u_AC4RSfsNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit unsigned short channel with unmodified alpha in place image division, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_16u_AC4IRSfs(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiDiv_16u_AC4IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDiv_16u_AC4IRSfsNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit unsigned short channel image division, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_16u_C4RSfs(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiDiv_16u_C4RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDiv_16u_C4RSfsNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit unsigned short channel in place image division, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_16u_C4IRSfs(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiDiv_16u_C4IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDiv_16u_C4IRSfsNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit signed short channel image division, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_16s_C1RSfs(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiDiv_16s_C1RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDiv_16s_C1RSfsNative(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit signed short channel in place image division, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_16s_C1IRSfs(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiDiv_16s_C1IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDiv_16s_C1IRSfsNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 16-bit signed short channel image division, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_16s_C3RSfs(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiDiv_16s_C3RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDiv_16s_C3RSfsNative(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit signed short channel in place image division, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_16s_C3IRSfs(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiDiv_16s_C3IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDiv_16s_C3IRSfsNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit signed short channel with unmodified alpha image division, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_16s_AC4RSfs(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiDiv_16s_AC4RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDiv_16s_AC4RSfsNative(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit signed short channel with unmodified alpha in place image division, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_16s_AC4IRSfs(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiDiv_16s_AC4IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDiv_16s_AC4IRSfsNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit signed short channel image division, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_16s_C4RSfs(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiDiv_16s_C4RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDiv_16s_C4RSfsNative(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit signed short channel in place image division, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_16s_C4IRSfs(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiDiv_16s_C4IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDiv_16s_C4IRSfsNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit signed short complex number (16-bit real, 16-bit imaginary) channel image division, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_16sc_C1RSfs(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiDiv_16sc_C1RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDiv_16sc_C1RSfsNative(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit signed short complex number (16-bit real, 16-bit imaginary) channel in place image division, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_16sc_C1IRSfs(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiDiv_16sc_C1IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDiv_16sc_C1IRSfsNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 16-bit signed short complex number (16-bit real, 16-bit imaginary) channel image division, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_16sc_C3RSfs(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiDiv_16sc_C3RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDiv_16sc_C3RSfsNative(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit signed short complex number (16-bit real, 16-bit imaginary) channel in place image division, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_16sc_C3IRSfs(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiDiv_16sc_C3IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDiv_16sc_C3IRSfsNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit signed short complex number (16-bit real, 16-bit imaginary) channel with unmodified alpha image division, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_16sc_AC4RSfs(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiDiv_16sc_AC4RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDiv_16sc_AC4RSfsNative(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit signed short complex number (16-bit real, 16-bit imaginary) channel with unmodified alpha in place image division, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_16sc_AC4IRSfs(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiDiv_16sc_AC4IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDiv_16sc_AC4IRSfsNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 32-bit signed integer channel image division, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_32s_C1RSfs(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiDiv_32s_C1RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDiv_32s_C1RSfsNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Note: This function is to be deprecated in future NPP releases, use the function above with a scale factor of 0 instead. 
     * 32-bit image division.
     * Divide pixels in pSrc2 by pSrc1's pixels. 
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_32s_C1R(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiDiv_32s_C1RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiDiv_32s_C1RNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 32-bit signed integer channel in place image division, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_32s_C1IRSfs(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiDiv_32s_C1IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDiv_32s_C1IRSfsNative(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 32-bit signed integer channel image division, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_32s_C3RSfs(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiDiv_32s_C3RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDiv_32s_C3RSfsNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 32-bit signed integer channel in place image division, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_32s_C3IRSfs(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiDiv_32s_C3IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDiv_32s_C3IRSfsNative(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 32-bit signed integer complex number (32-bit real, 32-bit imaginary) channel image division, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_32sc_C1RSfs(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiDiv_32sc_C1RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDiv_32sc_C1RSfsNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 32-bit signed integer complex number (32-bit real, 32-bit imaginary) channel in place image division, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_32sc_C1IRSfs(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiDiv_32sc_C1IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDiv_32sc_C1IRSfsNative(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 32-bit signed integer complex number (32-bit real, 32-bit imaginary) channel image division, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_32sc_C3RSfs(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiDiv_32sc_C3RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDiv_32sc_C3RSfsNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 32-bit signed integer complex number (32-bit real, 32-bit imaginary) channel in place image division, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_32sc_C3IRSfs(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiDiv_32sc_C3IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDiv_32sc_C3IRSfsNative(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 32-bit signed integer complex number (32-bit real, 32-bit imaginary) channel with unmodified alpha image division, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_32sc_AC4RSfs(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiDiv_32sc_AC4RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDiv_32sc_AC4RSfsNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 32-bit signed integer complex number (32-bit real, 32-bit imaginary) channel with unmodified alpha in place image division, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_32sc_AC4IRSfs(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiDiv_32sc_AC4IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDiv_32sc_AC4IRSfsNative(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 32-bit floating point channel image division.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_32f_C1R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiDiv_32f_C1RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiDiv_32f_C1RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 32-bit floating point channel in place image division.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_32f_C1IR(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiDiv_32f_C1IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiDiv_32f_C1IRNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 32-bit floating point channel image division.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_32f_C3R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiDiv_32f_C3RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiDiv_32f_C3RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 32-bit floating point channel in place image division.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_32f_C3IR(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiDiv_32f_C3IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiDiv_32f_C3IRNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit floating point channel with unmodified alpha image division.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_32f_AC4R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiDiv_32f_AC4RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiDiv_32f_AC4RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit floating point channel with unmodified alpha in place image division.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_32f_AC4IR(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiDiv_32f_AC4IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiDiv_32f_AC4IRNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit floating point channel image division.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_32f_C4R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiDiv_32f_C4RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiDiv_32f_C4RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit floating point channel in place image division.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_32f_C4IR(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiDiv_32f_C4IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiDiv_32f_C4IRNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 32-bit floating point complex number (32-bit real, 32-bit imaginary) channel image division.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_32fc_C1R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiDiv_32fc_C1RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiDiv_32fc_C1RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 32-bit floating point complex number (32-bit real, 32-bit imaginary) channel in place image division.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_32fc_C1IR(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiDiv_32fc_C1IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiDiv_32fc_C1IRNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 32-bit floating point complex number (32-bit real, 32-bit imaginary) channel image division.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_32fc_C3R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiDiv_32fc_C3RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiDiv_32fc_C3RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 32-bit floating point complex number (32-bit real, 32-bit imaginary) channel in place image division.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_32fc_C3IR(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiDiv_32fc_C3IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiDiv_32fc_C3IRNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit floating point complex number (32-bit real, 32-bit imaginary) channel with unmodified alpha image division.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_32fc_AC4R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiDiv_32fc_AC4RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiDiv_32fc_AC4RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit floating point complex number (32-bit real, 32-bit imaginary) channel with unmodified alpha in place image division.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_32fc_AC4IR(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiDiv_32fc_AC4IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiDiv_32fc_AC4IRNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit floating point complex number (32-bit real, 32-bit imaginary) channel image division.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_32fc_C4R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiDiv_32fc_C4RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiDiv_32fc_C4RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit floating point complex number (32-bit real, 32-bit imaginary) channel in place image division.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_32fc_C4IR(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiDiv_32fc_C4IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiDiv_32fc_C4IRNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /** @} image_div */
    /**
     * <pre>
     * @defgroup image_divround Div_Round
     *
     * Pixel by pixel division of two images using result rounding modes.
     *
     * @{
     * </pre>
     */
    /**
     * <pre>
     * One 8-bit unsigned char channel image division, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param rndMode Result Rounding mode to be used (NPP_RND_ZERO, NPP_RND_NEAR, or NP_RND_FINANCIAL)
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_Round_8u_C1RSfs(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int rndMode, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiDiv_Round_8u_C1RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, rndMode, nScaleFactor));
    }
    private static native int nppiDiv_Round_8u_C1RSfsNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int rndMode, 
        int nScaleFactor);


    /**
     * <pre>
     * One 8-bit unsigned char channel in place image division, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param rndMode Result Rounding mode to be used (NPP_RND_ZERO, NPP_RND_NEAR, or NP_RND_FINANCIAL)
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_Round_8u_C1IRSfs(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int rndMode, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiDiv_Round_8u_C1IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, rndMode, nScaleFactor));
    }
    private static native int nppiDiv_Round_8u_C1IRSfsNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int rndMode, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 8-bit unsigned char channel image division, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param rndMode Result Rounding mode to be used (NPP_RND_ZERO, NPP_RND_NEAR, or NP_RND_FINANCIAL)
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_Round_8u_C3RSfs(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int rndMode, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiDiv_Round_8u_C3RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, rndMode, nScaleFactor));
    }
    private static native int nppiDiv_Round_8u_C3RSfsNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int rndMode, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 8-bit unsigned char channel in place image division, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param rndMode Result Rounding mode to be used (NPP_RND_ZERO, NPP_RND_NEAR, or NP_RND_FINANCIAL)
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_Round_8u_C3IRSfs(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int rndMode, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiDiv_Round_8u_C3IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, rndMode, nScaleFactor));
    }
    private static native int nppiDiv_Round_8u_C3IRSfsNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int rndMode, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 8-bit unsigned char channel image division with unmodified alpha, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param rndMode Result Rounding mode to be used (NPP_RND_ZERO, NPP_RND_NEAR, or NP_RND_FINANCIAL)
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_Round_8u_AC4RSfs(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int rndMode, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiDiv_Round_8u_AC4RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, rndMode, nScaleFactor));
    }
    private static native int nppiDiv_Round_8u_AC4RSfsNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int rndMode, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 8-bit unsigned char channel in place image division with unmodified alpha, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param rndMode Result Rounding mode to be used (NPP_RND_ZERO, NPP_RND_NEAR, or NP_RND_FINANCIAL)
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_Round_8u_AC4IRSfs(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int rndMode, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiDiv_Round_8u_AC4IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, rndMode, nScaleFactor));
    }
    private static native int nppiDiv_Round_8u_AC4IRSfsNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int rndMode, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 8-bit unsigned char channel image division, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param rndMode Result Rounding mode to be used (NPP_RND_ZERO, NPP_RND_NEAR, or NP_RND_FINANCIAL)
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_Round_8u_C4RSfs(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int rndMode, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiDiv_Round_8u_C4RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, rndMode, nScaleFactor));
    }
    private static native int nppiDiv_Round_8u_C4RSfsNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int rndMode, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 8-bit unsigned char channel in place image division, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param rndMode Result Rounding mode to be used (NPP_RND_ZERO, NPP_RND_NEAR, or NP_RND_FINANCIAL)
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_Round_8u_C4IRSfs(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int rndMode, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiDiv_Round_8u_C4IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, rndMode, nScaleFactor));
    }
    private static native int nppiDiv_Round_8u_C4IRSfsNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int rndMode, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit unsigned short channel image division, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param rndMode Result Rounding mode to be used (NPP_RND_ZERO, NPP_RND_NEAR, or NP_RND_FINANCIAL)
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_Round_16u_C1RSfs(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int rndMode, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiDiv_Round_16u_C1RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, rndMode, nScaleFactor));
    }
    private static native int nppiDiv_Round_16u_C1RSfsNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int rndMode, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit unsigned short channel in place image division, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param rndMode Result Rounding mode to be used (NPP_RND_ZERO, NPP_RND_NEAR, or NP_RND_FINANCIAL)
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_Round_16u_C1IRSfs(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int rndMode, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiDiv_Round_16u_C1IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, rndMode, nScaleFactor));
    }
    private static native int nppiDiv_Round_16u_C1IRSfsNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int rndMode, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 16-bit unsigned short channel image division, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param rndMode Result Rounding mode to be used (NPP_RND_ZERO, NPP_RND_NEAR, or NP_RND_FINANCIAL)
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_Round_16u_C3RSfs(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int rndMode, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiDiv_Round_16u_C3RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, rndMode, nScaleFactor));
    }
    private static native int nppiDiv_Round_16u_C3RSfsNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int rndMode, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 16-bit unsigned short channel in place image division, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param rndMode Result Rounding mode to be used (NPP_RND_ZERO, NPP_RND_NEAR, or NP_RND_FINANCIAL)
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_Round_16u_C3IRSfs(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int rndMode, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiDiv_Round_16u_C3IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, rndMode, nScaleFactor));
    }
    private static native int nppiDiv_Round_16u_C3IRSfsNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int rndMode, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit unsigned short channel image division with unmodified alpha, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param rndMode Result Rounding mode to be used (NPP_RND_ZERO, NPP_RND_NEAR, or NP_RND_FINANCIAL)
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_Round_16u_AC4RSfs(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int rndMode, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiDiv_Round_16u_AC4RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, rndMode, nScaleFactor));
    }
    private static native int nppiDiv_Round_16u_AC4RSfsNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int rndMode, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit unsigned short channel in place image division with unmodified alpha, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param rndMode Result Rounding mode to be used (NPP_RND_ZERO, NPP_RND_NEAR, or NP_RND_FINANCIAL)
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_Round_16u_AC4IRSfs(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int rndMode, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiDiv_Round_16u_AC4IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, rndMode, nScaleFactor));
    }
    private static native int nppiDiv_Round_16u_AC4IRSfsNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int rndMode, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit unsigned short channel image division, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param rndMode Result Rounding mode to be used (NPP_RND_ZERO, NPP_RND_NEAR, or NP_RND_FINANCIAL)
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_Round_16u_C4RSfs(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int rndMode, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiDiv_Round_16u_C4RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, rndMode, nScaleFactor));
    }
    private static native int nppiDiv_Round_16u_C4RSfsNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int rndMode, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit unsigned short channel in place image division, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param rndMode Result Rounding mode to be used (NPP_RND_ZERO, NPP_RND_NEAR, or NP_RND_FINANCIAL)
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_Round_16u_C4IRSfs(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int rndMode, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiDiv_Round_16u_C4IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, rndMode, nScaleFactor));
    }
    private static native int nppiDiv_Round_16u_C4IRSfsNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int rndMode, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit signed short channel image division, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param rndMode Result Rounding mode to be used (NPP_RND_ZERO, NPP_RND_NEAR, or NP_RND_FINANCIAL)
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_Round_16s_C1RSfs(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int rndMode, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiDiv_Round_16s_C1RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, rndMode, nScaleFactor));
    }
    private static native int nppiDiv_Round_16s_C1RSfsNative(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int rndMode, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit signed short channel in place image division, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param rndMode Result Rounding mode to be used (NPP_RND_ZERO, NPP_RND_NEAR, or NP_RND_FINANCIAL)
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_Round_16s_C1IRSfs(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int rndMode, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiDiv_Round_16s_C1IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, rndMode, nScaleFactor));
    }
    private static native int nppiDiv_Round_16s_C1IRSfsNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int rndMode, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 16-bit signed short channel image division, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param rndMode Result Rounding mode to be used (NPP_RND_ZERO, NPP_RND_NEAR, or NP_RND_FINANCIAL)
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_Round_16s_C3RSfs(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int rndMode, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiDiv_Round_16s_C3RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, rndMode, nScaleFactor));
    }
    private static native int nppiDiv_Round_16s_C3RSfsNative(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int rndMode, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 16-bit signed short channel in place image division, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param rndMode Result Rounding mode to be used (NPP_RND_ZERO, NPP_RND_NEAR, or NP_RND_FINANCIAL)
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_Round_16s_C3IRSfs(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int rndMode, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiDiv_Round_16s_C3IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, rndMode, nScaleFactor));
    }
    private static native int nppiDiv_Round_16s_C3IRSfsNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int rndMode, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit signed short channel image division with unmodified alpha, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param rndMode Result Rounding mode to be used (NPP_RND_ZERO, NPP_RND_NEAR, or NP_RND_FINANCIAL)
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_Round_16s_AC4RSfs(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int rndMode, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiDiv_Round_16s_AC4RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, rndMode, nScaleFactor));
    }
    private static native int nppiDiv_Round_16s_AC4RSfsNative(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int rndMode, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit signed short channel in place image division with unmodified alpha, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param rndMode Result Rounding mode to be used (NPP_RND_ZERO, NPP_RND_NEAR, or NP_RND_FINANCIAL)
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_Round_16s_AC4IRSfs(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int rndMode, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiDiv_Round_16s_AC4IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, rndMode, nScaleFactor));
    }
    private static native int nppiDiv_Round_16s_AC4IRSfsNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int rndMode, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit signed short channel image division, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param rndMode Result Rounding mode to be used (NPP_RND_ZERO, NPP_RND_NEAR, or NP_RND_FINANCIAL)
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_Round_16s_C4RSfs(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int rndMode, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiDiv_Round_16s_C4RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, rndMode, nScaleFactor));
    }
    private static native int nppiDiv_Round_16s_C4RSfsNative(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int rndMode, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit signed short channel in place image division, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param rndMode Result Rounding mode to be used (NPP_RND_ZERO, NPP_RND_NEAR, or NP_RND_FINANCIAL)
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_Round_16s_C4IRSfs(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int rndMode, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiDiv_Round_16s_C4IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, rndMode, nScaleFactor));
    }
    private static native int nppiDiv_Round_16s_C4IRSfsNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int rndMode, 
        int nScaleFactor);


    /** @} image_divround */
    /**
     * <pre>
     * @defgroup image_abs Abs
     *
     * Absolute value of each pixel value in an image.
     *
     * @{
     * </pre>
     */
    /**
     * <pre>
     * One 16-bit signed short channel image absolute value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAbs_16s_C1R(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiAbs_16s_C1RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiAbs_16s_C1RNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 16-bit signed short channel in place image absolute value.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAbs_16s_C1IR(
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiAbs_16s_C1IRNative(pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiAbs_16s_C1IRNative(
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 16-bit signed short channel image absolute value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAbs_16s_C3R(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiAbs_16s_C3RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiAbs_16s_C3RNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 16-bit signed short channel in place image absolute value.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAbs_16s_C3IR(
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiAbs_16s_C3IRNative(pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiAbs_16s_C3IRNative(
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 16-bit signed short channel image absolute value with unmodified alpha.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAbs_16s_AC4R(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiAbs_16s_AC4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiAbs_16s_AC4RNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 16-bit signed short channel in place image absolute value with unmodified alpha.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAbs_16s_AC4IR(
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiAbs_16s_AC4IRNative(pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiAbs_16s_AC4IRNative(
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 16-bit signed short channel image absolute value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAbs_16s_C4R(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiAbs_16s_C4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiAbs_16s_C4RNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 16-bit signed short channel in place image absolute value.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAbs_16s_C4IR(
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiAbs_16s_C4IRNative(pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiAbs_16s_C4IRNative(
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 32-bit floating point channel image absolute value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAbs_32f_C1R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiAbs_32f_C1RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiAbs_32f_C1RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 32-bit floating point channel in place image absolute value.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAbs_32f_C1IR(
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiAbs_32f_C1IRNative(pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiAbs_32f_C1IRNative(
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 32-bit floating point channel image absolute value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAbs_32f_C3R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiAbs_32f_C3RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiAbs_32f_C3RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 32-bit floating point channel in place image absolute value.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAbs_32f_C3IR(
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiAbs_32f_C3IRNative(pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiAbs_32f_C3IRNative(
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit floating point channel image absolute value with unmodified alpha.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAbs_32f_AC4R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiAbs_32f_AC4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiAbs_32f_AC4RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit floating point channel in place image absolute value with unmodified alpha.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAbs_32f_AC4IR(
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiAbs_32f_AC4IRNative(pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiAbs_32f_AC4IRNative(
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit floating point channel image absolute value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAbs_32f_C4R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiAbs_32f_C4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiAbs_32f_C4RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit floating point channel in place image absolute value.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAbs_32f_C4IR(
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiAbs_32f_C4IRNative(pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiAbs_32f_C4IRNative(
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /** @} image_abs */
    /**
     * <pre>
     * @defgroup image_absdiff AbsDiff
     *
     * Pixel by pixel absolute difference between two images.
     *
     * @{
     * </pre>
     */
    /**
     * <pre>
     * One 8-bit unsigned char channel absolute difference of image1 minus image2.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAbsDiff_8u_C1R(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiAbsDiff_8u_C1RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiAbsDiff_8u_C1RNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 8-bit unsigned char channels absolute difference of image1 minus image2.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAbsDiff_8u_C3R(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiAbsDiff_8u_C3RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiAbsDiff_8u_C3RNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 8-bit unsigned char channels absolute difference of image1 minus image2.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAbsDiff_8u_C4R(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiAbsDiff_8u_C4RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiAbsDiff_8u_C4RNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 16-bit unsigned short channel absolute difference of image1 minus image2.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAbsDiff_16u_C1R(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiAbsDiff_16u_C1RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiAbsDiff_16u_C1RNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 32-bit floating point channel absolute difference of image1 minus image2.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAbsDiff_32f_C1R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiAbsDiff_32f_C1RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiAbsDiff_32f_C1RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /** @} image_absdiff */
    /**
     * <pre>
     * @defgroup image_sqr Sqr
     *
     * Square each pixel in an image.
     *
     * @{
     * </pre>
     */
    /**
     * <pre>
     * One 8-bit unsigned char channel image squared, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSqr_8u_C1RSfs(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiSqr_8u_C1RSfsNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSqr_8u_C1RSfsNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 8-bit unsigned char channel in place image squared, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSqr_8u_C1IRSfs(
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiSqr_8u_C1IRSfsNative(pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSqr_8u_C1IRSfsNative(
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 8-bit unsigned char channel image squared, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSqr_8u_C3RSfs(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiSqr_8u_C3RSfsNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSqr_8u_C3RSfsNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 8-bit unsigned char channel in place image squared, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSqr_8u_C3IRSfs(
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiSqr_8u_C3IRSfsNative(pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSqr_8u_C3IRSfsNative(
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 8-bit unsigned char channel image squared with unmodified alpha, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSqr_8u_AC4RSfs(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiSqr_8u_AC4RSfsNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSqr_8u_AC4RSfsNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 8-bit unsigned char channel in place image squared with unmodified alpha, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSqr_8u_AC4IRSfs(
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiSqr_8u_AC4IRSfsNative(pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSqr_8u_AC4IRSfsNative(
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 8-bit unsigned char channel image squared, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSqr_8u_C4RSfs(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiSqr_8u_C4RSfsNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSqr_8u_C4RSfsNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 8-bit unsigned char channel in place image squared, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSqr_8u_C4IRSfs(
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiSqr_8u_C4IRSfsNative(pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSqr_8u_C4IRSfsNative(
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit unsigned short channel image squared, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSqr_16u_C1RSfs(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiSqr_16u_C1RSfsNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSqr_16u_C1RSfsNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit unsigned short channel in place image squared, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSqr_16u_C1IRSfs(
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiSqr_16u_C1IRSfsNative(pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSqr_16u_C1IRSfsNative(
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 16-bit unsigned short channel image squared, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSqr_16u_C3RSfs(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiSqr_16u_C3RSfsNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSqr_16u_C3RSfsNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 16-bit unsigned short channel in place image squared, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSqr_16u_C3IRSfs(
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiSqr_16u_C3IRSfsNative(pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSqr_16u_C3IRSfsNative(
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit unsigned short channel image squared with unmodified alpha, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSqr_16u_AC4RSfs(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiSqr_16u_AC4RSfsNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSqr_16u_AC4RSfsNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit unsigned short channel in place image squared with unmodified alpha, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSqr_16u_AC4IRSfs(
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiSqr_16u_AC4IRSfsNative(pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSqr_16u_AC4IRSfsNative(
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit unsigned short channel image squared, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSqr_16u_C4RSfs(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiSqr_16u_C4RSfsNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSqr_16u_C4RSfsNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit unsigned short channel in place image squared, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSqr_16u_C4IRSfs(
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiSqr_16u_C4IRSfsNative(pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSqr_16u_C4IRSfsNative(
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit signed short channel image squared, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSqr_16s_C1RSfs(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiSqr_16s_C1RSfsNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSqr_16s_C1RSfsNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit signed short channel in place image squared, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSqr_16s_C1IRSfs(
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiSqr_16s_C1IRSfsNative(pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSqr_16s_C1IRSfsNative(
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 16-bit signed short channel image squared, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSqr_16s_C3RSfs(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiSqr_16s_C3RSfsNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSqr_16s_C3RSfsNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 16-bit signed short channel in place image squared, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSqr_16s_C3IRSfs(
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiSqr_16s_C3IRSfsNative(pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSqr_16s_C3IRSfsNative(
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit signed short channel image squared with unmodified alpha, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSqr_16s_AC4RSfs(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiSqr_16s_AC4RSfsNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSqr_16s_AC4RSfsNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit signed short channel in place image squared with unmodified alpha, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSqr_16s_AC4IRSfs(
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiSqr_16s_AC4IRSfsNative(pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSqr_16s_AC4IRSfsNative(
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit signed short channel image squared, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSqr_16s_C4RSfs(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiSqr_16s_C4RSfsNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSqr_16s_C4RSfsNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit signed short channel in place image squared, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSqr_16s_C4IRSfs(
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiSqr_16s_C4IRSfsNative(pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSqr_16s_C4IRSfsNative(
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 32-bit floating point channel image squared.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSqr_32f_C1R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiSqr_32f_C1RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiSqr_32f_C1RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 32-bit floating point channel in place image squared.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSqr_32f_C1IR(
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiSqr_32f_C1IRNative(pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiSqr_32f_C1IRNative(
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 32-bit floating point channel image squared.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSqr_32f_C3R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiSqr_32f_C3RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiSqr_32f_C3RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 32-bit floating point channel in place image squared.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSqr_32f_C3IR(
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiSqr_32f_C3IRNative(pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiSqr_32f_C3IRNative(
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit floating point channel image squared with unmodified alpha.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSqr_32f_AC4R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiSqr_32f_AC4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiSqr_32f_AC4RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit floating point channel in place image squared with unmodified alpha.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSqr_32f_AC4IR(
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiSqr_32f_AC4IRNative(pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiSqr_32f_AC4IRNative(
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit floating point channel image squared.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSqr_32f_C4R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiSqr_32f_C4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiSqr_32f_C4RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit floating point channel in place image squared.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSqr_32f_C4IR(
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiSqr_32f_C4IRNative(pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiSqr_32f_C4IRNative(
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /** @} image_sqr */
    /**
     * <pre>
     * @defgroup image_sqrt Sqrt
     *
     * Pixel by pixel square root of each pixel in an image.
     *
     * @{
     * </pre>
     */
    /**
     * <pre>
     * One 8-bit unsigned char channel image square root, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSqrt_8u_C1RSfs(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiSqrt_8u_C1RSfsNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSqrt_8u_C1RSfsNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 8-bit unsigned char channel in place image square root, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSqrt_8u_C1IRSfs(
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiSqrt_8u_C1IRSfsNative(pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSqrt_8u_C1IRSfsNative(
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 8-bit unsigned char channel image square root, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSqrt_8u_C3RSfs(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiSqrt_8u_C3RSfsNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSqrt_8u_C3RSfsNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 8-bit unsigned char channel in place image square root, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSqrt_8u_C3IRSfs(
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiSqrt_8u_C3IRSfsNative(pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSqrt_8u_C3IRSfsNative(
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 8-bit unsigned char channel image square root with unmodified alpha, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSqrt_8u_AC4RSfs(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiSqrt_8u_AC4RSfsNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSqrt_8u_AC4RSfsNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 8-bit unsigned char channel in place image square root with unmodified alpha, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSqrt_8u_AC4IRSfs(
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiSqrt_8u_AC4IRSfsNative(pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSqrt_8u_AC4IRSfsNative(
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit unsigned short channel image square root, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSqrt_16u_C1RSfs(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiSqrt_16u_C1RSfsNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSqrt_16u_C1RSfsNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit unsigned short channel in place image square root, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSqrt_16u_C1IRSfs(
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiSqrt_16u_C1IRSfsNative(pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSqrt_16u_C1IRSfsNative(
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 16-bit unsigned short channel image square root, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSqrt_16u_C3RSfs(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiSqrt_16u_C3RSfsNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSqrt_16u_C3RSfsNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 16-bit unsigned short channel in place image square root, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSqrt_16u_C3IRSfs(
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiSqrt_16u_C3IRSfsNative(pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSqrt_16u_C3IRSfsNative(
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit unsigned short channel image square root with unmodified alpha, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSqrt_16u_AC4RSfs(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiSqrt_16u_AC4RSfsNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSqrt_16u_AC4RSfsNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit unsigned short channel in place image square root with unmodified alpha, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSqrt_16u_AC4IRSfs(
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiSqrt_16u_AC4IRSfsNative(pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSqrt_16u_AC4IRSfsNative(
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit signed short channel image square root, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSqrt_16s_C1RSfs(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiSqrt_16s_C1RSfsNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSqrt_16s_C1RSfsNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit signed short channel in place image square root, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSqrt_16s_C1IRSfs(
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiSqrt_16s_C1IRSfsNative(pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSqrt_16s_C1IRSfsNative(
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 16-bit signed short channel image square root, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSqrt_16s_C3RSfs(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiSqrt_16s_C3RSfsNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSqrt_16s_C3RSfsNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 16-bit signed short channel in place image square root, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSqrt_16s_C3IRSfs(
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiSqrt_16s_C3IRSfsNative(pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSqrt_16s_C3IRSfsNative(
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit signed short channel image square root with unmodified alpha, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSqrt_16s_AC4RSfs(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiSqrt_16s_AC4RSfsNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSqrt_16s_AC4RSfsNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit signed short channel in place image square root with unmodified alpha, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSqrt_16s_AC4IRSfs(
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiSqrt_16s_AC4IRSfsNative(pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSqrt_16s_AC4IRSfsNative(
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 32-bit floating point channel image square root.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSqrt_32f_C1R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiSqrt_32f_C1RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiSqrt_32f_C1RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 32-bit floating point channel in place image square root.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSqrt_32f_C1IR(
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiSqrt_32f_C1IRNative(pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiSqrt_32f_C1IRNative(
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 32-bit floating point channel image square root.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSqrt_32f_C3R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiSqrt_32f_C3RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiSqrt_32f_C3RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 32-bit floating point channel in place image square root.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSqrt_32f_C3IR(
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiSqrt_32f_C3IRNative(pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiSqrt_32f_C3IRNative(
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit floating point channel image square root with unmodified alpha.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSqrt_32f_AC4R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiSqrt_32f_AC4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiSqrt_32f_AC4RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit floating point channel in place image square root with unmodified alpha.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSqrt_32f_AC4IR(
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiSqrt_32f_AC4IRNative(pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiSqrt_32f_AC4IRNative(
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit floating point channel image square root.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSqrt_32f_C4R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiSqrt_32f_C4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiSqrt_32f_C4RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit floating point channel in place image square root.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSqrt_32f_C4IR(
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiSqrt_32f_C4IRNative(pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiSqrt_32f_C4IRNative(
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /** @} image_sqrt */
    /**
     * <pre>
     * @defgroup image_ln Ln
     *
     * Pixel by pixel natural logarithm of each pixel in an image.
     *
     * @{
     * </pre>
     */
    /**
     * <pre>
     * One 8-bit unsigned char channel image natural logarithm, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiLn_8u_C1RSfs(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiLn_8u_C1RSfsNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiLn_8u_C1RSfsNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 8-bit unsigned char channel in place image natural logarithm, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiLn_8u_C1IRSfs(
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiLn_8u_C1IRSfsNative(pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiLn_8u_C1IRSfsNative(
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 8-bit unsigned char channel image natural logarithm, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiLn_8u_C3RSfs(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiLn_8u_C3RSfsNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiLn_8u_C3RSfsNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 8-bit unsigned char channel in place image natural logarithm, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiLn_8u_C3IRSfs(
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiLn_8u_C3IRSfsNative(pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiLn_8u_C3IRSfsNative(
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit unsigned short channel image natural logarithm, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiLn_16u_C1RSfs(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiLn_16u_C1RSfsNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiLn_16u_C1RSfsNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit unsigned short channel in place image natural logarithm, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiLn_16u_C1IRSfs(
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiLn_16u_C1IRSfsNative(pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiLn_16u_C1IRSfsNative(
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 16-bit unsigned short channel image natural logarithm, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiLn_16u_C3RSfs(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiLn_16u_C3RSfsNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiLn_16u_C3RSfsNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 16-bit unsigned short channel in place image natural logarithm, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiLn_16u_C3IRSfs(
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiLn_16u_C3IRSfsNative(pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiLn_16u_C3IRSfsNative(
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit signed short channel image natural logarithm, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiLn_16s_C1RSfs(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiLn_16s_C1RSfsNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiLn_16s_C1RSfsNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit signed short channel in place image natural logarithm, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiLn_16s_C1IRSfs(
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiLn_16s_C1IRSfsNative(pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiLn_16s_C1IRSfsNative(
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 16-bit signed short channel image natural logarithm, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiLn_16s_C3RSfs(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiLn_16s_C3RSfsNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiLn_16s_C3RSfsNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 16-bit signed short channel in place image natural logarithm, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiLn_16s_C3IRSfs(
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiLn_16s_C3IRSfsNative(pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiLn_16s_C3IRSfsNative(
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 32-bit floating point channel image natural logarithm.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiLn_32f_C1R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiLn_32f_C1RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiLn_32f_C1RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 32-bit floating point channel in place image natural logarithm.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiLn_32f_C1IR(
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiLn_32f_C1IRNative(pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiLn_32f_C1IRNative(
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 32-bit floating point channel image natural logarithm.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiLn_32f_C3R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiLn_32f_C3RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiLn_32f_C3RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 32-bit floating point channel in place image natural logarithm.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiLn_32f_C3IR(
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiLn_32f_C3IRNative(pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiLn_32f_C3IRNative(
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /** @} image_ln */
    /**
     * <pre>
     * @defgroup image_exp Exp
     *
     * Exponential value of each pixel in an image.
     *
     * @{
     * </pre>
     */
    /**
     * <pre>
     * One 8-bit unsigned char channel image exponential, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiExp_8u_C1RSfs(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiExp_8u_C1RSfsNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiExp_8u_C1RSfsNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 8-bit unsigned char channel in place image exponential, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiExp_8u_C1IRSfs(
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiExp_8u_C1IRSfsNative(pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiExp_8u_C1IRSfsNative(
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 8-bit unsigned char channel image exponential, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiExp_8u_C3RSfs(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiExp_8u_C3RSfsNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiExp_8u_C3RSfsNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 8-bit unsigned char channel in place image exponential, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiExp_8u_C3IRSfs(
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiExp_8u_C3IRSfsNative(pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiExp_8u_C3IRSfsNative(
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit unsigned short channel image exponential, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiExp_16u_C1RSfs(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiExp_16u_C1RSfsNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiExp_16u_C1RSfsNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit unsigned short channel in place image exponential, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiExp_16u_C1IRSfs(
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiExp_16u_C1IRSfsNative(pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiExp_16u_C1IRSfsNative(
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 16-bit unsigned short channel image exponential, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiExp_16u_C3RSfs(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiExp_16u_C3RSfsNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiExp_16u_C3RSfsNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 16-bit unsigned short channel in place image exponential, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiExp_16u_C3IRSfs(
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiExp_16u_C3IRSfsNative(pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiExp_16u_C3IRSfsNative(
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit signed short channel image exponential, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiExp_16s_C1RSfs(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiExp_16s_C1RSfsNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiExp_16s_C1RSfsNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit signed short channel in place image exponential, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiExp_16s_C1IRSfs(
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiExp_16s_C1IRSfsNative(pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiExp_16s_C1IRSfsNative(
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 16-bit signed short channel image exponential, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiExp_16s_C3RSfs(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiExp_16s_C3RSfsNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiExp_16s_C3RSfsNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 16-bit signed short channel in place image exponential, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiExp_16s_C3IRSfs(
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return JNpp.checkResult(nppiExp_16s_C3IRSfsNative(pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiExp_16s_C3IRSfsNative(
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 32-bit floating point channel image exponential.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiExp_32f_C1R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiExp_32f_C1RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiExp_32f_C1RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 32-bit floating point channel in place image exponential.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiExp_32f_C1IR(
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiExp_32f_C1IRNative(pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiExp_32f_C1IRNative(
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 32-bit floating point channel image exponential.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiExp_32f_C3R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiExp_32f_C3RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiExp_32f_C3RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 32-bit floating point channel in place image exponential.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiExp_32f_C3IR(
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiExp_32f_C3IRNative(pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiExp_32f_C3IRNative(
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /** @} image_exp */
    /** @} image_arithmetic_operations */
    /**
     * <pre>
     * @defgroup image_logical_operations Logical Operations
     *
     * @{
     * </pre>
     */
    /**
     * <pre>
     * @defgroup image_andc AndC
     *
     * Pixel by pixel logical and of an image with a constant.
     *
     * @{
     * </pre>
     */
    /**
     * <pre>
     * One 8-bit unsigned char channel image logical and with constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nConstant Constant.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAndC_8u_C1R(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        byte nConstant, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiAndC_8u_C1RNative(pSrc1, nSrc1Step, nConstant, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiAndC_8u_C1RNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        byte nConstant, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 8-bit unsigned char channel in place image logical and with constant.
     * @param nConstant Constant.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAndC_8u_C1IR(
        byte nConstant, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiAndC_8u_C1IRNative(nConstant, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiAndC_8u_C1IRNative(
        byte nConstant, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 8-bit unsigned char channel image logical and with constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAndC_8u_C3R(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        byte[] aConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiAndC_8u_C3RNative(pSrc1, nSrc1Step, aConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiAndC_8u_C3RNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        byte[] aConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 8-bit unsigned char channel in place image logical and with constant.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAndC_8u_C3IR(
        byte[] aConstants, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiAndC_8u_C3IRNative(aConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiAndC_8u_C3IRNative(
        byte[] aConstants, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 8-bit unsigned char channel image logical and with constant with unmodified alpha.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAndC_8u_AC4R(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        byte[] aConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiAndC_8u_AC4RNative(pSrc1, nSrc1Step, aConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiAndC_8u_AC4RNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        byte[] aConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 8-bit unsigned char channel in place image logical and with constant with unmodified alpha.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAndC_8u_AC4IR(
        byte[] aConstants, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiAndC_8u_AC4IRNative(aConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiAndC_8u_AC4IRNative(
        byte[] aConstants, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 8-bit unsigned char channel image logical and with constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAndC_8u_C4R(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        byte[] aConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiAndC_8u_C4RNative(pSrc1, nSrc1Step, aConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiAndC_8u_C4RNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        byte[] aConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 8-bit unsigned char channel in place image logical and with constant.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAndC_8u_C4IR(
        byte[] aConstants, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiAndC_8u_C4IRNative(aConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiAndC_8u_C4IRNative(
        byte[] aConstants, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 16-bit unsigned short channel image logical and with constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nConstant Constant.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAndC_16u_C1R(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        short nConstant, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiAndC_16u_C1RNative(pSrc1, nSrc1Step, nConstant, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiAndC_16u_C1RNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        short nConstant, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 16-bit unsigned short channel in place image logical and with constant.
     * @param nConstant Constant.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAndC_16u_C1IR(
        short nConstant, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiAndC_16u_C1IRNative(nConstant, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiAndC_16u_C1IRNative(
        short nConstant, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 16-bit unsigned short channel image logical and with constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAndC_16u_C3R(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        short[] aConstants, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiAndC_16u_C3RNative(pSrc1, nSrc1Step, aConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiAndC_16u_C3RNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        short[] aConstants, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 16-bit unsigned short channel in place image logical and with constant.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAndC_16u_C3IR(
        short[] aConstants, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiAndC_16u_C3IRNative(aConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiAndC_16u_C3IRNative(
        short[] aConstants, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 16-bit unsigned short channel image logical and with constant with unmodified alpha.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAndC_16u_AC4R(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        short[] aConstants, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiAndC_16u_AC4RNative(pSrc1, nSrc1Step, aConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiAndC_16u_AC4RNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        short[] aConstants, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 16-bit unsigned short channel in place image logical and with constant with unmodified alpha.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAndC_16u_AC4IR(
        short[] aConstants, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiAndC_16u_AC4IRNative(aConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiAndC_16u_AC4IRNative(
        short[] aConstants, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 16-bit unsigned short channel image logical and with constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAndC_16u_C4R(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        short[] aConstants, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiAndC_16u_C4RNative(pSrc1, nSrc1Step, aConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiAndC_16u_C4RNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        short[] aConstants, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 16-bit unsigned short channel in place image logical and with constant.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAndC_16u_C4IR(
        short[] aConstants, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiAndC_16u_C4IRNative(aConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiAndC_16u_C4IRNative(
        short[] aConstants, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 32-bit signed integer channel image logical and with constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nConstant Constant.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAndC_32s_C1R(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        int nConstant, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiAndC_32s_C1RNative(pSrc1, nSrc1Step, nConstant, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiAndC_32s_C1RNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        int nConstant, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 32-bit signed integer channel in place image logical and with constant.
     * @param nConstant Constant.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAndC_32s_C1IR(
        int nConstant, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiAndC_32s_C1IRNative(nConstant, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiAndC_32s_C1IRNative(
        int nConstant, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 32-bit signed integer channel image logical and with constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAndC_32s_C3R(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        int[] aConstants, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiAndC_32s_C3RNative(pSrc1, nSrc1Step, aConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiAndC_32s_C3RNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        int[] aConstants, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 32-bit signed integer channel in place image logical and with constant.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAndC_32s_C3IR(
        int[] aConstants, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiAndC_32s_C3IRNative(aConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiAndC_32s_C3IRNative(
        int[] aConstants, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit signed integer channel image logical and with constant with unmodified alpha.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAndC_32s_AC4R(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        int[] aConstants, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiAndC_32s_AC4RNative(pSrc1, nSrc1Step, aConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiAndC_32s_AC4RNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        int[] aConstants, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit signed integer channel in place image logical and with constant with unmodified alpha.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAndC_32s_AC4IR(
        int[] aConstants, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiAndC_32s_AC4IRNative(aConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiAndC_32s_AC4IRNative(
        int[] aConstants, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit signed integer channel image logical and with constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAndC_32s_C4R(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        int[] aConstants, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiAndC_32s_C4RNative(pSrc1, nSrc1Step, aConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiAndC_32s_C4RNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        int[] aConstants, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit signed integer channel in place image logical and with constant.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAndC_32s_C4IR(
        int[] aConstants, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiAndC_32s_C4IRNative(aConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiAndC_32s_C4IRNative(
        int[] aConstants, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /** @} image_andc */
    /**
     * <pre>
     * @defgroup image_orc OrC
     *
     * Pixel by pixel logical or of an image with a constant.
     *
     * @{
     * </pre>
     */
    /**
     * <pre>
     * One 8-bit unsigned char channel image logical or with constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nConstant Constant.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiOrC_8u_C1R(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        byte nConstant, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiOrC_8u_C1RNative(pSrc1, nSrc1Step, nConstant, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiOrC_8u_C1RNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        byte nConstant, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 8-bit unsigned char channel in place image logical or with constant.
     * @param nConstant Constant.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiOrC_8u_C1IR(
        byte nConstant, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiOrC_8u_C1IRNative(nConstant, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiOrC_8u_C1IRNative(
        byte nConstant, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 8-bit unsigned char channel image logical or with constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiOrC_8u_C3R(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        byte[] aConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiOrC_8u_C3RNative(pSrc1, nSrc1Step, aConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiOrC_8u_C3RNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        byte[] aConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 8-bit unsigned char channel in place image logical or with constant.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiOrC_8u_C3IR(
        byte[] aConstants, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiOrC_8u_C3IRNative(aConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiOrC_8u_C3IRNative(
        byte[] aConstants, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 8-bit unsigned char channel image logical or with constant with unmodified alpha.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiOrC_8u_AC4R(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        byte[] aConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiOrC_8u_AC4RNative(pSrc1, nSrc1Step, aConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiOrC_8u_AC4RNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        byte[] aConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 8-bit unsigned char channel in place image logical or with constant with unmodified alpha.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiOrC_8u_AC4IR(
        byte[] aConstants, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiOrC_8u_AC4IRNative(aConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiOrC_8u_AC4IRNative(
        byte[] aConstants, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 8-bit unsigned char channel image logical or with constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiOrC_8u_C4R(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        byte[] aConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiOrC_8u_C4RNative(pSrc1, nSrc1Step, aConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiOrC_8u_C4RNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        byte[] aConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 8-bit unsigned char channel in place image logical or with constant.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiOrC_8u_C4IR(
        byte[] aConstants, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiOrC_8u_C4IRNative(aConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiOrC_8u_C4IRNative(
        byte[] aConstants, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 16-bit unsigned short channel image logical or with constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nConstant Constant.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiOrC_16u_C1R(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        short nConstant, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiOrC_16u_C1RNative(pSrc1, nSrc1Step, nConstant, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiOrC_16u_C1RNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        short nConstant, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 16-bit unsigned short channel in place image logical or with constant.
     * @param nConstant Constant.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiOrC_16u_C1IR(
        short nConstant, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiOrC_16u_C1IRNative(nConstant, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiOrC_16u_C1IRNative(
        short nConstant, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 16-bit unsigned short channel image logical or with constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiOrC_16u_C3R(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        short[] aConstants, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiOrC_16u_C3RNative(pSrc1, nSrc1Step, aConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiOrC_16u_C3RNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        short[] aConstants, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 16-bit unsigned short channel in place image logical or with constant.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiOrC_16u_C3IR(
        short[] aConstants, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiOrC_16u_C3IRNative(aConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiOrC_16u_C3IRNative(
        short[] aConstants, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 16-bit unsigned short channel image logical or with constant with unmodified alpha.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiOrC_16u_AC4R(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        short[] aConstants, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiOrC_16u_AC4RNative(pSrc1, nSrc1Step, aConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiOrC_16u_AC4RNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        short[] aConstants, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 16-bit unsigned short channel in place image logical or with constant with unmodified alpha.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiOrC_16u_AC4IR(
        short[] aConstants, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiOrC_16u_AC4IRNative(aConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiOrC_16u_AC4IRNative(
        short[] aConstants, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 16-bit unsigned short channel image logical or with constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiOrC_16u_C4R(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        short[] aConstants, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiOrC_16u_C4RNative(pSrc1, nSrc1Step, aConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiOrC_16u_C4RNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        short[] aConstants, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 16-bit unsigned short channel in place image logical or with constant.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiOrC_16u_C4IR(
        short[] aConstants, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiOrC_16u_C4IRNative(aConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiOrC_16u_C4IRNative(
        short[] aConstants, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 32-bit signed integer channel image logical or with constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nConstant Constant.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiOrC_32s_C1R(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        int nConstant, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiOrC_32s_C1RNative(pSrc1, nSrc1Step, nConstant, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiOrC_32s_C1RNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        int nConstant, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 32-bit signed integer channel in place image logical or with constant.
     * @param nConstant Constant.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiOrC_32s_C1IR(
        int nConstant, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiOrC_32s_C1IRNative(nConstant, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiOrC_32s_C1IRNative(
        int nConstant, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 32-bit signed integer channel image logical or with constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiOrC_32s_C3R(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        int[] aConstants, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiOrC_32s_C3RNative(pSrc1, nSrc1Step, aConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiOrC_32s_C3RNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        int[] aConstants, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 32-bit signed integer channel in place image logical or with constant.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiOrC_32s_C3IR(
        int[] aConstants, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiOrC_32s_C3IRNative(aConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiOrC_32s_C3IRNative(
        int[] aConstants, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit signed integer channel image logical or with constant with unmodified alpha.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiOrC_32s_AC4R(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        int[] aConstants, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiOrC_32s_AC4RNative(pSrc1, nSrc1Step, aConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiOrC_32s_AC4RNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        int[] aConstants, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit signed integer channel in place image logical or with constant with unmodified alpha.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiOrC_32s_AC4IR(
        int[] aConstants, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiOrC_32s_AC4IRNative(aConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiOrC_32s_AC4IRNative(
        int[] aConstants, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit signed integer channel image logical or with constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiOrC_32s_C4R(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        int[] aConstants, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiOrC_32s_C4RNative(pSrc1, nSrc1Step, aConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiOrC_32s_C4RNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        int[] aConstants, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit signed integer channel in place image logical or with constant.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiOrC_32s_C4IR(
        int[] aConstants, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiOrC_32s_C4IRNative(aConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiOrC_32s_C4IRNative(
        int[] aConstants, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /** @} image_orc */
    /**
     * <pre>
     * @defgroup image_xorc XorC
     *
     * Pixel by pixel logical exclusive or of an image with a constant.
     *
     * @{
     * </pre>
     */
    /**
     * <pre>
     * One 8-bit unsigned char channel image logical exclusive or with constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nConstant Constant.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiXorC_8u_C1R(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        byte nConstant, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiXorC_8u_C1RNative(pSrc1, nSrc1Step, nConstant, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiXorC_8u_C1RNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        byte nConstant, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 8-bit unsigned char channel in place image logical exclusive or with constant.
     * @param nConstant Constant.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiXorC_8u_C1IR(
        byte nConstant, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiXorC_8u_C1IRNative(nConstant, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiXorC_8u_C1IRNative(
        byte nConstant, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 8-bit unsigned char channel image logical exclusive or with constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiXorC_8u_C3R(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        byte[] aConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiXorC_8u_C3RNative(pSrc1, nSrc1Step, aConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiXorC_8u_C3RNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        byte[] aConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 8-bit unsigned char channel in place image logical exclusive or with constant.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiXorC_8u_C3IR(
        byte[] aConstants, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiXorC_8u_C3IRNative(aConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiXorC_8u_C3IRNative(
        byte[] aConstants, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 8-bit unsigned char channel image logical exclusive or with constant with unmodified alpha.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiXorC_8u_AC4R(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        byte[] aConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiXorC_8u_AC4RNative(pSrc1, nSrc1Step, aConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiXorC_8u_AC4RNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        byte[] aConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 8-bit unsigned char channel in place image logical exclusive or with constant with unmodified alpha.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiXorC_8u_AC4IR(
        byte[] aConstants, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiXorC_8u_AC4IRNative(aConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiXorC_8u_AC4IRNative(
        byte[] aConstants, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 8-bit unsigned char channel image logical exclusive or with constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiXorC_8u_C4R(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        byte[] aConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiXorC_8u_C4RNative(pSrc1, nSrc1Step, aConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiXorC_8u_C4RNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        byte[] aConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 8-bit unsigned char channel in place image logical exclusive or with constant.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiXorC_8u_C4IR(
        byte[] aConstants, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiXorC_8u_C4IRNative(aConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiXorC_8u_C4IRNative(
        byte[] aConstants, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 16-bit unsigned short channel image logical exclusive or with constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nConstant Constant.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiXorC_16u_C1R(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        short nConstant, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiXorC_16u_C1RNative(pSrc1, nSrc1Step, nConstant, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiXorC_16u_C1RNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        short nConstant, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 16-bit unsigned short channel in place image logical exclusive or with constant.
     * @param nConstant Constant.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiXorC_16u_C1IR(
        short nConstant, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiXorC_16u_C1IRNative(nConstant, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiXorC_16u_C1IRNative(
        short nConstant, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 16-bit unsigned short channel image logical exclusive or with constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiXorC_16u_C3R(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        short[] aConstants, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiXorC_16u_C3RNative(pSrc1, nSrc1Step, aConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiXorC_16u_C3RNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        short[] aConstants, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 16-bit unsigned short channel in place image logical exclusive or with constant.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiXorC_16u_C3IR(
        short[] aConstants, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiXorC_16u_C3IRNative(aConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiXorC_16u_C3IRNative(
        short[] aConstants, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 16-bit unsigned short channel image logical exclusive or with constant with unmodified alpha.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiXorC_16u_AC4R(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        short[] aConstants, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiXorC_16u_AC4RNative(pSrc1, nSrc1Step, aConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiXorC_16u_AC4RNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        short[] aConstants, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 16-bit unsigned short channel in place image logical exclusive or with constant with unmodified alpha.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiXorC_16u_AC4IR(
        short[] aConstants, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiXorC_16u_AC4IRNative(aConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiXorC_16u_AC4IRNative(
        short[] aConstants, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 16-bit unsigned short channel image logical exclusive or with constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiXorC_16u_C4R(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        short[] aConstants, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiXorC_16u_C4RNative(pSrc1, nSrc1Step, aConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiXorC_16u_C4RNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        short[] aConstants, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 16-bit unsigned short channel in place image logical exclusive or with constant.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiXorC_16u_C4IR(
        short[] aConstants, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiXorC_16u_C4IRNative(aConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiXorC_16u_C4IRNative(
        short[] aConstants, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 32-bit signed integer channel image logical exclusive or with constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nConstant Constant.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiXorC_32s_C1R(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        int nConstant, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiXorC_32s_C1RNative(pSrc1, nSrc1Step, nConstant, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiXorC_32s_C1RNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        int nConstant, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 32-bit signed integer channel in place image logical exclusive or with constant.
     * @param nConstant Constant.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiXorC_32s_C1IR(
        int nConstant, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiXorC_32s_C1IRNative(nConstant, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiXorC_32s_C1IRNative(
        int nConstant, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 32-bit signed integer channel image logical exclusive or with constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiXorC_32s_C3R(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        int[] aConstants, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiXorC_32s_C3RNative(pSrc1, nSrc1Step, aConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiXorC_32s_C3RNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        int[] aConstants, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 32-bit signed integer channel in place image logical exclusive or with constant.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiXorC_32s_C3IR(
        int[] aConstants, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiXorC_32s_C3IRNative(aConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiXorC_32s_C3IRNative(
        int[] aConstants, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit signed integer channel image logical exclusive or with constant with unmodified alpha.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiXorC_32s_AC4R(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        int[] aConstants, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiXorC_32s_AC4RNative(pSrc1, nSrc1Step, aConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiXorC_32s_AC4RNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        int[] aConstants, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit signed integer channel in place image logical exclusive or with constant with unmodified alpha.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiXorC_32s_AC4IR(
        int[] aConstants, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiXorC_32s_AC4IRNative(aConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiXorC_32s_AC4IRNative(
        int[] aConstants, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit signed integer channel image logical exclusive or with constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiXorC_32s_C4R(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        int[] aConstants, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiXorC_32s_C4RNative(pSrc1, nSrc1Step, aConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiXorC_32s_C4RNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        int[] aConstants, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit signed integer channel in place image logical exclusive or with constant.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiXorC_32s_C4IR(
        int[] aConstants, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiXorC_32s_C4IRNative(aConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiXorC_32s_C4IRNative(
        int[] aConstants, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /** @} image_xorc */
    /**
     * <pre>
     * @defgroup image_rshiftc RShiftC
     *
     * Pixel by pixel right shift of an image by a constant value.
     *
     * @{
     * </pre>
     */
    /**
     * <pre>
     * One 8-bit unsigned char channel image right shift by constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nConstant Constant.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiRShiftC_8u_C1R(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        int nConstant, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiRShiftC_8u_C1RNative(pSrc1, nSrc1Step, nConstant, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiRShiftC_8u_C1RNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        int nConstant, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 8-bit unsigned char channel in place image right shift by constant.
     * @param nConstant Constant.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiRShiftC_8u_C1IR(
        int nConstant, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiRShiftC_8u_C1IRNative(nConstant, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiRShiftC_8u_C1IRNative(
        int nConstant, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 8-bit unsigned char channel image right shift by constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiRShiftC_8u_C3R(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        int[] aConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiRShiftC_8u_C3RNative(pSrc1, nSrc1Step, aConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiRShiftC_8u_C3RNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        int[] aConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 8-bit unsigned char channel in place image right shift by constant.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiRShiftC_8u_C3IR(
        int[] aConstants, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiRShiftC_8u_C3IRNative(aConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiRShiftC_8u_C3IRNative(
        int[] aConstants, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 8-bit unsigned char channel image right shift by constant with unmodified alpha.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiRShiftC_8u_AC4R(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        int[] aConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiRShiftC_8u_AC4RNative(pSrc1, nSrc1Step, aConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiRShiftC_8u_AC4RNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        int[] aConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 8-bit unsigned char channel in place image right shift by constant with unmodified alpha.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiRShiftC_8u_AC4IR(
        int[] aConstants, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiRShiftC_8u_AC4IRNative(aConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiRShiftC_8u_AC4IRNative(
        int[] aConstants, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 8-bit unsigned char channel image right shift by constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiRShiftC_8u_C4R(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        int[] aConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiRShiftC_8u_C4RNative(pSrc1, nSrc1Step, aConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiRShiftC_8u_C4RNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        int[] aConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 8-bit unsigned char channel in place image right shift by constant.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiRShiftC_8u_C4IR(
        int[] aConstants, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiRShiftC_8u_C4IRNative(aConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiRShiftC_8u_C4IRNative(
        int[] aConstants, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 8-bit signed char channel image right shift by constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nConstant Constant.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiRShiftC_8s_C1R(
        TypedPointer<Npp8s> pSrc1, 
        int nSrc1Step, 
        int nConstant, 
        TypedPointer<Npp8s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiRShiftC_8s_C1RNative(pSrc1, nSrc1Step, nConstant, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiRShiftC_8s_C1RNative(
        TypedPointer<Npp8s> pSrc1, 
        int nSrc1Step, 
        int nConstant, 
        TypedPointer<Npp8s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 8-bit signed char channel in place image right shift by constant.
     * @param nConstant Constant.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiRShiftC_8s_C1IR(
        int nConstant, 
        TypedPointer<Npp8s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiRShiftC_8s_C1IRNative(nConstant, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiRShiftC_8s_C1IRNative(
        int nConstant, 
        TypedPointer<Npp8s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 8-bit signed char channel image right shift by constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiRShiftC_8s_C3R(
        TypedPointer<Npp8s> pSrc1, 
        int nSrc1Step, 
        int[] aConstants, 
        TypedPointer<Npp8s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiRShiftC_8s_C3RNative(pSrc1, nSrc1Step, aConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiRShiftC_8s_C3RNative(
        TypedPointer<Npp8s> pSrc1, 
        int nSrc1Step, 
        int[] aConstants, 
        TypedPointer<Npp8s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 8-bit signed char channel in place image right shift by constant.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiRShiftC_8s_C3IR(
        int[] aConstants, 
        TypedPointer<Npp8s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiRShiftC_8s_C3IRNative(aConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiRShiftC_8s_C3IRNative(
        int[] aConstants, 
        TypedPointer<Npp8s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 8-bit signed char channel image right shift by constant with unmodified alpha.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiRShiftC_8s_AC4R(
        TypedPointer<Npp8s> pSrc1, 
        int nSrc1Step, 
        int[] aConstants, 
        TypedPointer<Npp8s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiRShiftC_8s_AC4RNative(pSrc1, nSrc1Step, aConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiRShiftC_8s_AC4RNative(
        TypedPointer<Npp8s> pSrc1, 
        int nSrc1Step, 
        int[] aConstants, 
        TypedPointer<Npp8s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 8-bit signed char channel in place image right shift by constant with unmodified alpha.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiRShiftC_8s_AC4IR(
        int[] aConstants, 
        TypedPointer<Npp8s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiRShiftC_8s_AC4IRNative(aConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiRShiftC_8s_AC4IRNative(
        int[] aConstants, 
        TypedPointer<Npp8s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 8-bit signed char channel image right shift by constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiRShiftC_8s_C4R(
        TypedPointer<Npp8s> pSrc1, 
        int nSrc1Step, 
        int[] aConstants, 
        TypedPointer<Npp8s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiRShiftC_8s_C4RNative(pSrc1, nSrc1Step, aConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiRShiftC_8s_C4RNative(
        TypedPointer<Npp8s> pSrc1, 
        int nSrc1Step, 
        int[] aConstants, 
        TypedPointer<Npp8s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 8-bit signed char channel in place image right shift by constant.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiRShiftC_8s_C4IR(
        int[] aConstants, 
        TypedPointer<Npp8s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiRShiftC_8s_C4IRNative(aConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiRShiftC_8s_C4IRNative(
        int[] aConstants, 
        TypedPointer<Npp8s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 16-bit unsigned short channel image right shift by constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nConstant Constant.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiRShiftC_16u_C1R(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        int nConstant, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiRShiftC_16u_C1RNative(pSrc1, nSrc1Step, nConstant, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiRShiftC_16u_C1RNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        int nConstant, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 16-bit unsigned short channel in place image right shift by constant.
     * @param nConstant Constant.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiRShiftC_16u_C1IR(
        int nConstant, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiRShiftC_16u_C1IRNative(nConstant, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiRShiftC_16u_C1IRNative(
        int nConstant, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 16-bit unsigned short channel image right shift by constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiRShiftC_16u_C3R(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        int[] aConstants, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiRShiftC_16u_C3RNative(pSrc1, nSrc1Step, aConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiRShiftC_16u_C3RNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        int[] aConstants, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 16-bit unsigned short channel in place image right shift by constant.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiRShiftC_16u_C3IR(
        int[] aConstants, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiRShiftC_16u_C3IRNative(aConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiRShiftC_16u_C3IRNative(
        int[] aConstants, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 16-bit unsigned short channel image right shift by constant with unmodified alpha.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiRShiftC_16u_AC4R(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        int[] aConstants, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiRShiftC_16u_AC4RNative(pSrc1, nSrc1Step, aConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiRShiftC_16u_AC4RNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        int[] aConstants, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 16-bit unsigned short channel in place image right shift by constant with unmodified alpha.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiRShiftC_16u_AC4IR(
        int[] aConstants, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiRShiftC_16u_AC4IRNative(aConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiRShiftC_16u_AC4IRNative(
        int[] aConstants, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 16-bit unsigned short channel image right shift by constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiRShiftC_16u_C4R(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        int[] aConstants, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiRShiftC_16u_C4RNative(pSrc1, nSrc1Step, aConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiRShiftC_16u_C4RNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        int[] aConstants, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 16-bit unsigned short channel in place image right shift by constant.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiRShiftC_16u_C4IR(
        int[] aConstants, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiRShiftC_16u_C4IRNative(aConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiRShiftC_16u_C4IRNative(
        int[] aConstants, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 16-bit signed short channel image right shift by constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nConstant Constant.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiRShiftC_16s_C1R(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        int nConstant, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiRShiftC_16s_C1RNative(pSrc1, nSrc1Step, nConstant, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiRShiftC_16s_C1RNative(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        int nConstant, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 16-bit signed short channel in place image right shift by constant.
     * @param nConstant Constant.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiRShiftC_16s_C1IR(
        int nConstant, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiRShiftC_16s_C1IRNative(nConstant, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiRShiftC_16s_C1IRNative(
        int nConstant, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 16-bit signed short channel image right shift by constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiRShiftC_16s_C3R(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        int[] aConstants, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiRShiftC_16s_C3RNative(pSrc1, nSrc1Step, aConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiRShiftC_16s_C3RNative(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        int[] aConstants, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 16-bit signed short channel in place image right shift by constant.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiRShiftC_16s_C3IR(
        int[] aConstants, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiRShiftC_16s_C3IRNative(aConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiRShiftC_16s_C3IRNative(
        int[] aConstants, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 16-bit signed short channel image right shift by constant with unmodified alpha.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiRShiftC_16s_AC4R(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        int[] aConstants, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiRShiftC_16s_AC4RNative(pSrc1, nSrc1Step, aConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiRShiftC_16s_AC4RNative(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        int[] aConstants, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 16-bit signed short channel in place image right shift by constant with unmodified alpha.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiRShiftC_16s_AC4IR(
        int[] aConstants, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiRShiftC_16s_AC4IRNative(aConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiRShiftC_16s_AC4IRNative(
        int[] aConstants, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 16-bit signed short channel image right shift by constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiRShiftC_16s_C4R(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        int[] aConstants, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiRShiftC_16s_C4RNative(pSrc1, nSrc1Step, aConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiRShiftC_16s_C4RNative(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        int[] aConstants, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 16-bit signed short channel in place image right shift by constant.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiRShiftC_16s_C4IR(
        int[] aConstants, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiRShiftC_16s_C4IRNative(aConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiRShiftC_16s_C4IRNative(
        int[] aConstants, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 32-bit signed integer channel image right shift by constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nConstant Constant.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiRShiftC_32s_C1R(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        int nConstant, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiRShiftC_32s_C1RNative(pSrc1, nSrc1Step, nConstant, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiRShiftC_32s_C1RNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        int nConstant, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 32-bit signed integer channel in place image right shift by constant.
     * @param nConstant Constant.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiRShiftC_32s_C1IR(
        int nConstant, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiRShiftC_32s_C1IRNative(nConstant, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiRShiftC_32s_C1IRNative(
        int nConstant, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 32-bit signed integer channel image right shift by constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiRShiftC_32s_C3R(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        int[] aConstants, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiRShiftC_32s_C3RNative(pSrc1, nSrc1Step, aConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiRShiftC_32s_C3RNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        int[] aConstants, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 32-bit signed integer channel in place image right shift by constant.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiRShiftC_32s_C3IR(
        int[] aConstants, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiRShiftC_32s_C3IRNative(aConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiRShiftC_32s_C3IRNative(
        int[] aConstants, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit signed integer channel image right shift by constant with unmodified alpha.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiRShiftC_32s_AC4R(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        int[] aConstants, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiRShiftC_32s_AC4RNative(pSrc1, nSrc1Step, aConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiRShiftC_32s_AC4RNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        int[] aConstants, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit signed integer channel in place image right shift by constant with unmodified alpha.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiRShiftC_32s_AC4IR(
        int[] aConstants, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiRShiftC_32s_AC4IRNative(aConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiRShiftC_32s_AC4IRNative(
        int[] aConstants, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit signed integer channel image right shift by constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiRShiftC_32s_C4R(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        int[] aConstants, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiRShiftC_32s_C4RNative(pSrc1, nSrc1Step, aConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiRShiftC_32s_C4RNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        int[] aConstants, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit signed integer channel in place image right shift by constant.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiRShiftC_32s_C4IR(
        int[] aConstants, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiRShiftC_32s_C4IRNative(aConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiRShiftC_32s_C4IRNative(
        int[] aConstants, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /** @} image_rshiftc */
    /**
     * <pre>
     * @defgroup image_lshiftc LShiftC
     *
     * Pixel by pixel left shift of an image by a constant value.
     *
     * @{
     * </pre>
     */
    /**
     * <pre>
     * One 8-bit unsigned char channel image left shift by constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nConstant Constant.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiLShiftC_8u_C1R(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        int nConstant, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiLShiftC_8u_C1RNative(pSrc1, nSrc1Step, nConstant, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiLShiftC_8u_C1RNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        int nConstant, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 8-bit unsigned char channel in place image left shift by constant.
     * @param nConstant Constant.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiLShiftC_8u_C1IR(
        int nConstant, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiLShiftC_8u_C1IRNative(nConstant, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiLShiftC_8u_C1IRNative(
        int nConstant, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 8-bit unsigned char channel image left shift by constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiLShiftC_8u_C3R(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        int[] aConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiLShiftC_8u_C3RNative(pSrc1, nSrc1Step, aConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiLShiftC_8u_C3RNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        int[] aConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 8-bit unsigned char channel in place image left shift by constant.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiLShiftC_8u_C3IR(
        int[] aConstants, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiLShiftC_8u_C3IRNative(aConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiLShiftC_8u_C3IRNative(
        int[] aConstants, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 8-bit unsigned char channel image left shift by constant with unmodified alpha.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiLShiftC_8u_AC4R(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        int[] aConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiLShiftC_8u_AC4RNative(pSrc1, nSrc1Step, aConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiLShiftC_8u_AC4RNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        int[] aConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 8-bit unsigned char channel in place image left shift by constant with unmodified alpha.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiLShiftC_8u_AC4IR(
        int[] aConstants, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiLShiftC_8u_AC4IRNative(aConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiLShiftC_8u_AC4IRNative(
        int[] aConstants, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 8-bit unsigned char channel image left shift by constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiLShiftC_8u_C4R(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        int[] aConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiLShiftC_8u_C4RNative(pSrc1, nSrc1Step, aConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiLShiftC_8u_C4RNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        int[] aConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 8-bit unsigned char channel in place image left shift by constant.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiLShiftC_8u_C4IR(
        int[] aConstants, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiLShiftC_8u_C4IRNative(aConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiLShiftC_8u_C4IRNative(
        int[] aConstants, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 16-bit unsigned short channel image left shift by constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nConstant Constant
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiLShiftC_16u_C1R(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        int nConstant, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiLShiftC_16u_C1RNative(pSrc1, nSrc1Step, nConstant, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiLShiftC_16u_C1RNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        int nConstant, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 16-bit unsigned short channel in place image left shift by constant.
     * @param nConstant Constant.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiLShiftC_16u_C1IR(
        int nConstant, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiLShiftC_16u_C1IRNative(nConstant, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiLShiftC_16u_C1IRNative(
        int nConstant, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 16-bit unsigned short channel image left shift by constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiLShiftC_16u_C3R(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        int[] aConstants, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiLShiftC_16u_C3RNative(pSrc1, nSrc1Step, aConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiLShiftC_16u_C3RNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        int[] aConstants, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 16-bit unsigned short channel in place image left shift by constant.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiLShiftC_16u_C3IR(
        int[] aConstants, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiLShiftC_16u_C3IRNative(aConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiLShiftC_16u_C3IRNative(
        int[] aConstants, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 16-bit unsigned short channel image left shift by constant with unmodified alpha.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiLShiftC_16u_AC4R(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        int[] aConstants, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiLShiftC_16u_AC4RNative(pSrc1, nSrc1Step, aConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiLShiftC_16u_AC4RNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        int[] aConstants, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 16-bit unsigned short channel in place image left shift by constant with unmodified alpha.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiLShiftC_16u_AC4IR(
        int[] aConstants, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiLShiftC_16u_AC4IRNative(aConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiLShiftC_16u_AC4IRNative(
        int[] aConstants, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 16-bit unsigned short channel image left shift by constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiLShiftC_16u_C4R(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        int[] aConstants, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiLShiftC_16u_C4RNative(pSrc1, nSrc1Step, aConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiLShiftC_16u_C4RNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        int[] aConstants, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 16-bit unsigned short channel in place image left shift by constant.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiLShiftC_16u_C4IR(
        int[] aConstants, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiLShiftC_16u_C4IRNative(aConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiLShiftC_16u_C4IRNative(
        int[] aConstants, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 32-bit signed integer channel image left shift by constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nConstant Constant.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiLShiftC_32s_C1R(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        int nConstant, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiLShiftC_32s_C1RNative(pSrc1, nSrc1Step, nConstant, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiLShiftC_32s_C1RNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        int nConstant, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 32-bit signed integer channel in place image left shift by constant.
     * @param nConstant Constant.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiLShiftC_32s_C1IR(
        int nConstant, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiLShiftC_32s_C1IRNative(nConstant, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiLShiftC_32s_C1IRNative(
        int nConstant, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 32-bit signed integer channel image left shift by constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiLShiftC_32s_C3R(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        int[] aConstants, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiLShiftC_32s_C3RNative(pSrc1, nSrc1Step, aConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiLShiftC_32s_C3RNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        int[] aConstants, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 32-bit signed integer channel in place image left shift by constant.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiLShiftC_32s_C3IR(
        int[] aConstants, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiLShiftC_32s_C3IRNative(aConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiLShiftC_32s_C3IRNative(
        int[] aConstants, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit signed integer channel image left shift by constant with unmodified alpha.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiLShiftC_32s_AC4R(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        int[] aConstants, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiLShiftC_32s_AC4RNative(pSrc1, nSrc1Step, aConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiLShiftC_32s_AC4RNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        int[] aConstants, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit signed integer channel in place image left shift by constant with unmodified alpha.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiLShiftC_32s_AC4IR(
        int[] aConstants, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiLShiftC_32s_AC4IRNative(aConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiLShiftC_32s_AC4IRNative(
        int[] aConstants, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit signed integer channel image left shift by constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiLShiftC_32s_C4R(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        int[] aConstants, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiLShiftC_32s_C4RNative(pSrc1, nSrc1Step, aConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiLShiftC_32s_C4RNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        int[] aConstants, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit signed integer channel in place image left shift by constant.
     * @param aConstants fixed size array of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiLShiftC_32s_C4IR(
        int[] aConstants, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiLShiftC_32s_C4IRNative(aConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiLShiftC_32s_C4IRNative(
        int[] aConstants, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /** @} image_lshiftc */
    /**
     * <pre>
     * @defgroup image_and And
     *
     * Pixel by pixel logical and of images.
     *
     * @{
     * </pre>
     */
    /**
     * <pre>
     * One 8-bit unsigned char channel image logical and.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAnd_8u_C1R(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiAnd_8u_C1RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiAnd_8u_C1RNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 8-bit unsigned char channel in place image logical and.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAnd_8u_C1IR(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiAnd_8u_C1IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiAnd_8u_C1IRNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 8-bit unsigned char channel image logical and.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAnd_8u_C3R(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiAnd_8u_C3RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiAnd_8u_C3RNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 8-bit unsigned char channel in place image logical and.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAnd_8u_C3IR(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiAnd_8u_C3IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiAnd_8u_C3IRNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 8-bit unsigned char channel image logical and with unmodified alpha.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAnd_8u_AC4R(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiAnd_8u_AC4RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiAnd_8u_AC4RNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 8-bit unsigned char channel in place image logical and with unmodified alpha.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAnd_8u_AC4IR(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiAnd_8u_AC4IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiAnd_8u_AC4IRNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 8-bit unsigned char channel image logical and.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAnd_8u_C4R(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiAnd_8u_C4RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiAnd_8u_C4RNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 8-bit unsigned char channel in place image logical and.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAnd_8u_C4IR(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiAnd_8u_C4IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiAnd_8u_C4IRNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 16-bit unsigned short channel image logical and.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAnd_16u_C1R(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiAnd_16u_C1RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiAnd_16u_C1RNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 16-bit unsigned short channel in place image logical and.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAnd_16u_C1IR(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiAnd_16u_C1IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiAnd_16u_C1IRNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 16-bit unsigned short channel image logical and.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAnd_16u_C3R(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiAnd_16u_C3RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiAnd_16u_C3RNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 16-bit unsigned short channel in place image logical and.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAnd_16u_C3IR(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiAnd_16u_C3IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiAnd_16u_C3IRNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 16-bit unsigned short channel image logical and with unmodified alpha.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAnd_16u_AC4R(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiAnd_16u_AC4RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiAnd_16u_AC4RNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 16-bit unsigned short channel in place image logical and with unmodified alpha.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAnd_16u_AC4IR(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiAnd_16u_AC4IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiAnd_16u_AC4IRNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 16-bit unsigned short channel image logical and.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAnd_16u_C4R(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiAnd_16u_C4RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiAnd_16u_C4RNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 16-bit unsigned short channel in place image logical and.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAnd_16u_C4IR(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiAnd_16u_C4IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiAnd_16u_C4IRNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 32-bit signed integer channel image logical and.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAnd_32s_C1R(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiAnd_32s_C1RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiAnd_32s_C1RNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 32-bit signed integer channel in place image logical and.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAnd_32s_C1IR(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiAnd_32s_C1IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiAnd_32s_C1IRNative(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 32-bit signed integer channel image logical and.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAnd_32s_C3R(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiAnd_32s_C3RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiAnd_32s_C3RNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 32-bit signed integer channel in place image logical and.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAnd_32s_C3IR(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiAnd_32s_C3IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiAnd_32s_C3IRNative(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit signed integer channel image logical and with unmodified alpha.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAnd_32s_AC4R(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiAnd_32s_AC4RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiAnd_32s_AC4RNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit signed integer channel in place image logical and with unmodified alpha.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAnd_32s_AC4IR(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiAnd_32s_AC4IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiAnd_32s_AC4IRNative(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit signed integer channel image logical and.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAnd_32s_C4R(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiAnd_32s_C4RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiAnd_32s_C4RNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit signed integer channel in place image logical and.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAnd_32s_C4IR(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiAnd_32s_C4IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiAnd_32s_C4IRNative(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /** @} image_and */
    /**
     * <pre>
     * @defgroup image_or Or
     *
     * Pixel by pixel logical or of images.
     *
     * @{
     * </pre>
     */
    /**
     * <pre>
     * One 8-bit unsigned char channel image logical or.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiOr_8u_C1R(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiOr_8u_C1RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiOr_8u_C1RNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 8-bit unsigned char channel in place image logical or.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiOr_8u_C1IR(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiOr_8u_C1IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiOr_8u_C1IRNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 8-bit unsigned char channel image logical or.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiOr_8u_C3R(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiOr_8u_C3RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiOr_8u_C3RNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 8-bit unsigned char channel in place image logical or.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiOr_8u_C3IR(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiOr_8u_C3IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiOr_8u_C3IRNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 8-bit unsigned char channel image logical or with unmodified alpha.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiOr_8u_AC4R(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiOr_8u_AC4RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiOr_8u_AC4RNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 8-bit unsigned char channel in place image logical or with unmodified alpha.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiOr_8u_AC4IR(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiOr_8u_AC4IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiOr_8u_AC4IRNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 8-bit unsigned char channel image logical or.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiOr_8u_C4R(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiOr_8u_C4RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiOr_8u_C4RNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 8-bit unsigned char channel in place image logical or.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiOr_8u_C4IR(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiOr_8u_C4IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiOr_8u_C4IRNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 16-bit unsigned short channel image logical or.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiOr_16u_C1R(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiOr_16u_C1RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiOr_16u_C1RNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 16-bit unsigned short channel in place image logical or.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiOr_16u_C1IR(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiOr_16u_C1IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiOr_16u_C1IRNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 16-bit unsigned short channel image logical or.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiOr_16u_C3R(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiOr_16u_C3RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiOr_16u_C3RNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 16-bit unsigned short channel in place image logical or.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiOr_16u_C3IR(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiOr_16u_C3IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiOr_16u_C3IRNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 16-bit unsigned short channel image logical or with unmodified alpha.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiOr_16u_AC4R(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiOr_16u_AC4RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiOr_16u_AC4RNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 16-bit unsigned short channel in place image logical or with unmodified alpha.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiOr_16u_AC4IR(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiOr_16u_AC4IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiOr_16u_AC4IRNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 16-bit unsigned short channel image logical or.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiOr_16u_C4R(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiOr_16u_C4RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiOr_16u_C4RNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 16-bit unsigned short channel in place image logical or.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiOr_16u_C4IR(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiOr_16u_C4IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiOr_16u_C4IRNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 32-bit signed integer channel image logical or.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiOr_32s_C1R(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiOr_32s_C1RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiOr_32s_C1RNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 32-bit signed integer channel in place image logical or.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiOr_32s_C1IR(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiOr_32s_C1IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiOr_32s_C1IRNative(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 32-bit signed integer channel image logical or.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiOr_32s_C3R(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiOr_32s_C3RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiOr_32s_C3RNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 32-bit signed integer channel in place image logical or.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiOr_32s_C3IR(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiOr_32s_C3IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiOr_32s_C3IRNative(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit signed integer channel image logical or with unmodified alpha.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiOr_32s_AC4R(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiOr_32s_AC4RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiOr_32s_AC4RNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit signed integer channel in place image logical or with unmodified alpha.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiOr_32s_AC4IR(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiOr_32s_AC4IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiOr_32s_AC4IRNative(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit signed integer channel image logical or.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiOr_32s_C4R(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiOr_32s_C4RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiOr_32s_C4RNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit signed integer channel in place image logical or.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiOr_32s_C4IR(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiOr_32s_C4IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiOr_32s_C4IRNative(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /** @} image_or */
    /**
     * <pre>
     * @defgroup image_xor Xor
     *
     * Pixel by pixel logical exclusive or of images.
     *
     * @{
     * </pre>
     */
    /**
     * <pre>
     * One 8-bit unsigned char channel image logical exclusive or.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiXor_8u_C1R(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiXor_8u_C1RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiXor_8u_C1RNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 8-bit unsigned char channel in place image logical exclusive or.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiXor_8u_C1IR(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiXor_8u_C1IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiXor_8u_C1IRNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 8-bit unsigned char channel image logical exclusive or.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiXor_8u_C3R(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiXor_8u_C3RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiXor_8u_C3RNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 8-bit unsigned char channel in place image logical exclusive or.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiXor_8u_C3IR(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiXor_8u_C3IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiXor_8u_C3IRNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 8-bit unsigned char channel image logical exclusive or with unmodified alpha.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiXor_8u_AC4R(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiXor_8u_AC4RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiXor_8u_AC4RNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 8-bit unsigned char channel in place image logical exclusive or with unmodified alpha.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiXor_8u_AC4IR(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiXor_8u_AC4IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiXor_8u_AC4IRNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 8-bit unsigned char channel image logical exclusive or.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiXor_8u_C4R(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiXor_8u_C4RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiXor_8u_C4RNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 8-bit unsigned char channel in place image logical exclusive or.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiXor_8u_C4IR(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiXor_8u_C4IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiXor_8u_C4IRNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 16-bit unsigned short channel image logical exclusive or.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiXor_16u_C1R(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiXor_16u_C1RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiXor_16u_C1RNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 16-bit unsigned short channel in place image logical exclusive or.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiXor_16u_C1IR(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiXor_16u_C1IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiXor_16u_C1IRNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 16-bit unsigned short channel image logical exclusive or.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiXor_16u_C3R(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiXor_16u_C3RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiXor_16u_C3RNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 16-bit unsigned short channel in place image logical exclusive or.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiXor_16u_C3IR(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiXor_16u_C3IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiXor_16u_C3IRNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 16-bit unsigned short channel image logical exclusive or with unmodified alpha.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiXor_16u_AC4R(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiXor_16u_AC4RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiXor_16u_AC4RNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 16-bit unsigned short channel in place image logical exclusive or with unmodified alpha.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiXor_16u_AC4IR(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiXor_16u_AC4IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiXor_16u_AC4IRNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 16-bit unsigned short channel image logical exclusive or.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiXor_16u_C4R(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiXor_16u_C4RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiXor_16u_C4RNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 16-bit unsigned short channel in place image logical exclusive or.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiXor_16u_C4IR(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiXor_16u_C4IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiXor_16u_C4IRNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 32-bit signed integer channel image logical exclusive or.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiXor_32s_C1R(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiXor_32s_C1RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiXor_32s_C1RNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 32-bit signed integer channel in place image logical exclusive or.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiXor_32s_C1IR(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiXor_32s_C1IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiXor_32s_C1IRNative(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 32-bit signed integer channel image logical exclusive or.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiXor_32s_C3R(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiXor_32s_C3RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiXor_32s_C3RNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 32-bit signed integer channel in place image logical exclusive or.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiXor_32s_C3IR(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiXor_32s_C3IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiXor_32s_C3IRNative(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit signed integer channel image logical exclusive or with unmodified alpha.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiXor_32s_AC4R(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiXor_32s_AC4RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiXor_32s_AC4RNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit signed integer channel in place image logical exclusive or with unmodified alpha.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiXor_32s_AC4IR(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiXor_32s_AC4IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiXor_32s_AC4IRNative(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit signed integer channel image logical exclusive or.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiXor_32s_C4R(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiXor_32s_C4RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiXor_32s_C4RNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit signed integer channel in place image logical exclusive or.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiXor_32s_C4IR(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiXor_32s_C4IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiXor_32s_C4IRNative(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /** @} image_xor */
    /**
     * <pre>
     * @defgroup image_not Not
     *
     * Pixel by pixel logical not of image.
     *
     * @{
     * </pre>
     */
    /**
     * <pre>
     * One 8-bit unsigned char channel image logical not.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiNot_8u_C1R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiNot_8u_C1RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiNot_8u_C1RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 8-bit unsigned char channel in place image logical not.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiNot_8u_C1IR(
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiNot_8u_C1IRNative(pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiNot_8u_C1IRNative(
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 8-bit unsigned char channel image logical not.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiNot_8u_C3R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiNot_8u_C3RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiNot_8u_C3RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 8-bit unsigned char channel in place image logical not.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiNot_8u_C3IR(
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiNot_8u_C3IRNative(pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiNot_8u_C3IRNative(
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 8-bit unsigned char channel image logical not with unmodified alpha.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiNot_8u_AC4R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiNot_8u_AC4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiNot_8u_AC4RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 8-bit unsigned char channel in place image logical not with unmodified alpha.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiNot_8u_AC4IR(
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiNot_8u_AC4IRNative(pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiNot_8u_AC4IRNative(
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 8-bit unsigned char channel image logical not.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiNot_8u_C4R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiNot_8u_C4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiNot_8u_C4RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 8-bit unsigned char channel in place image logical not.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiNot_8u_C4IR(
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiNot_8u_C4IRNative(pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiNot_8u_C4IRNative(
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /** @} image_not */
    /** @} image_logical_operations */
    /**
     * <pre>
     * @defgroup image_alpha_composition_operations Alpha Composition
     * @{
     * </pre>
     */
    /**
     * <pre>
     * @defgroup image_alphacompc AlphaCompC
     *
     * Composite two images using constant alpha values.
     *
     * @{
     * </pre>
     */
    /**
     * <pre>
     * One 8-bit unsigned char channel image composition using constant alpha.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nAlpha1 Image alpha opacity (0 - max channel pixel value).
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param nAlpha2 Image alpha opacity (0 - max channel pixel value).
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param eAlphaOp alpha-blending operation..
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAlphaCompC_8u_C1R(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        byte nAlpha1, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        byte nAlpha2, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eAlphaOp)
    {
        return JNpp.checkResult(nppiAlphaCompC_8u_C1RNative(pSrc1, nSrc1Step, nAlpha1, pSrc2, nSrc2Step, nAlpha2, pDst, nDstStep, oSizeROI, eAlphaOp));
    }
    private static native int nppiAlphaCompC_8u_C1RNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        byte nAlpha1, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        byte nAlpha2, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eAlphaOp);


    /**
     * <pre>
     * Three 8-bit unsigned char channel image composition using constant alpha.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nAlpha1 Image alpha opacity (0 - max channel pixel value).
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param nAlpha2 Image alpha opacity (0 - max channel pixel value).
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param eAlphaOp alpha-blending operation..
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAlphaCompC_8u_C3R(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        byte nAlpha1, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        byte nAlpha2, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eAlphaOp)
    {
        return JNpp.checkResult(nppiAlphaCompC_8u_C3RNative(pSrc1, nSrc1Step, nAlpha1, pSrc2, nSrc2Step, nAlpha2, pDst, nDstStep, oSizeROI, eAlphaOp));
    }
    private static native int nppiAlphaCompC_8u_C3RNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        byte nAlpha1, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        byte nAlpha2, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eAlphaOp);


    /**
     * <pre>
     * Four 8-bit unsigned char channel image composition using constant alpha.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nAlpha1 Image alpha opacity (0 - max channel pixel value).
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param nAlpha2 Image alpha opacity (0 - max channel pixel value).
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param eAlphaOp alpha-blending operation..
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAlphaCompC_8u_C4R(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        byte nAlpha1, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        byte nAlpha2, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eAlphaOp)
    {
        return JNpp.checkResult(nppiAlphaCompC_8u_C4RNative(pSrc1, nSrc1Step, nAlpha1, pSrc2, nSrc2Step, nAlpha2, pDst, nDstStep, oSizeROI, eAlphaOp));
    }
    private static native int nppiAlphaCompC_8u_C4RNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        byte nAlpha1, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        byte nAlpha2, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eAlphaOp);


    /**
     * <pre>
     * Four 8-bit unsigned char channel image composition with alpha using constant source alpha.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nAlpha1 Image alpha opacity (0 - max channel pixel value).
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param nAlpha2 Image alpha opacity (0 - max channel pixel value).
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param eAlphaOp alpha-blending operation..
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAlphaCompC_8u_AC4R(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        byte nAlpha1, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        byte nAlpha2, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eAlphaOp)
    {
        return JNpp.checkResult(nppiAlphaCompC_8u_AC4RNative(pSrc1, nSrc1Step, nAlpha1, pSrc2, nSrc2Step, nAlpha2, pDst, nDstStep, oSizeROI, eAlphaOp));
    }
    private static native int nppiAlphaCompC_8u_AC4RNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        byte nAlpha1, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        byte nAlpha2, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eAlphaOp);


    /**
     * <pre>
     * One 8-bit signed char channel image composition using constant alpha.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nAlpha1 Image alpha opacity (0 - max channel pixel value).
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param nAlpha2 Image alpha opacity (0 - max channel pixel value).
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param eAlphaOp alpha-blending operation..
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAlphaCompC_8s_C1R(
        TypedPointer<Npp8s> pSrc1, 
        int nSrc1Step, 
        byte nAlpha1, 
        TypedPointer<Npp8s> pSrc2, 
        int nSrc2Step, 
        byte nAlpha2, 
        TypedPointer<Npp8s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eAlphaOp)
    {
        return JNpp.checkResult(nppiAlphaCompC_8s_C1RNative(pSrc1, nSrc1Step, nAlpha1, pSrc2, nSrc2Step, nAlpha2, pDst, nDstStep, oSizeROI, eAlphaOp));
    }
    private static native int nppiAlphaCompC_8s_C1RNative(
        TypedPointer<Npp8s> pSrc1, 
        int nSrc1Step, 
        byte nAlpha1, 
        TypedPointer<Npp8s> pSrc2, 
        int nSrc2Step, 
        byte nAlpha2, 
        TypedPointer<Npp8s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eAlphaOp);


    /**
     * <pre>
     * One 16-bit unsigned short channel image composition using constant alpha.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nAlpha1 Image alpha opacity (0 - max channel pixel value).
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param nAlpha2 Image alpha opacity (0 - max channel pixel value).
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param eAlphaOp alpha-blending operation..
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAlphaCompC_16u_C1R(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        short nAlpha1, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        short nAlpha2, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eAlphaOp)
    {
        return JNpp.checkResult(nppiAlphaCompC_16u_C1RNative(pSrc1, nSrc1Step, nAlpha1, pSrc2, nSrc2Step, nAlpha2, pDst, nDstStep, oSizeROI, eAlphaOp));
    }
    private static native int nppiAlphaCompC_16u_C1RNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        short nAlpha1, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        short nAlpha2, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eAlphaOp);


    /**
     * <pre>
     * Three 16-bit unsigned short channel image composition using constant alpha.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nAlpha1 Image alpha opacity (0 - max channel pixel value).
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param nAlpha2 Image alpha opacity (0 - max channel pixel value).
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param eAlphaOp alpha-blending operation..
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAlphaCompC_16u_C3R(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        short nAlpha1, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        short nAlpha2, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eAlphaOp)
    {
        return JNpp.checkResult(nppiAlphaCompC_16u_C3RNative(pSrc1, nSrc1Step, nAlpha1, pSrc2, nSrc2Step, nAlpha2, pDst, nDstStep, oSizeROI, eAlphaOp));
    }
    private static native int nppiAlphaCompC_16u_C3RNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        short nAlpha1, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        short nAlpha2, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eAlphaOp);


    /**
     * <pre>
     * Four 16-bit unsigned short channel image composition using constant alpha.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nAlpha1 Image alpha opacity (0 - max channel pixel value).
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param nAlpha2 Image alpha opacity (0 - max channel pixel value).
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param eAlphaOp alpha-blending operation..
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAlphaCompC_16u_C4R(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        short nAlpha1, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        short nAlpha2, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eAlphaOp)
    {
        return JNpp.checkResult(nppiAlphaCompC_16u_C4RNative(pSrc1, nSrc1Step, nAlpha1, pSrc2, nSrc2Step, nAlpha2, pDst, nDstStep, oSizeROI, eAlphaOp));
    }
    private static native int nppiAlphaCompC_16u_C4RNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        short nAlpha1, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        short nAlpha2, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eAlphaOp);


    /**
     * <pre>
     * Four 16-bit unsigned short channel image composition with alpha using constant source alpha.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nAlpha1 Image alpha opacity (0 - max channel pixel value).
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param nAlpha2 Image alpha opacity (0 - max channel pixel value).
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param eAlphaOp alpha-blending operation..
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAlphaCompC_16u_AC4R(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        short nAlpha1, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        short nAlpha2, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eAlphaOp)
    {
        return JNpp.checkResult(nppiAlphaCompC_16u_AC4RNative(pSrc1, nSrc1Step, nAlpha1, pSrc2, nSrc2Step, nAlpha2, pDst, nDstStep, oSizeROI, eAlphaOp));
    }
    private static native int nppiAlphaCompC_16u_AC4RNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        short nAlpha1, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        short nAlpha2, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eAlphaOp);


    /**
     * <pre>
     * One 16-bit signed short channel image composition using constant alpha.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nAlpha1 Image alpha opacity (0 - max channel pixel value).
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param nAlpha2 Image alpha opacity (0 - max channel pixel value).
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param eAlphaOp alpha-blending operation..
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAlphaCompC_16s_C1R(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        short nAlpha1, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        short nAlpha2, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eAlphaOp)
    {
        return JNpp.checkResult(nppiAlphaCompC_16s_C1RNative(pSrc1, nSrc1Step, nAlpha1, pSrc2, nSrc2Step, nAlpha2, pDst, nDstStep, oSizeROI, eAlphaOp));
    }
    private static native int nppiAlphaCompC_16s_C1RNative(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        short nAlpha1, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        short nAlpha2, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eAlphaOp);


    /**
     * <pre>
     * One 32-bit unsigned integer channel image composition using constant alpha.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nAlpha1 Image alpha opacity (0 - max channel pixel value).
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param nAlpha2 Image alpha opacity (0 - max channel pixel value).
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param eAlphaOp alpha-blending operation..
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAlphaCompC_32u_C1R(
        TypedPointer<Npp32u> pSrc1, 
        int nSrc1Step, 
        int nAlpha1, 
        TypedPointer<Npp32u> pSrc2, 
        int nSrc2Step, 
        int nAlpha2, 
        TypedPointer<Npp32u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eAlphaOp)
    {
        return JNpp.checkResult(nppiAlphaCompC_32u_C1RNative(pSrc1, nSrc1Step, nAlpha1, pSrc2, nSrc2Step, nAlpha2, pDst, nDstStep, oSizeROI, eAlphaOp));
    }
    private static native int nppiAlphaCompC_32u_C1RNative(
        TypedPointer<Npp32u> pSrc1, 
        int nSrc1Step, 
        int nAlpha1, 
        TypedPointer<Npp32u> pSrc2, 
        int nSrc2Step, 
        int nAlpha2, 
        TypedPointer<Npp32u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eAlphaOp);


    /**
     * <pre>
     * One 32-bit signed integer channel image composition using constant alpha.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nAlpha1 Image alpha opacity (0 - max channel pixel value).
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param nAlpha2 Image alpha opacity (0 - max channel pixel value).
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param eAlphaOp alpha-blending operation..
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAlphaCompC_32s_C1R(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        int nAlpha1, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        int nAlpha2, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eAlphaOp)
    {
        return JNpp.checkResult(nppiAlphaCompC_32s_C1RNative(pSrc1, nSrc1Step, nAlpha1, pSrc2, nSrc2Step, nAlpha2, pDst, nDstStep, oSizeROI, eAlphaOp));
    }
    private static native int nppiAlphaCompC_32s_C1RNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        int nAlpha1, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        int nAlpha2, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eAlphaOp);


    /**
     * <pre>
     * One 32-bit floating point channel image composition using constant alpha.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nAlpha1 Image alpha opacity (0.0 - 1.0).
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param nAlpha2 Image alpha opacity (0.0 - 1.0).
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param eAlphaOp alpha-blending operation..
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAlphaCompC_32f_C1R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        float nAlpha1, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        float nAlpha2, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eAlphaOp)
    {
        return JNpp.checkResult(nppiAlphaCompC_32f_C1RNative(pSrc1, nSrc1Step, nAlpha1, pSrc2, nSrc2Step, nAlpha2, pDst, nDstStep, oSizeROI, eAlphaOp));
    }
    private static native int nppiAlphaCompC_32f_C1RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        float nAlpha1, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        float nAlpha2, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eAlphaOp);


    /** @} image_alphacompc */
    /**
     * <pre>
     * @defgroup image_alphapremulc AlphaPremulC
     * 
     * Premultiplies pixels of an image using a constant alpha value.
     *
     * @{
     * </pre>
     */
    /**
     * <pre>
     * One 8-bit unsigned char channel image premultiplication using constant alpha.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nAlpha1 Image alpha opacity (0 - max channel pixel value).
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAlphaPremulC_8u_C1R(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        byte nAlpha1, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiAlphaPremulC_8u_C1RNative(pSrc1, nSrc1Step, nAlpha1, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiAlphaPremulC_8u_C1RNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        byte nAlpha1, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 8-bit unsigned char channel in place image premultiplication using constant alpha.
     * @param nAlpha1 Image alpha opacity (0 - max channel pixel value).
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAlphaPremulC_8u_C1IR(
        byte nAlpha1, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiAlphaPremulC_8u_C1IRNative(nAlpha1, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiAlphaPremulC_8u_C1IRNative(
        byte nAlpha1, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 8-bit unsigned char channel image premultiplication using constant alpha.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nAlpha1 Image alpha opacity (0 - max channel pixel value).
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAlphaPremulC_8u_C3R(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        byte nAlpha1, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiAlphaPremulC_8u_C3RNative(pSrc1, nSrc1Step, nAlpha1, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiAlphaPremulC_8u_C3RNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        byte nAlpha1, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 8-bit unsigned char channel in place image premultiplication using constant alpha.
     * @param nAlpha1 Image alpha opacity (0 - max channel pixel value).
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAlphaPremulC_8u_C3IR(
        byte nAlpha1, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiAlphaPremulC_8u_C3IRNative(nAlpha1, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiAlphaPremulC_8u_C3IRNative(
        byte nAlpha1, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 8-bit unsigned char channel image premultiplication using constant alpha.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nAlpha1 Image alpha opacity (0 - max channel pixel value).
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAlphaPremulC_8u_C4R(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        byte nAlpha1, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiAlphaPremulC_8u_C4RNative(pSrc1, nSrc1Step, nAlpha1, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiAlphaPremulC_8u_C4RNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        byte nAlpha1, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 8-bit unsigned char channel in place image premultiplication using constant alpha.
     * @param nAlpha1 Image alpha opacity (0 - max channel pixel value).
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAlphaPremulC_8u_C4IR(
        byte nAlpha1, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiAlphaPremulC_8u_C4IRNative(nAlpha1, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiAlphaPremulC_8u_C4IRNative(
        byte nAlpha1, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 8-bit unsigned char channel image premultiplication with alpha using constant alpha.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nAlpha1 Image alpha opacity (0 - max channel pixel value).
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAlphaPremulC_8u_AC4R(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        byte nAlpha1, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiAlphaPremulC_8u_AC4RNative(pSrc1, nSrc1Step, nAlpha1, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiAlphaPremulC_8u_AC4RNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        byte nAlpha1, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 8-bit unsigned char channel in place image premultiplication with alpha using constant alpha.
     * @param nAlpha1 Image alpha opacity (0 - max channel pixel value).
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAlphaPremulC_8u_AC4IR(
        byte nAlpha1, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiAlphaPremulC_8u_AC4IRNative(nAlpha1, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiAlphaPremulC_8u_AC4IRNative(
        byte nAlpha1, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 16-bit unsigned short channel image premultiplication using constant alpha.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nAlpha1 Image alpha opacity (0 - max channel pixel value).
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAlphaPremulC_16u_C1R(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        short nAlpha1, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiAlphaPremulC_16u_C1RNative(pSrc1, nSrc1Step, nAlpha1, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiAlphaPremulC_16u_C1RNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        short nAlpha1, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 16-bit unsigned short channel in place image premultiplication using constant alpha.
     * @param nAlpha1 Image alpha opacity (0 - max channel pixel value).
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAlphaPremulC_16u_C1IR(
        short nAlpha1, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiAlphaPremulC_16u_C1IRNative(nAlpha1, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiAlphaPremulC_16u_C1IRNative(
        short nAlpha1, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 16-bit unsigned short channel image premultiplication using constant alpha.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nAlpha1 Image alpha opacity (0 - max channel pixel value).
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAlphaPremulC_16u_C3R(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        short nAlpha1, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiAlphaPremulC_16u_C3RNative(pSrc1, nSrc1Step, nAlpha1, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiAlphaPremulC_16u_C3RNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        short nAlpha1, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 16-bit unsigned short channel in place image premultiplication using constant alpha.
     * @param nAlpha1 Image alpha opacity (0 - max channel pixel value).
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAlphaPremulC_16u_C3IR(
        short nAlpha1, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiAlphaPremulC_16u_C3IRNative(nAlpha1, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiAlphaPremulC_16u_C3IRNative(
        short nAlpha1, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 16-bit unsigned short channel image premultiplication using constant alpha.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nAlpha1 Image alpha opacity (0 - max channel pixel value).
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAlphaPremulC_16u_C4R(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        short nAlpha1, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiAlphaPremulC_16u_C4RNative(pSrc1, nSrc1Step, nAlpha1, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiAlphaPremulC_16u_C4RNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        short nAlpha1, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 16-bit unsigned short channel in place image premultiplication using constant alpha.
     * @param nAlpha1 Image alpha opacity (0 - max channel pixel value).
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAlphaPremulC_16u_C4IR(
        short nAlpha1, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiAlphaPremulC_16u_C4IRNative(nAlpha1, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiAlphaPremulC_16u_C4IRNative(
        short nAlpha1, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 16-bit unsigned short channel image premultiplication with alpha using constant alpha.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nAlpha1 Image alpha opacity (0 - max channel pixel value).
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAlphaPremulC_16u_AC4R(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        short nAlpha1, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiAlphaPremulC_16u_AC4RNative(pSrc1, nSrc1Step, nAlpha1, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiAlphaPremulC_16u_AC4RNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        short nAlpha1, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 16-bit unsigned short channel in place image premultiplication with alpha using constant alpha.
     * @param nAlpha1 Image alpha opacity (0 - max channel pixel value).
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAlphaPremulC_16u_AC4IR(
        short nAlpha1, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiAlphaPremulC_16u_AC4IRNative(nAlpha1, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiAlphaPremulC_16u_AC4IRNative(
        short nAlpha1, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /** @} image_alphapremulc */
    /**
     * <pre>
     * @defgroup image_alphacomp AlphaComp
     *
     * Composite two images using alpha opacity values contained in each image.
     *
     * @{
     * </pre>
     */
    /**
     * <pre>
     * One 8-bit unsigned char channel image composition using image alpha values (0 - max channel pixel value).
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param eAlphaOp alpha-blending operation..
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAlphaComp_8u_AC1R(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eAlphaOp)
    {
        return JNpp.checkResult(nppiAlphaComp_8u_AC1RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, eAlphaOp));
    }
    private static native int nppiAlphaComp_8u_AC1RNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eAlphaOp);


    /**
     * <pre>
     * Four 8-bit unsigned char channel image composition using image alpha values (0 - max channel pixel value).
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param eAlphaOp alpha-blending operation..
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAlphaComp_8u_AC4R(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eAlphaOp)
    {
        return JNpp.checkResult(nppiAlphaComp_8u_AC4RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, eAlphaOp));
    }
    private static native int nppiAlphaComp_8u_AC4RNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eAlphaOp);


    /**
     * <pre>
     * One 8-bit signed char channel image composition using image alpha values (0 - max channel pixel value).
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param eAlphaOp alpha-blending operation..
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAlphaComp_8s_AC1R(
        TypedPointer<Npp8s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eAlphaOp)
    {
        return JNpp.checkResult(nppiAlphaComp_8s_AC1RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, eAlphaOp));
    }
    private static native int nppiAlphaComp_8s_AC1RNative(
        TypedPointer<Npp8s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eAlphaOp);


    /**
     * <pre>
     * One 16-bit unsigned short channel image composition using image alpha values (0 - max channel pixel value).
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param eAlphaOp alpha-blending operation..
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAlphaComp_16u_AC1R(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eAlphaOp)
    {
        return JNpp.checkResult(nppiAlphaComp_16u_AC1RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, eAlphaOp));
    }
    private static native int nppiAlphaComp_16u_AC1RNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eAlphaOp);


    /**
     * <pre>
     * Four 16-bit unsigned short channel image composition using image alpha values (0 - max channel pixel value).
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param eAlphaOp alpha-blending operation..
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAlphaComp_16u_AC4R(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eAlphaOp)
    {
        return JNpp.checkResult(nppiAlphaComp_16u_AC4RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, eAlphaOp));
    }
    private static native int nppiAlphaComp_16u_AC4RNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eAlphaOp);


    /**
     * <pre>
     * One 16-bit signed short channel image composition using image alpha values (0 - max channel pixel value).
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param eAlphaOp alpha-blending operation..
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAlphaComp_16s_AC1R(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eAlphaOp)
    {
        return JNpp.checkResult(nppiAlphaComp_16s_AC1RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, eAlphaOp));
    }
    private static native int nppiAlphaComp_16s_AC1RNative(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eAlphaOp);


    /**
     * <pre>
     * One 32-bit unsigned integer channel image composition using image alpha values (0 - max channel pixel value).
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param eAlphaOp alpha-blending operation..
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAlphaComp_32u_AC1R(
        TypedPointer<Npp32u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eAlphaOp)
    {
        return JNpp.checkResult(nppiAlphaComp_32u_AC1RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, eAlphaOp));
    }
    private static native int nppiAlphaComp_32u_AC1RNative(
        TypedPointer<Npp32u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eAlphaOp);


    /**
     * <pre>
     * Four 32-bit unsigned integer channel image composition using image alpha values (0 - max channel pixel value).
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param eAlphaOp alpha-blending operation..
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAlphaComp_32u_AC4R(
        TypedPointer<Npp32u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eAlphaOp)
    {
        return JNpp.checkResult(nppiAlphaComp_32u_AC4RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, eAlphaOp));
    }
    private static native int nppiAlphaComp_32u_AC4RNative(
        TypedPointer<Npp32u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eAlphaOp);


    /**
     * <pre>
     * One 32-bit signed integer channel image composition using image alpha values (0 - max channel pixel value).
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param eAlphaOp alpha-blending operation..
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAlphaComp_32s_AC1R(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eAlphaOp)
    {
        return JNpp.checkResult(nppiAlphaComp_32s_AC1RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, eAlphaOp));
    }
    private static native int nppiAlphaComp_32s_AC1RNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eAlphaOp);


    /**
     * <pre>
     * Four 32-bit signed integer channel image composition using image alpha values (0 - max channel pixel value).
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param eAlphaOp alpha-blending operation..
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAlphaComp_32s_AC4R(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eAlphaOp)
    {
        return JNpp.checkResult(nppiAlphaComp_32s_AC4RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, eAlphaOp));
    }
    private static native int nppiAlphaComp_32s_AC4RNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eAlphaOp);


    /**
     * <pre>
     * One 32-bit floating point channel image composition using image alpha values (0.0 - 1.0).
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param eAlphaOp alpha-blending operation..
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAlphaComp_32f_AC1R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eAlphaOp)
    {
        return JNpp.checkResult(nppiAlphaComp_32f_AC1RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, eAlphaOp));
    }
    private static native int nppiAlphaComp_32f_AC1RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eAlphaOp);


    /**
     * <pre>
     * Four 32-bit floating point channel image composition using image alpha values (0.0 - 1.0).
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param eAlphaOp alpha-blending operation..
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAlphaComp_32f_AC4R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eAlphaOp)
    {
        return JNpp.checkResult(nppiAlphaComp_32f_AC4RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, eAlphaOp));
    }
    private static native int nppiAlphaComp_32f_AC4RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eAlphaOp);


    /** @} image_alphacomp */
    /**
     * <pre>
     * @defgroup image_alphapremul AlphaPremul
     * 
     * Premultiplies image pixels by image alpha opacity values.
     *
     * @{
     * </pre>
     */
    /**
     * <pre>
     * Four 8-bit unsigned char channel image premultiplication with pixel alpha (0 - max channel pixel value).
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAlphaPremul_8u_AC4R(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiAlphaPremul_8u_AC4RNative(pSrc1, nSrc1Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiAlphaPremul_8u_AC4RNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 8-bit unsigned char channel in place image premultiplication with pixel alpha (0 - max channel pixel value).
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAlphaPremul_8u_AC4IR(
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiAlphaPremul_8u_AC4IRNative(pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiAlphaPremul_8u_AC4IRNative(
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 16-bit unsigned short channel image premultiplication with pixel alpha (0 - max channel pixel value).
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAlphaPremul_16u_AC4R(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiAlphaPremul_16u_AC4RNative(pSrc1, nSrc1Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiAlphaPremul_16u_AC4RNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 16-bit unsigned short channel in place image premultiplication with pixel alpha (0 - max channel pixel value).
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAlphaPremul_16u_AC4IR(
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiAlphaPremul_16u_AC4IRNative(pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiAlphaPremul_16u_AC4IRNative(
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 3 channel 8-bit unsigned packed RGB to 3 channel 8-bit unsigned packed YUV color conversion.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiRGBToYUV_8u_C3R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiRGBToYUV_8u_C3RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiRGBToYUV_8u_C3RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 4 channel 8-bit unsigned packed RGB with alpha to 4 channel 8-bit unsigned packed YUV color conversion with alpha, not affecting alpha.
     * images.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiRGBToYUV_8u_AC4R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiRGBToYUV_8u_AC4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiRGBToYUV_8u_AC4RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 3 channel 8-bit unsigned planar RGB to 3 channel 8-bit unsigned planar YUV color conversion.
     *
     * @param pSrc \ref source_planar_image_pointer_array.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_planar_image_pointer_array.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiRGBToYUV_8u_P3R(
        TypedPointer<Npp8u>[] pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u>[] pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiRGBToYUV_8u_P3RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiRGBToYUV_8u_P3RNative(
        TypedPointer<Npp8u>[] pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u>[] pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 3 channel 8-bit unsigned packed RGB to 3 channel 8-bit unsigned planar YUV color conversion.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_planar_image_pointer_array.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiRGBToYUV_8u_C3P3R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u>[] pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiRGBToYUV_8u_C3P3RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiRGBToYUV_8u_C3P3RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u>[] pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 4 channel 8-bit unsigned packed RGB with alpha to 4 channel 8-bit unsigned planar YUV color conversion with alpha.
     * images.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_planar_image_pointer_array.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiRGBToYUV_8u_AC4P4R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u>[] pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiRGBToYUV_8u_AC4P4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiRGBToYUV_8u_AC4P4RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u>[] pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 3 channel 8-bit unsigned packed YUV to 3 channel 8-bit unsigned packed RGB color conversion.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiYUVToRGB_8u_C3R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiYUVToRGB_8u_C3RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiYUVToRGB_8u_C3RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 4 channel 8-bit packed YUV with alpha to 4 channel 8-bit unsigned packed RGB color conversion with alpha, not affecting alpha.
     * images.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiYUVToRGB_8u_AC4R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiYUVToRGB_8u_AC4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiYUVToRGB_8u_AC4RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 3 channel 8-bit unsigned planar YUV to 3 channel 8-bit unsigned planar RGB color conversion.
     *
     * @param pSrc \ref source_planar_image_pointer_array.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_planar_image_pointer_array.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiYUVToRGB_8u_P3R(
        TypedPointer<Npp8u>[] pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u>[] pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiYUVToRGB_8u_P3RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiYUVToRGB_8u_P3RNative(
        TypedPointer<Npp8u>[] pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u>[] pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 3 channel 8-bit unsigned planar YUV to 3 channel 8-bit unsigned packed RGB color conversion.
     *
     * @param pSrc \ref source_planar_image_pointer_array.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiYUVToRGB_8u_P3C3R(
        TypedPointer<Npp8u>[] pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiYUVToRGB_8u_P3C3RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiYUVToRGB_8u_P3C3RNative(
        TypedPointer<Npp8u>[] pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 3 channel 8-bit unsigned packed RGB to 2 channel 8-bit unsigned packed YUV422 color conversion.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiRGBToYUV422_8u_C3C2R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiRGBToYUV422_8u_C3C2RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiRGBToYUV422_8u_C3C2RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 3 channel 8-bit unsigned planar RGB to 3 channel 8-bit unsigned planar YUV422 color conversion.
     * images.
     *                         
     * @param pSrc \ref source_planar_image_pointer_array.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_planar_image_pointer_array.
     * @param rDstStep \ref destination_planar_image_line_step_array.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiRGBToYUV422_8u_P3R(
        TypedPointer<Npp8u>[] pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u>[] pDst, 
        int[] rDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiRGBToYUV422_8u_P3RNative(pSrc, nSrcStep, pDst, rDstStep, oSizeROI));
    }
    private static native int nppiRGBToYUV422_8u_P3RNative(
        TypedPointer<Npp8u>[] pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u>[] pDst, 
        int[] rDstStep, 
        NppiSize oSizeROI);


    public static int nppiRGBToYUV422_8u_C3P3R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u>[] pDst, 
        int[] rDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiRGBToYUV422_8u_C3P3RNative(pSrc, nSrcStep, pDst, rDstStep, oSizeROI));
    }
    private static native int nppiRGBToYUV422_8u_C3P3RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u>[] pDst, 
        int[] rDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 2 channel 8-bit unsigned packed YUV422 to 3 channel 8-bit unsigned packed RGB color conversion.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiYUV422ToRGB_8u_C2C3R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiYUV422ToRGB_8u_C2C3RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiYUV422ToRGB_8u_C2C3RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 3 channel 8-bit unsigned planar YUV422 to 3 channel 8-bit unsigned planar RGB color conversion.
     *
     * @param pSrc \ref source_planar_image_pointer_array.
     * @param rSrcStep \ref source_planar_image_line_step_array.
     * @param pDst \ref destination_planar_image_pointer_array.
     * @param nDstStep \ref destination_planar_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiYUV422ToRGB_8u_P3R(
        TypedPointer<Npp8u>[] pSrc, 
        int[] rSrcStep, 
        TypedPointer<Npp8u>[] pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiYUV422ToRGB_8u_P3RNative(pSrc, rSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiYUV422ToRGB_8u_P3RNative(
        TypedPointer<Npp8u>[] pSrc, 
        int[] rSrcStep, 
        TypedPointer<Npp8u>[] pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    public static int nppiYUV422ToRGB_8u_P3C3R(
        TypedPointer<Npp8u>[] pSrc, 
        int[] rSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiYUV422ToRGB_8u_P3C3RNative(pSrc, rSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiYUV422ToRGB_8u_P3C3RNative(
        TypedPointer<Npp8u>[] pSrc, 
        int[] rSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 3 channel 8-bit unsigned planar YUV422 to 4 channel 8-bit unsigned packed RGB color conversion with alpha.
     *
     * @param pSrc \ref source_planar_image_pointer_array.
     * @param rSrcStep \ref source_planar_image_line_step_array.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiYUV422ToRGB_8u_P3AC4R(
        TypedPointer<Npp8u>[] pSrc, 
        int[] rSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiYUV422ToRGB_8u_P3AC4RNative(pSrc, rSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiYUV422ToRGB_8u_P3AC4RNative(
        TypedPointer<Npp8u>[] pSrc, 
        int[] rSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 3 channel 8-bit unsigned planar RGB to 3 channel 8-bit unsigned planar YUV420 color conversion.
     * images.
     *
     * @param pSrc \ref source_planar_image_pointer_array.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_planar_image_pointer_array.
     * @param rDstStep \ref destination_planar_image_line_step_array.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiRGBToYUV420_8u_P3R(
        TypedPointer<Npp8u>[] pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u>[] pDst, 
        int[] rDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiRGBToYUV420_8u_P3RNative(pSrc, nSrcStep, pDst, rDstStep, oSizeROI));
    }
    private static native int nppiRGBToYUV420_8u_P3RNative(
        TypedPointer<Npp8u>[] pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u>[] pDst, 
        int[] rDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 3 channel 8-bit unsigned packed RGB to 3 channel 8-bit unsigned planar YUV420 color conversion.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_planar_image_pointer_array.
     * @param rDstStep \ref destination_planar_image_line_step_array.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiRGBToYUV420_8u_C3P3R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u>[] pDst, 
        int[] rDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiRGBToYUV420_8u_C3P3RNative(pSrc, nSrcStep, pDst, rDstStep, oSizeROI));
    }
    private static native int nppiRGBToYUV420_8u_C3P3RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u>[] pDst, 
        int[] rDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 3 channel 8-bit unsigned planar YUV420 to 3 channel 8-bit unsigned planar RGB color conversion.
     *
     * @param pSrc \ref source_planar_image_pointer_array.
     * @param rSrcStep \ref source_planar_image_line_step_array.
     * @param pDst \ref destination_planar_image_pointer_array.
     * @param nDstStep \ref destination_planar_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiYUV420ToRGB_8u_P3R(
        TypedPointer<Npp8u>[] pSrc, 
        int[] rSrcStep, 
        TypedPointer<Npp8u>[] pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiYUV420ToRGB_8u_P3RNative(pSrc, rSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiYUV420ToRGB_8u_P3RNative(
        TypedPointer<Npp8u>[] pSrc, 
        int[] rSrcStep, 
        TypedPointer<Npp8u>[] pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 3 channel 8-bit unsigned planar YUV420 to 3 channel 8-bit unsigned packed RGB color conversion.
     *
     * @param pSrc \ref source_planar_image_pointer_array.
     * @param rSrcStep \ref source_planar_image_line_step_array.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiYUV420ToRGB_8u_P3C3R(
        TypedPointer<Npp8u>[] pSrc, 
        int[] rSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiYUV420ToRGB_8u_P3C3RNative(pSrc, rSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiYUV420ToRGB_8u_P3C3RNative(
        TypedPointer<Npp8u>[] pSrc, 
        int[] rSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 3 channel 8-bit unsigned planar YUV420 to 4 channel 8-bit unsigned packed RGB color conversion with alpha.
     *
     * @param pSrc \ref source_planar_image_pointer_array.
     * @param rSrcStep \ref source_planar_image_line_step_array.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiYUV420ToRGB_8u_P3AC4R(
        TypedPointer<Npp8u>[] pSrc, 
        int[] rSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiYUV420ToRGB_8u_P3AC4RNative(pSrc, rSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiYUV420ToRGB_8u_P3AC4RNative(
        TypedPointer<Npp8u>[] pSrc, 
        int[] rSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 4 channel 8-bit unsigned pacmed BGR with alpha to 3 channel 8-bit unsigned planar YUV420 color conversion.
     * images.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_planar_image_pointer_array.
     * @param rDstStep \ref destination_planar_image_line_step_array.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiBGRToYUV420_8u_AC4P3R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u>[] pDst, 
        int[] rDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiBGRToYUV420_8u_AC4P3RNative(pSrc, nSrcStep, pDst, rDstStep, oSizeROI));
    }
    private static native int nppiBGRToYUV420_8u_AC4P3RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u>[] pDst, 
        int[] rDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 3 channel 8-bit unsigned planar YUV420 to 3 channel 8-bit unsigned packed BGR color conversion.
     *
     * @param pSrc \ref source_planar_image_pointer_array.
     * @param rSrcStep \ref source_planar_image_line_step_array.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiYUV420ToBGR_8u_P3C3R(
        TypedPointer<Npp8u>[] pSrc, 
        int[] rSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiYUV420ToBGR_8u_P3C3RNative(pSrc, rSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiYUV420ToBGR_8u_P3C3RNative(
        TypedPointer<Npp8u>[] pSrc, 
        int[] rSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 3 channel 8-bit unsigned packed RGB to 3 channel unsigned 8-bit packed YCbCr color conversion.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiRGBToYCbCr_8u_C3R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiRGBToYCbCr_8u_C3RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiRGBToYCbCr_8u_C3RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 4 channel 8-bit unsigned packed RGB with alpha to 4 channel unsigned 8-bit packed YCbCr with alpha color conversion, not affecting alpha.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiRGBToYCbCr_8u_AC4R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiRGBToYCbCr_8u_AC4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiRGBToYCbCr_8u_AC4RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    public static int nppiRGBToYCbCr_8u_P3R(
        TypedPointer<Npp8u>[] pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u>[] pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiRGBToYCbCr_8u_P3RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiRGBToYCbCr_8u_P3RNative(
        TypedPointer<Npp8u>[] pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u>[] pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 3 channel 8-bit unsigned packed RGB to 3 channel unsigned 8-bit planar YCbCr color conversion.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiRGBToYCbCr_8u_C3P3R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u>[] pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiRGBToYCbCr_8u_C3P3RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiRGBToYCbCr_8u_C3P3RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u>[] pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 4 channel 8-bit unsigned packed RGB with alpha to 3 channel 8-bit unsigned planar YCbCr color conversion.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_planar_image_pointer_array.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiRGBToYCbCr_8u_AC4P3R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u>[] pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiRGBToYCbCr_8u_AC4P3RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiRGBToYCbCr_8u_AC4P3RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u>[] pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 3 channel 8-bit unsigned packed YCbCr to 3 channel 8-bit unsigned packed RGB color conversion.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiYCbCrToRGB_8u_C3R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiYCbCrToRGB_8u_C3RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiYCbCrToRGB_8u_C3RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 4 channel 8-bit unsigned packed YCbCr with alpha to 4 channel 8-bit unsigned packed RGB with alpha color conversion, not affecting alpha.
     * Alpha channel is the last channel and is not processed.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiYCbCrToRGB_8u_AC4R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiYCbCrToRGB_8u_AC4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiYCbCrToRGB_8u_AC4RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 3 channel 8-bit unsigned planar YCbCr to 3 channel 8-bit unsigned planar RGB color conversion.
     *
     * @param pSrc \ref source_planar_image_pointer_array.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_planar_image_pointer_array.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiYCbCrToRGB_8u_P3R(
        TypedPointer<Npp8u>[] pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u>[] pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiYCbCrToRGB_8u_P3RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiYCbCrToRGB_8u_P3RNative(
        TypedPointer<Npp8u>[] pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u>[] pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 3 channel 8-bit unsigned planar YCbCr to 3 channel 8-bit unsigned packed RGB color conversion.
     *
     * @param pSrc \ref source_planar_image_pointer_array.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiYCbCrToRGB_8u_P3C3R(
        TypedPointer<Npp8u>[] pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiYCbCrToRGB_8u_P3C3RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiYCbCrToRGB_8u_P3C3RNative(
        TypedPointer<Npp8u>[] pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 3 channel 8-bit unsigned planar YCbCr to 4 channel 8-bit unsigned packed RGB color conversion with constant alpha.
     *
     * @param pSrc \ref source_planar_image_pointer_array.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nAval 8-bit unsigned alpha constant.                                         
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiYCbCrToRGB_8u_P3C4R(
        TypedPointer<Npp8u>[] pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        byte nAval)
    {
        return JNpp.checkResult(nppiYCbCrToRGB_8u_P3C4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, nAval));
    }
    private static native int nppiYCbCrToRGB_8u_P3C4RNative(
        TypedPointer<Npp8u>[] pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        byte nAval);


    /**
     * <pre>
     * 3 channel 8-bit unsigned planar YCbCr to 3 channel 8-bit unsigned packed BGR color conversion.
     *
     * @param pSrc \ref source_planar_image_pointer_array.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiYCbCrToBGR_8u_P3C3R(
        TypedPointer<Npp8u>[] pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiYCbCrToBGR_8u_P3C3RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiYCbCrToBGR_8u_P3C3RNative(
        TypedPointer<Npp8u>[] pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 3 channel 8-bit unsigned planar YCbCr to 4 channel 8-bit unsigned packed BGR color conversion with constant alpha.
     *
     * @param pSrc \ref source_planar_image_pointer_array.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nAval 8-bit unsigned alpha constant.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiYCbCrToBGR_8u_P3C4R(
        TypedPointer<Npp8u>[] pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        byte nAval)
    {
        return JNpp.checkResult(nppiYCbCrToBGR_8u_P3C4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, nAval));
    }
    private static native int nppiYCbCrToBGR_8u_P3C4RNative(
        TypedPointer<Npp8u>[] pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        byte nAval);


    public static int nppiYCbCrToBGR_709CSC_8u_P3C3R(
        TypedPointer<Npp8u>[] pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiYCbCrToBGR_709CSC_8u_P3C3RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiYCbCrToBGR_709CSC_8u_P3C3RNative(
        TypedPointer<Npp8u>[] pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 3 channel 8-bit unsigned planar YCbCr to 4 channel 8-bit unsigned packed BGR_709CSC color conversion with constant alpha.
     *
     * @param pSrc \ref source_planar_image_pointer_array.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nAval 8-bit unsigned alpha constant.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiYCbCrToBGR_709CSC_8u_P3C4R(
        TypedPointer<Npp8u>[] pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        byte nAval)
    {
        return JNpp.checkResult(nppiYCbCrToBGR_709CSC_8u_P3C4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, nAval));
    }
    private static native int nppiYCbCrToBGR_709CSC_8u_P3C4RNative(
        TypedPointer<Npp8u>[] pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        byte nAval);


    /**
     * <pre>
     * 3 channel 8-bit unsigned packed RGB to 2 channel 8-bit unsigned packed YCbCr422 color conversion.
     * images.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiRGBToYCbCr422_8u_C3C2R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiRGBToYCbCr422_8u_C3C2RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiRGBToYCbCr422_8u_C3C2RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 3 channel 8-bit unsigned packed RGB to 3 channel 8-bit unsigned planar YCbCr422 color conversion.
     * images.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_planar_image_pointer_array.
     * @param rDstStep \ref destination_planar_image_line_step_array.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiRGBToYCbCr422_8u_C3P3R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u>[] pDst, 
        int[] rDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiRGBToYCbCr422_8u_C3P3RNative(pSrc, nSrcStep, pDst, rDstStep, oSizeROI));
    }
    private static native int nppiRGBToYCbCr422_8u_C3P3RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u>[] pDst, 
        int[] rDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 3 channel 8-bit unsigned planar RGB to 2 channel 8-bit unsigned packed YCbCr422 color conversion.
     * images.
     *
     * @param pSrc \ref source_planar_image_pointer_array.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiRGBToYCbCr422_8u_P3C2R(
        TypedPointer<Npp8u>[] pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiRGBToYCbCr422_8u_P3C2RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiRGBToYCbCr422_8u_P3C2RNative(
        TypedPointer<Npp8u>[] pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    public static int nppiYCbCr422ToRGB_8u_C2C3R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiYCbCr422ToRGB_8u_C2C3RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiYCbCr422ToRGB_8u_C2C3RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 2 channel 8-bit unsigned packed YCbCr422 to 3 channel 8-bit unsigned planar RGB color conversion.
     * images.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_planar_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiYCbCr422ToRGB_8u_C2P3R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u>[] pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiYCbCr422ToRGB_8u_C2P3RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiYCbCr422ToRGB_8u_C2P3RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u>[] pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 3 channel 8-bit unsigned planar YCbCr422 to 3 channel 8-bit unsigned packed RGB color conversion.
     * images.
     *
     * @param pSrc \ref source_planar_image_pointer_array.
     * @param rSrcStep \ref source_planar_image_line_step_array.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiYCbCr422ToRGB_8u_P3C3R(
        TypedPointer<Npp8u>[] pSrc, 
        int[] rSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiYCbCr422ToRGB_8u_P3C3RNative(pSrc, rSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiYCbCr422ToRGB_8u_P3C3RNative(
        TypedPointer<Npp8u>[] pSrc, 
        int[] rSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 3 channel 8-bit unsigned packed RGB to 2 channel 8-bit unsigned packed YCrCb422 color conversion.
     * images.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiRGBToYCrCb422_8u_C3C2R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiRGBToYCrCb422_8u_C3C2RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiRGBToYCrCb422_8u_C3C2RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 3 channel 8-bit unsigned planar RGB to 2 channel 8-bit unsigned packed YCrCb422 color conversion.
     * images.
     *
     * @param pSrc \ref source_planar_image_pointer_array.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiRGBToYCrCb422_8u_P3C2R(
        TypedPointer<Npp8u>[] pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiRGBToYCrCb422_8u_P3C2RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiRGBToYCrCb422_8u_P3C2RNative(
        TypedPointer<Npp8u>[] pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 2 channel 8-bit unsigned packed YCrCb422 to 3 channel 8-bit unsigned packed RGB color conversion.
     * images.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiYCrCb422ToRGB_8u_C2C3R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiYCrCb422ToRGB_8u_C2C3RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiYCrCb422ToRGB_8u_C2C3RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 2 channel 8-bit unsigned packed YCrCb422 to 3 channel 8-bit unsigned planar RGB color conversion.
     * images.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_planar_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiYCrCb422ToRGB_8u_C2P3R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u>[] pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiYCrCb422ToRGB_8u_C2P3RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiYCrCb422ToRGB_8u_C2P3RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u>[] pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 3 channel 8-bit unsigned packed BGR to 2 channel 8-bit unsigned packed YCrCb422 color conversion.
     * images.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiBGRToYCbCr422_8u_C3C2R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiBGRToYCbCr422_8u_C3C2RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiBGRToYCbCr422_8u_C3C2RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 4 channel 8-bit unsigned packed BGR with alpha to 2 channel 8-bit unsigned packed YCrCb422 color conversion.
     * images.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiBGRToYCbCr422_8u_AC4C2R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiBGRToYCbCr422_8u_AC4C2RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiBGRToYCbCr422_8u_AC4C2RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 3 channel 8-bit unsigned packed BGR to 3 channel 8-bit unsigned planar YCbCr422 color conversion.
     * images.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_planar_image_pointer_array.
     * @param rDstStep \ref destination_planar_image_line_step_array.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiBGRToYCbCr422_8u_C3P3R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u>[] pDst, 
        int[] rDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiBGRToYCbCr422_8u_C3P3RNative(pSrc, nSrcStep, pDst, rDstStep, oSizeROI));
    }
    private static native int nppiBGRToYCbCr422_8u_C3P3RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u>[] pDst, 
        int[] rDstStep, 
        NppiSize oSizeROI);


    public static int nppiBGRToYCbCr422_8u_AC4P3R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u>[] pDst, 
        int[] rDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiBGRToYCbCr422_8u_AC4P3RNative(pSrc, nSrcStep, pDst, rDstStep, oSizeROI));
    }
    private static native int nppiBGRToYCbCr422_8u_AC4P3RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u>[] pDst, 
        int[] rDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 2 channel 8-bit unsigned packed YCrCb422 to 3 channel 8-bit unsigned packed BGR color conversion.
     * images.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiYCbCr422ToBGR_8u_C2C3R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiYCbCr422ToBGR_8u_C2C3RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiYCbCr422ToBGR_8u_C2C3RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 2 channel 8-bit unsigned packed YCrCb422 to 4 channel 8-bit unsigned packed BGR color conversion with constant alpha.
     * images.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nAval 8-bit unsigned alpha constant.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiYCbCr422ToBGR_8u_C2C4R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        byte nAval)
    {
        return JNpp.checkResult(nppiYCbCr422ToBGR_8u_C2C4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, nAval));
    }
    private static native int nppiYCbCr422ToBGR_8u_C2C4RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        byte nAval);


    /**
     * <pre>
     * 3 channel 8-bit unsigned planar YCbCr422 to 3 channel 8-bit unsigned packed BGR color conversion.
     * images.
     *
     * @param pSrc \ref source_planar_image_pointer_array.
     * @param rSrcStep \ref source_planar_image_line_step_array.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiYCbCr422ToBGR_8u_P3C3R(
        TypedPointer<Npp8u>[] pSrc, 
        int[] rSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiYCbCr422ToBGR_8u_P3C3RNative(pSrc, rSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiYCbCr422ToBGR_8u_P3C3RNative(
        TypedPointer<Npp8u>[] pSrc, 
        int[] rSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 3 channel 8-bit unsigned packed RGB to 2 channel 8-bit unsigned packed CbYCr422 color conversion.
     * images.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiRGBToCbYCr422_8u_C3C2R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiRGBToCbYCr422_8u_C3C2RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiRGBToCbYCr422_8u_C3C2RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    public static int nppiRGBToCbYCr422Gamma_8u_C3C2R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiRGBToCbYCr422Gamma_8u_C3C2RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiRGBToCbYCr422Gamma_8u_C3C2RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 2 channel 8-bit unsigned packed CbYCrC22 to 3 channel 8-bit unsigned packed RGB color conversion.
     * images.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCbYCr422ToRGB_8u_C2C3R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiCbYCr422ToRGB_8u_C2C3RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCbYCr422ToRGB_8u_C2C3RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    public static int nppiBGRToCbYCr422_8u_AC4C2R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiBGRToCbYCr422_8u_AC4C2RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiBGRToCbYCr422_8u_AC4C2RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 3 channel 8-bit unsigned packed BGR to 2 channel 8-bit unsigned packed CbYCr422_709HDTV color conversion.
     * images.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiBGRToCbYCr422_709HDTV_8u_C3C2R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiBGRToCbYCr422_709HDTV_8u_C3C2RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiBGRToCbYCr422_709HDTV_8u_C3C2RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    public static int nppiBGRToCbYCr422_709HDTV_8u_AC4C2R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiBGRToCbYCr422_709HDTV_8u_AC4C2RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiBGRToCbYCr422_709HDTV_8u_AC4C2RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 2 channel 8-bit unsigned packed CbYCr422 to 4 channel 8-bit unsigned packed BGR color conversion with alpha.
     * images.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nAval 8-bit unsigned alpha constant.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCbYCr422ToBGR_8u_C2C4R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        byte nAval)
    {
        return JNpp.checkResult(nppiCbYCr422ToBGR_8u_C2C4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, nAval));
    }
    private static native int nppiCbYCr422ToBGR_8u_C2C4RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        byte nAval);


    public static int nppiCbYCr422ToBGR_709HDTV_8u_C2C3R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiCbYCr422ToBGR_709HDTV_8u_C2C3RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCbYCr422ToBGR_709HDTV_8u_C2C3RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 2 channel 8-bit unsigned packed CbYCr422 to 4 channel 8-bit unsigned packed BGR_709HDTV color conversion with constant alpha.
     * images.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nAval 8-bit unsigned alpha constant.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCbYCr422ToBGR_709HDTV_8u_C2C4R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        byte nAval)
    {
        return JNpp.checkResult(nppiCbYCr422ToBGR_709HDTV_8u_C2C4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, nAval));
    }
    private static native int nppiCbYCr422ToBGR_709HDTV_8u_C2C4RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        byte nAval);


    /**
     * <pre>
     * 3 channel 8-bit unsigned packed RGB to 3 channel 8-bit unsigned planar YCbCr420 color conversion.
     * images.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_planar_image_pointer_array.
     * @param rDstStep \ref destination_planar_image_line_step_array.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiRGBToYCbCr420_8u_C3P3R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u>[] pDst, 
        int[] rDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiRGBToYCbCr420_8u_C3P3RNative(pSrc, nSrcStep, pDst, rDstStep, oSizeROI));
    }
    private static native int nppiRGBToYCbCr420_8u_C3P3RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u>[] pDst, 
        int[] rDstStep, 
        NppiSize oSizeROI);


    public static int nppiYCbCr420ToRGB_8u_P3C3R(
        TypedPointer<Npp8u>[] pSrc, 
        int[] rSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiYCbCr420ToRGB_8u_P3C3RNative(pSrc, rSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiYCbCr420ToRGB_8u_P3C3RNative(
        TypedPointer<Npp8u>[] pSrc, 
        int[] rSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    public static int nppiRGBToYCrCb420_8u_AC4P3R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u>[] pDst, 
        int[] rDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiRGBToYCrCb420_8u_AC4P3RNative(pSrc, nSrcStep, pDst, rDstStep, oSizeROI));
    }
    private static native int nppiRGBToYCrCb420_8u_AC4P3RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u>[] pDst, 
        int[] rDstStep, 
        NppiSize oSizeROI);


    public static int nppiYCrCb420ToRGB_8u_P3C4R(
        TypedPointer<Npp8u>[] pSrc, 
        int[] rSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        byte nAval)
    {
        return JNpp.checkResult(nppiYCrCb420ToRGB_8u_P3C4RNative(pSrc, rSrcStep, pDst, nDstStep, oSizeROI, nAval));
    }
    private static native int nppiYCrCb420ToRGB_8u_P3C4RNative(
        TypedPointer<Npp8u>[] pSrc, 
        int[] rSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        byte nAval);


    /**
     * <pre>
     * 3 channel 8-bit unsigned packed BGR to 3 channel 8-bit unsigned planar YCbCr420 color conversion.
     * images.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_planar_image_pointer_array.
     * @param rDstStep \ref destination_planar_image_line_step_array.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiBGRToYCbCr420_8u_C3P3R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u>[] pDst, 
        int[] rDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiBGRToYCbCr420_8u_C3P3RNative(pSrc, nSrcStep, pDst, rDstStep, oSizeROI));
    }
    private static native int nppiBGRToYCbCr420_8u_C3P3RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u>[] pDst, 
        int[] rDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 4 channel 8-bit unsigned packed BGR with alpha to 3 channel 8-bit unsigned planar YCbCr420 color conversion.
     * images.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_planar_image_pointer_array.
     * @param rDstStep \ref destination_planar_image_line_step_array.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiBGRToYCbCr420_8u_AC4P3R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u>[] pDst, 
        int[] rDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiBGRToYCbCr420_8u_AC4P3RNative(pSrc, nSrcStep, pDst, rDstStep, oSizeROI));
    }
    private static native int nppiBGRToYCbCr420_8u_AC4P3RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u>[] pDst, 
        int[] rDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 3 channel 8-bit unsigned packed BGR to 3 channel 8-bit unsigned planar YCbCr420_709CSC color conversion.
     * images.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_planar_image_pointer_array.
     * @param rDstStep \ref destination_planar_image_line_step_array.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiBGRToYCbCr420_709CSC_8u_C3P3R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u>[] pDst, 
        int[] rDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiBGRToYCbCr420_709CSC_8u_C3P3RNative(pSrc, nSrcStep, pDst, rDstStep, oSizeROI));
    }
    private static native int nppiBGRToYCbCr420_709CSC_8u_C3P3RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u>[] pDst, 
        int[] rDstStep, 
        NppiSize oSizeROI);


    public static int nppiBGRToYCbCr420_709CSC_8u_AC4P3R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u>[] pDst, 
        int[] rDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiBGRToYCbCr420_709CSC_8u_AC4P3RNative(pSrc, nSrcStep, pDst, rDstStep, oSizeROI));
    }
    private static native int nppiBGRToYCbCr420_709CSC_8u_AC4P3RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u>[] pDst, 
        int[] rDstStep, 
        NppiSize oSizeROI);


    public static int nppiBGRToYCbCr420_709HDTV_8u_AC4P3R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u>[] pDst, 
        int[] rDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiBGRToYCbCr420_709HDTV_8u_AC4P3RNative(pSrc, nSrcStep, pDst, rDstStep, oSizeROI));
    }
    private static native int nppiBGRToYCbCr420_709HDTV_8u_AC4P3RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u>[] pDst, 
        int[] rDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 3 channel 8-bit unsigned packed BGR to 3 channel 8-bit unsigned planar YCrCb420_709CSC color conversion.
     * images.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_planar_image_pointer_array.
     * @param rDstStep \ref destination_planar_image_line_step_array.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiBGRToYCrCb420_709CSC_8u_C3P3R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u>[] pDst, 
        int[] rDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiBGRToYCrCb420_709CSC_8u_C3P3RNative(pSrc, nSrcStep, pDst, rDstStep, oSizeROI));
    }
    private static native int nppiBGRToYCrCb420_709CSC_8u_C3P3RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u>[] pDst, 
        int[] rDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 4 channel 8-bit unsigned packed BGR with alpha to 3 channel 8-bit unsigned planar YCrCb420_709CSC color conversion.
     * images.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_planar_image_pointer_array.
     * @param rDstStep \ref destination_planar_image_line_step_array.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiBGRToYCrCb420_709CSC_8u_AC4P3R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u>[] pDst, 
        int[] rDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiBGRToYCrCb420_709CSC_8u_AC4P3RNative(pSrc, nSrcStep, pDst, rDstStep, oSizeROI));
    }
    private static native int nppiBGRToYCrCb420_709CSC_8u_AC4P3RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u>[] pDst, 
        int[] rDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 3 channel 8-bit unsigned planar YCbCr420 to 3 channel 8-bit unsigned packed BGR color conversion.
     *
     * @param pSrc \ref source_planar_image_pointer_array.
     * @param rSrcStep \ref source_planar_image_line_step_array.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiYCbCr420ToBGR_8u_P3C3R(
        TypedPointer<Npp8u>[] pSrc, 
        int[] rSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiYCbCr420ToBGR_8u_P3C3RNative(pSrc, rSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiYCbCr420ToBGR_8u_P3C3RNative(
        TypedPointer<Npp8u>[] pSrc, 
        int[] rSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 3 channel 8-bit unsigned planar YCbCr420 to 4 channel 8-bit unsigned packed BGR color conversion with constant alpha.
     *
     * @param pSrc \ref source_planar_image_pointer_array.
     * @param rSrcStep \ref source_planar_image_line_step_array.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nAval 8-bit unsigned alpha constant.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiYCbCr420ToBGR_8u_P3C4R(
        TypedPointer<Npp8u>[] pSrc, 
        int[] rSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        byte nAval)
    {
        return JNpp.checkResult(nppiYCbCr420ToBGR_8u_P3C4RNative(pSrc, rSrcStep, pDst, nDstStep, oSizeROI, nAval));
    }
    private static native int nppiYCbCr420ToBGR_8u_P3C4RNative(
        TypedPointer<Npp8u>[] pSrc, 
        int[] rSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        byte nAval);


    public static int nppiYCbCr420ToBGR_709CSC_8u_P3C3R(
        TypedPointer<Npp8u>[] pSrc, 
        int[] rSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiYCbCr420ToBGR_709CSC_8u_P3C3RNative(pSrc, rSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiYCbCr420ToBGR_709CSC_8u_P3C3RNative(
        TypedPointer<Npp8u>[] pSrc, 
        int[] rSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 3 channel 8-bit unsigned planar YCbCr420 to 4 channel 8-bit unsigned packed BGR_709HDTV color conversion with constant alpha.
     *
     * @param pSrc \ref source_planar_image_pointer_array.
     * @param rSrcStep \ref source_planar_image_line_step_array.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nAval 8-bit unsigned alpha constant.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiYCbCr420ToBGR_709HDTV_8u_P3C4R(
        TypedPointer<Npp8u>[] pSrc, 
        int[] rSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        byte nAval)
    {
        return JNpp.checkResult(nppiYCbCr420ToBGR_709HDTV_8u_P3C4RNative(pSrc, rSrcStep, pDst, nDstStep, oSizeROI, nAval));
    }
    private static native int nppiYCbCr420ToBGR_709HDTV_8u_P3C4RNative(
        TypedPointer<Npp8u>[] pSrc, 
        int[] rSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        byte nAval);


    /**
     * <pre>
     * 3 channel 8-bit unsigned packed BGR to 3 channel 8-bit unsigned planar YCrCb420 color conversion.
     * images.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_planar_image_pointer_array.
     * @param rDstStep \ref destination_planar_image_line_step_array.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiBGRToYCrCb420_8u_C3P3R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u>[] pDst, 
        int[] rDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiBGRToYCrCb420_8u_C3P3RNative(pSrc, nSrcStep, pDst, rDstStep, oSizeROI));
    }
    private static native int nppiBGRToYCrCb420_8u_C3P3RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u>[] pDst, 
        int[] rDstStep, 
        NppiSize oSizeROI);


    public static int nppiBGRToYCrCb420_8u_AC4P3R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u>[] pDst, 
        int[] rDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiBGRToYCrCb420_8u_AC4P3RNative(pSrc, nSrcStep, pDst, rDstStep, oSizeROI));
    }
    private static native int nppiBGRToYCrCb420_8u_AC4P3RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u>[] pDst, 
        int[] rDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 3 channel 8-bit unsigned packed BGR to 3 channel 8-bit unsigned planar YCbCr411 color conversion.
     * images.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_planar_image_pointer_array.
     * @param rDstStep \ref destination_planar_image_line_step_array.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiBGRToYCbCr411_8u_C3P3R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u>[] pDst, 
        int[] rDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiBGRToYCbCr411_8u_C3P3RNative(pSrc, nSrcStep, pDst, rDstStep, oSizeROI));
    }
    private static native int nppiBGRToYCbCr411_8u_C3P3RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u>[] pDst, 
        int[] rDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 4 channel 8-bit unsigned packed BGR with alpha to 3 channel 8-bit unsigned planar YCbCr411 color conversion.
     * images.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_planar_image_pointer_array.
     * @param rDstStep \ref destination_planar_image_line_step_array.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiBGRToYCbCr411_8u_AC4P3R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u>[] pDst, 
        int[] rDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiBGRToYCbCr411_8u_AC4P3RNative(pSrc, nSrcStep, pDst, rDstStep, oSizeROI));
    }
    private static native int nppiBGRToYCbCr411_8u_AC4P3RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u>[] pDst, 
        int[] rDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 3 channel 8-bit unsigned planar YCbCr411 to 3 channel 8-bit unsigned packed BGR color conversion.
     *
     * @param pSrc \ref source_planar_image_pointer_array.
     * @param rSrcStep \ref source_planar_image_line_step_array.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiYCbCr411ToBGR_8u_P3C3R(
        TypedPointer<Npp8u>[] pSrc, 
        int[] rSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiYCbCr411ToBGR_8u_P3C3RNative(pSrc, rSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiYCbCr411ToBGR_8u_P3C3RNative(
        TypedPointer<Npp8u>[] pSrc, 
        int[] rSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 3 channel 8-bit unsigned planar YCbCr411 to 4 channel 8-bit unsigned packed BGR color conversion with constant alpha.
     *
     * @param pSrc \ref source_planar_image_pointer_array.
     * @param rSrcStep \ref source_planar_image_line_step_array.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nAval 8-bit unsigned alpha constant.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiYCbCr411ToBGR_8u_P3C4R(
        TypedPointer<Npp8u>[] pSrc, 
        int[] rSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        byte nAval)
    {
        return JNpp.checkResult(nppiYCbCr411ToBGR_8u_P3C4RNative(pSrc, rSrcStep, pDst, nDstStep, oSizeROI, nAval));
    }
    private static native int nppiYCbCr411ToBGR_8u_P3C4RNative(
        TypedPointer<Npp8u>[] pSrc, 
        int[] rSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        byte nAval);


    /**
     * <pre>
     * 3 channel 8-bit unsigned packed RGB to 3 channel 8-bit unsigned packed XYZ color conversion.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiRGBToXYZ_8u_C3R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiRGBToXYZ_8u_C3RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiRGBToXYZ_8u_C3RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 4 channel 8-bit unsigned packed RGB with alpha to 4 channel 8-bit unsigned packed XYZ with alpha color conversion.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiRGBToXYZ_8u_AC4R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiRGBToXYZ_8u_AC4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiRGBToXYZ_8u_AC4RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 3 channel 8-bit unsigned packed XYZ to 3 channel 8-bit unsigned packed RGB color conversion.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiXYZToRGB_8u_C3R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiXYZToRGB_8u_C3RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiXYZToRGB_8u_C3RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 4 channel 8-bit unsigned packed XYZ with alpha to 4 channel 8-bit unsigned packed RGB with alpha color conversion.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiXYZToRGB_8u_AC4R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiXYZToRGB_8u_AC4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiXYZToRGB_8u_AC4RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 3 channel 8-bit unsigned packed RGB to 3 channel 8-bit unsigned packed LUV color conversion.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiRGBToLUV_8u_C3R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiRGBToLUV_8u_C3RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiRGBToLUV_8u_C3RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 4 channel 8-bit unsigned packed RGB with alpha to 4 channel 8-bit unsigned packed LUV with alpha color conversion.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiRGBToLUV_8u_AC4R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiRGBToLUV_8u_AC4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiRGBToLUV_8u_AC4RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    public static int nppiLUVToRGB_8u_C3R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiLUVToRGB_8u_C3RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiLUVToRGB_8u_C3RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    public static int nppiLUVToRGB_8u_AC4R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiLUVToRGB_8u_AC4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiLUVToRGB_8u_AC4RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 3 channel 8-bit unsigned packed BGR to 3 channel 8-bit unsigned packed Lab color conversion.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiBGRToLab_8u_C3R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiBGRToLab_8u_C3RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiBGRToLab_8u_C3RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    public static int nppiLabToBGR_8u_C3R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiLabToBGR_8u_C3RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiLabToBGR_8u_C3RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 3 channel 8-bit unsigned packed RGB to 3 channel 8-bit unsigned packed YCC color conversion.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiRGBToYCC_8u_C3R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiRGBToYCC_8u_C3RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiRGBToYCC_8u_C3RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 4 channel 8-bit unsigned packed RGB with alpha to 4 channel 8-bit unsigned packed YCC with alpha color conversion.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiRGBToYCC_8u_AC4R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiRGBToYCC_8u_AC4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiRGBToYCC_8u_AC4RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    public static int nppiYCCToRGB_8u_C3R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiYCCToRGB_8u_C3RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiYCCToRGB_8u_C3RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 4 channel 8-bit unsigned packed YCC with alpha to 4 channel 8-bit unsigned packed RGB with alpha color conversion.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiYCCToRGB_8u_AC4R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiYCCToRGB_8u_AC4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiYCCToRGB_8u_AC4RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 3 channel 8-bit unsigned packed RGB to 3 channel 8-bit unsigned packed HLS color conversion.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiRGBToHLS_8u_C3R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiRGBToHLS_8u_C3RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiRGBToHLS_8u_C3RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 4 channel 8-bit unsigned packed RGB with alpha to 4 channel 8-bit unsigned packed HLS with alpha color conversion.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiRGBToHLS_8u_AC4R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiRGBToHLS_8u_AC4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiRGBToHLS_8u_AC4RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 3 channel 8-bit unsigned packed HLS to 3 channel 8-bit unsigned packed RGB color conversion.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiHLSToRGB_8u_C3R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiHLSToRGB_8u_C3RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiHLSToRGB_8u_C3RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 4 channel 8-bit unsigned packed HLS with alpha to 4 channel 8-bit unsigned packed RGB with alpha color conversion.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiHLSToRGB_8u_AC4R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiHLSToRGB_8u_AC4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiHLSToRGB_8u_AC4RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 4 channel 8-bit unsigned packed BGR with alpha to 4 channel 8-bit unsigned packed HLS with alpha color conversion.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiBGRToHLS_8u_AC4R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiBGRToHLS_8u_AC4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiBGRToHLS_8u_AC4RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 3 channel 8-bit unsigned packed BGR to 3 channel 8-bit unsigned planar HLS color conversion.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_planar_image_pointer_array.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiBGRToHLS_8u_C3P3R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u>[] pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiBGRToHLS_8u_C3P3RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiBGRToHLS_8u_C3P3RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u>[] pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 4 channel 8-bit unsigned packed BGR with alpha to 4 channel 8-bit unsigned planar HLS with alpha color conversion.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_planar_image_pointer_array.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiBGRToHLS_8u_AC4P4R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u>[] pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiBGRToHLS_8u_AC4P4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiBGRToHLS_8u_AC4P4RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u>[] pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 3 channel 8-bit unsigned planar BGR to 3 channel 8-bit unsigned packed HLS color conversion.
     *
     * @param pSrc \ref source_planar_image_pointer_array.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiBGRToHLS_8u_P3C3R(
        TypedPointer<Npp8u>[] pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiBGRToHLS_8u_P3C3RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiBGRToHLS_8u_P3C3RNative(
        TypedPointer<Npp8u>[] pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 4 channel 8-bit unsigned planar BGR with alpha to 4 channel 8-bit unsigned packed HLS with alpha color conversion.
     *
     * @param pSrc \ref source_planar_image_pointer_array.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiBGRToHLS_8u_AP4C4R(
        TypedPointer<Npp8u>[] pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiBGRToHLS_8u_AP4C4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiBGRToHLS_8u_AP4C4RNative(
        TypedPointer<Npp8u>[] pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 3 channel 8-bit unsigned planar BGR to 3 channel 8-bit unsigned planar HLS color conversion.
     *
     * @param pSrc \ref source_planar_image_pointer_array.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_planar_image_pointer_array.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiBGRToHLS_8u_P3R(
        TypedPointer<Npp8u>[] pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u>[] pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiBGRToHLS_8u_P3RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiBGRToHLS_8u_P3RNative(
        TypedPointer<Npp8u>[] pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u>[] pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 4 channel 8-bit unsigned planar BGR with alpha to 4 channel 8-bit unsigned planar HLS with alpha color conversion.
     *
     * @param pSrc \ref source_planar_image_pointer_array.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_planar_image_pointer_array.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiBGRToHLS_8u_AP4R(
        TypedPointer<Npp8u>[] pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u>[] pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiBGRToHLS_8u_AP4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiBGRToHLS_8u_AP4RNative(
        TypedPointer<Npp8u>[] pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u>[] pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    public static int nppiHLSToBGR_8u_C3P3R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u>[] pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiHLSToBGR_8u_C3P3RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiHLSToBGR_8u_C3P3RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u>[] pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 4 channel 8-bit unsigned packed HLS with alpha to 4 channel 8-bit unsigned planar BGR with alpha color conversion.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_planar_image_pointer_array.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiHLSToBGR_8u_AC4P4R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u>[] pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiHLSToBGR_8u_AC4P4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiHLSToBGR_8u_AC4P4RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u>[] pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 3 channel 8-bit unsigned planar HLS to 3 channel 8-bit unsigned planar BGR color conversion.
     *
     * @param pSrc \ref source_planar_image_pointer_array.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_planar_image_pointer_array.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiHLSToBGR_8u_P3R(
        TypedPointer<Npp8u>[] pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u>[] pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiHLSToBGR_8u_P3RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiHLSToBGR_8u_P3RNative(
        TypedPointer<Npp8u>[] pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u>[] pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 4 channel 8-bit unsigned planar HLS with alpha to 4 channel 8-bit unsigned planar BGR with alpha color conversion.
     *
     * @param pSrc \ref source_planar_image_pointer_array.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_planar_image_pointer_array.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiHLSToBGR_8u_AP4R(
        TypedPointer<Npp8u>[] pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u>[] pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiHLSToBGR_8u_AP4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiHLSToBGR_8u_AP4RNative(
        TypedPointer<Npp8u>[] pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u>[] pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 4 channel 8-bit unsigned packed HLS with alpha to 4 channel 8-bit unsigned packed BGR with alpha color conversion.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiHLSToBGR_8u_AC4R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiHLSToBGR_8u_AC4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiHLSToBGR_8u_AC4RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 3 channel 8-bit unsigned planar HLS to 3 channel 8-bit unsigned packed BGR color conversion.
     *
     * @param pSrc \ref source_planar_image_pointer_array.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiHLSToBGR_8u_P3C3R(
        TypedPointer<Npp8u>[] pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiHLSToBGR_8u_P3C3RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiHLSToBGR_8u_P3C3RNative(
        TypedPointer<Npp8u>[] pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 4 channel 8-bit unsigned planar HLS with alpha to 4 channel 8-bit unsigned packed BGR with alpha color conversion.
     *
     * @param pSrc \ref source_planar_image_pointer_array.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiHLSToBGR_8u_AP4C4R(
        TypedPointer<Npp8u>[] pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiHLSToBGR_8u_AP4C4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiHLSToBGR_8u_AP4C4RNative(
        TypedPointer<Npp8u>[] pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    public static int nppiRGBToHSV_8u_C3R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiRGBToHSV_8u_C3RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiRGBToHSV_8u_C3RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 4 channel 8-bit unsigned packed RGB with alpha to 4 channel 8-bit unsigned packed HSV with alpha color conversion.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiRGBToHSV_8u_AC4R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiRGBToHSV_8u_AC4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiRGBToHSV_8u_AC4RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 3 channel 8-bit unsigned packed HSV to 3 channel 8-bit unsigned packed RGB color conversion.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiHSVToRGB_8u_C3R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiHSVToRGB_8u_C3RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiHSVToRGB_8u_C3RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 4 channel 8-bit unsigned packed HSV with alpha to 4 channel 8-bit unsigned packed RGB with alpha color conversion.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiHSVToRGB_8u_AC4R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiHSVToRGB_8u_AC4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiHSVToRGB_8u_AC4RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 3 channel 8-bit unsigned planar YCbCr420 to 2 channel 8-bit unsigned planar YCbCr411 sampling format conversion.
     *
     * @param pSrc \ref source_planar_image_pointer_array.
     * @param rSrcStep \ref source_planar_image_line_step_array.
     * @param pDstY \ref destination_planar_image_pointer.
     * @param nDstYStep \ref destination_planar_image_line_step.
     * @param pDstCbCr \ref destination_planar_image_pointer.
     * @param nDstCbCrStep \ref destination_planar_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiYCbCr420ToYCbCr411_8u_P3P2R(
        TypedPointer<Npp8u>[] pSrc, 
        int[] rSrcStep, 
        TypedPointer<Npp8u> pDstY, 
        int nDstYStep, 
        TypedPointer<Npp8u> pDstCbCr, 
        int nDstCbCrStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiYCbCr420ToYCbCr411_8u_P3P2RNative(pSrc, rSrcStep, pDstY, nDstYStep, pDstCbCr, nDstCbCrStep, oSizeROI));
    }
    private static native int nppiYCbCr420ToYCbCr411_8u_P3P2RNative(
        TypedPointer<Npp8u>[] pSrc, 
        int[] rSrcStep, 
        TypedPointer<Npp8u> pDstY, 
        int nDstYStep, 
        TypedPointer<Npp8u> pDstCbCr, 
        int nDstCbCrStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 2 channel 8-bit unsigned planar YCbCr420 to 3 channel 8-bit unsigned planar YCbCr411 sampling format conversion.
     *
     * @param pSrcY \ref source_planar_image_pointer.
     * @param nSrcYStep \ref source_planar_image_line_step.
     * @param pSrcCbCr \ref source_planar_image_pointer.
     * @param nSrcCbCrStep \ref source_planar_image_line_step.
     * @param pDst \ref destination_planar_image_pointer_array.
     * @param rDstStep \ref destination_planar_image_line_step_array.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiYCbCr420ToYCbCr411_8u_P2P3R(
        TypedPointer<Npp8u> pSrcY, 
        int nSrcYStep, 
        TypedPointer<Npp8u> pSrcCbCr, 
        int nSrcCbCrStep, 
        TypedPointer<Npp8u>[] pDst, 
        int[] rDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiYCbCr420ToYCbCr411_8u_P2P3RNative(pSrcY, nSrcYStep, pSrcCbCr, nSrcCbCrStep, pDst, rDstStep, oSizeROI));
    }
    private static native int nppiYCbCr420ToYCbCr411_8u_P2P3RNative(
        TypedPointer<Npp8u> pSrcY, 
        int nSrcYStep, 
        TypedPointer<Npp8u> pSrcCbCr, 
        int nSrcCbCrStep, 
        TypedPointer<Npp8u>[] pDst, 
        int[] rDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 2 channel 8-bit unsigned packed YCbCr422 to 3 channel 8-bit unsigned planar YCbCr422 sampling format conversion.
     * images.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_planar_image_pointer_array.
     * @param rDstStep \ref destination_planar_image_line_step_array.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiYCbCr422_8u_C2P3R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u>[] pDst, 
        int[] rDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiYCbCr422_8u_C2P3RNative(pSrc, nSrcStep, pDst, rDstStep, oSizeROI));
    }
    private static native int nppiYCbCr422_8u_C2P3RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u>[] pDst, 
        int[] rDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 3 channel 8-bit unsigned planar YCbCr422 to 2 channel 8-bit unsigned packed YCbCr422 sampling format conversion.
     * images.
     *
     * @param pSrc \ref source_planar_image_pointer_array.
     * @param rSrcStep \ref source_planar_image_line_step_array.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiYCbCr422_8u_P3C2R(
        TypedPointer<Npp8u>[] pSrc, 
        int[] rSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiYCbCr422_8u_P3C2RNative(pSrc, rSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiYCbCr422_8u_P3C2RNative(
        TypedPointer<Npp8u>[] pSrc, 
        int[] rSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 2 channel 8-bit unsigned packed YCbCr422 to 2 channel 8-bit unsigned packed YCrCb422 sampling format conversion.
     * images.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiYCbCr422ToYCrCb422_8u_C2R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiYCbCr422ToYCrCb422_8u_C2RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiYCbCr422ToYCrCb422_8u_C2RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 3 channel 8-bit unsigned planar YCbCr422 to 2 channel 8-bit unsigned packed YCrCb422 sampling format conversion.
     * images.
     *
     * @param pSrc \ref source_planar_image_pointer_array.
     * @param rSrcStep \ref source_planar_image_line_step_array.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiYCbCr422ToYCrCb422_8u_P3C2R(
        TypedPointer<Npp8u>[] pSrc, 
        int[] rSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiYCbCr422ToYCrCb422_8u_P3C2RNative(pSrc, rSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiYCbCr422ToYCrCb422_8u_P3C2RNative(
        TypedPointer<Npp8u>[] pSrc, 
        int[] rSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 2 channel 8-bit unsigned packed YCbCr422 to 2 channel 8-bit unsigned packed CbYCr422 sampling format conversion.
     * images.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiYCbCr422ToCbYCr422_8u_C2R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiYCbCr422ToCbYCr422_8u_C2RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiYCbCr422ToCbYCr422_8u_C2RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    public static int nppiCbYCr422ToYCbCr411_8u_C2P3R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u>[] pDst, 
        int[] rDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiCbYCr422ToYCbCr411_8u_C2P3RNative(pSrc, nSrcStep, pDst, rDstStep, oSizeROI));
    }
    private static native int nppiCbYCr422ToYCbCr411_8u_C2P3RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u>[] pDst, 
        int[] rDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 3 channel 8-bit unsigned planar YCbCr422 to 3 channel 8-bit unsigned planar YCbCr420 sampling format conversion.
     * images.
     *
     * @param pSrc \ref source_planar_image_pointer_array.
     * @param rSrcStep \ref source_planar_image_line_step_array.
     * @param pDst \ref destination_planar_image_pointer_array.
     * @param nDstStep \ref destination_planar_image_line_step_array.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiYCbCr422ToYCbCr420_8u_P3R(
        TypedPointer<Npp8u>[] pSrc, 
        int[] rSrcStep, 
        TypedPointer<Npp8u>[] pDst, 
        int[] nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiYCbCr422ToYCbCr420_8u_P3RNative(pSrc, rSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiYCbCr422ToYCbCr420_8u_P3RNative(
        TypedPointer<Npp8u>[] pSrc, 
        int[] rSrcStep, 
        TypedPointer<Npp8u>[] pDst, 
        int[] nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 3 channel 8-bit unsigned planar YCbCr422 to 2 channel 8-bit unsigned planar YCbCr420 sampling format conversion.
     * images.
     *
     * @param pSrc \ref source_planar_image_pointer_array.
     * @param rSrcStep \ref source_planar_image_line_step_array.
     * @param pDstY \ref destination_planar_image_pointer.
     * @param nDstYStep \ref destination_planar_image_line_step.
     * @param pDstCbCr \ref destination_planar_image_pointer.
     * @param nDstCbCrStep \ref destination_planar_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiYCbCr422ToYCbCr420_8u_P3P2R(
        TypedPointer<Npp8u>[] pSrc, 
        int[] rSrcStep, 
        TypedPointer<Npp8u> pDstY, 
        int nDstYStep, 
        TypedPointer<Npp8u> pDstCbCr, 
        int nDstCbCrStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiYCbCr422ToYCbCr420_8u_P3P2RNative(pSrc, rSrcStep, pDstY, nDstYStep, pDstCbCr, nDstCbCrStep, oSizeROI));
    }
    private static native int nppiYCbCr422ToYCbCr420_8u_P3P2RNative(
        TypedPointer<Npp8u>[] pSrc, 
        int[] rSrcStep, 
        TypedPointer<Npp8u> pDstY, 
        int nDstYStep, 
        TypedPointer<Npp8u> pDstCbCr, 
        int nDstCbCrStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 2 channel 8-bit unsigned packed YCbCr422 to 3 channel 8-bit unsigned planar YCbCr420 sampling format conversion.
     * images.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_planar_image_pointer_array.
     * @param rDstStep \ref destination_planar_image_line_step_array.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiYCbCr422ToYCbCr420_8u_C2P3R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u>[] pDst, 
        int[] rDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiYCbCr422ToYCbCr420_8u_C2P3RNative(pSrc, nSrcStep, pDst, rDstStep, oSizeROI));
    }
    private static native int nppiYCbCr422ToYCbCr420_8u_C2P3RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u>[] pDst, 
        int[] rDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 2 channel 8-bit unsigned packed YCbCr422 to 2 channel 8-bit unsigned planar YCbCr420 sampling format conversion.
     * images.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDstY \ref destination_planar_image_pointer.
     * @param nDstYStep \ref destination_planar_image_line_step.
     * @param pDstCbCr \ref destination_planar_image_pointer.
     * @param nDstCbCrStep \ref destination_planar_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiYCbCr422ToYCbCr420_8u_C2P2R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDstY, 
        int nDstYStep, 
        TypedPointer<Npp8u> pDstCbCr, 
        int nDstCbCrStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiYCbCr422ToYCbCr420_8u_C2P2RNative(pSrc, nSrcStep, pDstY, nDstYStep, pDstCbCr, nDstCbCrStep, oSizeROI));
    }
    private static native int nppiYCbCr422ToYCbCr420_8u_C2P2RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDstY, 
        int nDstYStep, 
        TypedPointer<Npp8u> pDstCbCr, 
        int nDstCbCrStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 3 channel 8-bit unsigned planar YCrCb420 to 3 channel 8-bit unsigned planar YCbCr422 sampling format conversion.
     * images.
     *
     * @param pSrc \ref source_planar_image_pointer_array.
     * @param rSrcStep \ref source_planar_image_line_step_array.
     * @param pDst \ref destination_planar_image_pointer_array.
     * @param rDstStep \ref destination_planar_image_line_step_array.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiYCrCb420ToYCbCr422_8u_P3R(
        TypedPointer<Npp8u>[] pSrc, 
        int[] rSrcStep, 
        TypedPointer<Npp8u>[] pDst, 
        int[] rDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiYCrCb420ToYCbCr422_8u_P3RNative(pSrc, rSrcStep, pDst, rDstStep, oSizeROI));
    }
    private static native int nppiYCrCb420ToYCbCr422_8u_P3RNative(
        TypedPointer<Npp8u>[] pSrc, 
        int[] rSrcStep, 
        TypedPointer<Npp8u>[] pDst, 
        int[] rDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 3 channel 8-bit unsigned planar YCrCb420 to 2 channel 8-bit unsigned packed YCbCr422 sampling format conversion.
     * images.
     *
     * @param pSrc \ref source_planar_image_pointer_array.
     * @param rSrcStep \ref source_planar_image_line_step_array.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiYCrCb420ToYCbCr422_8u_P3C2R(
        TypedPointer<Npp8u>[] pSrc, 
        int[] rSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiYCrCb420ToYCbCr422_8u_P3C2RNative(pSrc, rSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiYCrCb420ToYCbCr422_8u_P3C2RNative(
        TypedPointer<Npp8u>[] pSrc, 
        int[] rSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    public static int nppiYCbCr422ToYCrCb420_8u_C2P3R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u>[] pDst, 
        int[] rDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiYCbCr422ToYCrCb420_8u_C2P3RNative(pSrc, nSrcStep, pDst, rDstStep, oSizeROI));
    }
    private static native int nppiYCbCr422ToYCrCb420_8u_C2P3RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u>[] pDst, 
        int[] rDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 3 channel 8-bit unsigned planar YCbCr422 to 3 channel 8-bit unsigned planar YCbCr411 sampling format conversion.
     * images.
     *
     * @param pSrc \ref source_planar_image_pointer_array.
     * @param rSrcStep \ref source_planar_image_line_step_array.
     * @param pDst \ref destination_planar_image_pointer_array.
     * @param rDstStep \ref destination_planar_image_line_step_array.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiYCbCr422ToYCbCr411_8u_P3R(
        TypedPointer<Npp8u>[] pSrc, 
        int[] rSrcStep, 
        TypedPointer<Npp8u>[] pDst, 
        int[] rDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiYCbCr422ToYCbCr411_8u_P3RNative(pSrc, rSrcStep, pDst, rDstStep, oSizeROI));
    }
    private static native int nppiYCbCr422ToYCbCr411_8u_P3RNative(
        TypedPointer<Npp8u>[] pSrc, 
        int[] rSrcStep, 
        TypedPointer<Npp8u>[] pDst, 
        int[] rDstStep, 
        NppiSize oSizeROI);


    public static int nppiYCbCr422ToYCbCr411_8u_P3P2R(
        TypedPointer<Npp8u>[] pSrc, 
        int[] rSrcStep, 
        TypedPointer<Npp8u> pDstY, 
        int nDstYStep, 
        TypedPointer<Npp8u> pDstCbCr, 
        int nDstCbCrStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiYCbCr422ToYCbCr411_8u_P3P2RNative(pSrc, rSrcStep, pDstY, nDstYStep, pDstCbCr, nDstCbCrStep, oSizeROI));
    }
    private static native int nppiYCbCr422ToYCbCr411_8u_P3P2RNative(
        TypedPointer<Npp8u>[] pSrc, 
        int[] rSrcStep, 
        TypedPointer<Npp8u> pDstY, 
        int nDstYStep, 
        TypedPointer<Npp8u> pDstCbCr, 
        int nDstCbCrStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 2 channel 8-bit unsigned packed YCbCr422 to 3 channel 8-bit unsigned planar YCbCr411 sampling format conversion.
     * images.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_planar_image_pointer_array.
     * @param rDstStep \ref destination_planar_image_line_step_array.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiYCbCr422ToYCbCr411_8u_C2P3R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u>[] pDst, 
        int[] rDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiYCbCr422ToYCbCr411_8u_C2P3RNative(pSrc, nSrcStep, pDst, rDstStep, oSizeROI));
    }
    private static native int nppiYCbCr422ToYCbCr411_8u_C2P3RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u>[] pDst, 
        int[] rDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 2 channel 8-bit unsigned packed YCbCr422 to 2 channel 8-bit unsigned planar YCbCr411 sampling format conversion.
     * images.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDstY \ref destination_planar_image_pointer.
     * @param nDstYStep \ref destination_planar_image_line_step.
     * @param pDstCbCr \ref destination_planar_image_pointer.
     * @param nDstCbCrStep \ref destination_planar_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiYCbCr422ToYCbCr411_8u_C2P2R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDstY, 
        int nDstYStep, 
        TypedPointer<Npp8u> pDstCbCr, 
        int nDstCbCrStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiYCbCr422ToYCbCr411_8u_C2P2RNative(pSrc, nSrcStep, pDstY, nDstYStep, pDstCbCr, nDstCbCrStep, oSizeROI));
    }
    private static native int nppiYCbCr422ToYCbCr411_8u_C2P2RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDstY, 
        int nDstYStep, 
        TypedPointer<Npp8u> pDstCbCr, 
        int nDstCbCrStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 2 channel 8-bit unsigned packed YCrCb422 to 3 channel 8-bit unsigned planar YCbCr422 sampling format conversion.
     * images.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_planar_image_pointer_array.
     * @param rDstStep \ref destination_planar_image_line_step_array.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiYCrCb422ToYCbCr422_8u_C2P3R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u>[] pDst, 
        int[] rDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiYCrCb422ToYCbCr422_8u_C2P3RNative(pSrc, nSrcStep, pDst, rDstStep, oSizeROI));
    }
    private static native int nppiYCrCb422ToYCbCr422_8u_C2P3RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u>[] pDst, 
        int[] rDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 2 channel 8-bit unsigned packed YCrCb422 to 3 channel 8-bit unsigned planar YCbCr420 sampling format conversion.
     * images.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_planar_image_pointer_array.
     * @param rDstStep \ref destination_planar_image_line_step_array.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiYCrCb422ToYCbCr420_8u_C2P3R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u>[] pDst, 
        int[] rDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiYCrCb422ToYCbCr420_8u_C2P3RNative(pSrc, nSrcStep, pDst, rDstStep, oSizeROI));
    }
    private static native int nppiYCrCb422ToYCbCr420_8u_C2P3RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u>[] pDst, 
        int[] rDstStep, 
        NppiSize oSizeROI);


    public static int nppiYCrCb422ToYCbCr411_8u_C2P3R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u>[] pDst, 
        int[] rDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiYCrCb422ToYCbCr411_8u_C2P3RNative(pSrc, nSrcStep, pDst, rDstStep, oSizeROI));
    }
    private static native int nppiYCrCb422ToYCbCr411_8u_C2P3RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u>[] pDst, 
        int[] rDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 2 channel 8-bit unsigned packed CbYCr422 to 2 channel 8-bit unsigned packed YCbCr422 sampling format conversion.
     * images.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCbYCr422ToYCbCr422_8u_C2R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiCbYCr422ToYCbCr422_8u_C2RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCbYCr422ToYCbCr422_8u_C2RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 2 channel 8-bit unsigned packed CbYCr422 to 3 channel 8-bit unsigned planar YCbCr422 sampling format conversion.
     * images.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_planar_image_pointer_array.
     * @param rDstStep \ref destination_planar_image_line_step_array.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCbYCr422ToYCbCr422_8u_C2P3R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u>[] pDst, 
        int[] rDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiCbYCr422ToYCbCr422_8u_C2P3RNative(pSrc, nSrcStep, pDst, rDstStep, oSizeROI));
    }
    private static native int nppiCbYCr422ToYCbCr422_8u_C2P3RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u>[] pDst, 
        int[] rDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 2 channel 8-bit unsigned packed CbYCr422 to 3 channel 8-bit unsigned planar YCbCr420 sampling format conversion.
     * images.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_planar_image_pointer_array.
     * @param rDstStep \ref destination_planar_image_line_step_array.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCbYCr422ToYCbCr420_8u_C2P3R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u>[] pDst, 
        int[] rDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiCbYCr422ToYCbCr420_8u_C2P3RNative(pSrc, nSrcStep, pDst, rDstStep, oSizeROI));
    }
    private static native int nppiCbYCr422ToYCbCr420_8u_C2P3RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u>[] pDst, 
        int[] rDstStep, 
        NppiSize oSizeROI);


    public static int nppiCbYCr422ToYCbCr420_8u_C2P2R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDstY, 
        int nDstYStep, 
        TypedPointer<Npp8u> pDstCbCr, 
        int nDstCbCrStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiCbYCr422ToYCbCr420_8u_C2P2RNative(pSrc, nSrcStep, pDstY, nDstYStep, pDstCbCr, nDstCbCrStep, oSizeROI));
    }
    private static native int nppiCbYCr422ToYCbCr420_8u_C2P2RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDstY, 
        int nDstYStep, 
        TypedPointer<Npp8u> pDstCbCr, 
        int nDstCbCrStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 2 channel 8-bit unsigned packed CbYCr422 to 3 channel 8-bit unsigned planar YCrCb420 sampling format conversion.
     * images.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_planar_image_pointer_array.
     * @param rDstStep \ref destination_planar_image_line_step_array.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCbYCr422ToYCrCb420_8u_C2P3R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u>[] pDst, 
        int[] rDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiCbYCr422ToYCrCb420_8u_C2P3RNative(pSrc, nSrcStep, pDst, rDstStep, oSizeROI));
    }
    private static native int nppiCbYCr422ToYCrCb420_8u_C2P3RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u>[] pDst, 
        int[] rDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 3 channel 8-bit unsigned planar YCbCr420 to 2 channel 8-bit unsigned planar YCbCr420 sampling format conversion.
     * images.
     *
     * @param pSrc \ref source_planar_image_pointer_array.
     * @param rSrcStep \ref source_planar_image_line_step_array.
     * @param pDstY \ref destination_planar_image_pointer.
     * @param nDstYStep \ref destination_planar_image_line_step.
     * @param pDstCbCr \ref destination_planar_image_pointer.
     * @param nDstCbCrStep \ref destination_planar_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiYCbCr420_8u_P3P2R(
        TypedPointer<Npp8u>[] pSrc, 
        int[] rSrcStep, 
        TypedPointer<Npp8u> pDstY, 
        int nDstYStep, 
        TypedPointer<Npp8u> pDstCbCr, 
        int nDstCbCrStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiYCbCr420_8u_P3P2RNative(pSrc, rSrcStep, pDstY, nDstYStep, pDstCbCr, nDstCbCrStep, oSizeROI));
    }
    private static native int nppiYCbCr420_8u_P3P2RNative(
        TypedPointer<Npp8u>[] pSrc, 
        int[] rSrcStep, 
        TypedPointer<Npp8u> pDstY, 
        int nDstYStep, 
        TypedPointer<Npp8u> pDstCbCr, 
        int nDstCbCrStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 2 channel 8-bit unsigned planar YCbCr420 to 3 channel 8-bit unsigned planar YCbCr420 sampling format conversion.
     *
     * @param pSrcY \ref source_planar_image_pointer.
     * @param nSrcYStep \ref source_planar_image_line_step.
     * @param pSrcCbCr \ref source_planar_image_pointer.
     * @param nSrcCbCrStep \ref source_planar_image_line_step.
     * @param pDst \ref destination_planar_image_pointer_array.
     * @param rDstStep \ref destination_planar_image_line_step_array.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiYCbCr420_8u_P2P3R(
        TypedPointer<Npp8u> pSrcY, 
        int nSrcYStep, 
        TypedPointer<Npp8u> pSrcCbCr, 
        int nSrcCbCrStep, 
        TypedPointer<Npp8u>[] pDst, 
        int[] rDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiYCbCr420_8u_P2P3RNative(pSrcY, nSrcYStep, pSrcCbCr, nSrcCbCrStep, pDst, rDstStep, oSizeROI));
    }
    private static native int nppiYCbCr420_8u_P2P3RNative(
        TypedPointer<Npp8u> pSrcY, 
        int nSrcYStep, 
        TypedPointer<Npp8u> pSrcCbCr, 
        int nSrcCbCrStep, 
        TypedPointer<Npp8u>[] pDst, 
        int[] rDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 3 channel 8-bit unsigned planar YCbCr420 to 3 channel 8-bit unsigned planar YCbCr422 sampling format conversion.
     * images.
     *
     * @param pSrc \ref source_planar_image_pointer_array.
     * @param rSrcStep \ref source_planar_image_line_step_array.
     * @param pDst \ref destination_planar_image_pointer_array.
     * @param nDstStep \ref destination_planar_image_line_step_array.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiYCbCr420ToYCbCr422_8u_P3R(
        TypedPointer<Npp8u>[] pSrc, 
        int[] rSrcStep, 
        TypedPointer<Npp8u>[] pDst, 
        int[] nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiYCbCr420ToYCbCr422_8u_P3RNative(pSrc, rSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiYCbCr420ToYCbCr422_8u_P3RNative(
        TypedPointer<Npp8u>[] pSrc, 
        int[] rSrcStep, 
        TypedPointer<Npp8u>[] pDst, 
        int[] nDstStep, 
        NppiSize oSizeROI);


    public static int nppiYCbCr420ToYCbCr422_8u_P2P3R(
        TypedPointer<Npp8u> pSrcY, 
        int nSrcYStep, 
        TypedPointer<Npp8u> pSrcCbCr, 
        int nSrcCbCrStep, 
        TypedPointer<Npp8u>[] pDst, 
        int[] rDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiYCbCr420ToYCbCr422_8u_P2P3RNative(pSrcY, nSrcYStep, pSrcCbCr, nSrcCbCrStep, pDst, rDstStep, oSizeROI));
    }
    private static native int nppiYCbCr420ToYCbCr422_8u_P2P3RNative(
        TypedPointer<Npp8u> pSrcY, 
        int nSrcYStep, 
        TypedPointer<Npp8u> pSrcCbCr, 
        int nSrcCbCrStep, 
        TypedPointer<Npp8u>[] pDst, 
        int[] rDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 2 channel 8-bit unsigned planar YCbCr420 to 2 channel 8-bit unsigned packed YCbCr422 sampling format conversion.
     *
     * @param pSrcY \ref source_planar_image_pointer.
     * @param nSrcYStep \ref source_planar_image_line_step.
     * @param pSrcCbCr \ref source_planar_image_pointer.
     * @param nSrcCbCrStep \ref source_planar_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiYCbCr420ToYCbCr422_8u_P2C2R(
        TypedPointer<Npp8u> pSrcY, 
        int nSrcYStep, 
        TypedPointer<Npp8u> pSrcCbCr, 
        int nSrcCbCrStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiYCbCr420ToYCbCr422_8u_P2C2RNative(pSrcY, nSrcYStep, pSrcCbCr, nSrcCbCrStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiYCbCr420ToYCbCr422_8u_P2C2RNative(
        TypedPointer<Npp8u> pSrcY, 
        int nSrcYStep, 
        TypedPointer<Npp8u> pSrcCbCr, 
        int nSrcCbCrStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 2 channel 8-bit unsigned planar YCbCr420 to 2 channel 8-bit unsigned packed CbYCr422 sampling format conversion.
     *
     * @param pSrcY \ref source_planar_image_pointer.
     * @param nSrcYStep \ref source_planar_image_line_step.
     * @param pSrcCbCr \ref source_planar_image_pointer.
     * @param nSrcCbCrStep \ref source_planar_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiYCbCr420ToCbYCr422_8u_P2C2R(
        TypedPointer<Npp8u> pSrcY, 
        int nSrcYStep, 
        TypedPointer<Npp8u> pSrcCbCr, 
        int nSrcCbCrStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiYCbCr420ToCbYCr422_8u_P2C2RNative(pSrcY, nSrcYStep, pSrcCbCr, nSrcCbCrStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiYCbCr420ToCbYCr422_8u_P2C2RNative(
        TypedPointer<Npp8u> pSrcY, 
        int nSrcYStep, 
        TypedPointer<Npp8u> pSrcCbCr, 
        int nSrcCbCrStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 2 channel 8-bit unsigned planar YCbCr420 to 3 channel 8-bit unsigned planar YCrCb420 sampling format conversion.
     *
     * @param pSrcY \ref source_planar_image_pointer.
     * @param nSrcYStep \ref source_planar_image_line_step.
     * @param pSrcCbCr \ref source_planar_image_pointer.
     * @param nSrcCbCrStep \ref source_planar_image_line_step.
     * @param pDst \ref destination_planar_image_pointer_array.
     * @param rDstStep \ref destination_planar_image_line_step_array.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiYCbCr420ToYCrCb420_8u_P2P3R(
        TypedPointer<Npp8u> pSrcY, 
        int nSrcYStep, 
        TypedPointer<Npp8u> pSrcCbCr, 
        int nSrcCbCrStep, 
        TypedPointer<Npp8u>[] pDst, 
        int[] rDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiYCbCr420ToYCrCb420_8u_P2P3RNative(pSrcY, nSrcYStep, pSrcCbCr, nSrcCbCrStep, pDst, rDstStep, oSizeROI));
    }
    private static native int nppiYCbCr420ToYCrCb420_8u_P2P3RNative(
        TypedPointer<Npp8u> pSrcY, 
        int nSrcYStep, 
        TypedPointer<Npp8u> pSrcCbCr, 
        int nSrcCbCrStep, 
        TypedPointer<Npp8u>[] pDst, 
        int[] rDstStep, 
        NppiSize oSizeROI);


    public static int nppiYCrCb420ToCbYCr422_8u_P3C2R(
        TypedPointer<Npp8u>[] pSrc, 
        int[] rSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiYCrCb420ToCbYCr422_8u_P3C2RNative(pSrc, rSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiYCrCb420ToCbYCr422_8u_P3C2RNative(
        TypedPointer<Npp8u>[] pSrc, 
        int[] rSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 3 channel 8-bit unsigned planar YCrCb420 to 2 channel 8-bit unsigned planar YCbCr420 sampling format conversion.
     * images.
     *
     * @param pSrc \ref source_planar_image_pointer_array.
     * @param rSrcStep \ref source_planar_image_line_step_array.
     * @param pDstY \ref destination_planar_image_pointer.
     * @param nDstYStep \ref destination_planar_image_line_step.
     * @param pDstCbCr \ref destination_planar_image_pointer.
     * @param nDstCbCrStep \ref destination_planar_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiYCrCb420ToYCbCr420_8u_P3P2R(
        TypedPointer<Npp8u>[] pSrc, 
        int[] rSrcStep, 
        TypedPointer<Npp8u> pDstY, 
        int nDstYStep, 
        TypedPointer<Npp8u> pDstCbCr, 
        int nDstCbCrStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiYCrCb420ToYCbCr420_8u_P3P2RNative(pSrc, rSrcStep, pDstY, nDstYStep, pDstCbCr, nDstCbCrStep, oSizeROI));
    }
    private static native int nppiYCrCb420ToYCbCr420_8u_P3P2RNative(
        TypedPointer<Npp8u>[] pSrc, 
        int[] rSrcStep, 
        TypedPointer<Npp8u> pDstY, 
        int nDstYStep, 
        TypedPointer<Npp8u> pDstCbCr, 
        int nDstCbCrStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 3 channel 8-bit unsigned planar YCrCb420 to 2 channel 8-bit unsigned planar YCbCr411 sampling format conversion.
     * images.
     *
     * @param pSrc \ref source_planar_image_pointer_array.
     * @param rSrcStep \ref source_planar_image_line_step_array.
     * @param pDstY \ref destination_planar_image_pointer.
     * @param nDstYStep \ref destination_planar_image_line_step.
     * @param pDstCbCr \ref destination_planar_image_pointer.
     * @param nDstCbCrStep \ref destination_planar_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiYCrCb420ToYCbCr411_8u_P3P2R(
        TypedPointer<Npp8u>[] pSrc, 
        int[] rSrcStep, 
        TypedPointer<Npp8u> pDstY, 
        int nDstYStep, 
        TypedPointer<Npp8u> pDstCbCr, 
        int nDstCbCrStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiYCrCb420ToYCbCr411_8u_P3P2RNative(pSrc, rSrcStep, pDstY, nDstYStep, pDstCbCr, nDstCbCrStep, oSizeROI));
    }
    private static native int nppiYCrCb420ToYCbCr411_8u_P3P2RNative(
        TypedPointer<Npp8u>[] pSrc, 
        int[] rSrcStep, 
        TypedPointer<Npp8u> pDstY, 
        int nDstYStep, 
        TypedPointer<Npp8u> pDstCbCr, 
        int nDstCbCrStep, 
        NppiSize oSizeROI);


    public static int nppiYCbCr411_8u_P3P2R(
        TypedPointer<Npp8u>[] pSrc, 
        int[] rSrcStep, 
        TypedPointer<Npp8u> pDstY, 
        int nDstYStep, 
        TypedPointer<Npp8u> pDstCbCr, 
        int nDstCbCrStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiYCbCr411_8u_P3P2RNative(pSrc, rSrcStep, pDstY, nDstYStep, pDstCbCr, nDstCbCrStep, oSizeROI));
    }
    private static native int nppiYCbCr411_8u_P3P2RNative(
        TypedPointer<Npp8u>[] pSrc, 
        int[] rSrcStep, 
        TypedPointer<Npp8u> pDstY, 
        int nDstYStep, 
        TypedPointer<Npp8u> pDstCbCr, 
        int nDstCbCrStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 2 channel 8-bit unsigned planar YCbCr411 to 3 channel 8-bit unsigned planar YCbCr411 sampling format conversion.
     *
     * @param pSrcY \ref source_planar_image_pointer.
     * @param nSrcYStep \ref source_planar_image_line_step.
     * @param pSrcCbCr \ref source_planar_image_pointer.
     * @param nSrcCbCrStep \ref source_planar_image_line_step.
     * @param pDst \ref destination_planar_image_pointer_array.
     * @param rDstStep \ref destination_planar_image_line_step_array.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiYCbCr411_8u_P2P3R(
        TypedPointer<Npp8u> pSrcY, 
        int nSrcYStep, 
        TypedPointer<Npp8u> pSrcCbCr, 
        int nSrcCbCrStep, 
        TypedPointer<Npp8u>[] pDst, 
        int[] rDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiYCbCr411_8u_P2P3RNative(pSrcY, nSrcYStep, pSrcCbCr, nSrcCbCrStep, pDst, rDstStep, oSizeROI));
    }
    private static native int nppiYCbCr411_8u_P2P3RNative(
        TypedPointer<Npp8u> pSrcY, 
        int nSrcYStep, 
        TypedPointer<Npp8u> pSrcCbCr, 
        int nSrcCbCrStep, 
        TypedPointer<Npp8u>[] pDst, 
        int[] rDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 3 channel 8-bit unsigned planar YCbCr411 to 3 channel 8-bit unsigned planar YCbCr422 sampling format conversion.
     * images.
     *
     * @param pSrc \ref source_planar_image_pointer_array.
     * @param rSrcStep \ref source_planar_image_line_step_array.
     * @param pDst \ref destination_planar_image_pointer_array.
     * @param nDstStep \ref destination_planar_image_line_step_array.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiYCbCr411ToYCbCr422_8u_P3R(
        TypedPointer<Npp8u>[] pSrc, 
        int[] rSrcStep, 
        TypedPointer<Npp8u>[] pDst, 
        int[] nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiYCbCr411ToYCbCr422_8u_P3RNative(pSrc, rSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiYCbCr411ToYCbCr422_8u_P3RNative(
        TypedPointer<Npp8u>[] pSrc, 
        int[] rSrcStep, 
        TypedPointer<Npp8u>[] pDst, 
        int[] nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 3 channel 8-bit unsigned planar YCbCr411 to 2 channel 8-bit unsigned packed YCbCr422 sampling format conversion.
     * images.
     *
     * @param pSrc \ref source_planar_image_pointer_array.
     * @param rSrcStep \ref source_planar_image_line_step_array.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiYCbCr411ToYCbCr422_8u_P3C2R(
        TypedPointer<Npp8u>[] pSrc, 
        int[] rSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiYCbCr411ToYCbCr422_8u_P3C2RNative(pSrc, rSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiYCbCr411ToYCbCr422_8u_P3C2RNative(
        TypedPointer<Npp8u>[] pSrc, 
        int[] rSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 2 channel 8-bit unsigned planar YCbCr411 to 3 channel 8-bit unsigned planar YCbCr422 sampling format conversion.
     *
     * @param pSrcY \ref source_planar_image_pointer.
     * @param nSrcYStep \ref source_planar_image_line_step.
     * @param pSrcCbCr \ref source_planar_image_pointer.
     * @param nSrcCbCrStep \ref source_planar_image_line_step.
     * @param pDst \ref destination_planar_image_pointer_array.
     * @param rDstStep \ref destination_planar_image_line_step_array.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiYCbCr411ToYCbCr422_8u_P2P3R(
        TypedPointer<Npp8u> pSrcY, 
        int nSrcYStep, 
        TypedPointer<Npp8u> pSrcCbCr, 
        int nSrcCbCrStep, 
        TypedPointer<Npp8u>[] pDst, 
        int[] rDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiYCbCr411ToYCbCr422_8u_P2P3RNative(pSrcY, nSrcYStep, pSrcCbCr, nSrcCbCrStep, pDst, rDstStep, oSizeROI));
    }
    private static native int nppiYCbCr411ToYCbCr422_8u_P2P3RNative(
        TypedPointer<Npp8u> pSrcY, 
        int nSrcYStep, 
        TypedPointer<Npp8u> pSrcCbCr, 
        int nSrcCbCrStep, 
        TypedPointer<Npp8u>[] pDst, 
        int[] rDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 2 channel 8-bit unsigned planar YCbCr411 to 2 channel 8-bit unsigned packed YCbCr422 sampling format conversion.
     *
     * @param pSrcY \ref source_planar_image_pointer.
     * @param nSrcYStep \ref source_planar_image_line_step.
     * @param pSrcCbCr \ref source_planar_image_pointer.
     * @param nSrcCbCrStep \ref source_planar_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiYCbCr411ToYCbCr422_8u_P2C2R(
        TypedPointer<Npp8u> pSrcY, 
        int nSrcYStep, 
        TypedPointer<Npp8u> pSrcCbCr, 
        int nSrcCbCrStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiYCbCr411ToYCbCr422_8u_P2C2RNative(pSrcY, nSrcYStep, pSrcCbCr, nSrcCbCrStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiYCbCr411ToYCbCr422_8u_P2C2RNative(
        TypedPointer<Npp8u> pSrcY, 
        int nSrcYStep, 
        TypedPointer<Npp8u> pSrcCbCr, 
        int nSrcCbCrStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 3 channel 8-bit unsigned planar YCbCr411 to 3 channel 8-bit unsigned planar YCrCb422 sampling format conversion.
     * images.
     *
     * @param pSrc \ref source_planar_image_pointer_array.
     * @param rSrcStep \ref source_planar_image_line_step_array.
     * @param pDst \ref destination_planar_image_pointer_array.
     * @param nDstStep \ref destination_planar_image_line_step_array.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiYCbCr411ToYCrCb422_8u_P3R(
        TypedPointer<Npp8u>[] pSrc, 
        int[] rSrcStep, 
        TypedPointer<Npp8u>[] pDst, 
        int[] nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiYCbCr411ToYCrCb422_8u_P3RNative(pSrc, rSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiYCbCr411ToYCrCb422_8u_P3RNative(
        TypedPointer<Npp8u>[] pSrc, 
        int[] rSrcStep, 
        TypedPointer<Npp8u>[] pDst, 
        int[] nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 3 channel 8-bit unsigned planar YCbCr411 to 2 channel 8-bit unsigned packed YCrCb422 sampling format conversion.
     * images.
     *
     * @param pSrc \ref source_planar_image_pointer_array.
     * @param rSrcStep \ref source_planar_image_line_step_array.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiYCbCr411ToYCrCb422_8u_P3C2R(
        TypedPointer<Npp8u>[] pSrc, 
        int[] rSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiYCbCr411ToYCrCb422_8u_P3C2RNative(pSrc, rSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiYCbCr411ToYCrCb422_8u_P3C2RNative(
        TypedPointer<Npp8u>[] pSrc, 
        int[] rSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 3 channel 8-bit unsigned planar YCbCr411 to 3 channel 8-bit unsigned planar YCbCr420 sampling format conversion.
     * images.
     *
     * @param pSrc \ref source_planar_image_pointer_array.
     * @param rSrcStep \ref source_planar_image_line_step_array.
     * @param pDst \ref destination_planar_image_pointer_array.
     * @param nDstStep \ref destination_planar_image_line_step_array.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiYCbCr411ToYCbCr420_8u_P3R(
        TypedPointer<Npp8u>[] pSrc, 
        int[] rSrcStep, 
        TypedPointer<Npp8u>[] pDst, 
        int[] nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiYCbCr411ToYCbCr420_8u_P3RNative(pSrc, rSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiYCbCr411ToYCbCr420_8u_P3RNative(
        TypedPointer<Npp8u>[] pSrc, 
        int[] rSrcStep, 
        TypedPointer<Npp8u>[] pDst, 
        int[] nDstStep, 
        NppiSize oSizeROI);


    public static int nppiYCbCr411ToYCbCr420_8u_P3P2R(
        TypedPointer<Npp8u>[] pSrc, 
        int[] rSrcStep, 
        TypedPointer<Npp8u> pDstY, 
        int nDstYStep, 
        TypedPointer<Npp8u> pDstCbCr, 
        int nDstCbCrStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiYCbCr411ToYCbCr420_8u_P3P2RNative(pSrc, rSrcStep, pDstY, nDstYStep, pDstCbCr, nDstCbCrStep, oSizeROI));
    }
    private static native int nppiYCbCr411ToYCbCr420_8u_P3P2RNative(
        TypedPointer<Npp8u>[] pSrc, 
        int[] rSrcStep, 
        TypedPointer<Npp8u> pDstY, 
        int nDstYStep, 
        TypedPointer<Npp8u> pDstCbCr, 
        int nDstCbCrStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 2 channel 8-bit unsigned planar YCbCr411 to 3 channel 8-bit unsigned planar YCbCr420 sampling format conversion.
     *
     * @param pSrcY \ref source_planar_image_pointer.
     * @param nSrcYStep \ref source_planar_image_line_step.
     * @param pSrcCbCr \ref source_planar_image_pointer.
     * @param nSrcCbCrStep \ref source_planar_image_line_step.
     * @param pDst \ref destination_planar_image_pointer_array.
     * @param rDstStep \ref destination_planar_image_line_step_array.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiYCbCr411ToYCbCr420_8u_P2P3R(
        TypedPointer<Npp8u> pSrcY, 
        int nSrcYStep, 
        TypedPointer<Npp8u> pSrcCbCr, 
        int nSrcCbCrStep, 
        TypedPointer<Npp8u>[] pDst, 
        int[] rDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiYCbCr411ToYCbCr420_8u_P2P3RNative(pSrcY, nSrcYStep, pSrcCbCr, nSrcCbCrStep, pDst, rDstStep, oSizeROI));
    }
    private static native int nppiYCbCr411ToYCbCr420_8u_P2P3RNative(
        TypedPointer<Npp8u> pSrcY, 
        int nSrcYStep, 
        TypedPointer<Npp8u> pSrcCbCr, 
        int nSrcCbCrStep, 
        TypedPointer<Npp8u>[] pDst, 
        int[] rDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 2 channel 8-bit unsigned planar YCbCr411 to 3 channel 8-bit unsigned planar YCrCb420 sampling format conversion.
     *
     * @param pSrcY \ref source_planar_image_pointer.
     * @param nSrcYStep \ref source_planar_image_line_step.
     * @param pSrcCbCr \ref source_planar_image_pointer.
     * @param nSrcCbCrStep \ref source_planar_image_line_step.
     * @param pDst \ref destination_planar_image_pointer_array.
     * @param rDstStep \ref destination_planar_image_line_step_array.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiYCbCr411ToYCrCb420_8u_P2P3R(
        TypedPointer<Npp8u> pSrcY, 
        int nSrcYStep, 
        TypedPointer<Npp8u> pSrcCbCr, 
        int nSrcCbCrStep, 
        TypedPointer<Npp8u>[] pDst, 
        int[] rDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiYCbCr411ToYCrCb420_8u_P2P3RNative(pSrcY, nSrcYStep, pSrcCbCr, nSrcCbCrStep, pDst, rDstStep, oSizeROI));
    }
    private static native int nppiYCbCr411ToYCrCb420_8u_P2P3RNative(
        TypedPointer<Npp8u> pSrcY, 
        int nSrcYStep, 
        TypedPointer<Npp8u> pSrcCbCr, 
        int nSrcCbCrStep, 
        TypedPointer<Npp8u>[] pDst, 
        int[] rDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 3 channel 8-bit unsigned packed color not in place forward gamma correction.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiGammaFwd_8u_C3R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiGammaFwd_8u_C3RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiGammaFwd_8u_C3RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 3 channel 8-bit unsigned packed color in place forward gamma correction.
     *
     * @param pSrcDst in place packed pixel image pointer.
     * @param nSrcDstStep in place packed pixel format image line step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiGammaFwd_8u_C3IR(
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiGammaFwd_8u_C3IRNative(pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiGammaFwd_8u_C3IRNative(
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 4 channel 8-bit unsigned packed color with alpha not in place forward gamma correction.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiGammaFwd_8u_AC4R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiGammaFwd_8u_AC4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiGammaFwd_8u_AC4RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 4 channel 8-bit unsigned packed color with alpha in place forward gamma correction.
     *
     * @param pSrcDst in place packed pixel format image pointer.
     * @param nSrcDstStep in place packed pixel format image line step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiGammaFwd_8u_AC4IR(
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiGammaFwd_8u_AC4IRNative(pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiGammaFwd_8u_AC4IRNative(
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    public static int nppiGammaFwd_8u_P3R(
        TypedPointer<Npp8u>[] pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u>[] pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiGammaFwd_8u_P3RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiGammaFwd_8u_P3RNative(
        TypedPointer<Npp8u>[] pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u>[] pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 3 channel 8-bit unsigned planar color in place forward gamma correction.
     *
     * @param pSrcDst in place planar pixel format image pointer array.
     * @param nSrcDstStep in place planar pixel format image line step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiGammaFwd_8u_IP3R(
        TypedPointer<Npp8u>[] pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiGammaFwd_8u_IP3RNative(pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiGammaFwd_8u_IP3RNative(
        TypedPointer<Npp8u>[] pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 3 channel 8-bit unsigned packed color not in place inverse gamma correction.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiGammaInv_8u_C3R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiGammaInv_8u_C3RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiGammaInv_8u_C3RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 3 channel 8-bit unsigned packed color in place inverse gamma correction.
     *
     * @param pSrcDst in place packed pixel format image pointer.
     * @param nSrcDstStep in place packed pixel format image line step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiGammaInv_8u_C3IR(
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiGammaInv_8u_C3IRNative(pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiGammaInv_8u_C3IRNative(
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 4 channel 8-bit unsigned packed color with alpha not in place inverse gamma correction.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiGammaInv_8u_AC4R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiGammaInv_8u_AC4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiGammaInv_8u_AC4RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 4 channel 8-bit unsigned packed color with alpha in place inverse gamma correction.
     *
     * @param pSrcDst in place packed pixel format image pointer.
     * @param nSrcDstStep in place packed pixel format image line step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiGammaInv_8u_AC4IR(
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiGammaInv_8u_AC4IRNative(pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiGammaInv_8u_AC4IRNative(
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    public static int nppiGammaInv_8u_P3R(
        TypedPointer<Npp8u>[] pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u>[] pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiGammaInv_8u_P3RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiGammaInv_8u_P3RNative(
        TypedPointer<Npp8u>[] pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u>[] pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 3 channel 8-bit unsigned planar color in place inverse gamma correction.
     *
     * @param pSrcDst in place planar pixel format image pointer array.
     * @param nSrcDstStep in place planar pixel format image line step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiGammaInv_8u_IP3R(
        TypedPointer<Npp8u>[] pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiGammaInv_8u_IP3RNative(pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiGammaInv_8u_IP3RNative(
        TypedPointer<Npp8u>[] pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 1 channel 8-bit unsigned packed color complement color key replacement of source image 1 by source image 2.
     *
     * @param pSrc1 source1 packed pixel format image pointer.
     * @param nSrc1Step source1 packed pixel format image line step.
     * @param pSrc2 source2 packed pixel format image pointer.
     * @param nSrc2Step source2 packed pixel format image line step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nColorKeyConst color key constant
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCompColorKey_8u_C1R(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        byte nColorKeyConst)
    {
        return JNpp.checkResult(nppiCompColorKey_8u_C1RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nColorKeyConst));
    }
    private static native int nppiCompColorKey_8u_C1RNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        byte nColorKeyConst);


    /**
     * <pre>
     * 3 channel 8-bit unsigned packed color complement color key replacement of source image 1 by source image 2.
     *
     * @param pSrc1 source1 packed pixel format image pointer.
     * @param nSrc1Step source1 packed pixel format image line step.
     * @param pSrc2 source2 packed pixel format image pointer.
     * @param nSrc2Step source2 packed pixel format image line step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nColorKeyConst color key constant array
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCompColorKey_8u_C3R(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        byte[] nColorKeyConst)
    {
        return JNpp.checkResult(nppiCompColorKey_8u_C3RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nColorKeyConst));
    }
    private static native int nppiCompColorKey_8u_C3RNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        byte[] nColorKeyConst);


    /**
     * <pre>
     * 4 channel 8-bit unsigned packed color complement color key replacement of source image 1 by source image 2.
     *
     * @param pSrc1 source1 packed pixel format image pointer.
     * @param nSrc1Step source1 packed pixel format image line step.
     * @param pSrc2 source2 packed pixel format image pointer.
     * @param nSrc2Step source2 packed pixel format image line step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nColorKeyConst color key constant array
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCompColorKey_8u_C4R(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        byte[] nColorKeyConst)
    {
        return JNpp.checkResult(nppiCompColorKey_8u_C4RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nColorKeyConst));
    }
    private static native int nppiCompColorKey_8u_C4RNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        byte[] nColorKeyConst);


    /**
     * <pre>
     * 4 channel 8-bit unsigned packed color complement color key replacement of source image 1 by source image 2 with alpha blending.
     *
     * @param pSrc1 source1 packed pixel format image pointer.
     * @param nSrc1Step source1 packed pixel format image line step.
     * @param nAlpha1 source1 image alpha opacity (0 - max channel pixel value).
     * @param pSrc2 source2 packed pixel format image pointer.
     * @param nSrc2Step source2 packed pixel format image line step.
     * @param nAlpha2 source2 image alpha opacity (0 - max channel pixel value).
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nColorKeyConst color key constant array
     * @param nppAlphaOp NppiAlphaOp alpha compositing operation selector  (excluding premul ops).
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAlphaCompColorKey_8u_AC4R(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        byte nAlpha1, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        byte nAlpha2, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        byte[] nColorKeyConst, 
        int nppAlphaOp)
    {
        return JNpp.checkResult(nppiAlphaCompColorKey_8u_AC4RNative(pSrc1, nSrc1Step, nAlpha1, pSrc2, nSrc2Step, nAlpha2, pDst, nDstStep, oSizeROI, nColorKeyConst, nppAlphaOp));
    }
    private static native int nppiAlphaCompColorKey_8u_AC4RNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        byte nAlpha1, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        byte nAlpha2, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        byte[] nColorKeyConst, 
        int nppAlphaOp);


    /**
     * <pre>
     * 3 channel 8-bit unsigned color twist.
     * 
     * An input color twist matrix with floating-point pixel values is applied
     * within ROI.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param twist The color twist matrix with floating-point pixel values.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiColorTwist32f_8u_C3R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        float[][] twist)
    {
        return JNpp.checkResult(nppiColorTwist32f_8u_C3RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, twist));
    }
    private static native int nppiColorTwist32f_8u_C3RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        float[][] twist);


    /**
     * <pre>
     * 3 channel planar 8-bit unsigned color twist.
     *
     * An input color twist matrix with floating-point pixel values is applied
     * within ROI.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param twist The color twist matrix with floating-point pixel values.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiColorTwist32f_8u_P3R(
        TypedPointer<Npp8u>[] pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u>[] pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        float[][] twist)
    {
        return JNpp.checkResult(nppiColorTwist32f_8u_P3RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, twist));
    }
    private static native int nppiColorTwist32f_8u_P3RNative(
        TypedPointer<Npp8u>[] pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u>[] pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        float[][] twist);


    /**
     * <pre>
     * 4 channel 8-bit unsigned color twist, not affecting Alpha.
     *
     * An input color twist matrix with floating-point pixel values is applied with
     * in ROI.
     * Alpha channel is the last channel and is not processed.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param twist The color twist matrix with floating-point pixel values.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiColorTwist32f_8u_AC4R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        float[][] twist)
    {
        return JNpp.checkResult(nppiColorTwist32f_8u_AC4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, twist));
    }
    private static native int nppiColorTwist32f_8u_AC4RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        float[][] twist);


    /**
     * <pre>
     * 8-bit unsigned look-up-table color conversion.
     *
     * The LUT is derived from a set of user defined mapping points through linear
     * interpolation. 
     *
     * >>>>>>> ATTENTION ATTENTION <<<<<<<
     *
     * NOTE: As of the 5.0 release of NPP, the pValues and pLevels pointers need to be device memory pointers.
     *
     * >>>>>>>                     <<<<<<<
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pValues Pointer to an array of user defined OUTPUT values (this is now a device memory pointer)
     * @param pLevels Pointer to an array of user defined INPUT values  (this is now a device memory pointer)
     * @param nLevels Number of user defined input/output mapping points (levels)
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     *        - #NPP_LUT_NUMBER_OF_LEVELS_ERROR if the number of levels is less than
     *         2.
     * </pre>
     */
    public static int nppiLUT_Linear_8u_C1R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp32s> pValues, 
        TypedPointer<Npp32s> pLevels, 
        int nLevels)
    {
        return JNpp.checkResult(nppiLUT_Linear_8u_C1RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, pValues, pLevels, nLevels));
    }
    private static native int nppiLUT_Linear_8u_C1RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp32s> pValues, 
        TypedPointer<Npp32s> pLevels, 
        int nLevels);


    /**
     * <pre>
     * 3 channel 8-bit unsigned look-up-table color conversion.
     * 
     * The LUT is derived from a set of user defined mapping points through linear
     * interpolation. 
     *
     * >>>>>>> ATTENTION ATTENTION <<<<<<<
     *
     * NOTE: As of the 5.0 release of NPP, the pValues and pLevels pointers need to be host memory pointers to arrays of device memory pointers.
     *
     * >>>>>>>                     <<<<<<<
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pValues Host pointer to an array of 3 device memory pointers, one per color CHANNEL, pointing to user defined OUTPUT values.
     * @param pLevels Host pointer to an array of 3 device memory pointers, one per color CHANNEL, pointing to user defined INPUT values.
     * @param nLevels Host pointer to an array of 3 user defined input/output mapping points, one per color CHANNEL.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     *        - #NPP_LUT_NUMBER_OF_LEVELS_ERROR if the number of levels is less than 2.
     * </pre>
     */
    public static int nppiLUT_Linear_8u_C3R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp32s>[] pValues, 
        TypedPointer<Npp32s>[] pLevels, 
        int[] nLevels)
    {
        return JNpp.checkResult(nppiLUT_Linear_8u_C3RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, pValues, pLevels, nLevels));
    }
    private static native int nppiLUT_Linear_8u_C3RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp32s>[] pValues, 
        TypedPointer<Npp32s>[] pLevels, 
        int[] nLevels);


    /**
     * <pre>
     * 4 channel 8-bit unsigned look-up-table color conversion.
     * 
     * The LUT is derived from a set of user defined mapping points through linear
     * interpolation. 
     *
     * >>>>>>> ATTENTION ATTENTION <<<<<<<
     *
     * NOTE: As of the 5.0 release of NPP, the pValues and pLevels pointers need to be host memory pointers to arrays of device memory pointers.
     *
     * >>>>>>>                     <<<<<<<
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pValues Host pointer to an array of 4 device memory pointers, one per color CHANNEL, pointing to user defined OUTPUT values.
     * @param pLevels Host pointer to an array of 4 device memory pointers, one per color CHANNEL, pointing to user defined INPUT values.
     * @param nLevels Host pointer to an array of 4 user defined input/output mapping points, one per color CHANNEL.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     *        - #NPP_LUT_NUMBER_OF_LEVELS_ERROR if the number of levels is less than 2.
     * </pre>
     */
    public static int nppiLUT_Linear_8u_C4R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp32s>[] pValues, 
        TypedPointer<Npp32s>[] pLevels, 
        int[] nLevels)
    {
        return JNpp.checkResult(nppiLUT_Linear_8u_C4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, pValues, pLevels, nLevels));
    }
    private static native int nppiLUT_Linear_8u_C4RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp32s>[] pValues, 
        TypedPointer<Npp32s>[] pLevels, 
        int[] nLevels);


    /**
     * <pre>
     * 4 channel 8-bit unsigned look-up-table color conversion, not affecting Alpha.
     *
     * The LUT is derived from a set of user defined mapping points through linear
     * interpolation. 
     * Alpha channel is the last channel and is not processed.
     *
     * >>>>>>> ATTENTION ATTENTION <<<<<<<
     *
     * NOTE: As of the 5.0 release of NPP, the pValues and pLevels pointers need to be host memory pointers to arrays of device memory pointers.
     *
     * >>>>>>>                     <<<<<<<
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pValues Host pointer to an array of 3 device memory pointers, one per color CHANNEL, pointing to user defined OUTPUT values.
     * @param pLevels Host pointer to an array of 3 device memory pointers, one per color CHANNEL, pointing to user defined INPUT values.
     * @param nLevels Host pointer to an array of 3 user defined input/output mapping points, one per color CHANNEL.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     *        - #NPP_LUT_NUMBER_OF_LEVELS_ERROR if the number of levels is less than 2.
     * </pre>
     */
    public static int nppiLUT_Linear_8u_AC4R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp32s>[] pValues, 
        TypedPointer<Npp32s>[] pLevels, 
        int[] nLevels)
    {
        return JNpp.checkResult(nppiLUT_Linear_8u_AC4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, pValues, pLevels, nLevels));
    }
    private static native int nppiLUT_Linear_8u_AC4RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp32s>[] pValues, 
        TypedPointer<Npp32s>[] pLevels, 
        int[] nLevels);


    /**
     * <pre>
     * 1 channel 8-bit unsigned char threshold.
     * If for a comparison operations OP the predicate (sourcePixel OP nThreshold) is true, the pixel is set
     * to nThreshold, otherwise it is set to sourcePixel.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nThreshold The threshold value.
     * @param eComparisonOperation The type of comparison operation to be used. The only valid
     *      values are: NPP_CMP_LESS and NPP_CMP_GREATER.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, or NPP_NOT_SUPPORTED_MODE_ERROR if an invalid
     * comparison operation type is specified.
     * </pre>
     */
    public static int nppiThreshold_8u_C1R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        byte nThreshold, 
        int eComparisonOperation)
    {
        return JNpp.checkResult(nppiThreshold_8u_C1RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, nThreshold, eComparisonOperation));
    }
    private static native int nppiThreshold_8u_C1RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        byte nThreshold, 
        int eComparisonOperation);


    public static int nppiThreshold_8u_C1IR(
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        byte nThreshold, 
        int eComparisonOperation)
    {
        return JNpp.checkResult(nppiThreshold_8u_C1IRNative(pSrcDst, nSrcDstStep, oSizeROI, nThreshold, eComparisonOperation));
    }
    private static native int nppiThreshold_8u_C1IRNative(
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        byte nThreshold, 
        int eComparisonOperation);


    public static int nppiThreshold_16u_C1R(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        short nThreshold, 
        int eComparisonOperation)
    {
        return JNpp.checkResult(nppiThreshold_16u_C1RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, nThreshold, eComparisonOperation));
    }
    private static native int nppiThreshold_16u_C1RNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        short nThreshold, 
        int eComparisonOperation);


    /**
     * <pre>
     * 1 channel 16-bit unsigned short in place threshold.
     * If for a comparison operations OP the predicate (sourcePixel OP nThreshold) is true, the pixel is set
     * to nThreshold, otherwise it is set to sourcePixel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nThreshold The threshold value.
     * @param eComparisonOperation The type of comparison operation to be used. The only valid
     *      values are: NPP_CMP_LESS and NPP_CMP_GREATER.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, or NPP_NOT_SUPPORTED_MODE_ERROR if an invalid
     * comparison operation type is specified.
     * </pre>
     */
    public static int nppiThreshold_16u_C1IR(
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        short nThreshold, 
        int eComparisonOperation)
    {
        return JNpp.checkResult(nppiThreshold_16u_C1IRNative(pSrcDst, nSrcDstStep, oSizeROI, nThreshold, eComparisonOperation));
    }
    private static native int nppiThreshold_16u_C1IRNative(
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        short nThreshold, 
        int eComparisonOperation);


    public static int nppiThreshold_16s_C1R(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        short nThreshold, 
        int eComparisonOperation)
    {
        return JNpp.checkResult(nppiThreshold_16s_C1RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, nThreshold, eComparisonOperation));
    }
    private static native int nppiThreshold_16s_C1RNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        short nThreshold, 
        int eComparisonOperation);


    /**
     * <pre>
     * 1 channel 16-bit signed short in place threshold.
     * If for a comparison operations OP the predicate (sourcePixel OP nThreshold) is true, the pixel is set
     * to nThreshold, otherwise it is set to sourcePixel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nThreshold The threshold value.
     * @param eComparisonOperation The type of comparison operation to be used. The only valid
     *      values are: NPP_CMP_LESS and NPP_CMP_GREATER.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, or NPP_NOT_SUPPORTED_MODE_ERROR if an invalid
     * comparison operation type is specified.
     * </pre>
     */
    public static int nppiThreshold_16s_C1IR(
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        short nThreshold, 
        int eComparisonOperation)
    {
        return JNpp.checkResult(nppiThreshold_16s_C1IRNative(pSrcDst, nSrcDstStep, oSizeROI, nThreshold, eComparisonOperation));
    }
    private static native int nppiThreshold_16s_C1IRNative(
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        short nThreshold, 
        int eComparisonOperation);


    /**
     * <pre>
     * 1 channel 32-bit floating point threshold.
     * If for a comparison operations OP the predicate (sourcePixel OP nThreshold) is true, the pixel is set
     * to nThreshold, otherwise it is set to sourcePixel.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nThreshold The threshold value.
     * @param eComparisonOperation The type of comparison operation to be used. The only valid
     *      values are: NPP_CMP_LESS and NPP_CMP_GREATER.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, or NPP_NOT_SUPPORTED_MODE_ERROR if an invalid
     * comparison operation type is specified.
     * </pre>
     */
    public static int nppiThreshold_32f_C1R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        float nThreshold, 
        int eComparisonOperation)
    {
        return JNpp.checkResult(nppiThreshold_32f_C1RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, nThreshold, eComparisonOperation));
    }
    private static native int nppiThreshold_32f_C1RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        float nThreshold, 
        int eComparisonOperation);


    /**
     * <pre>
     * 1 channel 32-bit floating point in place threshold.
     * If for a comparison operations OP the predicate (sourcePixel OP nThreshold) is true, the pixel is set
     * to nThreshold, otherwise it is set to sourcePixel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nThreshold The threshold value.
     * @param eComparisonOperation The type of comparison operation to be used. The only valid
     *      values are: NPP_CMP_LESS and NPP_CMP_GREATER.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, or NPP_NOT_SUPPORTED_MODE_ERROR if an invalid
     * comparison operation type is specified.
     * </pre>
     */
    public static int nppiThreshold_32f_C1IR(
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        float nThreshold, 
        int eComparisonOperation)
    {
        return JNpp.checkResult(nppiThreshold_32f_C1IRNative(pSrcDst, nSrcDstStep, oSizeROI, nThreshold, eComparisonOperation));
    }
    private static native int nppiThreshold_32f_C1IRNative(
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        float nThreshold, 
        int eComparisonOperation);


    public static int nppiThreshold_8u_C3R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        byte[] rThresholds, 
        int eComparisonOperation)
    {
        return JNpp.checkResult(nppiThreshold_8u_C3RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, rThresholds, eComparisonOperation));
    }
    private static native int nppiThreshold_8u_C3RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        byte[] rThresholds, 
        int eComparisonOperation);


    /**
     * <pre>
     * 3 channel 8-bit unsigned char in place threshold.
     * If for a comparison operations OP the predicate (sourcePixel OP nThreshold) is true, the pixel is set
     * to nThreshold, otherwise it is set to sourcePixel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param rThresholds The threshold values, one per color channel.
     * @param eComparisonOperation The type of comparison operation to be used. The only valid
     *      values are: NPP_CMP_LESS and NPP_CMP_GREATER.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, or NPP_NOT_SUPPORTED_MODE_ERROR if an invalid
     * comparison operation type is specified.
     * </pre>
     */
    public static int nppiThreshold_8u_C3IR(
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        byte[] rThresholds, 
        int eComparisonOperation)
    {
        return JNpp.checkResult(nppiThreshold_8u_C3IRNative(pSrcDst, nSrcDstStep, oSizeROI, rThresholds, eComparisonOperation));
    }
    private static native int nppiThreshold_8u_C3IRNative(
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        byte[] rThresholds, 
        int eComparisonOperation);


    /**
     * <pre>
     * 3 channel 16-bit unsigned short threshold.
     * If for a comparison operations OP the predicate (sourcePixel OP nThreshold) is true, the pixel is set
     * to nThreshold, otherwise it is set to sourcePixel.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param rThresholds The threshold values, one per color channel.
     * @param eComparisonOperation The type of comparison operation to be used. The only valid
     *      values are: NPP_CMP_LESS and NPP_CMP_GREATER.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, or NPP_NOT_SUPPORTED_MODE_ERROR if an invalid
     * comparison operation type is specified.
     * </pre>
     */
    public static int nppiThreshold_16u_C3R(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        short[] rThresholds, 
        int eComparisonOperation)
    {
        return JNpp.checkResult(nppiThreshold_16u_C3RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, rThresholds, eComparisonOperation));
    }
    private static native int nppiThreshold_16u_C3RNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        short[] rThresholds, 
        int eComparisonOperation);


    /**
     * <pre>
     * 3 channel 16-bit unsigned short in place threshold.
     * If for a comparison operations OP the predicate (sourcePixel OP nThreshold) is true, the pixel is set
     * to nThreshold, otherwise it is set to sourcePixel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param rThresholds The threshold values, one per color channel.
     * @param eComparisonOperation The type of comparison operation to be used. The only valid
     *      values are: NPP_CMP_LESS and NPP_CMP_GREATER.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, or NPP_NOT_SUPPORTED_MODE_ERROR if an invalid
     * comparison operation type is specified.
     * </pre>
     */
    public static int nppiThreshold_16u_C3IR(
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        short[] rThresholds, 
        int eComparisonOperation)
    {
        return JNpp.checkResult(nppiThreshold_16u_C3IRNative(pSrcDst, nSrcDstStep, oSizeROI, rThresholds, eComparisonOperation));
    }
    private static native int nppiThreshold_16u_C3IRNative(
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        short[] rThresholds, 
        int eComparisonOperation);


    /**
     * <pre>
     * 3 channel 16-bit signed short threshold.
     * If for a comparison operations OP the predicate (sourcePixel OP nThreshold) is true, the pixel is set
     * to nThreshold, otherwise it is set to sourcePixel.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param rThresholds The threshold values, one per color channel.
     * @param eComparisonOperation The type of comparison operation to be used. The only valid
     *      values are: NPP_CMP_LESS and NPP_CMP_GREATER.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, or NPP_NOT_SUPPORTED_MODE_ERROR if an invalid
     * comparison operation type is specified.
     * </pre>
     */
    public static int nppiThreshold_16s_C3R(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        short[] rThresholds, 
        int eComparisonOperation)
    {
        return JNpp.checkResult(nppiThreshold_16s_C3RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, rThresholds, eComparisonOperation));
    }
    private static native int nppiThreshold_16s_C3RNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        short[] rThresholds, 
        int eComparisonOperation);


    /**
     * <pre>
     * 3 channel 16-bit signed short in place threshold.
     * If for a comparison operations OP the predicate (sourcePixel OP nThreshold) is true, the pixel is set
     * to nThreshold, otherwise it is set to sourcePixel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param rThresholds The threshold values, one per color channel.
     * @param eComparisonOperation The type of comparison operation to be used. The only valid
     *      values are: NPP_CMP_LESS and NPP_CMP_GREATER.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, or NPP_NOT_SUPPORTED_MODE_ERROR if an invalid
     * comparison operation type is specified.
     * </pre>
     */
    public static int nppiThreshold_16s_C3IR(
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        short[] rThresholds, 
        int eComparisonOperation)
    {
        return JNpp.checkResult(nppiThreshold_16s_C3IRNative(pSrcDst, nSrcDstStep, oSizeROI, rThresholds, eComparisonOperation));
    }
    private static native int nppiThreshold_16s_C3IRNative(
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        short[] rThresholds, 
        int eComparisonOperation);


    /**
     * <pre>
     * 3 channel 32-bit floating point threshold.
     * If for a comparison operations OP the predicate (sourcePixel OP nThreshold) is true, the pixel is set
     * to nThreshold, otherwise it is set to sourcePixel.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param rThresholds The threshold values, one per color channel.
     * @param eComparisonOperation The type of comparison operation to be used. The only valid
     *      values are: NPP_CMP_LESS and NPP_CMP_GREATER.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, or NPP_NOT_SUPPORTED_MODE_ERROR if an invalid
     * comparison operation type is specified.
     * </pre>
     */
    public static int nppiThreshold_32f_C3R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        float[] rThresholds, 
        int eComparisonOperation)
    {
        return JNpp.checkResult(nppiThreshold_32f_C3RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, rThresholds, eComparisonOperation));
    }
    private static native int nppiThreshold_32f_C3RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        float[] rThresholds, 
        int eComparisonOperation);


    /**
     * <pre>
     * 3 channel 32-bit floating point in place threshold.
     * If for a comparison operations OP the predicate (sourcePixel OP nThreshold) is true, the pixel is set
     * to nThreshold, otherwise it is set to sourcePixel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param rThresholds The threshold values, one per color channel.
     * @param eComparisonOperation The type of comparison operation to be used. The only valid
     *      values are: NPP_CMP_LESS and NPP_CMP_GREATER.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, or NPP_NOT_SUPPORTED_MODE_ERROR if an invalid
     * comparison operation type is specified.
     * </pre>
     */
    public static int nppiThreshold_32f_C3IR(
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        float[] rThresholds, 
        int eComparisonOperation)
    {
        return JNpp.checkResult(nppiThreshold_32f_C3IRNative(pSrcDst, nSrcDstStep, oSizeROI, rThresholds, eComparisonOperation));
    }
    private static native int nppiThreshold_32f_C3IRNative(
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        float[] rThresholds, 
        int eComparisonOperation);


    /**
     * <pre>
     * 4 channel 8-bit unsigned char image threshold, not affecting Alpha.
     * If for a comparison operations OP the predicate (sourcePixel.channel OP nThreshold) is true, the channel
     * value is set to nThreshold, otherwise it is set to sourcePixel.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param rThresholds The threshold values, one per color channel.
     * @param eComparisonOperation The type of comparison operation to be used. The only valid
     *      values are: NPP_CMP_LESS and NPP_CMP_GREATER.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, or NPP_NOT_SUPPORTED_MODE_ERROR if an invalid
     * comparison operation type is specified.
     * </pre>
     */
    public static int nppiThreshold_8u_AC4R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        byte[] rThresholds, 
        int eComparisonOperation)
    {
        return JNpp.checkResult(nppiThreshold_8u_AC4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, rThresholds, eComparisonOperation));
    }
    private static native int nppiThreshold_8u_AC4RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        byte[] rThresholds, 
        int eComparisonOperation);


    /**
     * <pre>
     * 4 channel 8-bit unsigned char in place image threshold, not affecting Alpha.
     * If for a comparison operations OP the predicate (sourcePixel.channel OP nThreshold) is true, the channel
     * value is set to nThreshold, otherwise it is set to sourcePixel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param rThresholds The threshold values, one per color channel.
     * @param eComparisonOperation The type of comparison operation to be used. The only valid
     *      values are: NPP_CMP_LESS and NPP_CMP_GREATER.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, or NPP_NOT_SUPPORTED_MODE_ERROR if an invalid
     * comparison operation type is specified.
     * </pre>
     */
    public static int nppiThreshold_8u_AC4IR(
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        byte[] rThresholds, 
        int eComparisonOperation)
    {
        return JNpp.checkResult(nppiThreshold_8u_AC4IRNative(pSrcDst, nSrcDstStep, oSizeROI, rThresholds, eComparisonOperation));
    }
    private static native int nppiThreshold_8u_AC4IRNative(
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        byte[] rThresholds, 
        int eComparisonOperation);


    public static int nppiThreshold_16u_AC4R(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        short[] rThresholds, 
        int eComparisonOperation)
    {
        return JNpp.checkResult(nppiThreshold_16u_AC4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, rThresholds, eComparisonOperation));
    }
    private static native int nppiThreshold_16u_AC4RNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        short[] rThresholds, 
        int eComparisonOperation);


    public static int nppiThreshold_16u_AC4IR(
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        short[] rThresholds, 
        int eComparisonOperation)
    {
        return JNpp.checkResult(nppiThreshold_16u_AC4IRNative(pSrcDst, nSrcDstStep, oSizeROI, rThresholds, eComparisonOperation));
    }
    private static native int nppiThreshold_16u_AC4IRNative(
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        short[] rThresholds, 
        int eComparisonOperation);


    /**
     * <pre>
     * 4 channel 16-bit signed short image threshold, not affecting Alpha.
     * If for a comparison operations OP the predicate (sourcePixel.channel OP nThreshold) is true, the channel
     * value is set to nThreshold, otherwise it is set to sourcePixel.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param rThresholds The threshold values, one per color channel.
     * @param eComparisonOperation The type of comparison operation to be used. The only valid
     *      values are: NPP_CMP_LESS and NPP_CMP_GREATER.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, or NPP_NOT_SUPPORTED_MODE_ERROR if an invalid
     * comparison operation type is specified.
     * </pre>
     */
    public static int nppiThreshold_16s_AC4R(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        short[] rThresholds, 
        int eComparisonOperation)
    {
        return JNpp.checkResult(nppiThreshold_16s_AC4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, rThresholds, eComparisonOperation));
    }
    private static native int nppiThreshold_16s_AC4RNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        short[] rThresholds, 
        int eComparisonOperation);


    /**
     * <pre>
     * 4 channel 16-bit signed short in place image threshold, not affecting Alpha.
     * If for a comparison operations OP the predicate (sourcePixel.channel OP nThreshold) is true, the channel
     * value is set to nThreshold, otherwise it is set to sourcePixel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param rThresholds The threshold values, one per color channel.
     * @param eComparisonOperation The type of comparison operation to be used. The only valid
     *      values are: NPP_CMP_LESS and NPP_CMP_GREATER.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, or NPP_NOT_SUPPORTED_MODE_ERROR if an invalid
     * comparison operation type is specified.
     * </pre>
     */
    public static int nppiThreshold_16s_AC4IR(
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        short[] rThresholds, 
        int eComparisonOperation)
    {
        return JNpp.checkResult(nppiThreshold_16s_AC4IRNative(pSrcDst, nSrcDstStep, oSizeROI, rThresholds, eComparisonOperation));
    }
    private static native int nppiThreshold_16s_AC4IRNative(
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        short[] rThresholds, 
        int eComparisonOperation);


    /**
     * <pre>
     * 4 channel 32-bit floating point image threshold, not affecting Alpha.
     * If for a comparison operations OP the predicate (sourcePixel.channel OP nThreshold) is true, the channel
     * value is set to nThreshold, otherwise it is set to sourcePixel.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param rThresholds The threshold values, one per color channel.
     * @param eComparisonOperation The type of comparison operation to be used. The only valid
     *      values are: NPP_CMP_LESS and NPP_CMP_GREATER.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, or NPP_NOT_SUPPORTED_MODE_ERROR if an invalid
     * comparison operation type is specified.
     * </pre>
     */
    public static int nppiThreshold_32f_AC4R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        float[] rThresholds, 
        int eComparisonOperation)
    {
        return JNpp.checkResult(nppiThreshold_32f_AC4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, rThresholds, eComparisonOperation));
    }
    private static native int nppiThreshold_32f_AC4RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        float[] rThresholds, 
        int eComparisonOperation);


    /**
     * <pre>
     * 4 channel 32-bit floating point in place image threshold, not affecting Alpha.
     * If for a comparison operations OP the predicate (sourcePixel.channel OP nThreshold) is true, the channel
     * value is set to nThreshold, otherwise it is set to sourcePixel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param rThresholds The threshold values, one per color channel.
     * @param eComparisonOperation The type of comparison operation to be used. The only valid
     *      values are: NPP_CMP_LESS and NPP_CMP_GREATER.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, or NPP_NOT_SUPPORTED_MODE_ERROR if an invalid
     * comparison operation type is specified.
     * </pre>
     */
    public static int nppiThreshold_32f_AC4IR(
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        float[] rThresholds, 
        int eComparisonOperation)
    {
        return JNpp.checkResult(nppiThreshold_32f_AC4IRNative(pSrcDst, nSrcDstStep, oSizeROI, rThresholds, eComparisonOperation));
    }
    private static native int nppiThreshold_32f_AC4IRNative(
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        float[] rThresholds, 
        int eComparisonOperation);


    /**
     * <pre>
     * 1 channel 8-bit unsigned char threshold.
     * If for a comparison operations sourcePixel is greater than nThreshold is true, the pixel is set
     * to nThreshold, otherwise it is set to sourcePixel.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nThreshold The threshold value.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiThreshold_GT_8u_C1R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        byte nThreshold)
    {
        return JNpp.checkResult(nppiThreshold_GT_8u_C1RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, nThreshold));
    }
    private static native int nppiThreshold_GT_8u_C1RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        byte nThreshold);


    /**
     * <pre>
     * 1 channel 8-bit unsigned char in place threshold.
     * If for a comparison operations sourcePixel is greater than nThreshold is true, the pixel is set
     * to nThreshold, otherwise it is set to sourcePixel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nThreshold The threshold value.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiThreshold_GT_8u_C1IR(
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        byte nThreshold)
    {
        return JNpp.checkResult(nppiThreshold_GT_8u_C1IRNative(pSrcDst, nSrcDstStep, oSizeROI, nThreshold));
    }
    private static native int nppiThreshold_GT_8u_C1IRNative(
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        byte nThreshold);


    /**
     * <pre>
     * 1 channel 16-bit unsigned short threshold.
     * If for a comparison operations sourcePixel is greater than nThreshold is true, the pixel is set
     * to nThreshold, otherwise it is set to sourcePixel.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nThreshold The threshold value.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiThreshold_GT_16u_C1R(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        short nThreshold)
    {
        return JNpp.checkResult(nppiThreshold_GT_16u_C1RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, nThreshold));
    }
    private static native int nppiThreshold_GT_16u_C1RNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        short nThreshold);


    public static int nppiThreshold_GT_16u_C1IR(
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        short nThreshold)
    {
        return JNpp.checkResult(nppiThreshold_GT_16u_C1IRNative(pSrcDst, nSrcDstStep, oSizeROI, nThreshold));
    }
    private static native int nppiThreshold_GT_16u_C1IRNative(
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        short nThreshold);


    /**
     * <pre>
     * 1 channel 16-bit signed short threshold.
     * If for a comparison operations sourcePixel is greater than nThreshold is true, the pixel is set
     * to nThreshold, otherwise it is set to sourcePixel.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nThreshold The threshold value.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiThreshold_GT_16s_C1R(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        short nThreshold)
    {
        return JNpp.checkResult(nppiThreshold_GT_16s_C1RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, nThreshold));
    }
    private static native int nppiThreshold_GT_16s_C1RNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        short nThreshold);


    public static int nppiThreshold_GT_16s_C1IR(
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        short nThreshold)
    {
        return JNpp.checkResult(nppiThreshold_GT_16s_C1IRNative(pSrcDst, nSrcDstStep, oSizeROI, nThreshold));
    }
    private static native int nppiThreshold_GT_16s_C1IRNative(
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        short nThreshold);


    /**
     * <pre>
     * 1 channel 32-bit floating point threshold.
     * If for a comparison operations sourcePixel is greater than nThreshold is true, the pixel is set
     * to nThreshold, otherwise it is set to sourcePixel.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nThreshold The threshold value.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiThreshold_GT_32f_C1R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        float nThreshold)
    {
        return JNpp.checkResult(nppiThreshold_GT_32f_C1RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, nThreshold));
    }
    private static native int nppiThreshold_GT_32f_C1RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        float nThreshold);


    /**
     * <pre>
     * 1 channel 32-bit floating point in place threshold.
     * If for a comparison operations sourcePixel is greater than nThreshold is true, the pixel is set
     * to nThreshold, otherwise it is set to sourcePixel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nThreshold The threshold value.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiThreshold_GT_32f_C1IR(
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        float nThreshold)
    {
        return JNpp.checkResult(nppiThreshold_GT_32f_C1IRNative(pSrcDst, nSrcDstStep, oSizeROI, nThreshold));
    }
    private static native int nppiThreshold_GT_32f_C1IRNative(
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        float nThreshold);


    /**
     * <pre>
     * 3 channel 8-bit unsigned char threshold.
     * If for a comparison operations sourcePixel is greater than nThreshold is true, the pixel is set
     * to nThreshold, otherwise it is set to sourcePixel.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param rThresholds The threshold values, one per color channel.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiThreshold_GT_8u_C3R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        byte[] rThresholds)
    {
        return JNpp.checkResult(nppiThreshold_GT_8u_C3RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, rThresholds));
    }
    private static native int nppiThreshold_GT_8u_C3RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        byte[] rThresholds);


    /**
     * <pre>
     * 3 channel 8-bit unsigned char in place threshold.
     * If for a comparison operations sourcePixel is greater than nThreshold is true, the pixel is set
     * to nThreshold, otherwise it is set to sourcePixel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param rThresholds The threshold values, one per color channel.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiThreshold_GT_8u_C3IR(
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        byte[] rThresholds)
    {
        return JNpp.checkResult(nppiThreshold_GT_8u_C3IRNative(pSrcDst, nSrcDstStep, oSizeROI, rThresholds));
    }
    private static native int nppiThreshold_GT_8u_C3IRNative(
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        byte[] rThresholds);


    /**
     * <pre>
     * 3 channel 16-bit unsigned short threshold.
     * If for a comparison operations sourcePixel is greater than nThreshold is true, the pixel is set
     * to nThreshold, otherwise it is set to sourcePixel.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param rThresholds The threshold values, one per color channel.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiThreshold_GT_16u_C3R(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        short[] rThresholds)
    {
        return JNpp.checkResult(nppiThreshold_GT_16u_C3RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, rThresholds));
    }
    private static native int nppiThreshold_GT_16u_C3RNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        short[] rThresholds);


    public static int nppiThreshold_GT_16u_C3IR(
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        short[] rThresholds)
    {
        return JNpp.checkResult(nppiThreshold_GT_16u_C3IRNative(pSrcDst, nSrcDstStep, oSizeROI, rThresholds));
    }
    private static native int nppiThreshold_GT_16u_C3IRNative(
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        short[] rThresholds);


    /**
     * <pre>
     * 3 channel 16-bit signed short threshold.
     * If for a comparison operations sourcePixel is greater than nThreshold is true, the pixel is set
     * to nThreshold, otherwise it is set to sourcePixel.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param rThresholds The threshold values, one per color channel.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiThreshold_GT_16s_C3R(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        short[] rThresholds)
    {
        return JNpp.checkResult(nppiThreshold_GT_16s_C3RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, rThresholds));
    }
    private static native int nppiThreshold_GT_16s_C3RNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        short[] rThresholds);


    public static int nppiThreshold_GT_16s_C3IR(
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        short[] rThresholds)
    {
        return JNpp.checkResult(nppiThreshold_GT_16s_C3IRNative(pSrcDst, nSrcDstStep, oSizeROI, rThresholds));
    }
    private static native int nppiThreshold_GT_16s_C3IRNative(
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        short[] rThresholds);


    public static int nppiThreshold_GT_32f_C3R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        float[] rThresholds)
    {
        return JNpp.checkResult(nppiThreshold_GT_32f_C3RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, rThresholds));
    }
    private static native int nppiThreshold_GT_32f_C3RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        float[] rThresholds);


    /**
     * <pre>
     * 3 channel 32-bit floating point in place threshold.
     * If for a comparison operations sourcePixel is greater than nThreshold is true, the pixel is set
     * to nThreshold, otherwise it is set to sourcePixel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param rThresholds The threshold values, one per color channel.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiThreshold_GT_32f_C3IR(
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        float[] rThresholds)
    {
        return JNpp.checkResult(nppiThreshold_GT_32f_C3IRNative(pSrcDst, nSrcDstStep, oSizeROI, rThresholds));
    }
    private static native int nppiThreshold_GT_32f_C3IRNative(
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        float[] rThresholds);


    /**
     * <pre>
     * 4 channel 8-bit unsigned char image threshold, not affecting Alpha.
     * If for a comparison operations sourcePixel is greater than nThreshold is true, the pixel is set
     * value is set to nThreshold, otherwise it is set to sourcePixel.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param rThresholds The threshold values, one per color channel.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiThreshold_GT_8u_AC4R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        byte[] rThresholds)
    {
        return JNpp.checkResult(nppiThreshold_GT_8u_AC4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, rThresholds));
    }
    private static native int nppiThreshold_GT_8u_AC4RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        byte[] rThresholds);


    public static int nppiThreshold_GT_8u_AC4IR(
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        byte[] rThresholds)
    {
        return JNpp.checkResult(nppiThreshold_GT_8u_AC4IRNative(pSrcDst, nSrcDstStep, oSizeROI, rThresholds));
    }
    private static native int nppiThreshold_GT_8u_AC4IRNative(
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        byte[] rThresholds);


    /**
     * <pre>
     * 4 channel 16-bit unsigned short image threshold, not affecting Alpha.
     * If for a comparison operations sourcePixel is greater than nThreshold is true, the pixel is set
     * value is set to nThreshold, otherwise it is set to sourcePixel.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param rThresholds The threshold values, one per color channel.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiThreshold_GT_16u_AC4R(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        short[] rThresholds)
    {
        return JNpp.checkResult(nppiThreshold_GT_16u_AC4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, rThresholds));
    }
    private static native int nppiThreshold_GT_16u_AC4RNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        short[] rThresholds);


    /**
     * <pre>
     * 4 channel 16-bit unsigned short in place image threshold, not affecting Alpha.
     * If for a comparison operations sourcePixel is greater than nThreshold is true, the pixel is set
     * value is set to nThreshold, otherwise it is set to sourcePixel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param rThresholds The threshold values, one per color channel.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiThreshold_GT_16u_AC4IR(
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        short[] rThresholds)
    {
        return JNpp.checkResult(nppiThreshold_GT_16u_AC4IRNative(pSrcDst, nSrcDstStep, oSizeROI, rThresholds));
    }
    private static native int nppiThreshold_GT_16u_AC4IRNative(
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        short[] rThresholds);


    /**
     * <pre>
     * 4 channel 16-bit signed short image threshold, not affecting Alpha.
     * If for a comparison operations sourcePixel is greater than nThreshold is true, the pixel is set
     * value is set to nThreshold, otherwise it is set to sourcePixel.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param rThresholds The threshold values, one per color channel.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiThreshold_GT_16s_AC4R(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        short[] rThresholds)
    {
        return JNpp.checkResult(nppiThreshold_GT_16s_AC4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, rThresholds));
    }
    private static native int nppiThreshold_GT_16s_AC4RNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        short[] rThresholds);


    public static int nppiThreshold_GT_16s_AC4IR(
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        short[] rThresholds)
    {
        return JNpp.checkResult(nppiThreshold_GT_16s_AC4IRNative(pSrcDst, nSrcDstStep, oSizeROI, rThresholds));
    }
    private static native int nppiThreshold_GT_16s_AC4IRNative(
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        short[] rThresholds);


    /**
     * <pre>
     * 4 channel 32-bit floating point image threshold, not affecting Alpha.
     * If for a comparison operations sourcePixel is greater than nThreshold is true, the pixel is set
     * value is set to nThreshold, otherwise it is set to sourcePixel.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param rThresholds The threshold values, one per color channel.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiThreshold_GT_32f_AC4R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        float[] rThresholds)
    {
        return JNpp.checkResult(nppiThreshold_GT_32f_AC4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, rThresholds));
    }
    private static native int nppiThreshold_GT_32f_AC4RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        float[] rThresholds);


    public static int nppiThreshold_GT_32f_AC4IR(
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        float[] rThresholds)
    {
        return JNpp.checkResult(nppiThreshold_GT_32f_AC4IRNative(pSrcDst, nSrcDstStep, oSizeROI, rThresholds));
    }
    private static native int nppiThreshold_GT_32f_AC4IRNative(
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        float[] rThresholds);


    /**
     * <pre>
     * 1 channel 8-bit unsigned char threshold.
     * If for a comparison operations sourcePixel is less than nThreshold is true, the pixel is set
     * to nThreshold, otherwise it is set to sourcePixel.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nThreshold The threshold value.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiThreshold_LT_8u_C1R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        byte nThreshold)
    {
        return JNpp.checkResult(nppiThreshold_LT_8u_C1RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, nThreshold));
    }
    private static native int nppiThreshold_LT_8u_C1RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        byte nThreshold);


    /**
     * <pre>
     * 1 channel 8-bit unsigned char in place threshold.
     * If for a comparison operations sourcePixel is less than nThreshold is true, the pixel is set
     * to nThreshold, otherwise it is set to sourcePixel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nThreshold The threshold value.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiThreshold_LT_8u_C1IR(
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        byte nThreshold)
    {
        return JNpp.checkResult(nppiThreshold_LT_8u_C1IRNative(pSrcDst, nSrcDstStep, oSizeROI, nThreshold));
    }
    private static native int nppiThreshold_LT_8u_C1IRNative(
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        byte nThreshold);


    /**
     * <pre>
     * 1 channel 16-bit unsigned short threshold.
     * If for a comparison operations sourcePixel is less than nThreshold is true, the pixel is set
     * to nThreshold, otherwise it is set to sourcePixel.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nThreshold The threshold value.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiThreshold_LT_16u_C1R(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        short nThreshold)
    {
        return JNpp.checkResult(nppiThreshold_LT_16u_C1RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, nThreshold));
    }
    private static native int nppiThreshold_LT_16u_C1RNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        short nThreshold);


    public static int nppiThreshold_LT_16u_C1IR(
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        short nThreshold)
    {
        return JNpp.checkResult(nppiThreshold_LT_16u_C1IRNative(pSrcDst, nSrcDstStep, oSizeROI, nThreshold));
    }
    private static native int nppiThreshold_LT_16u_C1IRNative(
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        short nThreshold);


    /**
     * <pre>
     * 1 channel 16-bit signed short threshold.
     * If for a comparison operations sourcePixel is less than nThreshold is true, the pixel is set
     * to nThreshold, otherwise it is set to sourcePixel.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nThreshold The threshold value.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiThreshold_LT_16s_C1R(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        short nThreshold)
    {
        return JNpp.checkResult(nppiThreshold_LT_16s_C1RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, nThreshold));
    }
    private static native int nppiThreshold_LT_16s_C1RNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        short nThreshold);


    /**
     * <pre>
     * 1 channel 16-bit signed short in place threshold.
     * If for a comparison operations sourcePixel is less than nThreshold is true, the pixel is set
     * to nThreshold, otherwise it is set to sourcePixel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nThreshold The threshold value.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiThreshold_LT_16s_C1IR(
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        short nThreshold)
    {
        return JNpp.checkResult(nppiThreshold_LT_16s_C1IRNative(pSrcDst, nSrcDstStep, oSizeROI, nThreshold));
    }
    private static native int nppiThreshold_LT_16s_C1IRNative(
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        short nThreshold);


    /**
     * <pre>
     * 1 channel 32-bit floating point threshold.
     * If for a comparison operations sourcePixel is less than nThreshold is true, the pixel is set
     * to nThreshold, otherwise it is set to sourcePixel.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nThreshold The threshold value.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiThreshold_LT_32f_C1R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        float nThreshold)
    {
        return JNpp.checkResult(nppiThreshold_LT_32f_C1RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, nThreshold));
    }
    private static native int nppiThreshold_LT_32f_C1RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        float nThreshold);


    /**
     * <pre>
     * 1 channel 32-bit floating point in place threshold.
     * If for a comparison operations sourcePixel is less than nThreshold is true, the pixel is set
     * to nThreshold, otherwise it is set to sourcePixel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nThreshold The threshold value.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiThreshold_LT_32f_C1IR(
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        float nThreshold)
    {
        return JNpp.checkResult(nppiThreshold_LT_32f_C1IRNative(pSrcDst, nSrcDstStep, oSizeROI, nThreshold));
    }
    private static native int nppiThreshold_LT_32f_C1IRNative(
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        float nThreshold);


    /**
     * <pre>
     * 3 channel 8-bit unsigned char threshold.
     * If for a comparison operations sourcePixel is less than nThreshold is true, the pixel is set
     * to nThreshold, otherwise it is set to sourcePixel.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param rThresholds The threshold values, one per color channel.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiThreshold_LT_8u_C3R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        byte[] rThresholds)
    {
        return JNpp.checkResult(nppiThreshold_LT_8u_C3RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, rThresholds));
    }
    private static native int nppiThreshold_LT_8u_C3RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        byte[] rThresholds);


    /**
     * <pre>
     * 3 channel 8-bit unsigned char in place threshold.
     * If for a comparison operations sourcePixel is less than nThreshold is true, the pixel is set
     * to nThreshold, otherwise it is set to sourcePixel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param rThresholds The threshold values, one per color channel.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiThreshold_LT_8u_C3IR(
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        byte[] rThresholds)
    {
        return JNpp.checkResult(nppiThreshold_LT_8u_C3IRNative(pSrcDst, nSrcDstStep, oSizeROI, rThresholds));
    }
    private static native int nppiThreshold_LT_8u_C3IRNative(
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        byte[] rThresholds);


    /**
     * <pre>
     * 3 channel 16-bit unsigned short threshold.
     * If for a comparison operations sourcePixel is less than nThreshold is true, the pixel is set
     * to nThreshold, otherwise it is set to sourcePixel.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param rThresholds The threshold values, one per color channel.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiThreshold_LT_16u_C3R(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        short[] rThresholds)
    {
        return JNpp.checkResult(nppiThreshold_LT_16u_C3RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, rThresholds));
    }
    private static native int nppiThreshold_LT_16u_C3RNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        short[] rThresholds);


    /**
     * <pre>
     * 3 channel 16-bit unsigned short in place threshold.
     * If for a comparison operations sourcePixel is less than nThreshold is true, the pixel is set
     * to nThreshold, otherwise it is set to sourcePixel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param rThresholds The threshold values, one per color channel.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiThreshold_LT_16u_C3IR(
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        short[] rThresholds)
    {
        return JNpp.checkResult(nppiThreshold_LT_16u_C3IRNative(pSrcDst, nSrcDstStep, oSizeROI, rThresholds));
    }
    private static native int nppiThreshold_LT_16u_C3IRNative(
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        short[] rThresholds);


    /**
     * <pre>
     * 3 channel 16-bit signed short threshold.
     * If for a comparison operations sourcePixel is less than nThreshold is true, the pixel is set
     * to nThreshold, otherwise it is set to sourcePixel.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param rThresholds The threshold values, one per color channel.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiThreshold_LT_16s_C3R(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        short[] rThresholds)
    {
        return JNpp.checkResult(nppiThreshold_LT_16s_C3RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, rThresholds));
    }
    private static native int nppiThreshold_LT_16s_C3RNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        short[] rThresholds);


    /**
     * <pre>
     * 3 channel 16-bit signed short in place threshold.
     * If for a comparison operations sourcePixel is less than nThreshold is true, the pixel is set
     * to nThreshold, otherwise it is set to sourcePixel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param rThresholds The threshold values, one per color channel.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiThreshold_LT_16s_C3IR(
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        short[] rThresholds)
    {
        return JNpp.checkResult(nppiThreshold_LT_16s_C3IRNative(pSrcDst, nSrcDstStep, oSizeROI, rThresholds));
    }
    private static native int nppiThreshold_LT_16s_C3IRNative(
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        short[] rThresholds);


    /**
     * <pre>
     * 3 channel 32-bit floating point threshold.
     * If for a comparison operations sourcePixel is less than nThreshold is true, the pixel is set
     * to nThreshold, otherwise it is set to sourcePixel.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param rThresholds The threshold values, one per color channel.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiThreshold_LT_32f_C3R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        float[] rThresholds)
    {
        return JNpp.checkResult(nppiThreshold_LT_32f_C3RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, rThresholds));
    }
    private static native int nppiThreshold_LT_32f_C3RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        float[] rThresholds);


    /**
     * <pre>
     * 3 channel 32-bit floating point in place threshold.
     * If for a comparison operations sourcePixel is less than nThreshold is true, the pixel is set
     * to nThreshold, otherwise it is set to sourcePixel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param rThresholds The threshold values, one per color channel.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiThreshold_LT_32f_C3IR(
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        float[] rThresholds)
    {
        return JNpp.checkResult(nppiThreshold_LT_32f_C3IRNative(pSrcDst, nSrcDstStep, oSizeROI, rThresholds));
    }
    private static native int nppiThreshold_LT_32f_C3IRNative(
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        float[] rThresholds);


    /**
     * <pre>
     * 4 channel 8-bit unsigned char image threshold, not affecting Alpha.
     * If for a comparison operations sourcePixel is less than nThreshold is true, the pixel is set
     * value is set to nThreshold, otherwise it is set to sourcePixel.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param rThresholds The threshold values, one per color channel.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiThreshold_LT_8u_AC4R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        byte[] rThresholds)
    {
        return JNpp.checkResult(nppiThreshold_LT_8u_AC4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, rThresholds));
    }
    private static native int nppiThreshold_LT_8u_AC4RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        byte[] rThresholds);


    /**
     * <pre>
     * 4 channel 8-bit unsigned char in place image threshold, not affecting Alpha.
     * If for a comparison operations sourcePixel is less than nThreshold is true, the pixel is set
     * value is set to nThreshold, otherwise it is set to sourcePixel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param rThresholds The threshold values, one per color channel.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiThreshold_LT_8u_AC4IR(
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        byte[] rThresholds)
    {
        return JNpp.checkResult(nppiThreshold_LT_8u_AC4IRNative(pSrcDst, nSrcDstStep, oSizeROI, rThresholds));
    }
    private static native int nppiThreshold_LT_8u_AC4IRNative(
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        byte[] rThresholds);


    /**
     * <pre>
     * 4 channel 16-bit unsigned short image threshold, not affecting Alpha.
     * If for a comparison operations sourcePixel is less than nThreshold is true, the pixel is set
     * value is set to nThreshold, otherwise it is set to sourcePixel.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param rThresholds The threshold values, one per color channel.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiThreshold_LT_16u_AC4R(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        short[] rThresholds)
    {
        return JNpp.checkResult(nppiThreshold_LT_16u_AC4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, rThresholds));
    }
    private static native int nppiThreshold_LT_16u_AC4RNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        short[] rThresholds);


    public static int nppiThreshold_LT_16u_AC4IR(
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        short[] rThresholds)
    {
        return JNpp.checkResult(nppiThreshold_LT_16u_AC4IRNative(pSrcDst, nSrcDstStep, oSizeROI, rThresholds));
    }
    private static native int nppiThreshold_LT_16u_AC4IRNative(
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        short[] rThresholds);


    /**
     * <pre>
     * 4 channel 16-bit signed short image threshold, not affecting Alpha.
     * If for a comparison operations sourcePixel is less than nThreshold is true, the pixel is set
     * value is set to nThreshold, otherwise it is set to sourcePixel.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param rThresholds The threshold values, one per color channel.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiThreshold_LT_16s_AC4R(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        short[] rThresholds)
    {
        return JNpp.checkResult(nppiThreshold_LT_16s_AC4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, rThresholds));
    }
    private static native int nppiThreshold_LT_16s_AC4RNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        short[] rThresholds);


    /**
     * <pre>
     * 4 channel 16-bit signed short in place image threshold, not affecting Alpha.
     * If for a comparison operations sourcePixel is less than nThreshold is true, the pixel is set
     * value is set to nThreshold, otherwise it is set to sourcePixel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param rThresholds The threshold values, one per color channel.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiThreshold_LT_16s_AC4IR(
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        short[] rThresholds)
    {
        return JNpp.checkResult(nppiThreshold_LT_16s_AC4IRNative(pSrcDst, nSrcDstStep, oSizeROI, rThresholds));
    }
    private static native int nppiThreshold_LT_16s_AC4IRNative(
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        short[] rThresholds);


    /**
     * <pre>
     * 4 channel 32-bit floating point image threshold, not affecting Alpha.
     * If for a comparison operations sourcePixel is less than nThreshold is true, the pixel is set
     * value is set to nThreshold, otherwise it is set to sourcePixel.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param rThresholds The threshold values, one per color channel.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiThreshold_LT_32f_AC4R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        float[] rThresholds)
    {
        return JNpp.checkResult(nppiThreshold_LT_32f_AC4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, rThresholds));
    }
    private static native int nppiThreshold_LT_32f_AC4RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        float[] rThresholds);


    public static int nppiThreshold_LT_32f_AC4IR(
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        float[] rThresholds)
    {
        return JNpp.checkResult(nppiThreshold_LT_32f_AC4IRNative(pSrcDst, nSrcDstStep, oSizeROI, rThresholds));
    }
    private static native int nppiThreshold_LT_32f_AC4IRNative(
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        float[] rThresholds);


    /**
     * <pre>
     * 1 channel 8-bit unsigned char threshold.
     * If for a comparison operations OP the predicate (sourcePixel OP nThreshold) is true, the pixel is set
     * to nValue, otherwise it is set to sourcePixel.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nThreshold The threshold value.
     * @param nValue The threshold replacement value.
     * @param eComparisonOperation The type of comparison operation to be used. The only valid
     *      values are: NPP_CMP_LESS and NPP_CMP_GREATER.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, or NPP_NOT_SUPPORTED_MODE_ERROR if an invalid
     * comparison operation type is specified.
     * </pre>
     */
    public static int nppiThreshold_Val_8u_C1R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        byte nThreshold, 
        byte nValue, 
        int eComparisonOperation)
    {
        return JNpp.checkResult(nppiThreshold_Val_8u_C1RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, nThreshold, nValue, eComparisonOperation));
    }
    private static native int nppiThreshold_Val_8u_C1RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        byte nThreshold, 
        byte nValue, 
        int eComparisonOperation);


    /**
     * <pre>
     * 1 channel 8-bit unsigned char in place threshold.
     * If for a comparison operations OP the predicate (sourcePixel OP nThreshold) is true, the pixel is set
     * to nValue, otherwise it is set to sourcePixel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nThreshold The threshold value.
     * @param nValue The threshold replacement value.
     * @param eComparisonOperation The type of comparison operation to be used. The only valid
     *      values are: NPP_CMP_LESS and NPP_CMP_GREATER.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, or NPP_NOT_SUPPORTED_MODE_ERROR if an invalid
     * comparison operation type is specified.
     * </pre>
     */
    public static int nppiThreshold_Val_8u_C1IR(
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        byte nThreshold, 
        byte nValue, 
        int eComparisonOperation)
    {
        return JNpp.checkResult(nppiThreshold_Val_8u_C1IRNative(pSrcDst, nSrcDstStep, oSizeROI, nThreshold, nValue, eComparisonOperation));
    }
    private static native int nppiThreshold_Val_8u_C1IRNative(
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        byte nThreshold, 
        byte nValue, 
        int eComparisonOperation);


    /**
     * <pre>
     * 1 channel 16-bit unsigned short threshold.
     * If for a comparison operations OP the predicate (sourcePixel OP nThreshold) is true, the pixel is set
     * to nValue, otherwise it is set to sourcePixel.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nThreshold The threshold value.
     * @param nValue The threshold replacement value.
     * @param eComparisonOperation The type of comparison operation to be used. The only valid
     *      values are: NPP_CMP_LESS and NPP_CMP_GREATER.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, or NPP_NOT_SUPPORTED_MODE_ERROR if an invalid
     * comparison operation type is specified.
     * </pre>
     */
    public static int nppiThreshold_Val_16u_C1R(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        short nThreshold, 
        short nValue, 
        int eComparisonOperation)
    {
        return JNpp.checkResult(nppiThreshold_Val_16u_C1RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, nThreshold, nValue, eComparisonOperation));
    }
    private static native int nppiThreshold_Val_16u_C1RNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        short nThreshold, 
        short nValue, 
        int eComparisonOperation);


    /**
     * <pre>
     * 1 channel 16-bit unsigned short in place threshold.
     * If for a comparison operations OP the predicate (sourcePixel OP nThreshold) is true, the pixel is set
     * to nValue, otherwise it is set to sourcePixel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nThreshold The threshold value.
     * @param nValue The threshold replacement value.
     * @param eComparisonOperation The type of comparison operation to be used. The only valid
     *      values are: NPP_CMP_LESS and NPP_CMP_GREATER.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, or NPP_NOT_SUPPORTED_MODE_ERROR if an invalid
     * comparison operation type is specified.
     * </pre>
     */
    public static int nppiThreshold_Val_16u_C1IR(
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        short nThreshold, 
        short nValue, 
        int eComparisonOperation)
    {
        return JNpp.checkResult(nppiThreshold_Val_16u_C1IRNative(pSrcDst, nSrcDstStep, oSizeROI, nThreshold, nValue, eComparisonOperation));
    }
    private static native int nppiThreshold_Val_16u_C1IRNative(
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        short nThreshold, 
        short nValue, 
        int eComparisonOperation);


    /**
     * <pre>
     * 1 channel 16-bit signed short threshold.
     * If for a comparison operations OP the predicate (sourcePixel OP nThreshold) is true, the pixel is set
     * to nValue, otherwise it is set to sourcePixel.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nThreshold The threshold value.
     * @param nValue The threshold replacement value.
     * @param eComparisonOperation The type of comparison operation to be used. The only valid
     *      values are: NPP_CMP_LESS and NPP_CMP_GREATER.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, or NPP_NOT_SUPPORTED_MODE_ERROR if an invalid
     * comparison operation type is specified.
     * </pre>
     */
    public static int nppiThreshold_Val_16s_C1R(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        short nThreshold, 
        short nValue, 
        int eComparisonOperation)
    {
        return JNpp.checkResult(nppiThreshold_Val_16s_C1RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, nThreshold, nValue, eComparisonOperation));
    }
    private static native int nppiThreshold_Val_16s_C1RNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        short nThreshold, 
        short nValue, 
        int eComparisonOperation);


    /**
     * <pre>
     * 1 channel 16-bit signed short in place threshold.
     * If for a comparison operations OP the predicate (sourcePixel OP nThreshold) is true, the pixel is set
     * to nValue, otherwise it is set to sourcePixel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nThreshold The threshold value.
     * @param nValue The threshold replacement value.
     * @param eComparisonOperation The type of comparison operation to be used. The only valid
     *      values are: NPP_CMP_LESS and NPP_CMP_GREATER.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, or NPP_NOT_SUPPORTED_MODE_ERROR if an invalid
     * comparison operation type is specified.
     * </pre>
     */
    public static int nppiThreshold_Val_16s_C1IR(
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        short nThreshold, 
        short nValue, 
        int eComparisonOperation)
    {
        return JNpp.checkResult(nppiThreshold_Val_16s_C1IRNative(pSrcDst, nSrcDstStep, oSizeROI, nThreshold, nValue, eComparisonOperation));
    }
    private static native int nppiThreshold_Val_16s_C1IRNative(
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        short nThreshold, 
        short nValue, 
        int eComparisonOperation);


    /**
     * <pre>
     * 1 channel 32-bit floating point threshold.
     * If for a comparison operations OP the predicate (sourcePixel OP nThreshold) is true, the pixel is set
     * to nValue, otherwise it is set to sourcePixel.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nThreshold The threshold value.
     * @param nValue The threshold replacement value.
     * @param eComparisonOperation The type of comparison operation to be used. The only valid
     *      values are: NPP_CMP_LESS and NPP_CMP_GREATER.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, or NPP_NOT_SUPPORTED_MODE_ERROR if an invalid
     * comparison operation type is specified.
     * </pre>
     */
    public static int nppiThreshold_Val_32f_C1R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        float nThreshold, 
        float nValue, 
        int eComparisonOperation)
    {
        return JNpp.checkResult(nppiThreshold_Val_32f_C1RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, nThreshold, nValue, eComparisonOperation));
    }
    private static native int nppiThreshold_Val_32f_C1RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        float nThreshold, 
        float nValue, 
        int eComparisonOperation);


    /**
     * <pre>
     * 1 channel 32-bit floating point in place threshold.
     * If for a comparison operations OP the predicate (sourcePixel OP nThreshold) is true, the pixel is set
     * to nValue, otherwise it is set to sourcePixel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nThreshold The threshold value.
     * @param nValue The threshold replacement value.
     * @param eComparisonOperation The type of comparison operation to be used. The only valid
     *      values are: NPP_CMP_LESS and NPP_CMP_GREATER.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, or NPP_NOT_SUPPORTED_MODE_ERROR if an invalid
     * comparison operation type is specified.
     * </pre>
     */
    public static int nppiThreshold_Val_32f_C1IR(
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        float nThreshold, 
        float nValue, 
        int eComparisonOperation)
    {
        return JNpp.checkResult(nppiThreshold_Val_32f_C1IRNative(pSrcDst, nSrcDstStep, oSizeROI, nThreshold, nValue, eComparisonOperation));
    }
    private static native int nppiThreshold_Val_32f_C1IRNative(
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        float nThreshold, 
        float nValue, 
        int eComparisonOperation);


    /**
     * <pre>
     * 3 channel 8-bit unsigned char threshold.
     * If for a comparison operations OP the predicate (sourcePixel OP nThreshold) is true, the pixel is set
     * to nValue, otherwise it is set to sourcePixel.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param rThresholds The threshold values, one per color channel.
     * @param rValues The threshold replacement values, one per color channel.
     * @param eComparisonOperation The type of comparison operation to be used. The only valid
     *      values are: NPP_CMP_LESS and NPP_CMP_GREATER.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, or NPP_NOT_SUPPORTED_MODE_ERROR if an invalid
     * comparison operation type is specified.
     * </pre>
     */
    public static int nppiThreshold_Val_8u_C3R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        byte[] rThresholds, 
        byte[] rValues, 
        int eComparisonOperation)
    {
        return JNpp.checkResult(nppiThreshold_Val_8u_C3RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, rThresholds, rValues, eComparisonOperation));
    }
    private static native int nppiThreshold_Val_8u_C3RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        byte[] rThresholds, 
        byte[] rValues, 
        int eComparisonOperation);


    /**
     * <pre>
     * 3 channel 8-bit unsigned char in place threshold.
     * If for a comparison operations OP the predicate (sourcePixel OP nThreshold) is true, the pixel is set
     * to nValue, otherwise it is set to sourcePixel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param rThresholds The threshold values, one per color channel.
     * @param rValues The threshold replacement values, one per color channel.
     * @param eComparisonOperation The type of comparison operation to be used. The only valid
     *      values are: NPP_CMP_LESS and NPP_CMP_GREATER.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, or NPP_NOT_SUPPORTED_MODE_ERROR if an invalid
     * comparison operation type is specified.
     * </pre>
     */
    public static int nppiThreshold_Val_8u_C3IR(
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        byte[] rThresholds, 
        byte[] rValues, 
        int eComparisonOperation)
    {
        return JNpp.checkResult(nppiThreshold_Val_8u_C3IRNative(pSrcDst, nSrcDstStep, oSizeROI, rThresholds, rValues, eComparisonOperation));
    }
    private static native int nppiThreshold_Val_8u_C3IRNative(
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        byte[] rThresholds, 
        byte[] rValues, 
        int eComparisonOperation);


    public static int nppiThreshold_Val_16u_C3R(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        short[] rThresholds, 
        short[] rValues, 
        int eComparisonOperation)
    {
        return JNpp.checkResult(nppiThreshold_Val_16u_C3RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, rThresholds, rValues, eComparisonOperation));
    }
    private static native int nppiThreshold_Val_16u_C3RNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        short[] rThresholds, 
        short[] rValues, 
        int eComparisonOperation);


    /**
     * <pre>
     * 3 channel 16-bit unsigned short in place threshold.
     * If for a comparison operations OP the predicate (sourcePixel OP nThreshold) is true, the pixel is set
     * to nValue, otherwise it is set to sourcePixel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param rThresholds The threshold values, one per color channel.
     * @param rValues The threshold replacement values, one per color channel.
     * @param eComparisonOperation The type of comparison operation to be used. The only valid
     *      values are: NPP_CMP_LESS and NPP_CMP_GREATER.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, or NPP_NOT_SUPPORTED_MODE_ERROR if an invalid
     * comparison operation type is specified.
     * </pre>
     */
    public static int nppiThreshold_Val_16u_C3IR(
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        short[] rThresholds, 
        short[] rValues, 
        int eComparisonOperation)
    {
        return JNpp.checkResult(nppiThreshold_Val_16u_C3IRNative(pSrcDst, nSrcDstStep, oSizeROI, rThresholds, rValues, eComparisonOperation));
    }
    private static native int nppiThreshold_Val_16u_C3IRNative(
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        short[] rThresholds, 
        short[] rValues, 
        int eComparisonOperation);


    /**
     * <pre>
     * 3 channel 16-bit signed short threshold.
     * If for a comparison operations OP the predicate (sourcePixel OP nThreshold) is true, the pixel is set
     * to nValue, otherwise it is set to sourcePixel.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param rThresholds The threshold values, one per color channel.
     * @param rValues The threshold replacement values, one per color channel.
     * @param eComparisonOperation The type of comparison operation to be used. The only valid
     *      values are: NPP_CMP_LESS and NPP_CMP_GREATER.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, or NPP_NOT_SUPPORTED_MODE_ERROR if an invalid
     * comparison operation type is specified.
     * </pre>
     */
    public static int nppiThreshold_Val_16s_C3R(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        short[] rThresholds, 
        short[] rValues, 
        int eComparisonOperation)
    {
        return JNpp.checkResult(nppiThreshold_Val_16s_C3RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, rThresholds, rValues, eComparisonOperation));
    }
    private static native int nppiThreshold_Val_16s_C3RNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        short[] rThresholds, 
        short[] rValues, 
        int eComparisonOperation);


    /**
     * <pre>
     * 3 channel 16-bit signed short in place threshold.
     * If for a comparison operations OP the predicate (sourcePixel OP nThreshold) is true, the pixel is set
     * to nValue, otherwise it is set to sourcePixel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param rThresholds The threshold values, one per color channel.
     * @param rValues The threshold replacement values, one per color channel.
     * @param eComparisonOperation The type of comparison operation to be used. The only valid
     *      values are: NPP_CMP_LESS and NPP_CMP_GREATER.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, or NPP_NOT_SUPPORTED_MODE_ERROR if an invalid
     * comparison operation type is specified.
     * </pre>
     */
    public static int nppiThreshold_Val_16s_C3IR(
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        short[] rThresholds, 
        short[] rValues, 
        int eComparisonOperation)
    {
        return JNpp.checkResult(nppiThreshold_Val_16s_C3IRNative(pSrcDst, nSrcDstStep, oSizeROI, rThresholds, rValues, eComparisonOperation));
    }
    private static native int nppiThreshold_Val_16s_C3IRNative(
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        short[] rThresholds, 
        short[] rValues, 
        int eComparisonOperation);


    /**
     * <pre>
     * 3 channel 32-bit floating point threshold.
     * If for a comparison operations OP the predicate (sourcePixel OP nThreshold) is true, the pixel is set
     * to nValue, otherwise it is set to sourcePixel.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param rThresholds The threshold values, one per color channel.
     * @param rValues The threshold replacement values, one per color channel.
     * @param eComparisonOperation The type of comparison operation to be used. The only valid
     *      values are: NPP_CMP_LESS and NPP_CMP_GREATER.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, or NPP_NOT_SUPPORTED_MODE_ERROR if an invalid
     * comparison operation type is specified.
     * </pre>
     */
    public static int nppiThreshold_Val_32f_C3R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        float[] rThresholds, 
        float[] rValues, 
        int eComparisonOperation)
    {
        return JNpp.checkResult(nppiThreshold_Val_32f_C3RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, rThresholds, rValues, eComparisonOperation));
    }
    private static native int nppiThreshold_Val_32f_C3RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        float[] rThresholds, 
        float[] rValues, 
        int eComparisonOperation);


    /**
     * <pre>
     * 3 channel 32-bit floating point in place threshold.
     * If for a comparison operations OP the predicate (sourcePixel OP nThreshold) is true, the pixel is set
     * to nValue, otherwise it is set to sourcePixel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param rThresholds The threshold values, one per color channel.
     * @param rValues The threshold replacement values, one per color channel.
     * @param eComparisonOperation The type of comparison operation to be used. The only valid
     *      values are: NPP_CMP_LESS and NPP_CMP_GREATER.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, or NPP_NOT_SUPPORTED_MODE_ERROR if an invalid
     * comparison operation type is specified.
     * </pre>
     */
    public static int nppiThreshold_Val_32f_C3IR(
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        float[] rThresholds, 
        float[] rValues, 
        int eComparisonOperation)
    {
        return JNpp.checkResult(nppiThreshold_Val_32f_C3IRNative(pSrcDst, nSrcDstStep, oSizeROI, rThresholds, rValues, eComparisonOperation));
    }
    private static native int nppiThreshold_Val_32f_C3IRNative(
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        float[] rThresholds, 
        float[] rValues, 
        int eComparisonOperation);


    /**
     * <pre>
     * 4 channel 8-bit unsigned char image threshold, not affecting Alpha.
     * If for a comparison operations OP the predicate (sourcePixel.channel OP nThreshold) is true, the channel
     * value is set to nValue, otherwise it is set to sourcePixel.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param rThresholds The threshold values, one per color channel.
     * @param rValues The threshold replacement values, one per color channel.
     * @param eComparisonOperation The type of comparison operation to be used. The only valid
     *      values are: NPP_CMP_LESS and NPP_CMP_GREATER.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, or NPP_NOT_SUPPORTED_MODE_ERROR if an invalid
     * comparison operation type is specified.
     * </pre>
     */
    public static int nppiThreshold_Val_8u_AC4R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        byte[] rThresholds, 
        byte[] rValues, 
        int eComparisonOperation)
    {
        return JNpp.checkResult(nppiThreshold_Val_8u_AC4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, rThresholds, rValues, eComparisonOperation));
    }
    private static native int nppiThreshold_Val_8u_AC4RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        byte[] rThresholds, 
        byte[] rValues, 
        int eComparisonOperation);


    /**
     * <pre>
     * 4 channel 8-bit unsigned char in place image threshold, not affecting Alpha.
     * If for a comparison operations OP the predicate (sourcePixel.channel OP nThreshold) is true, the channel
     * value is set to nValue, otherwise it is set to sourcePixel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param rThresholds The threshold values, one per color channel.
     * @param rValues The threshold replacement values, one per color channel.
     * @param eComparisonOperation The type of comparison operation to be used. The only valid
     *      values are: NPP_CMP_LESS and NPP_CMP_GREATER.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, or NPP_NOT_SUPPORTED_MODE_ERROR if an invalid
     * comparison operation type is specified.
     * </pre>
     */
    public static int nppiThreshold_Val_8u_AC4IR(
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        byte[] rThresholds, 
        byte[] rValues, 
        int eComparisonOperation)
    {
        return JNpp.checkResult(nppiThreshold_Val_8u_AC4IRNative(pSrcDst, nSrcDstStep, oSizeROI, rThresholds, rValues, eComparisonOperation));
    }
    private static native int nppiThreshold_Val_8u_AC4IRNative(
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        byte[] rThresholds, 
        byte[] rValues, 
        int eComparisonOperation);


    /**
     * <pre>
     * 4 channel 16-bit unsigned short image threshold, not affecting Alpha.
     * If for a comparison operations OP the predicate (sourcePixel.channel OP nThreshold) is true, the channel
     * value is set to nValue, otherwise it is set to sourcePixel.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param rThresholds The threshold values, one per color channel.
     * @param rValues The threshold replacement values, one per color channel.
     * @param eComparisonOperation The type of comparison operation to be used. The only valid
     *      values are: NPP_CMP_LESS and NPP_CMP_GREATER.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, or NPP_NOT_SUPPORTED_MODE_ERROR if an invalid
     * comparison operation type is specified.
     * </pre>
     */
    public static int nppiThreshold_Val_16u_AC4R(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        short[] rThresholds, 
        short[] rValues, 
        int eComparisonOperation)
    {
        return JNpp.checkResult(nppiThreshold_Val_16u_AC4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, rThresholds, rValues, eComparisonOperation));
    }
    private static native int nppiThreshold_Val_16u_AC4RNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        short[] rThresholds, 
        short[] rValues, 
        int eComparisonOperation);


    /**
     * <pre>
     * 4 channel 16-bit unsigned short in place image threshold, not affecting Alpha.
     * If for a comparison operations OP the predicate (sourcePixel.channel OP nThreshold) is true, the channel
     * value is set to nValue, otherwise it is set to sourcePixel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param rThresholds The threshold values, one per color channel.
     * @param rValues The threshold replacement values, one per color channel.
     * @param eComparisonOperation The type of comparison operation to be used. The only valid
     *      values are: NPP_CMP_LESS and NPP_CMP_GREATER.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, or NPP_NOT_SUPPORTED_MODE_ERROR if an invalid
     * comparison operation type is specified.
     * </pre>
     */
    public static int nppiThreshold_Val_16u_AC4IR(
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        short[] rThresholds, 
        short[] rValues, 
        int eComparisonOperation)
    {
        return JNpp.checkResult(nppiThreshold_Val_16u_AC4IRNative(pSrcDst, nSrcDstStep, oSizeROI, rThresholds, rValues, eComparisonOperation));
    }
    private static native int nppiThreshold_Val_16u_AC4IRNative(
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        short[] rThresholds, 
        short[] rValues, 
        int eComparisonOperation);


    /**
     * <pre>
     * 4 channel 16-bit signed short image threshold, not affecting Alpha.
     * If for a comparison operations OP the predicate (sourcePixel.channel OP nThreshold) is true, the channel
     * value is set to nValue, otherwise it is set to sourcePixel.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param rThresholds The threshold values, one per color channel.
     * @param rValues The threshold replacement values, one per color channel.
     * @param eComparisonOperation The type of comparison operation to be used. The only valid
     *      values are: NPP_CMP_LESS and NPP_CMP_GREATER.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, or NPP_NOT_SUPPORTED_MODE_ERROR if an invalid
     * comparison operation type is specified.
     * </pre>
     */
    public static int nppiThreshold_Val_16s_AC4R(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        short[] rThresholds, 
        short[] rValues, 
        int eComparisonOperation)
    {
        return JNpp.checkResult(nppiThreshold_Val_16s_AC4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, rThresholds, rValues, eComparisonOperation));
    }
    private static native int nppiThreshold_Val_16s_AC4RNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        short[] rThresholds, 
        short[] rValues, 
        int eComparisonOperation);


    /**
     * <pre>
     * 4 channel 16-bit signed short in place image threshold, not affecting Alpha.
     * If for a comparison operations OP the predicate (sourcePixel.channel OP nThreshold) is true, the channel
     * value is set to nValue, otherwise it is set to sourcePixel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param rThresholds The threshold values, one per color channel.
     * @param rValues The threshold replacement values, one per color channel.
     * @param eComparisonOperation The type of comparison operation to be used. The only valid
     *      values are: NPP_CMP_LESS and NPP_CMP_GREATER.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, or NPP_NOT_SUPPORTED_MODE_ERROR if an invalid
     * comparison operation type is specified.
     * </pre>
     */
    public static int nppiThreshold_Val_16s_AC4IR(
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        short[] rThresholds, 
        short[] rValues, 
        int eComparisonOperation)
    {
        return JNpp.checkResult(nppiThreshold_Val_16s_AC4IRNative(pSrcDst, nSrcDstStep, oSizeROI, rThresholds, rValues, eComparisonOperation));
    }
    private static native int nppiThreshold_Val_16s_AC4IRNative(
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        short[] rThresholds, 
        short[] rValues, 
        int eComparisonOperation);


    /**
     * <pre>
     * 4 channel 32-bit floating point image threshold, not affecting Alpha.
     * If for a comparison operations OP the predicate (sourcePixel.channel OP nThreshold) is true, the channel
     * value is set to nValue, otherwise it is set to sourcePixel.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param rThresholds The threshold values, one per color channel.
     * @param rValues The threshold replacement values, one per color channel.
     * @param eComparisonOperation The type of comparison operation to be used. The only valid
     *      values are: NPP_CMP_LESS and NPP_CMP_GREATER.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, or NPP_NOT_SUPPORTED_MODE_ERROR if an invalid
     * comparison operation type is specified.
     * </pre>
     */
    public static int nppiThreshold_Val_32f_AC4R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        float[] rThresholds, 
        float[] rValues, 
        int eComparisonOperation)
    {
        return JNpp.checkResult(nppiThreshold_Val_32f_AC4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, rThresholds, rValues, eComparisonOperation));
    }
    private static native int nppiThreshold_Val_32f_AC4RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        float[] rThresholds, 
        float[] rValues, 
        int eComparisonOperation);


    public static int nppiThreshold_Val_32f_AC4IR(
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        float[] rThresholds, 
        float[] rValues, 
        int eComparisonOperation)
    {
        return JNpp.checkResult(nppiThreshold_Val_32f_AC4IRNative(pSrcDst, nSrcDstStep, oSizeROI, rThresholds, rValues, eComparisonOperation));
    }
    private static native int nppiThreshold_Val_32f_AC4IRNative(
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        float[] rThresholds, 
        float[] rValues, 
        int eComparisonOperation);


    /**
     * <pre>
     * 1 channel 8-bit unsigned char threshold.
     * If for a comparison operations sourcePixel is greater than nThreshold is true, the pixel is set
     * to nValue, otherwise it is set to sourcePixel.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nThreshold The threshold value.
     * @param nValue The threshold replacement value.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiThreshold_GTVal_8u_C1R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        byte nThreshold, 
        byte nValue)
    {
        return JNpp.checkResult(nppiThreshold_GTVal_8u_C1RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, nThreshold, nValue));
    }
    private static native int nppiThreshold_GTVal_8u_C1RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        byte nThreshold, 
        byte nValue);


    /**
     * <pre>
     * 1 channel 8-bit unsigned char in place threshold.
     * If for a comparison operations sourcePixel is greater than nThreshold is true, the pixel is set
     * to nValue, otherwise it is set to sourcePixel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nThreshold The threshold value.
     * @param nValue The threshold replacement value.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiThreshold_GTVal_8u_C1IR(
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        byte nThreshold, 
        byte nValue)
    {
        return JNpp.checkResult(nppiThreshold_GTVal_8u_C1IRNative(pSrcDst, nSrcDstStep, oSizeROI, nThreshold, nValue));
    }
    private static native int nppiThreshold_GTVal_8u_C1IRNative(
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        byte nThreshold, 
        byte nValue);


    /**
     * <pre>
     * 1 channel 16-bit unsigned short threshold.
     * If for a comparison operations sourcePixel is greater than nThreshold is true, the pixel is set
     * to nValue, otherwise it is set to sourcePixel.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nThreshold The threshold value.
     * @param nValue The threshold replacement value.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiThreshold_GTVal_16u_C1R(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        short nThreshold, 
        short nValue)
    {
        return JNpp.checkResult(nppiThreshold_GTVal_16u_C1RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, nThreshold, nValue));
    }
    private static native int nppiThreshold_GTVal_16u_C1RNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        short nThreshold, 
        short nValue);


    /**
     * <pre>
     * 1 channel 16-bit unsigned short in place threshold.
     * If for a comparison operations sourcePixel is greater than nThreshold is true, the pixel is set
     * to nValue, otherwise it is set to sourcePixel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nThreshold The threshold value.
     * @param nValue The threshold replacement value.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiThreshold_GTVal_16u_C1IR(
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        short nThreshold, 
        short nValue)
    {
        return JNpp.checkResult(nppiThreshold_GTVal_16u_C1IRNative(pSrcDst, nSrcDstStep, oSizeROI, nThreshold, nValue));
    }
    private static native int nppiThreshold_GTVal_16u_C1IRNative(
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        short nThreshold, 
        short nValue);


    public static int nppiThreshold_GTVal_16s_C1R(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        short nThreshold, 
        short nValue)
    {
        return JNpp.checkResult(nppiThreshold_GTVal_16s_C1RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, nThreshold, nValue));
    }
    private static native int nppiThreshold_GTVal_16s_C1RNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        short nThreshold, 
        short nValue);


    /**
     * <pre>
     * 1 channel 16-bit signed short in place threshold.
     * If for a comparison operations sourcePixel is greater than nThreshold is true, the pixel is set
     * to nValue, otherwise it is set to sourcePixel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nThreshold The threshold value.
     * @param nValue The threshold replacement value.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiThreshold_GTVal_16s_C1IR(
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        short nThreshold, 
        short nValue)
    {
        return JNpp.checkResult(nppiThreshold_GTVal_16s_C1IRNative(pSrcDst, nSrcDstStep, oSizeROI, nThreshold, nValue));
    }
    private static native int nppiThreshold_GTVal_16s_C1IRNative(
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        short nThreshold, 
        short nValue);


    /**
     * <pre>
     * 1 channel 32-bit floating point threshold.
     * If for a comparison operations sourcePixel is greater than nThreshold is true, the pixel is set
     * to nValue, otherwise it is set to sourcePixel.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nThreshold The threshold value.
     * @param nValue The threshold replacement value.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiThreshold_GTVal_32f_C1R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        float nThreshold, 
        float nValue)
    {
        return JNpp.checkResult(nppiThreshold_GTVal_32f_C1RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, nThreshold, nValue));
    }
    private static native int nppiThreshold_GTVal_32f_C1RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        float nThreshold, 
        float nValue);


    public static int nppiThreshold_GTVal_32f_C1IR(
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        float nThreshold, 
        float nValue)
    {
        return JNpp.checkResult(nppiThreshold_GTVal_32f_C1IRNative(pSrcDst, nSrcDstStep, oSizeROI, nThreshold, nValue));
    }
    private static native int nppiThreshold_GTVal_32f_C1IRNative(
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        float nThreshold, 
        float nValue);


    /**
     * <pre>
     * 3 channel 8-bit unsigned char threshold.
     * If for a comparison operations sourcePixel is greater than rThreshold is true, the pixel is set
     * to rValue, otherwise it is set to sourcePixel.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param rThresholds The threshold values, one per color channel.
     * @param rValues The threshold replacement values, one per color channel.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiThreshold_GTVal_8u_C3R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        byte[] rThresholds, 
        byte[] rValues)
    {
        return JNpp.checkResult(nppiThreshold_GTVal_8u_C3RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, rThresholds, rValues));
    }
    private static native int nppiThreshold_GTVal_8u_C3RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        byte[] rThresholds, 
        byte[] rValues);


    /**
     * <pre>
     * 3 channel 8-bit unsigned char in place threshold.
     * If for a comparison operations sourcePixel is greater than rThreshold is true, the pixel is set
     * to rValue, otherwise it is set to sourcePixel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param rThresholds The threshold values, one per color channel.
     * @param rValues The threshold replacement values, one per color channel.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiThreshold_GTVal_8u_C3IR(
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        byte[] rThresholds, 
        byte[] rValues)
    {
        return JNpp.checkResult(nppiThreshold_GTVal_8u_C3IRNative(pSrcDst, nSrcDstStep, oSizeROI, rThresholds, rValues));
    }
    private static native int nppiThreshold_GTVal_8u_C3IRNative(
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        byte[] rThresholds, 
        byte[] rValues);


    /**
     * <pre>
     * 3 channel 16-bit unsigned short threshold.
     * If for a comparison operations sourcePixel is greater than rThreshold is true, the pixel is set
     * to rValue, otherwise it is set to sourcePixel.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param rThresholds The threshold values, one per color channel.
     * @param rValues The threshold replacement values, one per color channel.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiThreshold_GTVal_16u_C3R(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        short[] rThresholds, 
        short[] rValues)
    {
        return JNpp.checkResult(nppiThreshold_GTVal_16u_C3RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, rThresholds, rValues));
    }
    private static native int nppiThreshold_GTVal_16u_C3RNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        short[] rThresholds, 
        short[] rValues);


    public static int nppiThreshold_GTVal_16u_C3IR(
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        short[] rThresholds, 
        short[] rValues)
    {
        return JNpp.checkResult(nppiThreshold_GTVal_16u_C3IRNative(pSrcDst, nSrcDstStep, oSizeROI, rThresholds, rValues));
    }
    private static native int nppiThreshold_GTVal_16u_C3IRNative(
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        short[] rThresholds, 
        short[] rValues);


    /**
     * <pre>
     * 3 channel 16-bit signed short threshold.
     * If for a comparison operations sourcePixel is greater than rThreshold is true, the pixel is set
     * to rValue, otherwise it is set to sourcePixel.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param rThresholds The threshold values, one per color channel.
     * @param rValues The threshold replacement values, one per color channel.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiThreshold_GTVal_16s_C3R(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        short[] rThresholds, 
        short[] rValues)
    {
        return JNpp.checkResult(nppiThreshold_GTVal_16s_C3RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, rThresholds, rValues));
    }
    private static native int nppiThreshold_GTVal_16s_C3RNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        short[] rThresholds, 
        short[] rValues);


    /**
     * <pre>
     * 3 channel 16-bit signed short in place threshold.
     * If for a comparison operations sourcePixel is greater than rThreshold is true, the pixel is set
     * to rValue, otherwise it is set to sourcePixel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param rThresholds The threshold values, one per color channel.
     * @param rValues The threshold replacement values, one per color channel.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiThreshold_GTVal_16s_C3IR(
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        short[] rThresholds, 
        short[] rValues)
    {
        return JNpp.checkResult(nppiThreshold_GTVal_16s_C3IRNative(pSrcDst, nSrcDstStep, oSizeROI, rThresholds, rValues));
    }
    private static native int nppiThreshold_GTVal_16s_C3IRNative(
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        short[] rThresholds, 
        short[] rValues);


    /**
     * <pre>
     * 3 channel 32-bit floating point threshold.
     * If for a comparison operations sourcePixel is greater than rThreshold is true, the pixel is set
     * to rValue, otherwise it is set to sourcePixel.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param rThresholds The threshold values, one per color channel.
     * @param rValues The threshold replacement values, one per color channel.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiThreshold_GTVal_32f_C3R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        float[] rThresholds, 
        float[] rValues)
    {
        return JNpp.checkResult(nppiThreshold_GTVal_32f_C3RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, rThresholds, rValues));
    }
    private static native int nppiThreshold_GTVal_32f_C3RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        float[] rThresholds, 
        float[] rValues);


    /**
     * <pre>
     * 3 channel 32-bit floating point in place threshold.
     * If for a comparison operations sourcePixel is greater than rThreshold is true, the pixel is set
     * to rValue, otherwise it is set to sourcePixel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param rThresholds The threshold values, one per color channel.
     * @param rValues The threshold replacement values, one per color channel.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiThreshold_GTVal_32f_C3IR(
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        float[] rThresholds, 
        float[] rValues)
    {
        return JNpp.checkResult(nppiThreshold_GTVal_32f_C3IRNative(pSrcDst, nSrcDstStep, oSizeROI, rThresholds, rValues));
    }
    private static native int nppiThreshold_GTVal_32f_C3IRNative(
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        float[] rThresholds, 
        float[] rValues);


    public static int nppiThreshold_GTVal_8u_AC4R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        byte[] rThresholds, 
        byte[] rValues)
    {
        return JNpp.checkResult(nppiThreshold_GTVal_8u_AC4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, rThresholds, rValues));
    }
    private static native int nppiThreshold_GTVal_8u_AC4RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        byte[] rThresholds, 
        byte[] rValues);


    /**
     * <pre>
     * 4 channel 8-bit unsigned char in place image threshold, not affecting Alpha.
     * If for a comparison operations sourcePixel is greater than rThreshold is true, the pixel is set
     * value is set to rValue, otherwise it is set to sourcePixel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param rThresholds The threshold values, one per color channel.
     * @param rValues The threshold replacement values, one per color channel.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiThreshold_GTVal_8u_AC4IR(
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        byte[] rThresholds, 
        byte[] rValues)
    {
        return JNpp.checkResult(nppiThreshold_GTVal_8u_AC4IRNative(pSrcDst, nSrcDstStep, oSizeROI, rThresholds, rValues));
    }
    private static native int nppiThreshold_GTVal_8u_AC4IRNative(
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        byte[] rThresholds, 
        byte[] rValues);


    /**
     * <pre>
     * 4 channel 16-bit unsigned short image threshold, not affecting Alpha.
     * If for a comparison operations sourcePixel is greater than rThreshold is true, the pixel is set
     * value is set to rValue, otherwise it is set to sourcePixel.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param rThresholds The threshold values, one per color channel.
     * @param rValues The threshold replacement values, one per color channel.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiThreshold_GTVal_16u_AC4R(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        short[] rThresholds, 
        short[] rValues)
    {
        return JNpp.checkResult(nppiThreshold_GTVal_16u_AC4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, rThresholds, rValues));
    }
    private static native int nppiThreshold_GTVal_16u_AC4RNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        short[] rThresholds, 
        short[] rValues);


    /**
     * <pre>
     * 4 channel 16-bit unsigned short in place image threshold, not affecting Alpha.
     * If for a comparison operations sourcePixel is greater than rThreshold is true, the pixel is set
     * value is set to rValue, otherwise it is set to sourcePixel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param rThresholds The threshold values, one per color channel.
     * @param rValues The threshold replacement values, one per color channel.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiThreshold_GTVal_16u_AC4IR(
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        short[] rThresholds, 
        short[] rValues)
    {
        return JNpp.checkResult(nppiThreshold_GTVal_16u_AC4IRNative(pSrcDst, nSrcDstStep, oSizeROI, rThresholds, rValues));
    }
    private static native int nppiThreshold_GTVal_16u_AC4IRNative(
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        short[] rThresholds, 
        short[] rValues);


    /**
     * <pre>
     * 4 channel 16-bit signed short image threshold, not affecting Alpha.
     * If for a comparison operations sourcePixel is greater than rThreshold is true, the pixel is set
     * value is set to rValue, otherwise it is set to sourcePixel.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param rThresholds The threshold values, one per color channel.
     * @param rValues The threshold replacement values, one per color channel.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiThreshold_GTVal_16s_AC4R(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        short[] rThresholds, 
        short[] rValues)
    {
        return JNpp.checkResult(nppiThreshold_GTVal_16s_AC4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, rThresholds, rValues));
    }
    private static native int nppiThreshold_GTVal_16s_AC4RNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        short[] rThresholds, 
        short[] rValues);


    public static int nppiThreshold_GTVal_16s_AC4IR(
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        short[] rThresholds, 
        short[] rValues)
    {
        return JNpp.checkResult(nppiThreshold_GTVal_16s_AC4IRNative(pSrcDst, nSrcDstStep, oSizeROI, rThresholds, rValues));
    }
    private static native int nppiThreshold_GTVal_16s_AC4IRNative(
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        short[] rThresholds, 
        short[] rValues);


    /**
     * <pre>
     * 4 channel 32-bit floating point image threshold, not affecting Alpha.
     * If for a comparison operations sourcePixel is greater than rThreshold is true, the pixel is set
     * value is set to rValue, otherwise it is set to sourcePixel.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param rThresholds The threshold values, one per color channel.
     * @param rValues The threshold replacement values, one per color channel.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiThreshold_GTVal_32f_AC4R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        float[] rThresholds, 
        float[] rValues)
    {
        return JNpp.checkResult(nppiThreshold_GTVal_32f_AC4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, rThresholds, rValues));
    }
    private static native int nppiThreshold_GTVal_32f_AC4RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        float[] rThresholds, 
        float[] rValues);


    public static int nppiThreshold_GTVal_32f_AC4IR(
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        float[] rThresholds, 
        float[] rValues)
    {
        return JNpp.checkResult(nppiThreshold_GTVal_32f_AC4IRNative(pSrcDst, nSrcDstStep, oSizeROI, rThresholds, rValues));
    }
    private static native int nppiThreshold_GTVal_32f_AC4IRNative(
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        float[] rThresholds, 
        float[] rValues);


    /**
     * <pre>
     * 1 channel 8-bit unsigned char threshold.
     * If for a comparison operations sourcePixel is less than nThreshold is true, the pixel is set
     * to nValue, otherwise it is set to sourcePixel.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nThreshold The threshold value.
     * @param nValue The threshold replacement value.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiThreshold_LTVal_8u_C1R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        byte nThreshold, 
        byte nValue)
    {
        return JNpp.checkResult(nppiThreshold_LTVal_8u_C1RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, nThreshold, nValue));
    }
    private static native int nppiThreshold_LTVal_8u_C1RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        byte nThreshold, 
        byte nValue);


    /**
     * <pre>
     * 1 channel 8-bit unsigned char in place threshold.
     * If for a comparison operations sourcePixel is less than nThreshold is true, the pixel is set
     * to nValue, otherwise it is set to sourcePixel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nThreshold The threshold value.
     * @param nValue The threshold replacement value.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiThreshold_LTVal_8u_C1IR(
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        byte nThreshold, 
        byte nValue)
    {
        return JNpp.checkResult(nppiThreshold_LTVal_8u_C1IRNative(pSrcDst, nSrcDstStep, oSizeROI, nThreshold, nValue));
    }
    private static native int nppiThreshold_LTVal_8u_C1IRNative(
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        byte nThreshold, 
        byte nValue);


    /**
     * <pre>
     * 1 channel 16-bit unsigned short threshold.
     * If for a comparison operations sourcePixel is less than nThreshold is true, the pixel is set
     * to nValue, otherwise it is set to sourcePixel.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nThreshold The threshold value.
     * @param nValue The threshold replacement value.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiThreshold_LTVal_16u_C1R(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        short nThreshold, 
        short nValue)
    {
        return JNpp.checkResult(nppiThreshold_LTVal_16u_C1RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, nThreshold, nValue));
    }
    private static native int nppiThreshold_LTVal_16u_C1RNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        short nThreshold, 
        short nValue);


    /**
     * <pre>
     * 1 channel 16-bit unsigned short in place threshold.
     * If for a comparison operations sourcePixel is less than nThreshold is true, the pixel is set
     * to nValue, otherwise it is set to sourcePixel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nThreshold The threshold value.
     * @param nValue The threshold replacement value.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiThreshold_LTVal_16u_C1IR(
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        short nThreshold, 
        short nValue)
    {
        return JNpp.checkResult(nppiThreshold_LTVal_16u_C1IRNative(pSrcDst, nSrcDstStep, oSizeROI, nThreshold, nValue));
    }
    private static native int nppiThreshold_LTVal_16u_C1IRNative(
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        short nThreshold, 
        short nValue);


    /**
     * <pre>
     * 1 channel 16-bit signed short threshold.
     * If for a comparison operations sourcePixel is less than nThreshold is true, the pixel is set
     * to nValue, otherwise it is set to sourcePixel.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nThreshold The threshold value.
     * @param nValue The threshold replacement value.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiThreshold_LTVal_16s_C1R(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        short nThreshold, 
        short nValue)
    {
        return JNpp.checkResult(nppiThreshold_LTVal_16s_C1RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, nThreshold, nValue));
    }
    private static native int nppiThreshold_LTVal_16s_C1RNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        short nThreshold, 
        short nValue);


    /**
     * <pre>
     * 1 channel 16-bit signed short in place threshold.
     * If for a comparison operations sourcePixel is less than nThreshold is true, the pixel is set
     * to nValue, otherwise it is set to sourcePixel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nThreshold The threshold value.
     * @param nValue The threshold replacement value.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiThreshold_LTVal_16s_C1IR(
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        short nThreshold, 
        short nValue)
    {
        return JNpp.checkResult(nppiThreshold_LTVal_16s_C1IRNative(pSrcDst, nSrcDstStep, oSizeROI, nThreshold, nValue));
    }
    private static native int nppiThreshold_LTVal_16s_C1IRNative(
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        short nThreshold, 
        short nValue);


    public static int nppiThreshold_LTVal_32f_C1R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        float nThreshold, 
        float nValue)
    {
        return JNpp.checkResult(nppiThreshold_LTVal_32f_C1RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, nThreshold, nValue));
    }
    private static native int nppiThreshold_LTVal_32f_C1RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        float nThreshold, 
        float nValue);


    /**
     * <pre>
     * 1 channel 32-bit floating point in place threshold.
     * If for a comparison operations sourcePixel is less than nThreshold is true, the pixel is set
     * to nValue, otherwise it is set to sourcePixel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nThreshold The threshold value.
     * @param nValue The threshold replacement value.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiThreshold_LTVal_32f_C1IR(
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        float nThreshold, 
        float nValue)
    {
        return JNpp.checkResult(nppiThreshold_LTVal_32f_C1IRNative(pSrcDst, nSrcDstStep, oSizeROI, nThreshold, nValue));
    }
    private static native int nppiThreshold_LTVal_32f_C1IRNative(
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        float nThreshold, 
        float nValue);


    public static int nppiThreshold_LTVal_8u_C3R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        byte[] rThresholds, 
        byte[] rValues)
    {
        return JNpp.checkResult(nppiThreshold_LTVal_8u_C3RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, rThresholds, rValues));
    }
    private static native int nppiThreshold_LTVal_8u_C3RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        byte[] rThresholds, 
        byte[] rValues);


    /**
     * <pre>
     * 3 channel 8-bit unsigned char in place threshold.
     * If for a comparison operations sourcePixel is less than rThreshold is true, the pixel is set
     * to rValue, otherwise it is set to sourcePixel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param rThresholds The threshold values, one per color channel.
     * @param rValues The threshold replacement values, one per color channel.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiThreshold_LTVal_8u_C3IR(
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        byte[] rThresholds, 
        byte[] rValues)
    {
        return JNpp.checkResult(nppiThreshold_LTVal_8u_C3IRNative(pSrcDst, nSrcDstStep, oSizeROI, rThresholds, rValues));
    }
    private static native int nppiThreshold_LTVal_8u_C3IRNative(
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        byte[] rThresholds, 
        byte[] rValues);


    /**
     * <pre>
     * 3 channel 16-bit unsigned short threshold.
     * If for a comparison operations sourcePixel is less than rThreshold is true, the pixel is set
     * to rValue, otherwise it is set to sourcePixel.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param rThresholds The threshold values, one per color channel.
     * @param rValues The threshold replacement values, one per color channel.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiThreshold_LTVal_16u_C3R(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        short[] rThresholds, 
        short[] rValues)
    {
        return JNpp.checkResult(nppiThreshold_LTVal_16u_C3RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, rThresholds, rValues));
    }
    private static native int nppiThreshold_LTVal_16u_C3RNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        short[] rThresholds, 
        short[] rValues);


    /**
     * <pre>
     * 3 channel 16-bit unsigned short in place threshold.
     * If for a comparison operations sourcePixel is less than rThreshold is true, the pixel is set
     * to rValue, otherwise it is set to sourcePixel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param rThresholds The threshold values, one per color channel.
     * @param rValues The threshold replacement values, one per color channel.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiThreshold_LTVal_16u_C3IR(
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        short[] rThresholds, 
        short[] rValues)
    {
        return JNpp.checkResult(nppiThreshold_LTVal_16u_C3IRNative(pSrcDst, nSrcDstStep, oSizeROI, rThresholds, rValues));
    }
    private static native int nppiThreshold_LTVal_16u_C3IRNative(
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        short[] rThresholds, 
        short[] rValues);


    public static int nppiThreshold_LTVal_16s_C3R(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        short[] rThresholds, 
        short[] rValues)
    {
        return JNpp.checkResult(nppiThreshold_LTVal_16s_C3RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, rThresholds, rValues));
    }
    private static native int nppiThreshold_LTVal_16s_C3RNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        short[] rThresholds, 
        short[] rValues);


    /**
     * <pre>
     * 3 channel 16-bit signed short in place threshold.
     * If for a comparison operations sourcePixel is less than rThreshold is true, the pixel is set
     * to rValue, otherwise it is set to sourcePixel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param rThresholds The threshold values, one per color channel.
     * @param rValues The threshold replacement values, one per color channel.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiThreshold_LTVal_16s_C3IR(
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        short[] rThresholds, 
        short[] rValues)
    {
        return JNpp.checkResult(nppiThreshold_LTVal_16s_C3IRNative(pSrcDst, nSrcDstStep, oSizeROI, rThresholds, rValues));
    }
    private static native int nppiThreshold_LTVal_16s_C3IRNative(
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        short[] rThresholds, 
        short[] rValues);


    public static int nppiThreshold_LTVal_32f_C3R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        float[] rThresholds, 
        float[] rValues)
    {
        return JNpp.checkResult(nppiThreshold_LTVal_32f_C3RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, rThresholds, rValues));
    }
    private static native int nppiThreshold_LTVal_32f_C3RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        float[] rThresholds, 
        float[] rValues);


    public static int nppiThreshold_LTVal_32f_C3IR(
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        float[] rThresholds, 
        float[] rValues)
    {
        return JNpp.checkResult(nppiThreshold_LTVal_32f_C3IRNative(pSrcDst, nSrcDstStep, oSizeROI, rThresholds, rValues));
    }
    private static native int nppiThreshold_LTVal_32f_C3IRNative(
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        float[] rThresholds, 
        float[] rValues);


    /**
     * <pre>
     * 4 channel 8-bit unsigned char image threshold, not affecting Alpha.
     * If for a comparison operations sourcePixel is less than rThreshold is true, the pixel is set
     * value is set to rValue, otherwise it is set to sourcePixel.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param rThresholds The threshold values, one per color channel.
     * @param rValues The threshold replacement values, one per color channel.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiThreshold_LTVal_8u_AC4R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        byte[] rThresholds, 
        byte[] rValues)
    {
        return JNpp.checkResult(nppiThreshold_LTVal_8u_AC4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, rThresholds, rValues));
    }
    private static native int nppiThreshold_LTVal_8u_AC4RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        byte[] rThresholds, 
        byte[] rValues);


    /**
     * <pre>
     * 4 channel 8-bit unsigned char in place image threshold, not affecting Alpha.
     * If for a comparison operations sourcePixel is less than rThreshold is true, the pixel is set
     * value is set to rValue, otherwise it is set to sourcePixel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param rThresholds The threshold values, one per color channel.
     * @param rValues The threshold replacement values, one per color channel.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiThreshold_LTVal_8u_AC4IR(
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        byte[] rThresholds, 
        byte[] rValues)
    {
        return JNpp.checkResult(nppiThreshold_LTVal_8u_AC4IRNative(pSrcDst, nSrcDstStep, oSizeROI, rThresholds, rValues));
    }
    private static native int nppiThreshold_LTVal_8u_AC4IRNative(
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        byte[] rThresholds, 
        byte[] rValues);


    /**
     * <pre>
     * 4 channel 16-bit unsigned short image threshold, not affecting Alpha.
     * If for a comparison operations sourcePixel is less than rThreshold is true, the pixel is set
     * value is set to rValue, otherwise it is set to sourcePixel.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param rThresholds The threshold values, one per color channel.
     * @param rValues The threshold replacement values, one per color channel.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiThreshold_LTVal_16u_AC4R(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        short[] rThresholds, 
        short[] rValues)
    {
        return JNpp.checkResult(nppiThreshold_LTVal_16u_AC4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, rThresholds, rValues));
    }
    private static native int nppiThreshold_LTVal_16u_AC4RNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        short[] rThresholds, 
        short[] rValues);


    /**
     * <pre>
     * 4 channel 16-bit unsigned short in place image threshold, not affecting Alpha.
     * If for a comparison operations sourcePixel is less than rThreshold is true, the pixel is set
     * value is set to rValue, otherwise it is set to sourcePixel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param rThresholds The threshold values, one per color channel.
     * @param rValues The threshold replacement values, one per color channel.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiThreshold_LTVal_16u_AC4IR(
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        short[] rThresholds, 
        short[] rValues)
    {
        return JNpp.checkResult(nppiThreshold_LTVal_16u_AC4IRNative(pSrcDst, nSrcDstStep, oSizeROI, rThresholds, rValues));
    }
    private static native int nppiThreshold_LTVal_16u_AC4IRNative(
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        short[] rThresholds, 
        short[] rValues);


    /**
     * <pre>
     * 4 channel 16-bit signed short image threshold, not affecting Alpha.
     * If for a comparison operations sourcePixel is less than rThreshold is true, the pixel is set
     * value is set to rValue, otherwise it is set to sourcePixel.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param rThresholds The threshold values, one per color channel.
     * @param rValues The threshold replacement values, one per color channel.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiThreshold_LTVal_16s_AC4R(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        short[] rThresholds, 
        short[] rValues)
    {
        return JNpp.checkResult(nppiThreshold_LTVal_16s_AC4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, rThresholds, rValues));
    }
    private static native int nppiThreshold_LTVal_16s_AC4RNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        short[] rThresholds, 
        short[] rValues);


    /**
     * <pre>
     * 4 channel 16-bit signed short in place image threshold, not affecting Alpha.
     * If for a comparison operations sourcePixel is less than rThreshold is true, the pixel is set
     * value is set to rValue, otherwise it is set to sourcePixel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param rThresholds The threshold values, one per color channel.
     * @param rValues The threshold replacement values, one per color channel.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiThreshold_LTVal_16s_AC4IR(
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        short[] rThresholds, 
        short[] rValues)
    {
        return JNpp.checkResult(nppiThreshold_LTVal_16s_AC4IRNative(pSrcDst, nSrcDstStep, oSizeROI, rThresholds, rValues));
    }
    private static native int nppiThreshold_LTVal_16s_AC4IRNative(
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        short[] rThresholds, 
        short[] rValues);


    /**
     * <pre>
     * 4 channel 32-bit floating point image threshold, not affecting Alpha.
     * If for a comparison operations sourcePixel is less than rThreshold is true, the pixel is set
     * value is set to rValue, otherwise it is set to sourcePixel.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param rThresholds The threshold values, one per color channel.
     * @param rValues The threshold replacement values, one per color channel.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiThreshold_LTVal_32f_AC4R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        float[] rThresholds, 
        float[] rValues)
    {
        return JNpp.checkResult(nppiThreshold_LTVal_32f_AC4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, rThresholds, rValues));
    }
    private static native int nppiThreshold_LTVal_32f_AC4RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        float[] rThresholds, 
        float[] rValues);


    /**
     * <pre>
     * 4 channel 32-bit floating point in place image threshold, not affecting Alpha.
     * If for a comparison operations sourcePixel is less than rThreshold is true, the pixel is set
     * value is set to rValue, otherwise it is set to sourcePixel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param rThresholds The threshold values, one per color channel.
     * @param rValues The threshold replacement values, one per color channel.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiThreshold_LTVal_32f_AC4IR(
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        float[] rThresholds, 
        float[] rValues)
    {
        return JNpp.checkResult(nppiThreshold_LTVal_32f_AC4IRNative(pSrcDst, nSrcDstStep, oSizeROI, rThresholds, rValues));
    }
    private static native int nppiThreshold_LTVal_32f_AC4IRNative(
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        float[] rThresholds, 
        float[] rValues);


    /**
     * <pre>
     * 1 channel 8-bit unsigned char threshold.
     * If for a comparison operations sourcePixel is less than nThresholdLT is true, the pixel is set
     * to nValueLT, else if sourcePixel is greater than nThresholdGT the pixel is set to nValueGT, otherwise it is set to sourcePixel.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nThresholdLT The thresholdLT value.
     * @param nValueLT The thresholdLT replacement value.
     * @param nThresholdGT The thresholdGT value.
     * @param nValueGT The thresholdGT replacement value.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiThreshold_LTValGTVal_8u_C1R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        byte nThresholdLT, 
        byte nValueLT, 
        byte nThresholdGT, 
        byte nValueGT)
    {
        return JNpp.checkResult(nppiThreshold_LTValGTVal_8u_C1RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, nThresholdLT, nValueLT, nThresholdGT, nValueGT));
    }
    private static native int nppiThreshold_LTValGTVal_8u_C1RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        byte nThresholdLT, 
        byte nValueLT, 
        byte nThresholdGT, 
        byte nValueGT);


    /**
     * <pre>
     * 1 channel 8-bit unsigned char in place threshold.
     * If for a comparison operations sourcePixel is less than nThresholdLT is true, the pixel is set
     * to nValueLT, else if sourcePixel is greater than nThresholdGT the pixel is set to nValueGT, otherwise it is set to sourcePixel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nThresholdLT The thresholdLT value.
     * @param nValueLT The thresholdLT replacement value.
     * @param nThresholdGT The thresholdGT value.
     * @param nValueGT The thresholdGT replacement value.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiThreshold_LTValGTVal_8u_C1IR(
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        byte nThresholdLT, 
        byte nValueLT, 
        byte nThresholdGT, 
        byte nValueGT)
    {
        return JNpp.checkResult(nppiThreshold_LTValGTVal_8u_C1IRNative(pSrcDst, nSrcDstStep, oSizeROI, nThresholdLT, nValueLT, nThresholdGT, nValueGT));
    }
    private static native int nppiThreshold_LTValGTVal_8u_C1IRNative(
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        byte nThresholdLT, 
        byte nValueLT, 
        byte nThresholdGT, 
        byte nValueGT);


    public static int nppiThreshold_LTValGTVal_16u_C1R(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        short nThresholdLT, 
        short nValueLT, 
        short nThresholdGT, 
        short nValueGT)
    {
        return JNpp.checkResult(nppiThreshold_LTValGTVal_16u_C1RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, nThresholdLT, nValueLT, nThresholdGT, nValueGT));
    }
    private static native int nppiThreshold_LTValGTVal_16u_C1RNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        short nThresholdLT, 
        short nValueLT, 
        short nThresholdGT, 
        short nValueGT);


    public static int nppiThreshold_LTValGTVal_16u_C1IR(
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        short nThresholdLT, 
        short nValueLT, 
        short nThresholdGT, 
        short nValueGT)
    {
        return JNpp.checkResult(nppiThreshold_LTValGTVal_16u_C1IRNative(pSrcDst, nSrcDstStep, oSizeROI, nThresholdLT, nValueLT, nThresholdGT, nValueGT));
    }
    private static native int nppiThreshold_LTValGTVal_16u_C1IRNative(
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        short nThresholdLT, 
        short nValueLT, 
        short nThresholdGT, 
        short nValueGT);


    /**
     * <pre>
     * 1 channel 16-bit signed short threshold.
     * If for a comparison operations sourcePixel is less than nThresholdLT is true, the pixel is set
     * to nValueLT, else if sourcePixel is greater than nThresholdGT the pixel is set to nValueGT, otherwise it is set to sourcePixel.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nThresholdLT The thresholdLT value.
     * @param nValueLT The thresholdLT replacement value.
     * @param nThresholdGT The thresholdGT value.
     * @param nValueGT The thresholdGT replacement value.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiThreshold_LTValGTVal_16s_C1R(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        short nThresholdLT, 
        short nValueLT, 
        short nThresholdGT, 
        short nValueGT)
    {
        return JNpp.checkResult(nppiThreshold_LTValGTVal_16s_C1RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, nThresholdLT, nValueLT, nThresholdGT, nValueGT));
    }
    private static native int nppiThreshold_LTValGTVal_16s_C1RNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        short nThresholdLT, 
        short nValueLT, 
        short nThresholdGT, 
        short nValueGT);


    /**
     * <pre>
     * 1 channel 16-bit signed short in place threshold.
     * If for a comparison operations sourcePixel is less than nThresholdLT is true, the pixel is set
     * to nValueLT, else if sourcePixel is greater than nThresholdGT the pixel is set to nValueGT, otherwise it is set to sourcePixel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nThresholdLT The thresholdLT value.
     * @param nValueLT The thresholdLT replacement value.
     * @param nThresholdGT The thresholdGT value.
     * @param nValueGT The thresholdGT replacement value.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiThreshold_LTValGTVal_16s_C1IR(
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        short nThresholdLT, 
        short nValueLT, 
        short nThresholdGT, 
        short nValueGT)
    {
        return JNpp.checkResult(nppiThreshold_LTValGTVal_16s_C1IRNative(pSrcDst, nSrcDstStep, oSizeROI, nThresholdLT, nValueLT, nThresholdGT, nValueGT));
    }
    private static native int nppiThreshold_LTValGTVal_16s_C1IRNative(
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        short nThresholdLT, 
        short nValueLT, 
        short nThresholdGT, 
        short nValueGT);


    /**
     * <pre>
     * 1 channel 32-bit floating point threshold.
     * If for a comparison operations sourcePixel is less than nThresholdLT is true, the pixel is set
     * to nValueLT, else if sourcePixel is greater than nThresholdGT the pixel is set to nValueGT, otherwise it is set to sourcePixel.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nThresholdLT The thresholdLT value.
     * @param nValueLT The thresholdLT replacement value.
     * @param nThresholdGT The thresholdGT value.
     * @param nValueGT The thresholdGT replacement value.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiThreshold_LTValGTVal_32f_C1R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        float nThresholdLT, 
        float nValueLT, 
        float nThresholdGT, 
        float nValueGT)
    {
        return JNpp.checkResult(nppiThreshold_LTValGTVal_32f_C1RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, nThresholdLT, nValueLT, nThresholdGT, nValueGT));
    }
    private static native int nppiThreshold_LTValGTVal_32f_C1RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        float nThresholdLT, 
        float nValueLT, 
        float nThresholdGT, 
        float nValueGT);


    public static int nppiThreshold_LTValGTVal_32f_C1IR(
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        float nThresholdLT, 
        float nValueLT, 
        float nThresholdGT, 
        float nValueGT)
    {
        return JNpp.checkResult(nppiThreshold_LTValGTVal_32f_C1IRNative(pSrcDst, nSrcDstStep, oSizeROI, nThresholdLT, nValueLT, nThresholdGT, nValueGT));
    }
    private static native int nppiThreshold_LTValGTVal_32f_C1IRNative(
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        float nThresholdLT, 
        float nValueLT, 
        float nThresholdGT, 
        float nValueGT);


    /**
     * <pre>
     * 3 channel 8-bit unsigned char threshold.
     * If for a comparison operations sourcePixel is less than rThresholdLT is true, the pixel is set
     * to rValueLT, else if sourcePixel is greater than rThresholdGT the pixel is set to rValueGT, otherwise it is set to sourcePixel.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param rThresholdsLT The thresholdLT values, one per color channel.
     * @param rValuesLT The thresholdLT replacement values, one per color channel.
     * @param rThresholdsGT The thresholdGT values, one per channel.
     * @param rValuesGT The thresholdGT replacement values, one per color channel.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiThreshold_LTValGTVal_8u_C3R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        byte[] rThresholdsLT, 
        byte[] rValuesLT, 
        byte[] rThresholdsGT, 
        byte[] rValuesGT)
    {
        return JNpp.checkResult(nppiThreshold_LTValGTVal_8u_C3RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, rThresholdsLT, rValuesLT, rThresholdsGT, rValuesGT));
    }
    private static native int nppiThreshold_LTValGTVal_8u_C3RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        byte[] rThresholdsLT, 
        byte[] rValuesLT, 
        byte[] rThresholdsGT, 
        byte[] rValuesGT);


    /**
     * <pre>
     * 3 channel 8-bit unsigned char in place threshold.
     * If for a comparison operations sourcePixel is less than rThresholdLT is true, the pixel is set
     * to rValueLT, else if sourcePixel is greater than rThresholdGT the pixel is set to rValueGT, otherwise it is set to sourcePixel.
     * @param pSrcDst \ref destination_image_pointer.
     * @param nSrcDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param rThresholdsLT The thresholdLT values, one per color channel.
     * @param rValuesLT The thresholdLT replacement values, one per color channel.
     * @param rThresholdsGT The thresholdGT values, one per channel.
     * @param rValuesGT The thresholdGT replacement values, one per color channel.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiThreshold_LTValGTVal_8u_C3IR(
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        byte[] rThresholdsLT, 
        byte[] rValuesLT, 
        byte[] rThresholdsGT, 
        byte[] rValuesGT)
    {
        return JNpp.checkResult(nppiThreshold_LTValGTVal_8u_C3IRNative(pSrcDst, nSrcDstStep, oSizeROI, rThresholdsLT, rValuesLT, rThresholdsGT, rValuesGT));
    }
    private static native int nppiThreshold_LTValGTVal_8u_C3IRNative(
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        byte[] rThresholdsLT, 
        byte[] rValuesLT, 
        byte[] rThresholdsGT, 
        byte[] rValuesGT);


    public static int nppiThreshold_LTValGTVal_16u_C3R(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        short[] rThresholdsLT, 
        short[] rValuesLT, 
        short[] rThresholdsGT, 
        short[] rValuesGT)
    {
        return JNpp.checkResult(nppiThreshold_LTValGTVal_16u_C3RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, rThresholdsLT, rValuesLT, rThresholdsGT, rValuesGT));
    }
    private static native int nppiThreshold_LTValGTVal_16u_C3RNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        short[] rThresholdsLT, 
        short[] rValuesLT, 
        short[] rThresholdsGT, 
        short[] rValuesGT);


    /**
     * <pre>
     * 3 channel 16-bit unsigned short in place threshold.
     * If for a comparison operations sourcePixel is less than rThresholdLT is true, the pixel is set
     * to rValueLT, else if sourcePixel is greater than rThresholdGT the pixel is set to rValueGT, otherwise it is set to sourcePixel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param rThresholdsLT The thresholdLT values, one per color channel.
     * @param rValuesLT The thresholdLT replacement values, one per color channel.
     * @param rThresholdsGT The thresholdGT values, one per channel.
     * @param rValuesGT The thresholdGT replacement values, one per color channel.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiThreshold_LTValGTVal_16u_C3IR(
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        short[] rThresholdsLT, 
        short[] rValuesLT, 
        short[] rThresholdsGT, 
        short[] rValuesGT)
    {
        return JNpp.checkResult(nppiThreshold_LTValGTVal_16u_C3IRNative(pSrcDst, nSrcDstStep, oSizeROI, rThresholdsLT, rValuesLT, rThresholdsGT, rValuesGT));
    }
    private static native int nppiThreshold_LTValGTVal_16u_C3IRNative(
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        short[] rThresholdsLT, 
        short[] rValuesLT, 
        short[] rThresholdsGT, 
        short[] rValuesGT);


    /**
     * <pre>
     * 3 channel 16-bit signed short threshold.
     * If for a comparison operations sourcePixel is less than rThresholdLT is true, the pixel is set
     * to rValueLT, else if sourcePixel is greater than rThresholdGT the pixel is set to rValueGT, otherwise it is set to sourcePixel.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param rThresholdsLT The thresholdLT values, one per color channel.
     * @param rValuesLT The thresholdLT replacement values, one per color channel.
     * @param rThresholdsGT The thresholdGT values, one per channel.
     * @param rValuesGT The thresholdGT replacement values, one per color channel.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiThreshold_LTValGTVal_16s_C3R(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        short[] rThresholdsLT, 
        short[] rValuesLT, 
        short[] rThresholdsGT, 
        short[] rValuesGT)
    {
        return JNpp.checkResult(nppiThreshold_LTValGTVal_16s_C3RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, rThresholdsLT, rValuesLT, rThresholdsGT, rValuesGT));
    }
    private static native int nppiThreshold_LTValGTVal_16s_C3RNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        short[] rThresholdsLT, 
        short[] rValuesLT, 
        short[] rThresholdsGT, 
        short[] rValuesGT);


    /**
     * <pre>
     * 3 channel 16-bit signed short in place threshold.
     * If for a comparison operations sourcePixel is less than rThresholdLT is true, the pixel is set
     * to rValueLT, else if sourcePixel is greater than rThresholdGT the pixel is set to rValueGT, otherwise it is set to sourcePixel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param rThresholdsLT The thresholdLT values, one per color channel.
     * @param rValuesLT The thresholdLT replacement values, one per color channel.
     * @param rThresholdsGT The thresholdGT values, one per channel.
     * @param rValuesGT The thresholdGT replacement values, one per color channel.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiThreshold_LTValGTVal_16s_C3IR(
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        short[] rThresholdsLT, 
        short[] rValuesLT, 
        short[] rThresholdsGT, 
        short[] rValuesGT)
    {
        return JNpp.checkResult(nppiThreshold_LTValGTVal_16s_C3IRNative(pSrcDst, nSrcDstStep, oSizeROI, rThresholdsLT, rValuesLT, rThresholdsGT, rValuesGT));
    }
    private static native int nppiThreshold_LTValGTVal_16s_C3IRNative(
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        short[] rThresholdsLT, 
        short[] rValuesLT, 
        short[] rThresholdsGT, 
        short[] rValuesGT);


    /**
     * <pre>
     * 3 channel 32-bit floating point threshold.
     * If for a comparison operations sourcePixel is less than rThresholdLT is true, the pixel is set
     * to rValueLT, else if sourcePixel is greater than rThresholdGT the pixel is set to rValueGT, otherwise it is set to sourcePixel.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param rThresholdsLT The thresholdLT values, one per color channel.
     * @param rValuesLT The thresholdLT replacement values, one per color channel.
     * @param rThresholdsGT The thresholdGT values, one per channel.
     * @param rValuesGT The thresholdGT replacement values, one per color channel.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiThreshold_LTValGTVal_32f_C3R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        float[] rThresholdsLT, 
        float[] rValuesLT, 
        float[] rThresholdsGT, 
        float[] rValuesGT)
    {
        return JNpp.checkResult(nppiThreshold_LTValGTVal_32f_C3RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, rThresholdsLT, rValuesLT, rThresholdsGT, rValuesGT));
    }
    private static native int nppiThreshold_LTValGTVal_32f_C3RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        float[] rThresholdsLT, 
        float[] rValuesLT, 
        float[] rThresholdsGT, 
        float[] rValuesGT);


    /**
     * <pre>
     * 3 channel 32-bit floating point in place threshold.
     * If for a comparison operations sourcePixel is less than rThresholdLT is true, the pixel is set
     * to rValueLT, else if sourcePixel is greater than rThresholdGT the pixel is set to rValueGT, otherwise it is set to sourcePixel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param rThresholdsLT The thresholdLT values, one per color channel.
     * @param rValuesLT The thresholdLT replacement values, one per color channel.
     * @param rThresholdsGT The thresholdGT values, one per channel.
     * @param rValuesGT The thresholdGT replacement values, one per color channel.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiThreshold_LTValGTVal_32f_C3IR(
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        float[] rThresholdsLT, 
        float[] rValuesLT, 
        float[] rThresholdsGT, 
        float[] rValuesGT)
    {
        return JNpp.checkResult(nppiThreshold_LTValGTVal_32f_C3IRNative(pSrcDst, nSrcDstStep, oSizeROI, rThresholdsLT, rValuesLT, rThresholdsGT, rValuesGT));
    }
    private static native int nppiThreshold_LTValGTVal_32f_C3IRNative(
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        float[] rThresholdsLT, 
        float[] rValuesLT, 
        float[] rThresholdsGT, 
        float[] rValuesGT);


    /**
     * <pre>
     * 4 channel 8-bit unsigned char image threshold, not affecting Alpha.
     * If for a comparison operations sourcePixel is less than rThresholdLT is true, the pixel is set
     * value is set to rValueLT, else if sourcePixel is greater than rThresholdGT the pixel is set to rValueGT, otherwise it is set to sourcePixel.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param rThresholdsLT The thresholdLT values, one per color channel.
     * @param rValuesLT The thresholdLT replacement values, one per color channel.
     * @param rThresholdsGT The thresholdGT values, one per channel.
     * @param rValuesGT The thresholdGT replacement values, one per color channel.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiThreshold_LTValGTVal_8u_AC4R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        byte[] rThresholdsLT, 
        byte[] rValuesLT, 
        byte[] rThresholdsGT, 
        byte[] rValuesGT)
    {
        return JNpp.checkResult(nppiThreshold_LTValGTVal_8u_AC4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, rThresholdsLT, rValuesLT, rThresholdsGT, rValuesGT));
    }
    private static native int nppiThreshold_LTValGTVal_8u_AC4RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        byte[] rThresholdsLT, 
        byte[] rValuesLT, 
        byte[] rThresholdsGT, 
        byte[] rValuesGT);


    /**
     * <pre>
     * 4 channel 8-bit unsigned char in place image threshold, not affecting Alpha.
     * If for a comparison operations sourcePixel is less than rThresholdLT is true, the pixel is set
     * value is set to rValueLT, else if sourcePixel is greater than rThresholdGT the pixel is set to rValueGT, otherwise it is set to sourcePixel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param rThresholdsLT The thresholdLT values, one per color channel.
     * @param rValuesLT The thresholdLT replacement values, one per color channel.
     * @param rThresholdsGT The thresholdGT values, one per channel.
     * @param rValuesGT The thresholdGT replacement values, one per color channel.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiThreshold_LTValGTVal_8u_AC4IR(
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        byte[] rThresholdsLT, 
        byte[] rValuesLT, 
        byte[] rThresholdsGT, 
        byte[] rValuesGT)
    {
        return JNpp.checkResult(nppiThreshold_LTValGTVal_8u_AC4IRNative(pSrcDst, nSrcDstStep, oSizeROI, rThresholdsLT, rValuesLT, rThresholdsGT, rValuesGT));
    }
    private static native int nppiThreshold_LTValGTVal_8u_AC4IRNative(
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        byte[] rThresholdsLT, 
        byte[] rValuesLT, 
        byte[] rThresholdsGT, 
        byte[] rValuesGT);


    /**
     * <pre>
     * 4 channel 16-bit unsigned short image threshold, not affecting Alpha.
     * If for a comparison operations sourcePixel is less than rThresholdLT is true, the pixel is set
     * value is set to rValueLT, else if sourcePixel is greater than rThresholdGT the pixel is set to rValueGT, otherwise it is set to sourcePixel.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param rThresholdsLT The thresholdLT values, one per color channel.
     * @param rValuesLT The thresholdLT replacement values, one per color channel.
     * @param rThresholdsGT The thresholdGT values, one per channel.
     * @param rValuesGT The thresholdGT replacement values, one per color channel.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiThreshold_LTValGTVal_16u_AC4R(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        short[] rThresholdsLT, 
        short[] rValuesLT, 
        short[] rThresholdsGT, 
        short[] rValuesGT)
    {
        return JNpp.checkResult(nppiThreshold_LTValGTVal_16u_AC4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, rThresholdsLT, rValuesLT, rThresholdsGT, rValuesGT));
    }
    private static native int nppiThreshold_LTValGTVal_16u_AC4RNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        short[] rThresholdsLT, 
        short[] rValuesLT, 
        short[] rThresholdsGT, 
        short[] rValuesGT);


    /**
     * <pre>
     * 4 channel 16-bit unsigned short in place image threshold, not affecting Alpha.
     * If for a comparison operations sourcePixel is less than rThresholdLT is true, the pixel is set
     * value is set to rValueLT, else if sourcePixel is greater than rThresholdGT the pixel is set to rValueGT, otherwise it is set to sourcePixel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param rThresholdsLT The thresholdLT values, one per color channel.
     * @param rValuesLT The thresholdLT replacement values, one per color channel.
     * @param rThresholdsGT The thresholdGT values, one per channel.
     * @param rValuesGT The thresholdGT replacement values, one per color channel.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiThreshold_LTValGTVal_16u_AC4IR(
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        short[] rThresholdsLT, 
        short[] rValuesLT, 
        short[] rThresholdsGT, 
        short[] rValuesGT)
    {
        return JNpp.checkResult(nppiThreshold_LTValGTVal_16u_AC4IRNative(pSrcDst, nSrcDstStep, oSizeROI, rThresholdsLT, rValuesLT, rThresholdsGT, rValuesGT));
    }
    private static native int nppiThreshold_LTValGTVal_16u_AC4IRNative(
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        short[] rThresholdsLT, 
        short[] rValuesLT, 
        short[] rThresholdsGT, 
        short[] rValuesGT);


    public static int nppiThreshold_LTValGTVal_16s_AC4R(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        short[] rThresholdsLT, 
        short[] rValuesLT, 
        short[] rThresholdsGT, 
        short[] rValuesGT)
    {
        return JNpp.checkResult(nppiThreshold_LTValGTVal_16s_AC4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, rThresholdsLT, rValuesLT, rThresholdsGT, rValuesGT));
    }
    private static native int nppiThreshold_LTValGTVal_16s_AC4RNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        short[] rThresholdsLT, 
        short[] rValuesLT, 
        short[] rThresholdsGT, 
        short[] rValuesGT);


    /**
     * <pre>
     * 4 channel 16-bit signed short in place image threshold, not affecting Alpha.
     * If for a comparison operations sourcePixel is less than rThresholdLT is true, the pixel is set
     * value is set to rValueLT, else if sourcePixel is greater than rThresholdGT the pixel is set to rValueGT, otherwise it is set to sourcePixel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param rThresholdsLT The thresholdLT values, one per color channel.
     * @param rValuesLT The thresholdLT replacement values, one per color channel.
     * @param rThresholdsGT The thresholdGT values, one per channel.
     * @param rValuesGT The thresholdGT replacement values, one per color channel.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiThreshold_LTValGTVal_16s_AC4IR(
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        short[] rThresholdsLT, 
        short[] rValuesLT, 
        short[] rThresholdsGT, 
        short[] rValuesGT)
    {
        return JNpp.checkResult(nppiThreshold_LTValGTVal_16s_AC4IRNative(pSrcDst, nSrcDstStep, oSizeROI, rThresholdsLT, rValuesLT, rThresholdsGT, rValuesGT));
    }
    private static native int nppiThreshold_LTValGTVal_16s_AC4IRNative(
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        short[] rThresholdsLT, 
        short[] rValuesLT, 
        short[] rThresholdsGT, 
        short[] rValuesGT);


    /**
     * <pre>
     * 4 channel 32-bit floating point image threshold, not affecting Alpha.
     * If for a comparison operations sourcePixel is less than rThresholdLT is true, the pixel is set
     * value is set to rValueLT, else if sourcePixel is greater than rThresholdGT the pixel is set to rValueGT, otherwise it is set to sourcePixel.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param rThresholdsLT The thresholdLT values, one per color channel.
     * @param rValuesLT The thresholdLT replacement values, one per color channel.
     * @param rThresholdsGT The thresholdGT values, one per channel.
     * @param rValuesGT The thresholdGT replacement values, one per color channel.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiThreshold_LTValGTVal_32f_AC4R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        float[] rThresholdsLT, 
        float[] rValuesLT, 
        float[] rThresholdsGT, 
        float[] rValuesGT)
    {
        return JNpp.checkResult(nppiThreshold_LTValGTVal_32f_AC4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, rThresholdsLT, rValuesLT, rThresholdsGT, rValuesGT));
    }
    private static native int nppiThreshold_LTValGTVal_32f_AC4RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        float[] rThresholdsLT, 
        float[] rValuesLT, 
        float[] rThresholdsGT, 
        float[] rValuesGT);


    /**
     * <pre>
     * 4 channel 32-bit floating point in place image threshold, not affecting Alpha.
     * If for a comparison operations sourcePixel is less than rThresholdLT is true, the pixel is set
     * value is set to rValueLT, else if sourcePixel is greater than rThresholdGT the pixel is set to rValueGT, otherwise it is set to sourcePixel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param rThresholdsLT The thresholdLT values, one per color channel.
     * @param rValuesLT The thresholdLT replacement values, one per color channel.
     * @param rThresholdsGT The thresholdGT values, one per channel.
     * @param rValuesGT The thresholdGT replacement values, one per color channel.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiThreshold_LTValGTVal_32f_AC4IR(
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        float[] rThresholdsLT, 
        float[] rValuesLT, 
        float[] rThresholdsGT, 
        float[] rValuesGT)
    {
        return JNpp.checkResult(nppiThreshold_LTValGTVal_32f_AC4IRNative(pSrcDst, nSrcDstStep, oSizeROI, rThresholdsLT, rValuesLT, rThresholdsGT, rValuesGT));
    }
    private static native int nppiThreshold_LTValGTVal_32f_AC4IRNative(
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        float[] rThresholdsLT, 
        float[] rValuesLT, 
        float[] rThresholdsGT, 
        float[] rValuesGT);


    /**
     * <pre>
     * 1 channel 8-bit unsigned char image compare.
     * Compare pSrc1's pixels with corresponding pixels in pSrc2. 
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param eComparisonOperation Specifies the comparison operation to be used in the pixel comparison.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCompare_8u_C1R(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eComparisonOperation)
    {
        return JNpp.checkResult(nppiCompare_8u_C1RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, eComparisonOperation));
    }
    private static native int nppiCompare_8u_C1RNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eComparisonOperation);


    /**
     * <pre>
     * 3 channel 8-bit unsigned char image compare.
     * Compare pSrc1's pixels with corresponding pixels in pSrc2. 
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param eComparisonOperation Specifies the comparison operation to be used in the pixel comparison.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCompare_8u_C3R(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eComparisonOperation)
    {
        return JNpp.checkResult(nppiCompare_8u_C3RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, eComparisonOperation));
    }
    private static native int nppiCompare_8u_C3RNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eComparisonOperation);


    /**
     * <pre>
     * 4 channel 8-bit unsigned char image compare.
     * Compare pSrc1's pixels with corresponding pixels in pSrc2. 
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param eComparisonOperation Specifies the comparison operation to be used in the pixel comparison.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCompare_8u_C4R(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eComparisonOperation)
    {
        return JNpp.checkResult(nppiCompare_8u_C4RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, eComparisonOperation));
    }
    private static native int nppiCompare_8u_C4RNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eComparisonOperation);


    /**
     * <pre>
     * 4 channel 8-bit unsigned char image compare, not affecting Alpha.
     * Compare pSrc1's pixels with corresponding pixels in pSrc2. 
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param eComparisonOperation Specifies the comparison operation to be used in the pixel comparison.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCompare_8u_AC4R(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eComparisonOperation)
    {
        return JNpp.checkResult(nppiCompare_8u_AC4RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, eComparisonOperation));
    }
    private static native int nppiCompare_8u_AC4RNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eComparisonOperation);


    /**
     * <pre>
     * 1 channel 16-bit unsigned short image compare.
     * Compare pSrc1's pixels with corresponding pixels in pSrc2. 
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param eComparisonOperation Specifies the comparison operation to be used in the pixel comparison.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCompare_16u_C1R(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eComparisonOperation)
    {
        return JNpp.checkResult(nppiCompare_16u_C1RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, eComparisonOperation));
    }
    private static native int nppiCompare_16u_C1RNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eComparisonOperation);


    /**
     * <pre>
     * 3 channel 16-bit unsigned short image compare.
     * Compare pSrc1's pixels with corresponding pixels in pSrc2. 
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param eComparisonOperation Specifies the comparison operation to be used in the pixel comparison.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCompare_16u_C3R(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eComparisonOperation)
    {
        return JNpp.checkResult(nppiCompare_16u_C3RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, eComparisonOperation));
    }
    private static native int nppiCompare_16u_C3RNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eComparisonOperation);


    public static int nppiCompare_16u_C4R(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eComparisonOperation)
    {
        return JNpp.checkResult(nppiCompare_16u_C4RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, eComparisonOperation));
    }
    private static native int nppiCompare_16u_C4RNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eComparisonOperation);


    /**
     * <pre>
     * 4 channel 16-bit unsigned short image compare, not affecting Alpha.
     * Compare pSrc1's pixels with corresponding pixels in pSrc2. 
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param eComparisonOperation Specifies the comparison operation to be used in the pixel comparison.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCompare_16u_AC4R(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eComparisonOperation)
    {
        return JNpp.checkResult(nppiCompare_16u_AC4RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, eComparisonOperation));
    }
    private static native int nppiCompare_16u_AC4RNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eComparisonOperation);


    /**
     * <pre>
     * 1 channel 16-bit signed short image compare.
     * Compare pSrc1's pixels with corresponding pixels in pSrc2. 
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param eComparisonOperation Specifies the comparison operation to be used in the pixel comparison.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCompare_16s_C1R(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eComparisonOperation)
    {
        return JNpp.checkResult(nppiCompare_16s_C1RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, eComparisonOperation));
    }
    private static native int nppiCompare_16s_C1RNative(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eComparisonOperation);


    /**
     * <pre>
     * 3 channel 16-bit signed short image compare.
     * Compare pSrc1's pixels with corresponding pixels in pSrc2. 
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param eComparisonOperation Specifies the comparison operation to be used in the pixel comparison.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCompare_16s_C3R(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eComparisonOperation)
    {
        return JNpp.checkResult(nppiCompare_16s_C3RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, eComparisonOperation));
    }
    private static native int nppiCompare_16s_C3RNative(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eComparisonOperation);


    /**
     * <pre>
     * 4 channel 16-bit signed short image compare.
     * Compare pSrc1's pixels with corresponding pixels in pSrc2. 
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param eComparisonOperation Specifies the comparison operation to be used in the pixel comparison.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCompare_16s_C4R(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eComparisonOperation)
    {
        return JNpp.checkResult(nppiCompare_16s_C4RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, eComparisonOperation));
    }
    private static native int nppiCompare_16s_C4RNative(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eComparisonOperation);


    /**
     * <pre>
     * 4 channel 16-bit signed short image compare, not affecting Alpha.
     * Compare pSrc1's pixels with corresponding pixels in pSrc2. 
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param eComparisonOperation Specifies the comparison operation to be used in the pixel comparison.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCompare_16s_AC4R(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eComparisonOperation)
    {
        return JNpp.checkResult(nppiCompare_16s_AC4RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, eComparisonOperation));
    }
    private static native int nppiCompare_16s_AC4RNative(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eComparisonOperation);


    /**
     * <pre>
     * 1 channel 32-bit floating point image compare.
     * Compare pSrc1's pixels with corresponding pixels in pSrc2. 
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param eComparisonOperation Specifies the comparison operation to be used in the pixel comparison.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCompare_32f_C1R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eComparisonOperation)
    {
        return JNpp.checkResult(nppiCompare_32f_C1RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, eComparisonOperation));
    }
    private static native int nppiCompare_32f_C1RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eComparisonOperation);


    /**
     * <pre>
     * 3 channel 32-bit floating point image compare.
     * Compare pSrc1's pixels with corresponding pixels in pSrc2. 
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param eComparisonOperation Specifies the comparison operation to be used in the pixel comparison.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCompare_32f_C3R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eComparisonOperation)
    {
        return JNpp.checkResult(nppiCompare_32f_C3RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, eComparisonOperation));
    }
    private static native int nppiCompare_32f_C3RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eComparisonOperation);


    /**
     * <pre>
     * 4 channel 32-bit floating point image compare.
     * Compare pSrc1's pixels with corresponding pixels in pSrc2. 
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param eComparisonOperation Specifies the comparison operation to be used in the pixel comparison.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCompare_32f_C4R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eComparisonOperation)
    {
        return JNpp.checkResult(nppiCompare_32f_C4RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, eComparisonOperation));
    }
    private static native int nppiCompare_32f_C4RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eComparisonOperation);


    /**
     * <pre>
     * 4 channel 32-bit signed floating point compare, not affecting Alpha.
     * Compare pSrc1's pixels with corresponding pixels in pSrc2. 
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param eComparisonOperation Specifies the comparison operation to be used in the pixel comparison.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCompare_32f_AC4R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eComparisonOperation)
    {
        return JNpp.checkResult(nppiCompare_32f_AC4RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, eComparisonOperation));
    }
    private static native int nppiCompare_32f_AC4RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eComparisonOperation);


    /**
     * <pre>
     * 1 channel 8-bit unsigned char image compare with constant value.
     * Compare pSrc's pixels with constant value. 
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param nConstant constant value.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param eComparisonOperation Specifies the comparison operation to be used in the pixel comparison.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCompareC_8u_C1R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        byte nConstant, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eComparisonOperation)
    {
        return JNpp.checkResult(nppiCompareC_8u_C1RNative(pSrc, nSrcStep, nConstant, pDst, nDstStep, oSizeROI, eComparisonOperation));
    }
    private static native int nppiCompareC_8u_C1RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        byte nConstant, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eComparisonOperation);


    /**
     * <pre>
     * 3 channel 8-bit unsigned char image compare with constant value.
     * Compare pSrc's pixels with constant value. 
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pConstants pointer to a list of constant values, one per color channel..
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param eComparisonOperation Specifies the comparison operation to be used in the pixel comparison.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCompareC_8u_C3R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eComparisonOperation)
    {
        return JNpp.checkResult(nppiCompareC_8u_C3RNative(pSrc, nSrcStep, pConstants, pDst, nDstStep, oSizeROI, eComparisonOperation));
    }
    private static native int nppiCompareC_8u_C3RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eComparisonOperation);


    /**
     * <pre>
     * 4 channel 8-bit unsigned char image compare with constant value.
     * Compare pSrc's pixels with constant value. 
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pConstants pointer to a list of constants, one per color channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param eComparisonOperation Specifies the comparison operation to be used in the pixel comparison.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCompareC_8u_C4R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eComparisonOperation)
    {
        return JNpp.checkResult(nppiCompareC_8u_C4RNative(pSrc, nSrcStep, pConstants, pDst, nDstStep, oSizeROI, eComparisonOperation));
    }
    private static native int nppiCompareC_8u_C4RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eComparisonOperation);


    public static int nppiCompareC_8u_AC4R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eComparisonOperation)
    {
        return JNpp.checkResult(nppiCompareC_8u_AC4RNative(pSrc, nSrcStep, pConstants, pDst, nDstStep, oSizeROI, eComparisonOperation));
    }
    private static native int nppiCompareC_8u_AC4RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eComparisonOperation);


    /**
     * <pre>
     * 1 channel 16-bit unsigned short image compare with constant value.
     * Compare pSrc's pixels with constant value. 
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param nConstant constant value
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param eComparisonOperation Specifies the comparison operation to be used in the pixel comparison.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCompareC_16u_C1R(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        short nConstant, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eComparisonOperation)
    {
        return JNpp.checkResult(nppiCompareC_16u_C1RNative(pSrc, nSrcStep, nConstant, pDst, nDstStep, oSizeROI, eComparisonOperation));
    }
    private static native int nppiCompareC_16u_C1RNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        short nConstant, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eComparisonOperation);


    public static int nppiCompareC_16u_C3R(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eComparisonOperation)
    {
        return JNpp.checkResult(nppiCompareC_16u_C3RNative(pSrc, nSrcStep, pConstants, pDst, nDstStep, oSizeROI, eComparisonOperation));
    }
    private static native int nppiCompareC_16u_C3RNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eComparisonOperation);


    /**
     * <pre>
     * 4 channel 16-bit unsigned short image compare with constant value.
     * Compare pSrc's pixels with constant value. 
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pConstants pointer to a list of constants, one per color channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param eComparisonOperation Specifies the comparison operation to be used in the pixel comparison.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCompareC_16u_C4R(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eComparisonOperation)
    {
        return JNpp.checkResult(nppiCompareC_16u_C4RNative(pSrc, nSrcStep, pConstants, pDst, nDstStep, oSizeROI, eComparisonOperation));
    }
    private static native int nppiCompareC_16u_C4RNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eComparisonOperation);


    /**
     * <pre>
     * 4 channel 16-bit unsigned short image compare, not affecting Alpha.
     * Compare pSrc's pixels with constant value. 
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pConstants pointer to a list of constants, one per color channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param eComparisonOperation Specifies the comparison operation to be used in the pixel comparison.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCompareC_16u_AC4R(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eComparisonOperation)
    {
        return JNpp.checkResult(nppiCompareC_16u_AC4RNative(pSrc, nSrcStep, pConstants, pDst, nDstStep, oSizeROI, eComparisonOperation));
    }
    private static native int nppiCompareC_16u_AC4RNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eComparisonOperation);


    /**
     * <pre>
     * 1 channel 16-bit signed short image compare with constant value.
     * Compare pSrc's pixels with constant value. 
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param nConstant constant value.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param eComparisonOperation Specifies the comparison operation to be used in the pixel comparison.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCompareC_16s_C1R(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        short nConstant, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eComparisonOperation)
    {
        return JNpp.checkResult(nppiCompareC_16s_C1RNative(pSrc, nSrcStep, nConstant, pDst, nDstStep, oSizeROI, eComparisonOperation));
    }
    private static native int nppiCompareC_16s_C1RNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        short nConstant, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eComparisonOperation);


    /**
     * <pre>
     * 3 channel 16-bit signed short image compare with constant value.
     * Compare pSrc's pixels with constant value. 
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pConstants pointer to a list of constants, one per color channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param eComparisonOperation Specifies the comparison operation to be used in the pixel comparison.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCompareC_16s_C3R(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eComparisonOperation)
    {
        return JNpp.checkResult(nppiCompareC_16s_C3RNative(pSrc, nSrcStep, pConstants, pDst, nDstStep, oSizeROI, eComparisonOperation));
    }
    private static native int nppiCompareC_16s_C3RNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eComparisonOperation);


    /**
     * <pre>
     * 4 channel 16-bit signed short image compare with constant value.
     * Compare pSrc's pixels with constant value. 
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pConstants pointer to a list of constants, one per color channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param eComparisonOperation Specifies the comparison operation to be used in the pixel comparison.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCompareC_16s_C4R(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eComparisonOperation)
    {
        return JNpp.checkResult(nppiCompareC_16s_C4RNative(pSrc, nSrcStep, pConstants, pDst, nDstStep, oSizeROI, eComparisonOperation));
    }
    private static native int nppiCompareC_16s_C4RNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eComparisonOperation);


    /**
     * <pre>
     * 4 channel 16-bit signed short image compare, not affecting Alpha.
     * Compare pSrc's pixels with constant value. 
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pConstants pointer to a list of constants, one per color channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param eComparisonOperation Specifies the comparison operation to be used in the pixel comparison.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCompareC_16s_AC4R(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eComparisonOperation)
    {
        return JNpp.checkResult(nppiCompareC_16s_AC4RNative(pSrc, nSrcStep, pConstants, pDst, nDstStep, oSizeROI, eComparisonOperation));
    }
    private static native int nppiCompareC_16s_AC4RNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eComparisonOperation);


    /**
     * <pre>
     * 1 channel 32-bit floating point image compare with constant value.
     * Compare pSrc's pixels with constant value. 
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param nConstant constant value
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param eComparisonOperation Specifies the comparison operation to be used in the pixel comparison.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCompareC_32f_C1R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        float nConstant, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eComparisonOperation)
    {
        return JNpp.checkResult(nppiCompareC_32f_C1RNative(pSrc, nSrcStep, nConstant, pDst, nDstStep, oSizeROI, eComparisonOperation));
    }
    private static native int nppiCompareC_32f_C1RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        float nConstant, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eComparisonOperation);


    /**
     * <pre>
     * 3 channel 32-bit floating point image compare with constant value.
     * Compare pSrc's pixels with constant value. 
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pConstants pointer to a list of constants, one per color channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param eComparisonOperation Specifies the comparison operation to be used in the pixel comparison.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCompareC_32f_C3R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eComparisonOperation)
    {
        return JNpp.checkResult(nppiCompareC_32f_C3RNative(pSrc, nSrcStep, pConstants, pDst, nDstStep, oSizeROI, eComparisonOperation));
    }
    private static native int nppiCompareC_32f_C3RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eComparisonOperation);


    /**
     * <pre>
     * 4 channel 32-bit floating point image compare with constant value.
     * Compare pSrc's pixels with constant value. 
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pConstants pointer to a list of constants, one per color channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param eComparisonOperation Specifies the comparison operation to be used in the pixel comparison.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCompareC_32f_C4R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eComparisonOperation)
    {
        return JNpp.checkResult(nppiCompareC_32f_C4RNative(pSrc, nSrcStep, pConstants, pDst, nDstStep, oSizeROI, eComparisonOperation));
    }
    private static native int nppiCompareC_32f_C4RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eComparisonOperation);


    /**
     * <pre>
     * 4 channel 32-bit signed floating point compare, not affecting Alpha.
     * Compare pSrc's pixels with constant value. 
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pConstants pointer to a list of constants, one per color channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param eComparisonOperation Specifies the comparison operation to be used in the pixel comparison.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCompareC_32f_AC4R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eComparisonOperation)
    {
        return JNpp.checkResult(nppiCompareC_32f_AC4RNative(pSrc, nSrcStep, pConstants, pDst, nDstStep, oSizeROI, eComparisonOperation));
    }
    private static native int nppiCompareC_32f_AC4RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eComparisonOperation);


    /**
     * <pre>
     * 1 channel 32-bit floating point image compare whether two images are equal within epsilon.
     * Compare pSrc1's pixels with corresponding pixels in pSrc2 to determine whether they are equal with a difference of epsilon. 
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nEpsilon epsilon tolerance value to compare to pixel absolute differences
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCompareEqualEps_32f_C1R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        float nEpsilon)
    {
        return JNpp.checkResult(nppiCompareEqualEps_32f_C1RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nEpsilon));
    }
    private static native int nppiCompareEqualEps_32f_C1RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        float nEpsilon);


    /**
     * <pre>
     * 3 channel 32-bit floating point image compare whether two images are equal within epsilon.
     * Compare pSrc1's pixels with corresponding pixels in pSrc2 to determine whether they are equal with a difference of epsilon. 
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nEpsilon epsilon tolerance value to compare to per color channel pixel absolute differences
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCompareEqualEps_32f_C3R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        float nEpsilon)
    {
        return JNpp.checkResult(nppiCompareEqualEps_32f_C3RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nEpsilon));
    }
    private static native int nppiCompareEqualEps_32f_C3RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        float nEpsilon);


    public static int nppiCompareEqualEps_32f_C4R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        float nEpsilon)
    {
        return JNpp.checkResult(nppiCompareEqualEps_32f_C4RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nEpsilon));
    }
    private static native int nppiCompareEqualEps_32f_C4RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        float nEpsilon);


    /**
     * <pre>
     * 4 channel 32-bit signed floating point compare whether two images are equal within epsilon, not affecting Alpha.
     * Compare pSrc1's pixels with corresponding pixels in pSrc2 to determine whether they are equal with a difference of epsilon. 
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nEpsilon epsilon tolerance value to compare to per color channel pixel absolute differences
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCompareEqualEps_32f_AC4R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        float nEpsilon)
    {
        return JNpp.checkResult(nppiCompareEqualEps_32f_AC4RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nEpsilon));
    }
    private static native int nppiCompareEqualEps_32f_AC4RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        float nEpsilon);


    /**
     * <pre>
     * 1 channel 32-bit floating point image compare whether image and constant are equal within epsilon.
     * Compare pSrc's pixels with constant value to determine whether they are equal within a difference of epsilon. 
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param nConstant constant value
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nEpsilon epsilon tolerance value to compare to pixel absolute differences
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCompareEqualEpsC_32f_C1R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        float nConstant, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        float nEpsilon)
    {
        return JNpp.checkResult(nppiCompareEqualEpsC_32f_C1RNative(pSrc, nSrcStep, nConstant, pDst, nDstStep, oSizeROI, nEpsilon));
    }
    private static native int nppiCompareEqualEpsC_32f_C1RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        float nConstant, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        float nEpsilon);


    public static int nppiCompareEqualEpsC_32f_C3R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        float nEpsilon)
    {
        return JNpp.checkResult(nppiCompareEqualEpsC_32f_C3RNative(pSrc, nSrcStep, pConstants, pDst, nDstStep, oSizeROI, nEpsilon));
    }
    private static native int nppiCompareEqualEpsC_32f_C3RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        float nEpsilon);


    /**
     * <pre>
     * 4 channel 32-bit floating point image compare whether image and constant are equal within epsilon.
     * Compare pSrc's pixels with constant value to determine whether they are equal within a difference of epsilon. 
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pConstants pointer to a list of constants, one per color channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nEpsilon epsilon tolerance value to compare to per color channel pixel absolute differences
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCompareEqualEpsC_32f_C4R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        float nEpsilon)
    {
        return JNpp.checkResult(nppiCompareEqualEpsC_32f_C4RNative(pSrc, nSrcStep, pConstants, pDst, nDstStep, oSizeROI, nEpsilon));
    }
    private static native int nppiCompareEqualEpsC_32f_C4RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        float nEpsilon);


    /**
     * <pre>
     * 4 channel 32-bit signed floating point compare whether image and constant are equal within epsilon, not affecting Alpha.
     * Compare pSrc's pixels with constant value to determine whether they are equal within a difference of epsilon. 
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pConstants pointer to a list of constants, one per color channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nEpsilon epsilon tolerance value to compare to per color channel pixel absolute differences
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCompareEqualEpsC_32f_AC4R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        float nEpsilon)
    {
        return JNpp.checkResult(nppiCompareEqualEpsC_32f_AC4RNative(pSrc, nSrcStep, pConstants, pDst, nDstStep, oSizeROI, nEpsilon));
    }
    private static native int nppiCompareEqualEpsC_32f_AC4RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        float nEpsilon);


    /**
     * <pre>
     * 8-bit unsigned image dilation.
     * 
     * Dilation computes the output pixel as the maximum pixel value of the pixels
     * under the mask. Pixels who's corresponding mask values are zero to not 
     * participate in the maximum search.
     *
     * @param pSrc  \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pMask Pointer to the start address of the mask array
     * @param oMaskSize Width and Height mask array.
     * @param oAnchor X and Y offsets of the mask origin frame of reference
     *        w.r.t the source pixel.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDilate_8u_C1R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        NppiSize oMaskSize, 
        NppiPoint oAnchor)
    {
        return JNpp.checkResult(nppiDilate_8u_C1RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, pMask, oMaskSize, oAnchor));
    }
    private static native int nppiDilate_8u_C1RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        NppiSize oMaskSize, 
        NppiPoint oAnchor);


    /**
     * <pre>
     * 4 channel 8-bit unsigned image dilation.
     * 
     * Dilation computes the output pixel as the maximum pixel value of the pixels
     * under the mask. Pixels who's corresponding mask values are zero to not 
     * participate in the maximum search.
     *
     * @param pSrc  \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pMask Pointer to the start address of the mask array
     * @param oMaskSize Width and Height mask array.
     * @param oAnchor X and Y offsets of the mask origin frame of reference
     *        w.r.t the source pixel.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDilate_8u_C4R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        NppiSize oMaskSize, 
        NppiPoint oAnchor)
    {
        return JNpp.checkResult(nppiDilate_8u_C4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, pMask, oMaskSize, oAnchor));
    }
    private static native int nppiDilate_8u_C4RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        NppiSize oMaskSize, 
        NppiPoint oAnchor);


    /**
     * <pre>
     * 8-bit unsigned image erosion.
     * 
     * Erosion computes the output pixel as the minimum pixel value of the pixels
     * under the mask. Pixels who's corresponding mask values are zero to not 
     * participate in the maximum search.
     *
     * @param pSrc  \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pMask Pointer to the start address of the mask array
     * @param oMaskSize Width and Height mask array.
     * @param oAnchor X and Y offsets of the mask origin frame of reference
     *        w.r.t the source pixel.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiErode_8u_C1R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        NppiSize oMaskSize, 
        NppiPoint oAnchor)
    {
        return JNpp.checkResult(nppiErode_8u_C1RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, pMask, oMaskSize, oAnchor));
    }
    private static native int nppiErode_8u_C1RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        NppiSize oMaskSize, 
        NppiPoint oAnchor);


    public static int nppiErode_8u_C4R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        NppiSize oMaskSize, 
        NppiPoint oAnchor)
    {
        return JNpp.checkResult(nppiErode_8u_C4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, pMask, oMaskSize, oAnchor));
    }
    private static native int nppiErode_8u_C4RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        NppiSize oMaskSize, 
        NppiPoint oAnchor);


    public static int nppiFilterColumn_8u_C1R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oROI, 
        TypedPointer<Npp32s> pKernel, 
        int nMaskSize, 
        int nAnchor, 
        int nDivisor)
    {
        return JNpp.checkResult(nppiFilterColumn_8u_C1RNative(pSrc, nSrcStep, pDst, nDstStep, oROI, pKernel, nMaskSize, nAnchor, nDivisor));
    }
    private static native int nppiFilterColumn_8u_C1RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oROI, 
        TypedPointer<Npp32s> pKernel, 
        int nMaskSize, 
        int nAnchor, 
        int nDivisor);


    public static int nppiFilterColumn_8u_C4R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oROI, 
        TypedPointer<Npp32s> pKernel, 
        int nMaskSize, 
        int nAnchor, 
        int nDivisor)
    {
        return JNpp.checkResult(nppiFilterColumn_8u_C4RNative(pSrc, nSrcStep, pDst, nDstStep, oROI, pKernel, nMaskSize, nAnchor, nDivisor));
    }
    private static native int nppiFilterColumn_8u_C4RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oROI, 
        TypedPointer<Npp32s> pKernel, 
        int nMaskSize, 
        int nAnchor, 
        int nDivisor);


    /**
     * <pre>
     * 8-bit unsigned 1D (row) image convolution.
     *
     * Apply general linear Row convolution filter, with rescaling, in a 1D mask
     * region around each source pixel for 1-channel 8 bit/pixel images.  
     * Result pixel is equal to the sum of the products between the kernel
     * coefficients (pKernel array) and corresponding neighboring row pixel values
     * in the source image defined by iKernelDim and iAnchorX, divided by iDivisor. 
     *
     * @param pSrc  \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oROI \ref roi_specification.
     * @param pKernel Pointer to the start address of the kernel coefficient array.
     *                Coefficients are expected to be stored in reverse order.  
     * @param nMaskSize Length of the linear kernel array.
     * @param nAnchor X offset of the kernel origin frame of reference w.r.t the
     *                 source pixel.
     * @param nDivisor The factor by which the convolved summation from the Filter
     *                 operation should be divided.  If equal to the sum of
     *                 coefficients, this will keep the maximum result value within
     *                 full scale.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiFilterRow_8u_C1R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oROI, 
        TypedPointer<Npp32s> pKernel, 
        int nMaskSize, 
        int nAnchor, 
        int nDivisor)
    {
        return JNpp.checkResult(nppiFilterRow_8u_C1RNative(pSrc, nSrcStep, pDst, nDstStep, oROI, pKernel, nMaskSize, nAnchor, nDivisor));
    }
    private static native int nppiFilterRow_8u_C1RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oROI, 
        TypedPointer<Npp32s> pKernel, 
        int nMaskSize, 
        int nAnchor, 
        int nDivisor);


    /**
     * <pre>
     * 4 channel 8-bit unsigned 1D (row) image convolution.
     *
     * Apply general linear Row convolution filter, with rescaling, in a 1D mask
     * region around each source pixel for 1-channel 8 bit/pixel images.  
     * Result pixel is equal to the sum of the products between the kernel
     * coefficients (pKernel array) and corresponding neighboring row pixel values
     * in the source image defined by iKernelDim and iAnchorX, divided by iDivisor. 
     *
     * @param pSrc  \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oROI \ref roi_specification.
     * @param pKernel Pointer to the start address of the kernel coefficient array.
     *                Coefficients are expected to be stored in reverse order.  
     * @param nMaskSize Length of the linear kernel array.
     * @param nAnchor X offset of the kernel origin frame of reference w.r.t the
     *                 source pixel.
     * @param nDivisor The factor by which the convolved summation from the Filter
     *                 operation should be divided.  If equal to the sum of
     *                 coefficients, this will keep the maximum result value within
     *                 full scale.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiFilterRow_8u_C4R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oROI, 
        TypedPointer<Npp32s> pKernel, 
        int nMaskSize, 
        int nAnchor, 
        int nDivisor)
    {
        return JNpp.checkResult(nppiFilterRow_8u_C4RNative(pSrc, nSrcStep, pDst, nDstStep, oROI, pKernel, nMaskSize, nAnchor, nDivisor));
    }
    private static native int nppiFilterRow_8u_C4RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oROI, 
        TypedPointer<Npp32s> pKernel, 
        int nMaskSize, 
        int nAnchor, 
        int nDivisor);


    /**
     * <pre>
     * 8-bit unsigned 1D (column) sum to 32f.
     *
     * Apply Column Window Summation filter over a 1D mask region around each
     * source pixel for 1-channel 8 bit/pixel input images with 32-bit floating point
     * output.  
     * Result 32-bit floating point pixel is equal to the sum of the corresponding and
     * neighboring column pixel values in a mask region of the source image defined by
     * nMaskSize and nAnchor. 
     *
     * @param pSrc  \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oROI \ref roi_specification.
     * @param nMaskSize Length of the linear kernel array.
     * @param nAnchor Y offset of the kernel origin frame of reference w.r.t the
     *        source pixel.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSumWindowColumn_8u32f_C1R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oROI, 
        int nMaskSize, 
        int nAnchor)
    {
        return JNpp.checkResult(nppiSumWindowColumn_8u32f_C1RNative(pSrc, nSrcStep, pDst, nDstStep, oROI, nMaskSize, nAnchor));
    }
    private static native int nppiSumWindowColumn_8u32f_C1RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oROI, 
        int nMaskSize, 
        int nAnchor);


    /**
     * <pre>
     * 8-bit unsigned 1D (row) sum to 32f.
     *
     * Apply Row Window Summation filter over a 1D mask region around each source
     * pixel for 1-channel 8-bit pixel input images with 32-bit floating point output.  
     * Result 32-bit floating point pixel is equal to the sum of the corresponding and
     * neighboring row pixel values in a mask region of the source image defined
     * by iKernelDim and iAnchorX. 
     *
     * @param pSrc  \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oROI \ref roi_specification.
     * @param nMaskSize Length of the linear kernel array.
     * @param nAnchor X offset of the kernel origin frame of reference w.r.t the
     *        source pixel.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSumWindowRow_8u32f_C1R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oROI, 
        int nMaskSize, 
        int nAnchor)
    {
        return JNpp.checkResult(nppiSumWindowRow_8u32f_C1RNative(pSrc, nSrcStep, pDst, nDstStep, oROI, nMaskSize, nAnchor));
    }
    private static native int nppiSumWindowRow_8u32f_C1RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oROI, 
        int nMaskSize, 
        int nAnchor);


    public static int nppiFilter_8u_C1R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp32s> pKernel, 
        NppiSize oKernelSize, 
        NppiPoint oAnchor, 
        int nDivisor)
    {
        return JNpp.checkResult(nppiFilter_8u_C1RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, pKernel, oKernelSize, oAnchor, nDivisor));
    }
    private static native int nppiFilter_8u_C1RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp32s> pKernel, 
        NppiSize oKernelSize, 
        NppiPoint oAnchor, 
        int nDivisor);


    /**
     * <pre>
     * 4 channel 8-bit unsigned convolution filter.
     * 
     * Pixels under the mask are multiplied by the respective weights in the mask
     * and the results are summed. Before writing the result pixel the sum is scaled
     * back via division by nDivisor.
     *
     * @param pSrc  \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pKernel Pointer to the start address of the kernel coefficient array.
     *        Coeffcients are expected to be stored in reverse order.
     * @param oKernelSize Width and Height of the rectangular kernel.
     * @param oAnchor X and Y offsets of the kernel origin frame of reference
     *        w.r.t the source pixel.
     * @param nDivisor The factor by which the convolved summation from the Filter
     *        operation should be divided.  If equal to the sum of coefficients,
     *        this will keep the maximum result value within full scale.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiFilter_8u_C4R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp32s> pKernel, 
        NppiSize oKernelSize, 
        NppiPoint oAnchor, 
        int nDivisor)
    {
        return JNpp.checkResult(nppiFilter_8u_C4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, pKernel, oKernelSize, oAnchor, nDivisor));
    }
    private static native int nppiFilter_8u_C4RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp32s> pKernel, 
        NppiSize oKernelSize, 
        NppiPoint oAnchor, 
        int nDivisor);


    /**
     * <pre>
     * 8-bit unsigned box filter.
     *
     * Computes the average pixel values of the pixels under a rectangular mask.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param oMaskSize Width and Height of the neighborhood region for the local
     *        Avg operation.
     * @param oAnchor X and Y offsets of the kernel origin frame of reference w.r.t
     *        the source pixel.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiFilterBox_8u_C1R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        NppiSize oMaskSize, 
        NppiPoint oAnchor)
    {
        return JNpp.checkResult(nppiFilterBox_8u_C1RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, oMaskSize, oAnchor));
    }
    private static native int nppiFilterBox_8u_C1RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        NppiSize oMaskSize, 
        NppiPoint oAnchor);


    /**
     * <pre>
     * 4 channel 8-bit unsigned box filter.
     *
     * Computes the average pixel values of the pixels under a rectangular mask.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param oMaskSize Width and Height of the neighborhood region for the local
     *        Avg operation.
     * @param oAnchor X and Y offsets of the kernel origin frame of reference w.r.t
     *        the source pixel.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiFilterBox_8u_C4R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        NppiSize oMaskSize, 
        NppiPoint oAnchor)
    {
        return JNpp.checkResult(nppiFilterBox_8u_C4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, oMaskSize, oAnchor));
    }
    private static native int nppiFilterBox_8u_C4RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        NppiSize oMaskSize, 
        NppiPoint oAnchor);


    /**
     * <pre>
     * 8-bit unsigned maximum filter.
     *
     * Result pixel value is the maximum of pixel values under the rectangular
     * mask region.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param oMaskSize Width and Height of the neighborhood region for the local
     *        Max operation.
     * @param oAnchor X and Y offsets of the kernel origin frame of reference
     *        w.r.t the source pixel.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiFilterMax_8u_C1R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        NppiSize oMaskSize, 
        NppiPoint oAnchor)
    {
        return JNpp.checkResult(nppiFilterMax_8u_C1RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, oMaskSize, oAnchor));
    }
    private static native int nppiFilterMax_8u_C1RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        NppiSize oMaskSize, 
        NppiPoint oAnchor);


    /**
     * <pre>
     * 4 channel 8-bit unsigned maximum filter.
     *
     * Result pixel value is the maximum of pixel values under the rectangular
     * mask region.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param oMaskSize Width and Height of the neighborhood region for the local
     *        Max operation.
     * @param oAnchor X and Y offsets of the kernel origin frame of reference
     *        w.r.t the source pixel.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiFilterMax_8u_C4R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        NppiSize oMaskSize, 
        NppiPoint oAnchor)
    {
        return JNpp.checkResult(nppiFilterMax_8u_C4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, oMaskSize, oAnchor));
    }
    private static native int nppiFilterMax_8u_C4RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        NppiSize oMaskSize, 
        NppiPoint oAnchor);


    /**
     * <pre>
     * 8-bit unsigned minimum filter.
     *
     * Result pixel value is the minimum of pixel values under the rectangular
     * mask region.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param oMaskSize Width and Height of the neighborhood region for the local
     *        Max operation.
     * @param oAnchor X and Y offsets of the kernel origin frame of reference
     *        w.r.t the source pixel.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiFilterMin_8u_C1R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        NppiSize oMaskSize, 
        NppiPoint oAnchor)
    {
        return JNpp.checkResult(nppiFilterMin_8u_C1RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, oMaskSize, oAnchor));
    }
    private static native int nppiFilterMin_8u_C1RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        NppiSize oMaskSize, 
        NppiPoint oAnchor);


    /**
     * <pre>
     * 4 channel 8-bit unsigned minimum filter.
     *
     * Result pixel value is the minimum of pixel values under the rectangular
     * mask region.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param oMaskSize Width and Height of the neighborhood region for the local
     *        Max operation.
     * @param oAnchor X and Y offsets of the kernel origin frame of reference
     *        w.r.t the source pixel.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiFilterMin_8u_C4R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        NppiSize oMaskSize, 
        NppiPoint oAnchor)
    {
        return JNpp.checkResult(nppiFilterMin_8u_C4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, oMaskSize, oAnchor));
    }
    private static native int nppiFilterMin_8u_C4RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        NppiSize oMaskSize, 
        NppiPoint oAnchor);


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiSum_8u_C1R.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiSumGetBufferHostSize_8u_C1R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiSumGetBufferHostSize_8u_C1RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiSumGetBufferHostSize_8u_C1RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiSum_8u64s_C1R.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiSumGetBufferHostSize_8u64s_C1R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiSumGetBufferHostSize_8u64s_C1RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiSumGetBufferHostSize_8u64s_C1RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);


    public static int nppiSumGetBufferHostSize_16u_C1R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiSumGetBufferHostSize_16u_C1RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiSumGetBufferHostSize_16u_C1RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiSum_16s_C1R.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiSumGetBufferHostSize_16s_C1R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiSumGetBufferHostSize_16s_C1RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiSumGetBufferHostSize_16s_C1RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiSum_32f_C1R.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiSumGetBufferHostSize_32f_C1R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiSumGetBufferHostSize_32f_C1RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiSumGetBufferHostSize_32f_C1RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiSum_8u_C3R.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiSumGetBufferHostSize_8u_C3R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiSumGetBufferHostSize_8u_C3RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiSumGetBufferHostSize_8u_C3RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);


    public static int nppiSumGetBufferHostSize_16u_C3R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)/** host pointer */
    {
        return JNpp.checkResult(nppiSumGetBufferHostSize_16u_C3RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiSumGetBufferHostSize_16u_C3RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);/** host pointer */


    public static int nppiSumGetBufferHostSize_16s_C3R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)/** host pointer */
    {
        return JNpp.checkResult(nppiSumGetBufferHostSize_16s_C3RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiSumGetBufferHostSize_16s_C3RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);/** host pointer */


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiSum_32f_C3R.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiSumGetBufferHostSize_32f_C3R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiSumGetBufferHostSize_32f_C3RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiSumGetBufferHostSize_32f_C3RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiSum_8u_AC4R.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiSumGetBufferHostSize_8u_AC4R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)/** host pointer */
    {
        return JNpp.checkResult(nppiSumGetBufferHostSize_8u_AC4RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiSumGetBufferHostSize_8u_AC4RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);/** host pointer */


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiSum_16u_AC4R.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiSumGetBufferHostSize_16u_AC4R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiSumGetBufferHostSize_16u_AC4RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiSumGetBufferHostSize_16u_AC4RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);


    public static int nppiSumGetBufferHostSize_16s_AC4R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiSumGetBufferHostSize_16s_AC4RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiSumGetBufferHostSize_16s_AC4RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiSum_32f_AC4R.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiSumGetBufferHostSize_32f_AC4R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiSumGetBufferHostSize_32f_AC4RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiSumGetBufferHostSize_32f_AC4RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiSum_8u64s_C4R.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiSumGetBufferHostSize_8u64s_C4R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiSumGetBufferHostSize_8u64s_C4RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiSumGetBufferHostSize_8u64s_C4RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiSum_8u_C4R.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiSumGetBufferHostSize_8u_C4R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiSumGetBufferHostSize_8u_C4RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiSumGetBufferHostSize_8u_C4RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiSum_16u_C4R.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiSumGetBufferHostSize_16u_C4R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiSumGetBufferHostSize_16u_C4RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiSumGetBufferHostSize_16u_C4RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);


    public static int nppiSumGetBufferHostSize_16s_C4R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiSumGetBufferHostSize_16s_C4RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiSumGetBufferHostSize_16s_C4RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);


    public static int nppiSumGetBufferHostSize_32f_C4R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiSumGetBufferHostSize_32f_C4RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiSumGetBufferHostSize_32f_C4RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);


    /**
     * <pre>
     * 1-channel 8-bit unsigned char image sum with 64-bit double precision result.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer. 
     *        Use \ref nppiSumGetBufferHostSize_8u_C1R to determine the minium number of bytes required.
     * @param pSum Pointer to the computed sum.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSum_8u_C1R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        TypedPointer<Npp64f> pSum)
    {
        return JNpp.checkResult(nppiSum_8u_C1RNative(pSrc, nSrcStep, oSizeROI, pDeviceBuffer, pSum));
    }
    private static native int nppiSum_8u_C1RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        TypedPointer<Npp64f> pSum);


    public static int nppiSum_8u64s_C1R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        TypedPointer<Npp64s> pSum)
    {
        return JNpp.checkResult(nppiSum_8u64s_C1RNative(pSrc, nSrcStep, oSizeROI, pDeviceBuffer, pSum));
    }
    private static native int nppiSum_8u64s_C1RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        TypedPointer<Npp64s> pSum);


    public static int nppiSum_16u_C1R(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        TypedPointer<Npp64f> pSum)
    {
        return JNpp.checkResult(nppiSum_16u_C1RNative(pSrc, nSrcStep, oSizeROI, pDeviceBuffer, pSum));
    }
    private static native int nppiSum_16u_C1RNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        TypedPointer<Npp64f> pSum);


    /**
     * <pre>
     * 1-channel 16-bit signed short image sum with 64-bit double precision result.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer. 
     *        Use \ref nppiSumGetBufferHostSize_16s_C1R to determine the minium number of bytes required.
     * @param pSum Pointer to the computed sum.
     * </pre>
     */
    public static int nppiSum_16s_C1R(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        TypedPointer<Npp64f> pSum)
    {
        return JNpp.checkResult(nppiSum_16s_C1RNative(pSrc, nSrcStep, oSizeROI, pDeviceBuffer, pSum));
    }
    private static native int nppiSum_16s_C1RNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        TypedPointer<Npp64f> pSum);


    public static int nppiSum_32f_C1R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        TypedPointer<Npp64f> pSum)
    {
        return JNpp.checkResult(nppiSum_32f_C1RNative(pSrc, nSrcStep, oSizeROI, pDeviceBuffer, pSum));
    }
    private static native int nppiSum_32f_C1RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        TypedPointer<Npp64f> pSum);


    /**
     * <pre>
     * 3-channel 8-bit unsigned char image sum with 64-bit double precision result.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer. 
     *        Use \ref nppiSumGetBufferHostSize_8u_C3R to determine the minium number of bytes required.
     * @param aSum Array that contains computed sum for each channel.
     * </pre>
     */
    public static int nppiSum_8u_C3R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        double[] aSum)
    {
        return JNpp.checkResult(nppiSum_8u_C3RNative(pSrc, nSrcStep, oSizeROI, pDeviceBuffer, aSum));
    }
    private static native int nppiSum_8u_C3RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        double[] aSum);


    public static int nppiSum_16u_C3R(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        double[] aSum)
    {
        return JNpp.checkResult(nppiSum_16u_C3RNative(pSrc, nSrcStep, oSizeROI, pDeviceBuffer, aSum));
    }
    private static native int nppiSum_16u_C3RNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        double[] aSum);


    /**
     * <pre>
     * 3-channel 16-bit signed short image sum with 64-bit double precision result.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer. 
     *        Use \ref nppiSumGetBufferHostSize_16s_C3R to determine the minium number of bytes required.
     * @param aSum Array that contains computed sum for each channel.
     * </pre>
     */
    public static int nppiSum_16s_C3R(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        double[] aSum)
    {
        return JNpp.checkResult(nppiSum_16s_C3RNative(pSrc, nSrcStep, oSizeROI, pDeviceBuffer, aSum));
    }
    private static native int nppiSum_16s_C3RNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        double[] aSum);


    public static int nppiSum_32f_C3R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        double[] aSum)
    {
        return JNpp.checkResult(nppiSum_32f_C3RNative(pSrc, nSrcStep, oSizeROI, pDeviceBuffer, aSum));
    }
    private static native int nppiSum_32f_C3RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        double[] aSum);


    /**
     * <pre>
     * 4-channel 8-bit unsigned char image sum with 64-bit double precision result.
     * Alpha channel is the last channel and is not processed.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer. 
     *        Use \ref nppiSumGetBufferHostSize_8u_AC4R to determine the minium number of bytes required.
     * @param aSum Array that contains computed sum for each channel (alpha channel is not computed).
     * </pre>
     */
    public static int nppiSum_8u_AC4R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        double[] aSum)
    {
        return JNpp.checkResult(nppiSum_8u_AC4RNative(pSrc, nSrcStep, oSizeROI, pDeviceBuffer, aSum));
    }
    private static native int nppiSum_8u_AC4RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        double[] aSum);


    /**
     * <pre>
     * 4-channel 16-bit unsigned short image sum with 64-bit double precision result.
     * Alpha channel is the last channel and is not processed.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer. 
     *        Use \ref nppiSumGetBufferHostSize_16u_AC4R to determine the minium number of bytes required.
     * @param aSum Array that contains computed sum for each channel (alpha channel is not computed).
     * </pre>
     */
    public static int nppiSum_16u_AC4R(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        double[] aSum)
    {
        return JNpp.checkResult(nppiSum_16u_AC4RNative(pSrc, nSrcStep, oSizeROI, pDeviceBuffer, aSum));
    }
    private static native int nppiSum_16u_AC4RNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        double[] aSum);


    /**
     * <pre>
     * 4-channel 16-bit signed short image sum with 64-bit double precision result.
     * Alpha channel is the last channel and is not processed.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer. 
     *        Use \ref nppiSumGetBufferHostSize_16s_AC4R to determine the minium number of bytes required.
     * @param aSum Array that contains computed sum for each channel (alpha channel is not computed).
     * </pre>
     */
    public static int nppiSum_16s_AC4R(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        double[] aSum)
    {
        return JNpp.checkResult(nppiSum_16s_AC4RNative(pSrc, nSrcStep, oSizeROI, pDeviceBuffer, aSum));
    }
    private static native int nppiSum_16s_AC4RNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        double[] aSum);


    public static int nppiSum_32f_AC4R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        double[] aSum)
    {
        return JNpp.checkResult(nppiSum_32f_AC4RNative(pSrc, nSrcStep, oSizeROI, pDeviceBuffer, aSum));
    }
    private static native int nppiSum_32f_AC4RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        double[] aSum);


    /**
     * <pre>
     * 4-channel 8-bit unsigned char image sum with 64-bit double precision result.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer
     *        Use \ref nppiSumGetBufferHostSize_8u_C4R to determine the minium number of bytes required.
     * @param aSum Array that contains computed sum for each channel.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSum_8u_C4R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        double[] aSum)
    {
        return JNpp.checkResult(nppiSum_8u_C4RNative(pSrc, nSrcStep, oSizeROI, pDeviceBuffer, aSum));
    }
    private static native int nppiSum_8u_C4RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        double[] aSum);


    /**
     * <pre>
     * 4-channel 8-bit unsigned char image sum with 64-bit long long result.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer
     *        Use \ref nppiSumGetBufferHostSize_8u64s_C4R to determine the minium number of bytes required.
     * @param aSum Array that contains computed sum for each channel.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSum_8u64s_C4R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        long[] aSum)
    {
        return JNpp.checkResult(nppiSum_8u64s_C4RNative(pSrc, nSrcStep, oSizeROI, pDeviceBuffer, aSum));
    }
    private static native int nppiSum_8u64s_C4RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        long[] aSum);


    /**
     * <pre>
     * 4-channel 16-bit unsigned short image sum with 64-bit double precision result.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer
     *        Use \ref nppiSumGetBufferHostSize_16u_C4R to determine the minium number of bytes required.
     * @param aSum Array that contains computed sum for each channel.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSum_16u_C4R(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        double[] aSum)
    {
        return JNpp.checkResult(nppiSum_16u_C4RNative(pSrc, nSrcStep, oSizeROI, pDeviceBuffer, aSum));
    }
    private static native int nppiSum_16u_C4RNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        double[] aSum);


    /**
     * <pre>
     * 4-channel 16-bit signed short image sum with 64-bit double precision result.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer
     *        Use \ref nppiSumGetBufferHostSize_16s_C4R to determine the minium number of bytes required.
     * @param aSum Array that contains computed sum for each channel.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSum_16s_C4R(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        double[] aSum)
    {
        return JNpp.checkResult(nppiSum_16s_C4RNative(pSrc, nSrcStep, oSizeROI, pDeviceBuffer, aSum));
    }
    private static native int nppiSum_16s_C4RNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        double[] aSum);


    /**
     * <pre>
     * 4-channel 32-bit floating point image sum with 64-bit double precision result.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer
     *        Use \ref nppiSumGetBufferHostSize_32f_C4R to determine the minium number of bytes required.
     * @param aSum Array that contains computed sum for each channel.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSum_32f_C4R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        double[] aSum)
    {
        return JNpp.checkResult(nppiSum_32f_C4RNative(pSrc, nSrcStep, oSizeROI, pDeviceBuffer, aSum));
    }
    private static native int nppiSum_32f_C4RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        double[] aSum);


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiMin_8u_C1R.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiMinGetBufferHostSize_8u_C1R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)/** host pointer */
    {
        return JNpp.checkResult(nppiMinGetBufferHostSize_8u_C1RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiMinGetBufferHostSize_8u_C1RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);/** host pointer */


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiMin_16u_C1R.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiMinGetBufferHostSize_16u_C1R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiMinGetBufferHostSize_16u_C1RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiMinGetBufferHostSize_16u_C1RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiMin_16s_C1R.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiMinGetBufferHostSize_16s_C1R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)/** host pointer */
    {
        return JNpp.checkResult(nppiMinGetBufferHostSize_16s_C1RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiMinGetBufferHostSize_16s_C1RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);/** host pointer */


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiMin_32f_C1R.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiMinGetBufferHostSize_32f_C1R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)/** host pointer */
    {
        return JNpp.checkResult(nppiMinGetBufferHostSize_32f_C1RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiMinGetBufferHostSize_32f_C1RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);/** host pointer */


    public static int nppiMinGetBufferHostSize_8u_C3R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiMinGetBufferHostSize_8u_C3RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiMinGetBufferHostSize_8u_C3RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiMin_16u_C3R.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiMinGetBufferHostSize_16u_C3R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)/** host pointer */
    {
        return JNpp.checkResult(nppiMinGetBufferHostSize_16u_C3RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiMinGetBufferHostSize_16u_C3RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);/** host pointer */


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiMin_16s_C3R.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiMinGetBufferHostSize_16s_C3R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiMinGetBufferHostSize_16s_C3RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiMinGetBufferHostSize_16s_C3RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiMin_32f_C3R.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiMinGetBufferHostSize_32f_C3R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiMinGetBufferHostSize_32f_C3RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiMinGetBufferHostSize_32f_C3RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);


    public static int nppiMinGetBufferHostSize_8u_C4R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiMinGetBufferHostSize_8u_C4RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiMinGetBufferHostSize_8u_C4RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);


    public static int nppiMinGetBufferHostSize_16u_C4R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiMinGetBufferHostSize_16u_C4RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiMinGetBufferHostSize_16u_C4RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);


    public static int nppiMinGetBufferHostSize_16s_C4R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiMinGetBufferHostSize_16s_C4RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiMinGetBufferHostSize_16s_C4RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiMin_32f_C4R.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiMinGetBufferHostSize_32f_C4R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiMinGetBufferHostSize_32f_C4RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiMinGetBufferHostSize_32f_C4RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiMin_8u_AC4R.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiMinGetBufferHostSize_8u_AC4R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiMinGetBufferHostSize_8u_AC4RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiMinGetBufferHostSize_8u_AC4RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiMin_16u_AC4R.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiMinGetBufferHostSize_16u_AC4R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiMinGetBufferHostSize_16u_AC4RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiMinGetBufferHostSize_16u_AC4RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);


    public static int nppiMinGetBufferHostSize_16s_AC4R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)/** host pointer */
    {
        return JNpp.checkResult(nppiMinGetBufferHostSize_16s_AC4RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiMinGetBufferHostSize_16s_AC4RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);/** host pointer */


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiMin_32f_AC4R.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiMinGetBufferHostSize_32f_AC4R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiMinGetBufferHostSize_32f_AC4RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiMinGetBufferHostSize_32f_AC4RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);


    /**
     * <pre>
     * 1-channel 8-bit unsigned char image min. 
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer
     *        Use \ref nppiMinGetBufferHostSize_8u_C1R to determine the minium number of bytes required.
     * @param pMin Device-memory pointer receiving the minimum result.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMin_8u_C1R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        TypedPointer<Npp8u> pMin)
    {
        return JNpp.checkResult(nppiMin_8u_C1RNative(pSrc, nSrcStep, oSizeROI, pDeviceBuffer, pMin));
    }
    private static native int nppiMin_8u_C1RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        TypedPointer<Npp8u> pMin);


    /**
     * <pre>
     * 1-channel 16-bit unsigned short integer image min.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer
     *        Use \ref nppiMinGetBufferHostSize_16u_C1R to determine the minium number of bytes required.
     * @param pMin Device-memory pointer receiving the minimum result.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMin_16u_C1R(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        TypedPointer<Npp16u> pMin)
    {
        return JNpp.checkResult(nppiMin_16u_C1RNative(pSrc, nSrcStep, oSizeROI, pDeviceBuffer, pMin));
    }
    private static native int nppiMin_16u_C1RNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        TypedPointer<Npp16u> pMin);


    /**
     * <pre>
     * 1-channel 16-bit signed short integer image min.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer
     *        Use \ref nppiMinGetBufferHostSize_16s_C1R to determine the minium number of bytes required.
     * @param pMin Device-memory pointer receiving the minimum result.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMin_16s_C1R(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        TypedPointer<Npp16s> pMin)
    {
        return JNpp.checkResult(nppiMin_16s_C1RNative(pSrc, nSrcStep, oSizeROI, pDeviceBuffer, pMin));
    }
    private static native int nppiMin_16s_C1RNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        TypedPointer<Npp16s> pMin);


    /**
     * <pre>
     * 1-channel 32-bit floating point image min.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer
     *        Use \ref nppiMinGetBufferHostSize_32f_C1R to determine the minium number of bytes required.
     * @param pMin Device-memory pointer receiving the minimum result.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMin_32f_C1R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        TypedPointer<Npp32f> pMin)
    {
        return JNpp.checkResult(nppiMin_32f_C1RNative(pSrc, nSrcStep, oSizeROI, pDeviceBuffer, pMin));
    }
    private static native int nppiMin_32f_C1RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        TypedPointer<Npp32f> pMin);


    /**
     * <pre>
     * 3-channel 8-bit unsigned char image min.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer
     *        Use \ref nppiMinGetBufferHostSize_8u_C3R to determine the minium number of bytes required.
     * @param aMin Device-memory array receiving the minimum results, three elements for three channels.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMin_8u_C3R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        byte[] aMin)
    {
        return JNpp.checkResult(nppiMin_8u_C3RNative(pSrc, nSrcStep, oSizeROI, pDeviceBuffer, aMin));
    }
    private static native int nppiMin_8u_C3RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        byte[] aMin);


    /**
     * <pre>
     * 3-channel 16-bit unsigned short integer image min.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer
     *        Use \ref nppiMinGetBufferHostSize_16u_C3R to determine the minium number of bytes required.
     * @param aMin Device-memory array receiving the minimum results, three elements for three channels.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMin_16u_C3R(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        short[] aMin)
    {
        return JNpp.checkResult(nppiMin_16u_C3RNative(pSrc, nSrcStep, oSizeROI, pDeviceBuffer, aMin));
    }
    private static native int nppiMin_16u_C3RNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        short[] aMin);


    public static int nppiMin_16s_C3R(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        short[] aMin)
    {
        return JNpp.checkResult(nppiMin_16s_C3RNative(pSrc, nSrcStep, oSizeROI, pDeviceBuffer, aMin));
    }
    private static native int nppiMin_16s_C3RNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        short[] aMin);


    /**
     * <pre>
     * 3-channel 32-bit floating point image min.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer
     *        Use \ref nppiMinGetBufferHostSize_32f_C3R to determine the minium number of bytes required.
     * @param aMin Device-memory array receiving the minimum results, three elements for three channels.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMin_32f_C3R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        float[] aMin)
    {
        return JNpp.checkResult(nppiMin_32f_C3RNative(pSrc, nSrcStep, oSizeROI, pDeviceBuffer, aMin));
    }
    private static native int nppiMin_32f_C3RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        float[] aMin);


    /**
     * <pre>
     * 4-channel 8-bit unsigned char image min.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer
     *        Use \ref nppiMinGetBufferHostSize_8u_C4R to determine the minium number of bytes required.
     * @param aMin Device-memory array receiving the minimum result, four elements for four channels.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMin_8u_C4R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        byte[] aMin)
    {
        return JNpp.checkResult(nppiMin_8u_C4RNative(pSrc, nSrcStep, oSizeROI, pDeviceBuffer, aMin));
    }
    private static native int nppiMin_8u_C4RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        byte[] aMin);


    /**
     * <pre>
     * 4-channel 16-bit unsigned short integer image min.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer
     *        Use \ref nppiMinGetBufferHostSize_16u_C4R to determine the minium number of bytes required.
     * @param aMin Device-memory array receiving the minimum result, four elements for four channels.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMin_16u_C4R(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        short[] aMin)
    {
        return JNpp.checkResult(nppiMin_16u_C4RNative(pSrc, nSrcStep, oSizeROI, pDeviceBuffer, aMin));
    }
    private static native int nppiMin_16u_C4RNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        short[] aMin);


    /**
     * <pre>
     * 4-channel 16-bit signed short integer image min.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer
     *        Use \ref nppiMinGetBufferHostSize_16s_C4R to determine the minium number of bytes required.
     * @param aMin Device-memory array receiving the minimum result, four elements for four channels.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMin_16s_C4R(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        short[] aMin)
    {
        return JNpp.checkResult(nppiMin_16s_C4RNative(pSrc, nSrcStep, oSizeROI, pDeviceBuffer, aMin));
    }
    private static native int nppiMin_16s_C4RNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        short[] aMin);


    /**
     * <pre>
     * 4-channel 32-bit floating point image min.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer
     *        Use \ref nppiMinGetBufferHostSize_32f_C4R to determine the minium number of bytes required.
     * @param aMin Device-memory array receiving the minimum result, four elements for four channels.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMin_32f_C4R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        float[] aMin)
    {
        return JNpp.checkResult(nppiMin_32f_C4RNative(pSrc, nSrcStep, oSizeROI, pDeviceBuffer, aMin));
    }
    private static native int nppiMin_32f_C4RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        float[] aMin);


    /**
     * <pre>
     * 4-channel 8-bit unsigned char image min (alpha channel is not processed).
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer
     *        Use \ref nppiMinGetBufferHostSize_8u_AC4R to determine the minium number of bytes required.
     * @param aMin Device-memory array receiving the minimum result, three elements for the first three channels.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMin_8u_AC4R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        byte[] aMin)
    {
        return JNpp.checkResult(nppiMin_8u_AC4RNative(pSrc, nSrcStep, oSizeROI, pDeviceBuffer, aMin));
    }
    private static native int nppiMin_8u_AC4RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        byte[] aMin);


    /**
     * <pre>
     * 4-channel 16-bit unsigned short integer image min (alpha channel is not processed).
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer
     *        Use \ref nppiMinGetBufferHostSize_16u_AC4R to determine the minium number of bytes required.
     * @param aMin Device-memory array receiving the minimum result, three elements for the first three channels.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMin_16u_AC4R(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        short[] aMin)
    {
        return JNpp.checkResult(nppiMin_16u_AC4RNative(pSrc, nSrcStep, oSizeROI, pDeviceBuffer, aMin));
    }
    private static native int nppiMin_16u_AC4RNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        short[] aMin);


    /**
     * <pre>
     * 4-channel 16-bit signed short integer image min (alpha channel is not processed).
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer
     *        Use \ref nppiMinGetBufferHostSize_16s_AC4R to determine the minium number of bytes required.
     * @param aMin Device-memory array receiving the minimum result, three elements for the first three channels.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMin_16s_AC4R(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        short[] aMin)
    {
        return JNpp.checkResult(nppiMin_16s_AC4RNative(pSrc, nSrcStep, oSizeROI, pDeviceBuffer, aMin));
    }
    private static native int nppiMin_16s_AC4RNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        short[] aMin);


    /**
     * <pre>
     * 4-channel 32-bit floating point image min (alpha channel is not processed).
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer
     *        Use \ref nppiMinGetBufferHostSize_32f_AC4R to determine the minium number of bytes required.
     * @param aMin Device-memory array receiving the minimum result, three elements for the first three channels.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMin_32f_AC4R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        float[] aMin)
    {
        return JNpp.checkResult(nppiMin_32f_AC4RNative(pSrc, nSrcStep, oSizeROI, pDeviceBuffer, aMin));
    }
    private static native int nppiMin_32f_AC4RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        float[] aMin);


    public static int nppiMinIndxGetBufferHostSize_8u_C1R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiMinIndxGetBufferHostSize_8u_C1RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiMinIndxGetBufferHostSize_8u_C1RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);


    public static int nppiMinIndxGetBufferHostSize_16u_C1R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)/** host pointer */
    {
        return JNpp.checkResult(nppiMinIndxGetBufferHostSize_16u_C1RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiMinIndxGetBufferHostSize_16u_C1RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);/** host pointer */


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiMinIndx_16s_C1R.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiMinIndxGetBufferHostSize_16s_C1R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiMinIndxGetBufferHostSize_16s_C1RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiMinIndxGetBufferHostSize_16s_C1RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiMinIndx_32f_C1R.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiMinIndxGetBufferHostSize_32f_C1R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)/** host pointer */
    {
        return JNpp.checkResult(nppiMinIndxGetBufferHostSize_32f_C1RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiMinIndxGetBufferHostSize_32f_C1RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);/** host pointer */


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiMinIndx_8u_C3R.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiMinIndxGetBufferHostSize_8u_C3R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiMinIndxGetBufferHostSize_8u_C3RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiMinIndxGetBufferHostSize_8u_C3RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiMinIndx_16u_C3R.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiMinIndxGetBufferHostSize_16u_C3R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)/** host pointer */
    {
        return JNpp.checkResult(nppiMinIndxGetBufferHostSize_16u_C3RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiMinIndxGetBufferHostSize_16u_C3RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);/** host pointer */


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiMinIndx_16s_C3R.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiMinIndxGetBufferHostSize_16s_C3R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiMinIndxGetBufferHostSize_16s_C3RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiMinIndxGetBufferHostSize_16s_C3RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiMinIndx_32f_C3R.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiMinIndxGetBufferHostSize_32f_C3R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)/** host pointer */
    {
        return JNpp.checkResult(nppiMinIndxGetBufferHostSize_32f_C3RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiMinIndxGetBufferHostSize_32f_C3RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);/** host pointer */


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiMinIndx_8u_C4R.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiMinIndxGetBufferHostSize_8u_C4R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)/** host pointer */
    {
        return JNpp.checkResult(nppiMinIndxGetBufferHostSize_8u_C4RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiMinIndxGetBufferHostSize_8u_C4RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);/** host pointer */


    public static int nppiMinIndxGetBufferHostSize_16u_C4R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiMinIndxGetBufferHostSize_16u_C4RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiMinIndxGetBufferHostSize_16u_C4RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiMinIndx_16s_C4R.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiMinIndxGetBufferHostSize_16s_C4R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)/** host pointer */
    {
        return JNpp.checkResult(nppiMinIndxGetBufferHostSize_16s_C4RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiMinIndxGetBufferHostSize_16s_C4RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);/** host pointer */


    public static int nppiMinIndxGetBufferHostSize_32f_C4R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiMinIndxGetBufferHostSize_32f_C4RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiMinIndxGetBufferHostSize_32f_C4RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiMinIndx_8u_AC4R.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiMinIndxGetBufferHostSize_8u_AC4R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiMinIndxGetBufferHostSize_8u_AC4RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiMinIndxGetBufferHostSize_8u_AC4RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiMinIndx_8u_AC4R.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiMinIndxGetBufferHostSize_16u_AC4R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiMinIndxGetBufferHostSize_16u_AC4RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiMinIndxGetBufferHostSize_16u_AC4RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);


    public static int nppiMinIndxGetBufferHostSize_16s_AC4R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiMinIndxGetBufferHostSize_16s_AC4RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiMinIndxGetBufferHostSize_16s_AC4RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiMinIndx_32f_AC4R.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiMinIndxGetBufferHostSize_32f_AC4R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiMinIndxGetBufferHostSize_32f_AC4RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiMinIndxGetBufferHostSize_32f_AC4RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);


    /**
     * <pre>
     * 1-channel 8-bit unsigned char image min with its X and Y coordinates.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer
     *        Use \ref nppiMinIndxGetBufferHostSize_8u_C1R to determine the minium number of bytes required.
     * @param pMin Device-memory pointer receiving the minimum result.
     * @param pIndexX Device-memory pointer to the X coordinate of the image min value.
     * @param pIndexY Device-memory pointer to the Y coordinate of the image min value.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMinIndx_8u_C1R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        TypedPointer<Npp8u> pMin, 
        int[] pIndexX, 
        int[] pIndexY)
    {
        return JNpp.checkResult(nppiMinIndx_8u_C1RNative(pSrc, nSrcStep, oSizeROI, pDeviceBuffer, pMin, pIndexX, pIndexY));
    }
    private static native int nppiMinIndx_8u_C1RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        TypedPointer<Npp8u> pMin, 
        int[] pIndexX, 
        int[] pIndexY);


    /**
     * <pre>
     * 1-channel 16-bit unsigned short integer image min with its X and Y coordinates.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer
     *        Use \ref nppiMinIndxGetBufferHostSize_16u_C1R to determine the minium number of bytes required.
     * @param pMin Device-memory pointer receiving the minimum result.
     * @param pIndexX Device-memory pointer to the X coordinate of the image min value.
     * @param pIndexY Device-memory pointer to the Y coordinate of the image min value.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMinIndx_16u_C1R(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        TypedPointer<Npp16u> pMin, 
        int[] pIndexX, 
        int[] pIndexY)
    {
        return JNpp.checkResult(nppiMinIndx_16u_C1RNative(pSrc, nSrcStep, oSizeROI, pDeviceBuffer, pMin, pIndexX, pIndexY));
    }
    private static native int nppiMinIndx_16u_C1RNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        TypedPointer<Npp16u> pMin, 
        int[] pIndexX, 
        int[] pIndexY);


    /**
     * <pre>
     * 1-channel 16-bit signed short integer image min with its X and Y coordinates.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer
     *        Use \ref nppiMinIndxGetBufferHostSize_16s_C1R to determine the minium number of bytes required.
     * @param pMin Device-memory pointer receiving the minimum result.
     * @param pIndexX Device-memory pointer to the X coordinate of the image min value.
     * @param pIndexY Device-memory pointer to the Y coordinate of the image min value.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMinIndx_16s_C1R(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        TypedPointer<Npp16s> pMin, 
        int[] pIndexX, 
        int[] pIndexY)
    {
        return JNpp.checkResult(nppiMinIndx_16s_C1RNative(pSrc, nSrcStep, oSizeROI, pDeviceBuffer, pMin, pIndexX, pIndexY));
    }
    private static native int nppiMinIndx_16s_C1RNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        TypedPointer<Npp16s> pMin, 
        int[] pIndexX, 
        int[] pIndexY);


    /**
     * <pre>
     * 1-channel 32-bit floating point image min with its X and Y coordinates.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer
     *        Use \ref nppiMinIndxGetBufferHostSize_32f_C1R to determine the minium number of bytes required.
     * @param pMin Device-memory pointer receiving the minimum result.
     * @param pIndexX Device-memory pointer to the X coordinate of the image min value.
     * @param pIndexY Device-memory pointer to the Y coordinate of the image min value.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMinIndx_32f_C1R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        TypedPointer<Npp32f> pMin, 
        int[] pIndexX, 
        int[] pIndexY)
    {
        return JNpp.checkResult(nppiMinIndx_32f_C1RNative(pSrc, nSrcStep, oSizeROI, pDeviceBuffer, pMin, pIndexX, pIndexY));
    }
    private static native int nppiMinIndx_32f_C1RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        TypedPointer<Npp32f> pMin, 
        int[] pIndexX, 
        int[] pIndexY);


    /**
     * <pre>
     * 3-channel 8-bit unsigned char image min values with their X and Y coordinates.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer
     *        Use \ref nppiMinIndxGetBufferHostSize_8u_C3R to determine the minium number of bytes required.
     * @param aMin Device-memory array receiving the minimum result, three elements for three channels.
     * @param aIndexX Device-memory array to the X coordinates of the image min values, three elements for three channels.
     * @param aIndexY Device-memory array to the Y coordinates of the image min values, three elements for three channels.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMinIndx_8u_C3R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        byte[] aMin, 
        int[] aIndexX, 
        int[] aIndexY)
    {
        return JNpp.checkResult(nppiMinIndx_8u_C3RNative(pSrc, nSrcStep, oSizeROI, pDeviceBuffer, aMin, aIndexX, aIndexY));
    }
    private static native int nppiMinIndx_8u_C3RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        byte[] aMin, 
        int[] aIndexX, 
        int[] aIndexY);


    public static int nppiMinIndx_16u_C3R(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        short[] aMin, 
        int[] aIndexX, 
        int[] aIndexY)
    {
        return JNpp.checkResult(nppiMinIndx_16u_C3RNative(pSrc, nSrcStep, oSizeROI, pDeviceBuffer, aMin, aIndexX, aIndexY));
    }
    private static native int nppiMinIndx_16u_C3RNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        short[] aMin, 
        int[] aIndexX, 
        int[] aIndexY);


    public static int nppiMinIndx_16s_C3R(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        short[] aMin, 
        int[] aIndexX, 
        int[] aIndexY)
    {
        return JNpp.checkResult(nppiMinIndx_16s_C3RNative(pSrc, nSrcStep, oSizeROI, pDeviceBuffer, aMin, aIndexX, aIndexY));
    }
    private static native int nppiMinIndx_16s_C3RNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        short[] aMin, 
        int[] aIndexX, 
        int[] aIndexY);


    /**
     * <pre>
     * 3-channel 32-bit floating point image min values with their X and Y coordinates.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer
     *        Use \ref nppiMinIndxGetBufferHostSize_32f_C3R to determine the minium number of bytes required.
     * @param aMin Device-memory array receiving the minimum result, three elements for three channels.
     * @param aIndexX Device-memory array to the X coordinates of the image min values, three elements for three channels.
     * @param aIndexY Device-memory array to the Y coordinates of the image min values, three elements for three channels.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMinIndx_32f_C3R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        float[] aMin, 
        int[] aIndexX, 
        int[] aIndexY)
    {
        return JNpp.checkResult(nppiMinIndx_32f_C3RNative(pSrc, nSrcStep, oSizeROI, pDeviceBuffer, aMin, aIndexX, aIndexY));
    }
    private static native int nppiMinIndx_32f_C3RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        float[] aMin, 
        int[] aIndexX, 
        int[] aIndexY);


    /**
     * <pre>
     * 4-channel 8-bit unsigned char image min values with their X and Y coordinates.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer
     *        Use \ref nppiMinIndxGetBufferHostSize_8u_C4R to determine the minium number of bytes required.
     * @param aMin Device-memory array receiving the minimum result, four elements for four channels.
     * @param aIndexX Device-memory array to the X coordinates of the image min values, four elements for four channels.
     * @param aIndexY Device-memory array to the Y coordinates of the image min values, four elements for four channels.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMinIndx_8u_C4R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        byte[] aMin, 
        int[] aIndexX, 
        int[] aIndexY)
    {
        return JNpp.checkResult(nppiMinIndx_8u_C4RNative(pSrc, nSrcStep, oSizeROI, pDeviceBuffer, aMin, aIndexX, aIndexY));
    }
    private static native int nppiMinIndx_8u_C4RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        byte[] aMin, 
        int[] aIndexX, 
        int[] aIndexY);


    /**
     * <pre>
     * 4-channel 16-bit unsigned short integer image min values with their X and Y coordinates.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer
     *        Use \ref nppiMinIndxGetBufferHostSize_16u_C4R to determine the minium number of bytes required.
     * @param aMin Device-memory array receiving the minimum result, four elements for four channels.
     * @param aIndexX Device-memory array to the X coordinates of the image min values, four elements for four channels.
     * @param aIndexY Device-memory array to the Y coordinates of the image min values, four elements for four channels.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMinIndx_16u_C4R(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        short[] aMin, 
        int[] aIndexX, 
        int[] aIndexY)
    {
        return JNpp.checkResult(nppiMinIndx_16u_C4RNative(pSrc, nSrcStep, oSizeROI, pDeviceBuffer, aMin, aIndexX, aIndexY));
    }
    private static native int nppiMinIndx_16u_C4RNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        short[] aMin, 
        int[] aIndexX, 
        int[] aIndexY);


    /**
     * <pre>
     * 4-channel 16-bit signed short integer image min values with their X and Y coordinates.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer
     *        Use \ref nppiMinIndxGetBufferHostSize_16s_C4R to determine the minium number of bytes required.
     * @param aMin Device-memory array receiving the minimum result, four elements for four channels.
     * @param aIndexX Device-memory array to the X coordinates of the image min values, four elements for four channels.
     * @param aIndexY Device-memory array to the Y coordinates of the image min values, four elements for four channels.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMinIndx_16s_C4R(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        short[] aMin, 
        int[] aIndexX, 
        int[] aIndexY)
    {
        return JNpp.checkResult(nppiMinIndx_16s_C4RNative(pSrc, nSrcStep, oSizeROI, pDeviceBuffer, aMin, aIndexX, aIndexY));
    }
    private static native int nppiMinIndx_16s_C4RNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        short[] aMin, 
        int[] aIndexX, 
        int[] aIndexY);


    /**
     * <pre>
     * 4-channel 32-bit floating point image min values with their X and Y coordinates.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer
     *        Use \ref nppiMinIndxGetBufferHostSize_32f_C4R to determine the minium number of bytes required.
     * @param aMin Device-memory array receiving the minimum result, four elements for four channels.
     * @param aIndexX Device-memory array to the X coordinates of the image min values, four elements for four channels.
     * @param aIndexY Device-memory array to the Y coordinates of the image min values, four elements for four channels.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMinIndx_32f_C4R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        float[] aMin, 
        int[] aIndexX, 
        int[] aIndexY)
    {
        return JNpp.checkResult(nppiMinIndx_32f_C4RNative(pSrc, nSrcStep, oSizeROI, pDeviceBuffer, aMin, aIndexX, aIndexY));
    }
    private static native int nppiMinIndx_32f_C4RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        float[] aMin, 
        int[] aIndexX, 
        int[] aIndexY);


    /**
     * <pre>
     * 4-channel 8-bit unsigned char image min values with their X and Y coordinates (alpha channel is not processed).
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer
     *        Use \ref nppiMinIndxGetBufferHostSize_8u_AC4R to determine the minium number of bytes required.
     * @param aMin Device-memory array receiving the minimum result, three elements for the three channels.
     * @param aIndexX Device-memory array to the X coordinates of the image min values, three elements for the three channels.
     * @param aIndexY Device-memory array to the Y coordinates of the image min values, three elements for the three channels.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMinIndx_8u_AC4R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        byte[] aMin, 
        int[] aIndexX, 
        int[] aIndexY)
    {
        return JNpp.checkResult(nppiMinIndx_8u_AC4RNative(pSrc, nSrcStep, oSizeROI, pDeviceBuffer, aMin, aIndexX, aIndexY));
    }
    private static native int nppiMinIndx_8u_AC4RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        byte[] aMin, 
        int[] aIndexX, 
        int[] aIndexY);


    public static int nppiMinIndx_16u_AC4R(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        short[] aMin, 
        int[] aIndexX, 
        int[] aIndexY)
    {
        return JNpp.checkResult(nppiMinIndx_16u_AC4RNative(pSrc, nSrcStep, oSizeROI, pDeviceBuffer, aMin, aIndexX, aIndexY));
    }
    private static native int nppiMinIndx_16u_AC4RNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        short[] aMin, 
        int[] aIndexX, 
        int[] aIndexY);


    /**
     * <pre>
     * 4-channel 16-bit signed short integer image min values with their X and Y coordinates (alpha channel is not processed).
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer
     *        Use \ref nppiMinIndxGetBufferHostSize_16s_AC4R to determine the minium number of bytes required.
     * @param aMin Device-memory array receiving the minimum result, three elements for the three channels.
     * @param aIndexX Device-memory array to the X coordinates of the image min values, three elements for the three channels.
     * @param aIndexY Device-memory array to the Y coordinates of the image min values, three elements for the three channels.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMinIndx_16s_AC4R(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        short[] aMin, 
        int[] aIndexX, 
        int[] aIndexY)
    {
        return JNpp.checkResult(nppiMinIndx_16s_AC4RNative(pSrc, nSrcStep, oSizeROI, pDeviceBuffer, aMin, aIndexX, aIndexY));
    }
    private static native int nppiMinIndx_16s_AC4RNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        short[] aMin, 
        int[] aIndexX, 
        int[] aIndexY);


    public static int nppiMinIndx_32f_AC4R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        float[] aMin, 
        int[] aIndexX, 
        int[] aIndexY)
    {
        return JNpp.checkResult(nppiMinIndx_32f_AC4RNative(pSrc, nSrcStep, oSizeROI, pDeviceBuffer, aMin, aIndexX, aIndexY));
    }
    private static native int nppiMinIndx_32f_AC4RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        float[] aMin, 
        int[] aIndexX, 
        int[] aIndexY);


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiMax_8u_C1R.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiMaxGetBufferHostSize_8u_C1R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiMaxGetBufferHostSize_8u_C1RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiMaxGetBufferHostSize_8u_C1RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiMax_16u_C1R.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiMaxGetBufferHostSize_16u_C1R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiMaxGetBufferHostSize_16u_C1RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiMaxGetBufferHostSize_16u_C1RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);


    public static int nppiMaxGetBufferHostSize_16s_C1R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiMaxGetBufferHostSize_16s_C1RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiMaxGetBufferHostSize_16s_C1RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiMax_32f_C1R.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiMaxGetBufferHostSize_32f_C1R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiMaxGetBufferHostSize_32f_C1RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiMaxGetBufferHostSize_32f_C1RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiMax_8u_C3R.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiMaxGetBufferHostSize_8u_C3R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)/** host pointer */
    {
        return JNpp.checkResult(nppiMaxGetBufferHostSize_8u_C3RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiMaxGetBufferHostSize_8u_C3RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);/** host pointer */


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiMax_16u_C3R.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiMaxGetBufferHostSize_16u_C3R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)/** host pointer */
    {
        return JNpp.checkResult(nppiMaxGetBufferHostSize_16u_C3RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiMaxGetBufferHostSize_16u_C3RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);/** host pointer */


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiMax_16s_C3R.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiMaxGetBufferHostSize_16s_C3R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiMaxGetBufferHostSize_16s_C3RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiMaxGetBufferHostSize_16s_C3RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiMax_32f_C3R.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiMaxGetBufferHostSize_32f_C3R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiMaxGetBufferHostSize_32f_C3RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiMaxGetBufferHostSize_32f_C3RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiMax_8u_C4R.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiMaxGetBufferHostSize_8u_C4R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)/** host pointer */
    {
        return JNpp.checkResult(nppiMaxGetBufferHostSize_8u_C4RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiMaxGetBufferHostSize_8u_C4RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);/** host pointer */


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiMax_16u_C4R.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiMaxGetBufferHostSize_16u_C4R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)/** host pointer */
    {
        return JNpp.checkResult(nppiMaxGetBufferHostSize_16u_C4RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiMaxGetBufferHostSize_16u_C4RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);/** host pointer */


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiMax_16s_C4R.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiMaxGetBufferHostSize_16s_C4R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiMaxGetBufferHostSize_16s_C4RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiMaxGetBufferHostSize_16s_C4RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiMax_32f_C4R.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiMaxGetBufferHostSize_32f_C4R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiMaxGetBufferHostSize_32f_C4RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiMaxGetBufferHostSize_32f_C4RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiMax_8u_AC4R.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiMaxGetBufferHostSize_8u_AC4R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiMaxGetBufferHostSize_8u_AC4RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiMaxGetBufferHostSize_8u_AC4RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiMax_16u_AC4R.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiMaxGetBufferHostSize_16u_AC4R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiMaxGetBufferHostSize_16u_AC4RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiMaxGetBufferHostSize_16u_AC4RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);


    public static int nppiMaxGetBufferHostSize_16s_AC4R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiMaxGetBufferHostSize_16s_AC4RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiMaxGetBufferHostSize_16s_AC4RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiMax_32f_AC4R.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiMaxGetBufferHostSize_32f_AC4R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiMaxGetBufferHostSize_32f_AC4RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiMaxGetBufferHostSize_32f_AC4RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);


    public static int nppiMax_8u_C1R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        TypedPointer<Npp8u> pMax)
    {
        return JNpp.checkResult(nppiMax_8u_C1RNative(pSrc, nSrcStep, oSizeROI, pDeviceBuffer, pMax));
    }
    private static native int nppiMax_8u_C1RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        TypedPointer<Npp8u> pMax);


    /**
     * <pre>
     * 1-channel 16-bit unsigned short integer image max.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer
     *        Use \ref nppiMaxGetBufferHostSize_16u_C1R to determine the minium number of bytes required.
     * @param pMax Device-memory pointer receiving the maximum result.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMax_16u_C1R(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        TypedPointer<Npp16u> pMax)
    {
        return JNpp.checkResult(nppiMax_16u_C1RNative(pSrc, nSrcStep, oSizeROI, pDeviceBuffer, pMax));
    }
    private static native int nppiMax_16u_C1RNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        TypedPointer<Npp16u> pMax);


    /**
     * <pre>
     * 1-channel 16-bit signed short integer image max.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer
     *        Use \ref nppiMaxGetBufferHostSize_16s_C1R to determine the minium number of bytes required.
     * @param pMax Device-memory pointer receiving the maximum result.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMax_16s_C1R(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        TypedPointer<Npp16s> pMax)
    {
        return JNpp.checkResult(nppiMax_16s_C1RNative(pSrc, nSrcStep, oSizeROI, pDeviceBuffer, pMax));
    }
    private static native int nppiMax_16s_C1RNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        TypedPointer<Npp16s> pMax);


    /**
     * <pre>
     * 1-channel 32-bit floating point image max.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer
     *        Use \ref nppiMaxGetBufferHostSize_32f_C1R to determine the minium number of bytes required.
     * @param pMax Device-memory pointer receiving the maximum result.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMax_32f_C1R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        TypedPointer<Npp32f> pMax)
    {
        return JNpp.checkResult(nppiMax_32f_C1RNative(pSrc, nSrcStep, oSizeROI, pDeviceBuffer, pMax));
    }
    private static native int nppiMax_32f_C1RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        TypedPointer<Npp32f> pMax);


    /**
     * <pre>
     * 3-channel 8-bit unsigned char image max.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer
     *        Use \ref nppiMaxGetBufferHostSize_8u_C3R to determine the minium number of bytes required.
     * @param aMax Device-memory array receiving the maximum results, three elements for three channels.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMax_8u_C3R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        byte[] aMax)
    {
        return JNpp.checkResult(nppiMax_8u_C3RNative(pSrc, nSrcStep, oSizeROI, pDeviceBuffer, aMax));
    }
    private static native int nppiMax_8u_C3RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        byte[] aMax);


    /**
     * <pre>
     * 3-channel 16-bit unsigned short integer image max.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer
     *        Use \ref nppiMaxGetBufferHostSize_16u_C3R to determine the minium number of bytes required.
     * @param aMax Device-memory array receiving the maximum results, three elements for three channels.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMax_16u_C3R(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        short[] aMax)
    {
        return JNpp.checkResult(nppiMax_16u_C3RNative(pSrc, nSrcStep, oSizeROI, pDeviceBuffer, aMax));
    }
    private static native int nppiMax_16u_C3RNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        short[] aMax);


    /**
     * <pre>
     * 3-channel 16-bit signed short integer image max.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer
     *        Use \ref nppiMaxGetBufferHostSize_16s_C3R to determine the minium number of bytes required.
     * @param aMax Device-memory array receiving the maximum results, three elements for three channels.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMax_16s_C3R(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        short[] aMax)
    {
        return JNpp.checkResult(nppiMax_16s_C3RNative(pSrc, nSrcStep, oSizeROI, pDeviceBuffer, aMax));
    }
    private static native int nppiMax_16s_C3RNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        short[] aMax);


    /**
     * <pre>
     * 3-channel 32-bit floating point image max.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer
     *        Use \ref nppiMaxGetBufferHostSize_32f_C3R to determine the minium number of bytes required.
     * @param aMax Device-memory array receiving the maximum results, three elements for three channels.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMax_32f_C3R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        float[] aMax)
    {
        return JNpp.checkResult(nppiMax_32f_C3RNative(pSrc, nSrcStep, oSizeROI, pDeviceBuffer, aMax));
    }
    private static native int nppiMax_32f_C3RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        float[] aMax);


    /**
     * <pre>
     * 4-channel 8-bit unsigned char image max.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer
     *        Use \ref nppiMaxGetBufferHostSize_8u_C4R to determine the minium number of bytes required.
     * @param aMax Device-memory array receiving the maximum results, four elements for four channels.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMax_8u_C4R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        byte[] aMax)
    {
        return JNpp.checkResult(nppiMax_8u_C4RNative(pSrc, nSrcStep, oSizeROI, pDeviceBuffer, aMax));
    }
    private static native int nppiMax_8u_C4RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        byte[] aMax);


    /**
     * <pre>
     * 4-channel 16-bit unsigned short integer image max.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer
     *        Use \ref nppiMaxGetBufferHostSize_16u_C4R to determine the minium number of bytes required.
     * @param aMax Device-memory array receiving the maximum results, four elements for four channels.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMax_16u_C4R(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        short[] aMax)
    {
        return JNpp.checkResult(nppiMax_16u_C4RNative(pSrc, nSrcStep, oSizeROI, pDeviceBuffer, aMax));
    }
    private static native int nppiMax_16u_C4RNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        short[] aMax);


    public static int nppiMax_16s_C4R(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        short[] aMax)
    {
        return JNpp.checkResult(nppiMax_16s_C4RNative(pSrc, nSrcStep, oSizeROI, pDeviceBuffer, aMax));
    }
    private static native int nppiMax_16s_C4RNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        short[] aMax);


    /**
     * <pre>
     * 4-channel 32-bit floating point image max.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer
     *        Use \ref nppiMaxGetBufferHostSize_32f_C4R to determine the minium number of bytes required.
     * @param aMax Device-memory array receiving the maximum results, four elements for four channels.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMax_32f_C4R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        float[] aMax)
    {
        return JNpp.checkResult(nppiMax_32f_C4RNative(pSrc, nSrcStep, oSizeROI, pDeviceBuffer, aMax));
    }
    private static native int nppiMax_32f_C4RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        float[] aMax);


    /**
     * <pre>
     * 4-channel 8-bit unsigned char image max (alpha channel is not processed).
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer
     *        Use \ref nppiMaxGetBufferHostSize_8u_AC4R to determine the minium number of bytes required.
     * @param aMax Device-memory array receiving the maximum result, three elements for the first three channels.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMax_8u_AC4R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        byte[] aMax)
    {
        return JNpp.checkResult(nppiMax_8u_AC4RNative(pSrc, nSrcStep, oSizeROI, pDeviceBuffer, aMax));
    }
    private static native int nppiMax_8u_AC4RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        byte[] aMax);


    /**
     * <pre>
     * 4-channel 16-bit unsigned short integer image max (alpha channel is not processed).
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer
     *        Use \ref nppiMaxGetBufferHostSize_16u_AC4R to determine the minium number of bytes required.
     * @param aMax Device-memory array receiving the maximum result, three elements for the first three channels.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMax_16u_AC4R(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        short[] aMax)
    {
        return JNpp.checkResult(nppiMax_16u_AC4RNative(pSrc, nSrcStep, oSizeROI, pDeviceBuffer, aMax));
    }
    private static native int nppiMax_16u_AC4RNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        short[] aMax);


    /**
     * <pre>
     * 4-channel 16-bit signed short integer image max (alpha channel is not processed).
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer
     *        Use \ref nppiMaxGetBufferHostSize_16s_AC4R to determine the minium number of bytes required.
     * @param aMax Device-memory array receiving the maximum result, three elements for the first three channels.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMax_16s_AC4R(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        short[] aMax)
    {
        return JNpp.checkResult(nppiMax_16s_AC4RNative(pSrc, nSrcStep, oSizeROI, pDeviceBuffer, aMax));
    }
    private static native int nppiMax_16s_AC4RNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        short[] aMax);


    /**
     * <pre>
     * 4-channel 32-bit floating point image max (alpha channel is not processed).
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer
     *        Use \ref nppiMaxGetBufferHostSize_32f_AC4R to determine the minium number of bytes required.
     * @param aMax Device-memory array receiving the maximum result, three elements for the first three channels.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMax_32f_AC4R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        float[] aMax)
    {
        return JNpp.checkResult(nppiMax_32f_AC4RNative(pSrc, nSrcStep, oSizeROI, pDeviceBuffer, aMax));
    }
    private static native int nppiMax_32f_AC4RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        float[] aMax);


    public static int nppiMaxIndxGetBufferHostSize_8u_C1R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiMaxIndxGetBufferHostSize_8u_C1RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiMaxIndxGetBufferHostSize_8u_C1RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiMaxIndx_16u_C1R.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiMaxIndxGetBufferHostSize_16u_C1R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiMaxIndxGetBufferHostSize_16u_C1RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiMaxIndxGetBufferHostSize_16u_C1RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiMaxIndx_16s_C1R.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiMaxIndxGetBufferHostSize_16s_C1R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiMaxIndxGetBufferHostSize_16s_C1RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiMaxIndxGetBufferHostSize_16s_C1RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiMaxIndx_32f_C1R.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiMaxIndxGetBufferHostSize_32f_C1R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiMaxIndxGetBufferHostSize_32f_C1RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiMaxIndxGetBufferHostSize_32f_C1RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);


    public static int nppiMaxIndxGetBufferHostSize_8u_C3R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)/** host pointer */
    {
        return JNpp.checkResult(nppiMaxIndxGetBufferHostSize_8u_C3RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiMaxIndxGetBufferHostSize_8u_C3RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);/** host pointer */


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiMaxIndx_16u_C3R.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiMaxIndxGetBufferHostSize_16u_C3R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)/** host pointer */
    {
        return JNpp.checkResult(nppiMaxIndxGetBufferHostSize_16u_C3RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiMaxIndxGetBufferHostSize_16u_C3RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);/** host pointer */


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiMaxIndx_16s_C3R.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiMaxIndxGetBufferHostSize_16s_C3R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiMaxIndxGetBufferHostSize_16s_C3RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiMaxIndxGetBufferHostSize_16s_C3RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiMaxIndx_32f_C3R.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiMaxIndxGetBufferHostSize_32f_C3R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiMaxIndxGetBufferHostSize_32f_C3RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiMaxIndxGetBufferHostSize_32f_C3RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiMaxIndx_8u_C4R.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiMaxIndxGetBufferHostSize_8u_C4R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiMaxIndxGetBufferHostSize_8u_C4RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiMaxIndxGetBufferHostSize_8u_C4RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiMaxIndx_16u_C4R.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiMaxIndxGetBufferHostSize_16u_C4R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiMaxIndxGetBufferHostSize_16u_C4RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiMaxIndxGetBufferHostSize_16u_C4RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiMaxIndx_16s_C4R.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiMaxIndxGetBufferHostSize_16s_C4R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiMaxIndxGetBufferHostSize_16s_C4RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiMaxIndxGetBufferHostSize_16s_C4RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiMaxIndx_32f_C4R.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiMaxIndxGetBufferHostSize_32f_C4R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiMaxIndxGetBufferHostSize_32f_C4RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiMaxIndxGetBufferHostSize_32f_C4RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiMaxIndx_8u_AC4R.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiMaxIndxGetBufferHostSize_8u_AC4R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)/** host pointer */
    {
        return JNpp.checkResult(nppiMaxIndxGetBufferHostSize_8u_AC4RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiMaxIndxGetBufferHostSize_8u_AC4RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);/** host pointer */


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiMaxIndx_16u_AC4R.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiMaxIndxGetBufferHostSize_16u_AC4R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)/** host pointer */
    {
        return JNpp.checkResult(nppiMaxIndxGetBufferHostSize_16u_AC4RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiMaxIndxGetBufferHostSize_16u_AC4RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);/** host pointer */


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiMaxIndx_16s_AC4R.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiMaxIndxGetBufferHostSize_16s_AC4R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiMaxIndxGetBufferHostSize_16s_AC4RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiMaxIndxGetBufferHostSize_16s_AC4RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiMaxIndx_32f_AC4R.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiMaxIndxGetBufferHostSize_32f_AC4R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiMaxIndxGetBufferHostSize_32f_AC4RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiMaxIndxGetBufferHostSize_32f_AC4RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);


    /**
     * <pre>
     * 1-channel 8-bit unsigned char image max value with its X and Y coordinates.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer
     *        Use \ref nppiMaxIndxGetBufferHostSize_8u_C1R to determine the minium number of bytes required.
     * @param pMax Device-memory pointer receiving the maximum result.
     * @param pIndexX Device-memory pointer to the X coordinate of the image max value.
     * @param pIndexY Device-memory pointer to the Y coordinate of the image max value.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMaxIndx_8u_C1R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        TypedPointer<Npp8u> pMax, 
        int[] pIndexX, 
        int[] pIndexY)
    {
        return JNpp.checkResult(nppiMaxIndx_8u_C1RNative(pSrc, nSrcStep, oSizeROI, pDeviceBuffer, pMax, pIndexX, pIndexY));
    }
    private static native int nppiMaxIndx_8u_C1RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        TypedPointer<Npp8u> pMax, 
        int[] pIndexX, 
        int[] pIndexY);


    /**
     * <pre>
     * 1-channel 16-bit unsigned short integer image max value with its X and Y coordinates.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer
     *        Use \ref nppiMaxIndxGetBufferHostSize_16u_C1R to determine the minium number of bytes required.
     * @param pMax Device-memory pointer receiving the maximum result.
     * @param pIndexX Device-memory pointer to the X coordinate of the image max value.
     * @param pIndexY Device-memory pointer to the Y coordinate of the image max value.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMaxIndx_16u_C1R(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        TypedPointer<Npp16u> pMax, 
        int[] pIndexX, 
        int[] pIndexY)
    {
        return JNpp.checkResult(nppiMaxIndx_16u_C1RNative(pSrc, nSrcStep, oSizeROI, pDeviceBuffer, pMax, pIndexX, pIndexY));
    }
    private static native int nppiMaxIndx_16u_C1RNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        TypedPointer<Npp16u> pMax, 
        int[] pIndexX, 
        int[] pIndexY);


    /**
     * <pre>
     * 1-channel 16-bit signed short integer image max value with its X and Y coordinates.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer
     *        Use \ref nppiMaxIndxGetBufferHostSize_16s_C1R to determine the minium number of bytes required.
     * @param pMax Device-memory pointer receiving the maximum result.
     * @param pIndexX Device-memory pointer to the X coordinate of the image max value.
     * @param pIndexY Device-memory pointer to the Y coordinate of the image max value.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMaxIndx_16s_C1R(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        TypedPointer<Npp16s> pMax, 
        int[] pIndexX, 
        int[] pIndexY)
    {
        return JNpp.checkResult(nppiMaxIndx_16s_C1RNative(pSrc, nSrcStep, oSizeROI, pDeviceBuffer, pMax, pIndexX, pIndexY));
    }
    private static native int nppiMaxIndx_16s_C1RNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        TypedPointer<Npp16s> pMax, 
        int[] pIndexX, 
        int[] pIndexY);


    public static int nppiMaxIndx_32f_C1R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        TypedPointer<Npp32f> pMax, 
        int[] pIndexX, 
        int[] pIndexY)
    {
        return JNpp.checkResult(nppiMaxIndx_32f_C1RNative(pSrc, nSrcStep, oSizeROI, pDeviceBuffer, pMax, pIndexX, pIndexY));
    }
    private static native int nppiMaxIndx_32f_C1RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        TypedPointer<Npp32f> pMax, 
        int[] pIndexX, 
        int[] pIndexY);


    /**
     * <pre>
     * 3-channel 8-bit unsigned char image max values with their X and Y coordinates.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer
     *        Use \ref nppiMaxIndxGetBufferHostSize_8u_C3R to determine the minium number of bytes required.
     * @param aMax Device-memory array receiving the maximum result, three elements for three channels.
     * @param aIndexX Device-memory array to the X coordinates of the image max values, three elements for three channels.
     * @param aIndexY Device-memory array to the Y coordinates of the image max values, three elements for three channels.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMaxIndx_8u_C3R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        byte[] aMax, 
        int[] aIndexX, 
        int[] aIndexY)
    {
        return JNpp.checkResult(nppiMaxIndx_8u_C3RNative(pSrc, nSrcStep, oSizeROI, pDeviceBuffer, aMax, aIndexX, aIndexY));
    }
    private static native int nppiMaxIndx_8u_C3RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        byte[] aMax, 
        int[] aIndexX, 
        int[] aIndexY);


    /**
     * <pre>
     * 3-channel 16-bit unsigned short integer image max values with their X and Y coordinates.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer
     *        Use \ref nppiMaxIndxGetBufferHostSize_16u_C3R to determine the minium number of bytes required.
     * @param aMax Device-memory array receiving the maximum result, three elements for three channels.
     * @param aIndexX Device-memory array to the X coordinates of the image max values, three elements for three channels.
     * @param aIndexY Device-memory array to the Y coordinates of the image max values, three elements for three channels.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMaxIndx_16u_C3R(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        short[] aMax, 
        int[] aIndexX, 
        int[] aIndexY)
    {
        return JNpp.checkResult(nppiMaxIndx_16u_C3RNative(pSrc, nSrcStep, oSizeROI, pDeviceBuffer, aMax, aIndexX, aIndexY));
    }
    private static native int nppiMaxIndx_16u_C3RNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        short[] aMax, 
        int[] aIndexX, 
        int[] aIndexY);


    /**
     * <pre>
     * 3-channel 16-bit signed short integer image max values with their X and Y coordinates.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer
     *        Use \ref nppiMaxIndxGetBufferHostSize_16s_C3R to determine the minium number of bytes required.
     * @param aMax Device-memory array receiving the maximum result, three elements for three channels.
     * @param aIndexX Device-memory array to the X coordinates of the image max values, three elements for three channels.
     * @param aIndexY Device-memory array to the Y coordinates of the image max values, three elements for three channels.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMaxIndx_16s_C3R(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        short[] aMax, 
        int[] aIndexX, 
        int[] aIndexY)
    {
        return JNpp.checkResult(nppiMaxIndx_16s_C3RNative(pSrc, nSrcStep, oSizeROI, pDeviceBuffer, aMax, aIndexX, aIndexY));
    }
    private static native int nppiMaxIndx_16s_C3RNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        short[] aMax, 
        int[] aIndexX, 
        int[] aIndexY);


    /**
     * <pre>
     * 3-channel 32-bit floating point image max values with their X and Y coordinates.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer
     *        Use \ref nppiMaxIndxGetBufferHostSize_32f_C3R to determine the minium number of bytes required.
     * @param aMax Device-memory array receiving the maximum result, three elements for three channels.
     * @param aIndexX Device-memory array to the X coordinates of the image max values, three elements for three channels.
     * @param aIndexY Device-memory array to the Y coordinates of the image max values, three elements for three channels.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMaxIndx_32f_C3R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        float[] aMax, 
        int[] aIndexX, 
        int[] aIndexY)
    {
        return JNpp.checkResult(nppiMaxIndx_32f_C3RNative(pSrc, nSrcStep, oSizeROI, pDeviceBuffer, aMax, aIndexX, aIndexY));
    }
    private static native int nppiMaxIndx_32f_C3RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        float[] aMax, 
        int[] aIndexX, 
        int[] aIndexY);


    public static int nppiMaxIndx_8u_C4R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        byte[] aMax, 
        int[] aIndexX, 
        int[] aIndexY)
    {
        return JNpp.checkResult(nppiMaxIndx_8u_C4RNative(pSrc, nSrcStep, oSizeROI, pDeviceBuffer, aMax, aIndexX, aIndexY));
    }
    private static native int nppiMaxIndx_8u_C4RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        byte[] aMax, 
        int[] aIndexX, 
        int[] aIndexY);


    /**
     * <pre>
     * 4-channel 16-bit unsigned short integer image max values with their X and Y coordinates.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer
     *        Use \ref nppiMaxIndxGetBufferHostSize_16u_C4R to determine the minium number of bytes required.
     * @param aMax Device-memory array receiving the maximum result, four elements for four channels.
     * @param aIndexX Device-memory array to the X coordinates of the image max values, four elements for four channels.
     * @param aIndexY Device-memory array to the Y coordinates of the image max values, four elements for four channels.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMaxIndx_16u_C4R(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        short[] aMax, 
        int[] aIndexX, 
        int[] aIndexY)
    {
        return JNpp.checkResult(nppiMaxIndx_16u_C4RNative(pSrc, nSrcStep, oSizeROI, pDeviceBuffer, aMax, aIndexX, aIndexY));
    }
    private static native int nppiMaxIndx_16u_C4RNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        short[] aMax, 
        int[] aIndexX, 
        int[] aIndexY);


    /**
     * <pre>
     * 4-channel 16-bit signed short integer image max values with their X and Y coordinates.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer
     *        Use \ref nppiMaxIndxGetBufferHostSize_16s_C4R to determine the minium number of bytes required.
     * @param aMax Device-memory array receiving the maximum result, four elements for four channels.
     * @param aIndexX Device-memory array to the X coordinates of the image max values, four elements for four channels.
     * @param aIndexY Device-memory array to the Y coordinates of the image max values, four elements for four channels.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMaxIndx_16s_C4R(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        short[] aMax, 
        int[] aIndexX, 
        int[] aIndexY)
    {
        return JNpp.checkResult(nppiMaxIndx_16s_C4RNative(pSrc, nSrcStep, oSizeROI, pDeviceBuffer, aMax, aIndexX, aIndexY));
    }
    private static native int nppiMaxIndx_16s_C4RNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        short[] aMax, 
        int[] aIndexX, 
        int[] aIndexY);


    /**
     * <pre>
     * 4-channel 32-bit floating point image max values with their X and Y coordinates.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer
     *        Use \ref nppiMaxIndxGetBufferHostSize_32f_C4R to determine the minium number of bytes required.
     * @param aMax Device-memory array receiving the maximum result, four elements for four channels.
     * @param aIndexX Device-memory array to the X coordinates of the image max values, four elements for four channels.
     * @param aIndexY Device-memory array to the Y coordinates of the image max values, four elements for four channels.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMaxIndx_32f_C4R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        float[] aMax, 
        int[] aIndexX, 
        int[] aIndexY)
    {
        return JNpp.checkResult(nppiMaxIndx_32f_C4RNative(pSrc, nSrcStep, oSizeROI, pDeviceBuffer, aMax, aIndexX, aIndexY));
    }
    private static native int nppiMaxIndx_32f_C4RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        float[] aMax, 
        int[] aIndexX, 
        int[] aIndexY);


    /**
     * <pre>
     * 4-channel 8-bit unsigned char image max values with their X and Y coordinates (alpha channel is not processed).
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer
     *        Use \ref nppiMaxIndxGetBufferHostSize_8u_AC4R to determine the minium number of bytes required.
     * @param aMax Device-memory array receiving the maximum result, three elements for the first three channels.
     * @param aIndexX Device-memory array to the X coordinates of the image max values, three elements for the first three channels.
     * @param aIndexY Device-memory array to the Y coordinates of the image max values, three elements for the first three channels.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMaxIndx_8u_AC4R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        byte[] aMax, 
        int[] aIndexX, 
        int[] aIndexY)
    {
        return JNpp.checkResult(nppiMaxIndx_8u_AC4RNative(pSrc, nSrcStep, oSizeROI, pDeviceBuffer, aMax, aIndexX, aIndexY));
    }
    private static native int nppiMaxIndx_8u_AC4RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        byte[] aMax, 
        int[] aIndexX, 
        int[] aIndexY);


    /**
     * <pre>
     * 4-channel 16-bit unsigned short integer image max values with their X and Y coordinates (alpha channel is not processed).
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer
     *        Use \ref nppiMaxIndxGetBufferHostSize_16u_AC4R to determine the minium number of bytes required.
     * @param aMax Device-memory array receiving the maximum result, three elements for the first three channels.
     * @param aIndexX Device-memory array to the X coordinates of the image max values, three elements for the first three channels.
     * @param aIndexY Device-memory array to the Y coordinates of the image max values, three elements for the first three channels.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMaxIndx_16u_AC4R(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        short[] aMax, 
        int[] aIndexX, 
        int[] aIndexY)
    {
        return JNpp.checkResult(nppiMaxIndx_16u_AC4RNative(pSrc, nSrcStep, oSizeROI, pDeviceBuffer, aMax, aIndexX, aIndexY));
    }
    private static native int nppiMaxIndx_16u_AC4RNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        short[] aMax, 
        int[] aIndexX, 
        int[] aIndexY);


    /**
     * <pre>
     * 4-channel 16-bit signed short integer image max values with their X and Y coordinates (alpha channel is not processed).
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer
     *        Use \ref nppiMaxIndxGetBufferHostSize_16s_AC4R to determine the minium number of bytes required.
     * @param aMax Device-memory array receiving the maximum result, three elements for the first three channels.
     * @param aIndexX Device-memory array to the X coordinates of the image max values, three elements for the first three channels.
     * @param aIndexY Device-memory array to the Y coordinates of the image max values, three elements for the first three channels.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMaxIndx_16s_AC4R(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        short[] aMax, 
        int[] aIndexX, 
        int[] aIndexY)
    {
        return JNpp.checkResult(nppiMaxIndx_16s_AC4RNative(pSrc, nSrcStep, oSizeROI, pDeviceBuffer, aMax, aIndexX, aIndexY));
    }
    private static native int nppiMaxIndx_16s_AC4RNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        short[] aMax, 
        int[] aIndexX, 
        int[] aIndexY);


    /**
     * <pre>
     * 4-channel 32-bit floating point image max values with their X and Y coordinates (alpha channel is not processed).
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer
     *        Use \ref nppiMaxIndxGetBufferHostSize_32f_AC4R to determine the minium number of bytes required.
     * @param aMax Device-memory array receiving the maximum result, three elements for the first three channels.
     * @param aIndexX Device-memory array to the X coordinates of the image max values, three elements for the first three channels.
     * @param aIndexY Device-memory array to the Y coordinates of the image max values, three elements for the first three channels.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMaxIndx_32f_AC4R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        float[] aMax, 
        int[] aIndexX, 
        int[] aIndexY)
    {
        return JNpp.checkResult(nppiMaxIndx_32f_AC4RNative(pSrc, nSrcStep, oSizeROI, pDeviceBuffer, aMax, aIndexX, aIndexY));
    }
    private static native int nppiMaxIndx_32f_AC4RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        float[] aMax, 
        int[] aIndexX, 
        int[] aIndexY);


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiMinManx_8u_C1R.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiMinMaxGetBufferHostSize_8u_C1R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)/** host pointer */
    {
        return JNpp.checkResult(nppiMinMaxGetBufferHostSize_8u_C1RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiMinMaxGetBufferHostSize_8u_C1RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);/** host pointer */


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiMinManx_16u_C1R.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiMinMaxGetBufferHostSize_16u_C1R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiMinMaxGetBufferHostSize_16u_C1RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiMinMaxGetBufferHostSize_16u_C1RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiMinManx_16s_C1R.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiMinMaxGetBufferHostSize_16s_C1R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiMinMaxGetBufferHostSize_16s_C1RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiMinMaxGetBufferHostSize_16s_C1RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiMinManx_32f_C1R.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiMinMaxGetBufferHostSize_32f_C1R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiMinMaxGetBufferHostSize_32f_C1RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiMinMaxGetBufferHostSize_32f_C1RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);


    public static int nppiMinMaxGetBufferHostSize_8u_C3R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)/** host pointer */
    {
        return JNpp.checkResult(nppiMinMaxGetBufferHostSize_8u_C3RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiMinMaxGetBufferHostSize_8u_C3RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);/** host pointer */


    public static int nppiMinMaxGetBufferHostSize_16u_C3R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiMinMaxGetBufferHostSize_16u_C3RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiMinMaxGetBufferHostSize_16u_C3RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiMinManx_16s_C3R.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiMinMaxGetBufferHostSize_16s_C3R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiMinMaxGetBufferHostSize_16s_C3RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiMinMaxGetBufferHostSize_16s_C3RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiMinManx_32f_C3R.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiMinMaxGetBufferHostSize_32f_C3R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)/** host pointer */
    {
        return JNpp.checkResult(nppiMinMaxGetBufferHostSize_32f_C3RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiMinMaxGetBufferHostSize_32f_C3RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);/** host pointer */


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiMinManx_8u_AC4R.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiMinMaxGetBufferHostSize_8u_AC4R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)/** host pointer */
    {
        return JNpp.checkResult(nppiMinMaxGetBufferHostSize_8u_AC4RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiMinMaxGetBufferHostSize_8u_AC4RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);/** host pointer */


    public static int nppiMinMaxGetBufferHostSize_16u_AC4R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiMinMaxGetBufferHostSize_16u_AC4RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiMinMaxGetBufferHostSize_16u_AC4RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiMinManx_16s_AC4R.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiMinMaxGetBufferHostSize_16s_AC4R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)/** host pointer */
    {
        return JNpp.checkResult(nppiMinMaxGetBufferHostSize_16s_AC4RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiMinMaxGetBufferHostSize_16s_AC4RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);/** host pointer */


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiMinManx_32f_AC4R.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiMinMaxGetBufferHostSize_32f_AC4R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiMinMaxGetBufferHostSize_32f_AC4RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiMinMaxGetBufferHostSize_32f_AC4RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiMinManx_8u_C4R.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiMinMaxGetBufferHostSize_8u_C4R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)/** host pointer */
    {
        return JNpp.checkResult(nppiMinMaxGetBufferHostSize_8u_C4RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiMinMaxGetBufferHostSize_8u_C4RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);/** host pointer */


    public static int nppiMinMaxGetBufferHostSize_16u_C4R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiMinMaxGetBufferHostSize_16u_C4RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiMinMaxGetBufferHostSize_16u_C4RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiMinManx_16s_C4R.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiMinMaxGetBufferHostSize_16s_C4R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiMinMaxGetBufferHostSize_16s_C4RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiMinMaxGetBufferHostSize_16s_C4RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiMinManx_32f_C4R.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiMinMaxGetBufferHostSize_32f_C4R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)/** host pointer */
    {
        return JNpp.checkResult(nppiMinMaxGetBufferHostSize_32f_C4RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiMinMaxGetBufferHostSize_32f_C4RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);/** host pointer */


    public static int nppiMinMax_8u_C1R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMin, 
        TypedPointer<Npp8u> pMax, 
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppiMinMax_8u_C1RNative(pSrc, nSrcStep, oSizeROI, pMin, pMax, pDeviceBuffer));
    }
    private static native int nppiMinMax_8u_C1RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMin, 
        TypedPointer<Npp8u> pMax, 
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 1-channel 16-bit unsigned short image minimum and maximum values.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pMin Device-memory pointer receiving the minimum result.
     * @param pMax Device-memory pointer receiving the maximum result.
     * @param pDeviceBuffer Buffer to a scratch memory. Use \ref nppiMinMaxGetBufferHostSize_16u_C1R to determine
     *          the minium number of bytes required.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMinMax_16u_C1R(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp16u> pMin, 
        TypedPointer<Npp16u> pMax, 
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppiMinMax_16u_C1RNative(pSrc, nSrcStep, oSizeROI, pMin, pMax, pDeviceBuffer));
    }
    private static native int nppiMinMax_16u_C1RNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp16u> pMin, 
        TypedPointer<Npp16u> pMax, 
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 1-channel 16-bit signed short image minimum and maximum values.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pMin Device-memory pointer receiving the minimum result.
     * @param pMax Device-memory pointer receiving the maximum result.
     * @param pDeviceBuffer Buffer to a scratch memory. Use \ref nppiMinMaxGetBufferHostSize_16s_C1R to determine
     *          the minium number of bytes required.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMinMax_16s_C1R(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp16s> pMin, 
        TypedPointer<Npp16s> pMax, 
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppiMinMax_16s_C1RNative(pSrc, nSrcStep, oSizeROI, pMin, pMax, pDeviceBuffer));
    }
    private static native int nppiMinMax_16s_C1RNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp16s> pMin, 
        TypedPointer<Npp16s> pMax, 
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 1-channel 32-bit floating point image minimum and maximum values.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pMin Device-memory pointer receiving the minimum result.
     * @param pMax Device-memory pointer receiving the maximum result.
     * @param pDeviceBuffer Buffer to a scratch memory. Use \ref nppiMinMaxGetBufferHostSize_32f_C1R to determine
     *          the minium number of bytes required.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMinMax_32f_C1R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp32f> pMin, 
        TypedPointer<Npp32f> pMax, 
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppiMinMax_32f_C1RNative(pSrc, nSrcStep, oSizeROI, pMin, pMax, pDeviceBuffer));
    }
    private static native int nppiMinMax_32f_C1RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp32f> pMin, 
        TypedPointer<Npp32f> pMax, 
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 3-channel 8-bit unsigned image minimum and maximum  values.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param aMin Device-memory array receiving the minimum result, three elements for three channels.
     * @param aMax Device-memory array receiving the maximum result, three elements for three channels.
     * @param pDeviceBuffer Buffer to a scratch memory. Use \ref nppiMinMaxGetBufferHostSize_8u_C3R to determine
     *          the minium number of bytes required.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMinMax_8u_C3R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        byte[] aMin, 
        byte[] aMax, 
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppiMinMax_8u_C3RNative(pSrc, nSrcStep, oSizeROI, aMin, aMax, pDeviceBuffer));
    }
    private static native int nppiMinMax_8u_C3RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        byte[] aMin, 
        byte[] aMax, 
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 3-channel 16-bit unsigned short image minimum and maximum values.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param aMin Device-memory array receiving the minimum result, three elements for three channels.
     * @param aMax Device-memory array receiving the maximum result, three elements for three channels.
     * @param pDeviceBuffer Buffer to a scratch memory. Use \ref nppiMinMaxGetBufferHostSize_16u_C3R to determine
     *          the minium number of bytes required.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMinMax_16u_C3R(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        short[] aMin, 
        short[] aMax, 
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppiMinMax_16u_C3RNative(pSrc, nSrcStep, oSizeROI, aMin, aMax, pDeviceBuffer));
    }
    private static native int nppiMinMax_16u_C3RNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        short[] aMin, 
        short[] aMax, 
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 3-channel 16-bit signed short image minimum and maximum values.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param aMin Device-memory array receiving the minimum result, three elements for three channels.
     * @param aMax Device-memory array receiving the maximum result, three elements for three channels.
     * @param pDeviceBuffer Buffer to a scratch memory. Use \ref nppiMinMaxGetBufferHostSize_16s_C3R to determine
     *          the minium number of bytes required.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMinMax_16s_C3R(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        short[] aMin, 
        short[] aMax, 
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppiMinMax_16s_C3RNative(pSrc, nSrcStep, oSizeROI, aMin, aMax, pDeviceBuffer));
    }
    private static native int nppiMinMax_16s_C3RNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        short[] aMin, 
        short[] aMax, 
        TypedPointer<Npp8u> pDeviceBuffer);


    public static int nppiMinMax_32f_C3R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        float[] aMin, 
        float[] aMax, 
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppiMinMax_32f_C3RNative(pSrc, nSrcStep, oSizeROI, aMin, aMax, pDeviceBuffer));
    }
    private static native int nppiMinMax_32f_C3RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        float[] aMin, 
        float[] aMax, 
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 4-channel 8-bit unsigned image minimum and maximum values (alpha channel is not calculated).
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param aMin Device-memory array receiving the minimum result, three elements for the first three channels.
     * @param aMax Device-memory array receiving the maximum result, three elements for the first three channels.
     * @param pDeviceBuffer Buffer to a scratch memory. Use \ref nppiMinMaxGetBufferHostSize_8u_AC4R to determine
     *          the minium number of bytes required.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMinMax_8u_AC4R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        byte[] aMin, 
        byte[] aMax, 
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppiMinMax_8u_AC4RNative(pSrc, nSrcStep, oSizeROI, aMin, aMax, pDeviceBuffer));
    }
    private static native int nppiMinMax_8u_AC4RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        byte[] aMin, 
        byte[] aMax, 
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 4-channel 16-bit unsigned short image minimum and maximum values (alpha channel is not calculated).
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param aMin Device-memory array receiving the minimum result, three elements for the first three channels.
     * @param aMax Device-memory array receiving the maximum result, three elements for the first three channels.
     * @param pDeviceBuffer Buffer to a scratch memory. Use \ref nppiMinMaxGetBufferHostSize_16u_AC4R to determine
     *          the minium number of bytes required.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMinMax_16u_AC4R(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        short[] aMin, 
        short[] aMax, 
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppiMinMax_16u_AC4RNative(pSrc, nSrcStep, oSizeROI, aMin, aMax, pDeviceBuffer));
    }
    private static native int nppiMinMax_16u_AC4RNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        short[] aMin, 
        short[] aMax, 
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 4-channel 16-bit signed short image minimum and maximum values (alpha channel is not calculated).
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param aMin Device-memory array receiving the minimum result, three elements for the first three channels.
     * @param aMax Device-memory array receiving the maximum result, three elements for the first three channels.
     * @param pDeviceBuffer Buffer to a scratch memory. Use \ref nppiMinMaxGetBufferHostSize_16s_AC4R to determine
     *          the minium number of bytes required.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMinMax_16s_AC4R(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        short[] aMin, 
        short[] aMax, 
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppiMinMax_16s_AC4RNative(pSrc, nSrcStep, oSizeROI, aMin, aMax, pDeviceBuffer));
    }
    private static native int nppiMinMax_16s_AC4RNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        short[] aMin, 
        short[] aMax, 
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 4-channel 32-bit floating point image minimum and maximum values (alpha channel is not calculated).
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param aMin Device-memory array receiving the minimum result, three elements for the first three channels.
     * @param aMax Device-memory array receiving the maximum result, three elements for the first three channels.
     * @param pDeviceBuffer Buffer to a scratch memory. Use \ref nppiMinMaxGetBufferHostSize_32f_AC4R to determine
     *          the minium number of bytes required.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMinMax_32f_AC4R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        float[] aMin, 
        float[] aMax, 
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppiMinMax_32f_AC4RNative(pSrc, nSrcStep, oSizeROI, aMin, aMax, pDeviceBuffer));
    }
    private static native int nppiMinMax_32f_AC4RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        float[] aMin, 
        float[] aMax, 
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 4-channel 8-bit unsigned image minimum and maximum values.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param aMin Device-memory array receiving the minimum result, four elements for four channels.
     * @param aMax Device-memory array receiving the maximum result, four elements for four channels.
     * @param pDeviceBuffer Buffer to a scratch memory. Use \ref nppiMinMaxGetBufferHostSize_8u_C4R to determine
     *          the minium number of bytes required.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMinMax_8u_C4R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        byte[] aMin, 
        byte[] aMax, 
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppiMinMax_8u_C4RNative(pSrc, nSrcStep, oSizeROI, aMin, aMax, pDeviceBuffer));
    }
    private static native int nppiMinMax_8u_C4RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        byte[] aMin, 
        byte[] aMax, 
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 4-channel 16-bit unsigned short image minimum and maximum values.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param aMin Device-memory array receiving the minimum result, four elements for four channels.
     * @param aMax Device-memory array receiving the maximum result, four elements for four channels.
     * @param pDeviceBuffer Buffer to a scratch memory. Use \ref nppiMinMaxGetBufferHostSize_16u_C4R to determine
     *          the minium number of bytes required.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMinMax_16u_C4R(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        short[] aMin, 
        short[] aMax, 
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppiMinMax_16u_C4RNative(pSrc, nSrcStep, oSizeROI, aMin, aMax, pDeviceBuffer));
    }
    private static native int nppiMinMax_16u_C4RNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        short[] aMin, 
        short[] aMax, 
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 4-channel 16-bit signed short image minimum and maximum values.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param aMin Device-memory array receiving the minimum result, four elements for four channels.
     * @param aMax Device-memory array receiving the maximum result, four elements for four channels.
     * @param pDeviceBuffer Buffer to a scratch memory. Use \ref nppiMinMaxGetBufferHostSize_16s_C4R to determine
     *          the minium number of bytes required.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMinMax_16s_C4R(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        short[] aMin, 
        short[] aMax, 
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppiMinMax_16s_C4RNative(pSrc, nSrcStep, oSizeROI, aMin, aMax, pDeviceBuffer));
    }
    private static native int nppiMinMax_16s_C4RNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        short[] aMin, 
        short[] aMax, 
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 4-channel 32-bit floating point image minimum and maximum values.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param aMin Device-memory array receiving the minimum result, four elements for four channels.
     * @param aMax Device-memory array receiving the maximum result, four elements for four channels.
     * @param pDeviceBuffer Buffer to a scratch memory. Use \ref nppiMinMaxGetBufferHostSize_32f_C4R to determine
     *          the minium number of bytes required.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMinMax_32f_C4R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        float[] aMin, 
        float[] aMax, 
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppiMinMax_32f_C4RNative(pSrc, nSrcStep, oSizeROI, aMin, aMax, pDeviceBuffer));
    }
    private static native int nppiMinMax_32f_C4RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        float[] aMin, 
        float[] aMax, 
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiMinMaxIndx_8u_C1R.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiMinMaxIndxGetBufferHostSize_8u_C1R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiMinMaxIndxGetBufferHostSize_8u_C1RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiMinMaxIndxGetBufferHostSize_8u_C1RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiMinMaxIndx_8s_C1R.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiMinMaxIndxGetBufferHostSize_8s_C1R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)/** host pointer */
    {
        return JNpp.checkResult(nppiMinMaxIndxGetBufferHostSize_8s_C1RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiMinMaxIndxGetBufferHostSize_8s_C1RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);/** host pointer */


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiMinMaxIndx_16u_C1R.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiMinMaxIndxGetBufferHostSize_16u_C1R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)/** host pointer */
    {
        return JNpp.checkResult(nppiMinMaxIndxGetBufferHostSize_16u_C1RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiMinMaxIndxGetBufferHostSize_16u_C1RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);/** host pointer */


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiMinMaxIndx_32f_C1R.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiMinMaxIndxGetBufferHostSize_32f_C1R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiMinMaxIndxGetBufferHostSize_32f_C1RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiMinMaxIndxGetBufferHostSize_32f_C1RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiMinMaxIndx_8u_C1MR.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiMinMaxIndxGetBufferHostSize_8u_C1MR(
        NppiSize oSizeROI, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiMinMaxIndxGetBufferHostSize_8u_C1MRNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiMinMaxIndxGetBufferHostSize_8u_C1MRNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiMinMaxIndx_8s_C1MR.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiMinMaxIndxGetBufferHostSize_8s_C1MR(
        NppiSize oSizeROI, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiMinMaxIndxGetBufferHostSize_8s_C1MRNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiMinMaxIndxGetBufferHostSize_8s_C1MRNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiMinMaxIndx_16u_C1MR.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiMinMaxIndxGetBufferHostSize_16u_C1MR(
        NppiSize oSizeROI, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiMinMaxIndxGetBufferHostSize_16u_C1MRNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiMinMaxIndxGetBufferHostSize_16u_C1MRNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiMinMaxIndx_32f_C1MR.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiMinMaxIndxGetBufferHostSize_32f_C1MR(
        NppiSize oSizeROI, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiMinMaxIndxGetBufferHostSize_32f_C1MRNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiMinMaxIndxGetBufferHostSize_32f_C1MRNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);


    public static int nppiMinMaxIndxGetBufferHostSize_8u_C3CR(
        NppiSize oSizeROI, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiMinMaxIndxGetBufferHostSize_8u_C3CRNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiMinMaxIndxGetBufferHostSize_8u_C3CRNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiMinMaxIndx_8s_C3CR.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiMinMaxIndxGetBufferHostSize_8s_C3CR(
        NppiSize oSizeROI, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiMinMaxIndxGetBufferHostSize_8s_C3CRNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiMinMaxIndxGetBufferHostSize_8s_C3CRNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiMinMaxIndx_16u_C3CR.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiMinMaxIndxGetBufferHostSize_16u_C3CR(
        NppiSize oSizeROI, 
        int[] hpBufferSize)/** host pointer */
    {
        return JNpp.checkResult(nppiMinMaxIndxGetBufferHostSize_16u_C3CRNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiMinMaxIndxGetBufferHostSize_16u_C3CRNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);/** host pointer */


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiMinMaxIndx_32f_C3CR.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiMinMaxIndxGetBufferHostSize_32f_C3CR(
        NppiSize oSizeROI, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiMinMaxIndxGetBufferHostSize_32f_C3CRNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiMinMaxIndxGetBufferHostSize_32f_C3CRNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiMinMaxIndx_8u_C3CMR.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiMinMaxIndxGetBufferHostSize_8u_C3CMR(
        NppiSize oSizeROI, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiMinMaxIndxGetBufferHostSize_8u_C3CMRNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiMinMaxIndxGetBufferHostSize_8u_C3CMRNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiMinMaxIndx_8s_C3CMR.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiMinMaxIndxGetBufferHostSize_8s_C3CMR(
        NppiSize oSizeROI, 
        int[] hpBufferSize)/** host pointer */
    {
        return JNpp.checkResult(nppiMinMaxIndxGetBufferHostSize_8s_C3CMRNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiMinMaxIndxGetBufferHostSize_8s_C3CMRNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);/** host pointer */


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiMinMaxIndx_16u_C3CMR.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiMinMaxIndxGetBufferHostSize_16u_C3CMR(
        NppiSize oSizeROI, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiMinMaxIndxGetBufferHostSize_16u_C3CMRNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiMinMaxIndxGetBufferHostSize_16u_C3CMRNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiMinMaxIndx_32f_C3CMR.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiMinMaxIndxGetBufferHostSize_32f_C3CMR(
        NppiSize oSizeROI, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiMinMaxIndxGetBufferHostSize_32f_C3CMRNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiMinMaxIndxGetBufferHostSize_32f_C3CMRNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);


    /**
     * <pre>
     * 1-channel 8-bit unsigned char image minimum and maximum values with their indices.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pMinValue Device-memory pointer receiving the minimum value.
     * @param pMaxValue Device-memory pointer receiving the maximum value.
     * @param pMinIndex Device-memory pointer receiving the indicies (X and Y coordinates) of the minimum value.
     * @param pMaxIndex Device-memory pointer receiving the indicies (X and Y coordinates) of the maximum value.
     * @param pDeviceBuffer Buffer to a scratch memory. Use \ref nppiMinMaxIndxGetBufferHostSize_8u_C1R to determine
     *          the minium number of bytes required.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes. 
     * If any of pMinValue, pMaxValue, pMinIndex, or pMaxIndex is not needed, zero pointer must be passed correspondingly.
     * </pre>
     */
    public static int nppiMinMaxIndx_8u_C1R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMinValue, 
        TypedPointer<Npp8u> pMaxValue, 
        NppiPoint[] pMinIndex, 
        NppiPoint[] pMaxIndex, 
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppiMinMaxIndx_8u_C1RNative(pSrc, nSrcStep, oSizeROI, pMinValue, pMaxValue, pMinIndex, pMaxIndex, pDeviceBuffer));
    }
    private static native int nppiMinMaxIndx_8u_C1RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMinValue, 
        TypedPointer<Npp8u> pMaxValue, 
        NppiPoint[] pMinIndex, 
        NppiPoint[] pMaxIndex, 
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 1-channel 8-bit signed char image minimum and maximum values with their indices.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pMinValue Device-memory pointer receiving the minimum value.
     * @param pMaxValue Device-memory pointer receiving the maximum value.
     * @param pMinIndex Device-memory pointer receiving the indicies (X and Y coordinates) of the minimum value.
     * @param pMaxIndex Device-memory pointer receiving the indicies (X and Y coordinates) of the maximum value.
     * @param pDeviceBuffer Buffer to a scratch memory. Use \ref nppiMinMaxIndxGetBufferHostSize_8s_C1R to determine
     *          the minium number of bytes required.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes. 
     * If any of pMinValue, pMaxValue, pMinIndex, or pMaxIndex is not needed, zero pointer must be passed correspondingly.
     * </pre>
     */
    public static int nppiMinMaxIndx_8s_C1R(
        TypedPointer<Npp8s> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8s> pMinValue, 
        TypedPointer<Npp8s> pMaxValue, 
        NppiPoint[] pMinIndex, 
        NppiPoint[] pMaxIndex, 
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppiMinMaxIndx_8s_C1RNative(pSrc, nSrcStep, oSizeROI, pMinValue, pMaxValue, pMinIndex, pMaxIndex, pDeviceBuffer));
    }
    private static native int nppiMinMaxIndx_8s_C1RNative(
        TypedPointer<Npp8s> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8s> pMinValue, 
        TypedPointer<Npp8s> pMaxValue, 
        NppiPoint[] pMinIndex, 
        NppiPoint[] pMaxIndex, 
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 1-channel 16-bit unsigned short image minimum and maximum values with their indices.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pMinValue Device-memory pointer receiving the minimum value.
     * @param pMaxValue Device-memory pointer receiving the maximum value.
     * @param pMinIndex Device-memory pointer receiving the indicies (X and Y coordinates) of the minimum value.
     * @param pMaxIndex Device-memory pointer receiving the indicies (X and Y coordinates) of the maximum value.
     * @param pDeviceBuffer Buffer to a scratch memory. Use \ref nppiMinMaxIndxGetBufferHostSize_16u_C1R to determine
     *          the minium number of bytes required.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes. 
     * If any of pMinValue, pMaxValue, pMinIndex, or pMaxIndex is not needed, zero pointer must be passed correspondingly.
     * </pre>
     */
    public static int nppiMinMaxIndx_16u_C1R(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp16u> pMinValue, 
        TypedPointer<Npp16u> pMaxValue, 
        NppiPoint[] pMinIndex, 
        NppiPoint[] pMaxIndex, 
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppiMinMaxIndx_16u_C1RNative(pSrc, nSrcStep, oSizeROI, pMinValue, pMaxValue, pMinIndex, pMaxIndex, pDeviceBuffer));
    }
    private static native int nppiMinMaxIndx_16u_C1RNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp16u> pMinValue, 
        TypedPointer<Npp16u> pMaxValue, 
        NppiPoint[] pMinIndex, 
        NppiPoint[] pMaxIndex, 
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 1-channel 32-bit floating point image minimum and maximum values with their indices.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pMinValue Device-memory pointer receiving the minimum value.
     * @param pMaxValue Device-memory pointer receiving the maximum value.
     * @param pMinIndex Device-memory pointer receiving the indicies (X and Y coordinates) of the minimum value.
     * @param pMaxIndex Device-memory pointer receiving the indicies (X and Y coordinates) of the maximum value.
     * @param pDeviceBuffer Buffer to a scratch memory. Use \ref nppiMinMaxIndxGetBufferHostSize_32f_C1R to determine
     *          the minium number of bytes required.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, or NPP_NOT_EVEN_STEP_ERROR if an invalid floating-point image is specified.
     * If any of pMinValue, pMaxValue, pMinIndex, or pMaxIndex is not needed, zero pointer must be passed correspondingly.
     * </pre>
     */
    public static int nppiMinMaxIndx_32f_C1R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp32f> pMinValue, 
        TypedPointer<Npp32f> pMaxValue, 
        NppiPoint[] pMinIndex, 
        NppiPoint[] pMaxIndex, 
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppiMinMaxIndx_32f_C1RNative(pSrc, nSrcStep, oSizeROI, pMinValue, pMaxValue, pMinIndex, pMaxIndex, pDeviceBuffer));
    }
    private static native int nppiMinMaxIndx_32f_C1RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp32f> pMinValue, 
        TypedPointer<Npp32f> pMaxValue, 
        NppiPoint[] pMinIndex, 
        NppiPoint[] pMaxIndex, 
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 1-channel 8-bit unsigned char image minimum and maximum values with their indices, \ref masked_operation.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pMask \ref mask_image_pointer.
     * @param nMaskStep \ref mask_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pMinValue Device-memory pointer receiving the minimum value.
     * @param pMaxValue Device-memory pointer receiving the maximum value.
     * @param pMinIndex Device-memory pointer receiving the indicies (X and Y coordinates) of the minimum value.
     * @param pMaxIndex Device-memory pointer receiving the indicies (X and Y coordinates) of the maximum value.
     * @param pDeviceBuffer Buffer to a scratch memory. Use \ref nppiMinMaxIndxGetBufferHostSize_8u_C1MR to determine
     *          the minium number of bytes required.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes. 
     * If the mask is filled with zeros, then all the returned values are zeros, i.e., pMinIndex = {0, 0}, pMaxIndex = {0, 0},
     * pMinValue = 0, pMaxValue = 0.
     * If any of pMinValue, pMaxValue, pMinIndex, or pMaxIndex is not needed, zero pointer must be passed correspondingly.
     * </pre>
     */
    public static int nppiMinMaxIndx_8u_C1MR(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMinValue, 
        TypedPointer<Npp8u> pMaxValue, 
        NppiPoint[] pMinIndex, 
        NppiPoint[] pMaxIndex, 
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppiMinMaxIndx_8u_C1MRNative(pSrc, nSrcStep, pMask, nMaskStep, oSizeROI, pMinValue, pMaxValue, pMinIndex, pMaxIndex, pDeviceBuffer));
    }
    private static native int nppiMinMaxIndx_8u_C1MRNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMinValue, 
        TypedPointer<Npp8u> pMaxValue, 
        NppiPoint[] pMinIndex, 
        NppiPoint[] pMaxIndex, 
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 1-channel 8-bit signed char image minimum and maximum values with their indices, \ref masked_operation.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pMask \ref mask_image_pointer.
     * @param nMaskStep \ref mask_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pMinValue Device-memory pointer receiving the minimum value.
     * @param pMaxValue Device-memory pointer receiving the maximum value.
     * @param pMinIndex Device-memory pointer receiving the indicies (X and Y coordinates) of the minimum value.
     * @param pMaxIndex Device-memory pointer receiving the indicies (X and Y coordinates) of the maximum value.
     * @param pDeviceBuffer Buffer to a scratch memory. Use \ref nppiMinMaxIndxGetBufferHostSize_8s_C1MR to determine
     *          the minium number of bytes required.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes. 
     * If the mask is filled with zeros, then all the returned values are zeros, i.e., pMinIndex = {0, 0}, pMaxIndex = {0, 0},
     * pMinValue = 0, pMaxValue = 0.
     * If any of pMinValue, pMaxValue, pMinIndex, or pMaxIndex is not needed, zero pointer must be passed correspondingly.
     * </pre>
     */
    public static int nppiMinMaxIndx_8s_C1MR(
        TypedPointer<Npp8s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8s> pMinValue, 
        TypedPointer<Npp8s> pMaxValue, 
        NppiPoint[] pMinIndex, 
        NppiPoint[] pMaxIndex, 
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppiMinMaxIndx_8s_C1MRNative(pSrc, nSrcStep, pMask, nMaskStep, oSizeROI, pMinValue, pMaxValue, pMinIndex, pMaxIndex, pDeviceBuffer));
    }
    private static native int nppiMinMaxIndx_8s_C1MRNative(
        TypedPointer<Npp8s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8s> pMinValue, 
        TypedPointer<Npp8s> pMaxValue, 
        NppiPoint[] pMinIndex, 
        NppiPoint[] pMaxIndex, 
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 1-channel 16-bit unsigned short image minimum and maximum values with their indices, \ref masked_operation.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pMask \ref mask_image_pointer.
     * @param nMaskStep \ref mask_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pMinValue Device-memory pointer receiving the minimum value.
     * @param pMaxValue Device-memory pointer receiving the maximum value.
     * @param pMinIndex Device-memory pointer receiving the indicies (X and Y coordinates) of the minimum value.
     * @param pMaxIndex Device-memory pointer receiving the indicies (X and Y coordinates) of the maximum value.
     * @param pDeviceBuffer Buffer to a scratch memory. Use \ref nppiMinMaxIndxGetBufferHostSize_16u_C1MR to determine
     *          the minium number of bytes required.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes. 
     * If the mask is filled with zeros, then all the returned values are zeros, i.e., pMinIndex = {0, 0}, pMaxIndex = {0, 0},
     * pMinValue = 0, pMaxValue = 0.
     * If any of pMinValue, pMaxValue, pMinIndex, or pMaxIndex is not needed, zero pointer must be passed correspondingly.
     * </pre>
     */
    public static int nppiMinMaxIndx_16u_C1MR(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp16u> pMinValue, 
        TypedPointer<Npp16u> pMaxValue, 
        NppiPoint[] pMinIndex, 
        NppiPoint[] pMaxIndex, 
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppiMinMaxIndx_16u_C1MRNative(pSrc, nSrcStep, pMask, nMaskStep, oSizeROI, pMinValue, pMaxValue, pMinIndex, pMaxIndex, pDeviceBuffer));
    }
    private static native int nppiMinMaxIndx_16u_C1MRNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp16u> pMinValue, 
        TypedPointer<Npp16u> pMaxValue, 
        NppiPoint[] pMinIndex, 
        NppiPoint[] pMaxIndex, 
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 1-channel 32-bit floating point image minimum and maximum values with their indices, \ref masked_operation.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pMask \ref mask_image_pointer.
     * @param nMaskStep \ref mask_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pMinValue Device-memory pointer receiving the minimum value.
     * @param pMaxValue Device-memory pointer receiving the maximum value.
     * @param pMinIndex Device-memory pointer receiving the indicies (X and Y coordinates) of the minimum value.
     * @param pMaxIndex Device-memory pointer receiving the indicies (X and Y coordinates) of the maximum value.
     * @param pDeviceBuffer Buffer to a scratch memory. Use \ref nppiMinMaxIndxGetBufferHostSize_32f_C1MR to determine
     *          the minium number of bytes required.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, or NPP_NOT_EVEN_STEP_ERROR if an invalid floating-point image is specified.
     * If the mask is filled with zeros, then all the returned values are zeros, i.e., pMinIndex = {0, 0}, pMaxIndex = {0, 0},
     * pMinValue = 0, pMaxValue = 0.
     * If any of pMinValue, pMaxValue, pMinIndex, or pMaxIndex is not needed, zero pointer must be passed correspondingly.
     * </pre>
     */
    public static int nppiMinMaxIndx_32f_C1MR(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp32f> pMinValue, 
        TypedPointer<Npp32f> pMaxValue, 
        NppiPoint[] pMinIndex, 
        NppiPoint[] pMaxIndex, 
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppiMinMaxIndx_32f_C1MRNative(pSrc, nSrcStep, pMask, nMaskStep, oSizeROI, pMinValue, pMaxValue, pMinIndex, pMaxIndex, pDeviceBuffer));
    }
    private static native int nppiMinMaxIndx_32f_C1MRNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp32f> pMinValue, 
        TypedPointer<Npp32f> pMaxValue, 
        NppiPoint[] pMinIndex, 
        NppiPoint[] pMaxIndex, 
        TypedPointer<Npp8u> pDeviceBuffer);


    public static int nppiMinMaxIndx_8u_C3CR(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        int nCOI, 
        TypedPointer<Npp8u> pMinValue, 
        TypedPointer<Npp8u> pMaxValue, 
        NppiPoint[] pMinIndex, 
        NppiPoint[] pMaxIndex, 
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppiMinMaxIndx_8u_C3CRNative(pSrc, nSrcStep, oSizeROI, nCOI, pMinValue, pMaxValue, pMinIndex, pMaxIndex, pDeviceBuffer));
    }
    private static native int nppiMinMaxIndx_8u_C3CRNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        int nCOI, 
        TypedPointer<Npp8u> pMinValue, 
        TypedPointer<Npp8u> pMaxValue, 
        NppiPoint[] pMinIndex, 
        NppiPoint[] pMaxIndex, 
        TypedPointer<Npp8u> pDeviceBuffer);


    public static int nppiMinMaxIndx_8s_C3CR(
        TypedPointer<Npp8s> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        int nCOI, 
        TypedPointer<Npp8s> pMinValue, 
        TypedPointer<Npp8s> pMaxValue, 
        NppiPoint[] pMinIndex, 
        NppiPoint[] pMaxIndex, 
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppiMinMaxIndx_8s_C3CRNative(pSrc, nSrcStep, oSizeROI, nCOI, pMinValue, pMaxValue, pMinIndex, pMaxIndex, pDeviceBuffer));
    }
    private static native int nppiMinMaxIndx_8s_C3CRNative(
        TypedPointer<Npp8s> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        int nCOI, 
        TypedPointer<Npp8s> pMinValue, 
        TypedPointer<Npp8s> pMaxValue, 
        NppiPoint[] pMinIndex, 
        NppiPoint[] pMaxIndex, 
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 1-channel 16-bit unsigned short image minimum and maximum values with their indices, \ref channel_of_interest.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nCOI \ref channel_of_interest_number.
     * @param pMinValue Device-memory pointer receiving the minimum value.
     * @param pMaxValue Device-memory pointer receiving the maximum value.
     * @param pMinIndex Device-memory pointer receiving the indicies (X and Y coordinates) of the minimum value.
     * @param pMaxIndex Device-memory pointer receiving the indicies (X and Y coordinates) of the maximum value.
     * @param pDeviceBuffer Buffer to a scratch memory. Use \ref nppiMinMaxIndxGetBufferHostSize_16u_C3CR to determine
     *          the minium number of bytes required.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, or NPP_COI_ERROR if an invalid channel of interest is specified.
     * If any of pMinValue, pMaxValue, pMinIndex, or pMaxIndex is not needed, zero pointer must be passed correspondingly.
     * </pre>
     */
    public static int nppiMinMaxIndx_16u_C3CR(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        int nCOI, 
        TypedPointer<Npp16u> pMinValue, 
        TypedPointer<Npp16u> pMaxValue, 
        NppiPoint[] pMinIndex, 
        NppiPoint[] pMaxIndex, 
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppiMinMaxIndx_16u_C3CRNative(pSrc, nSrcStep, oSizeROI, nCOI, pMinValue, pMaxValue, pMinIndex, pMaxIndex, pDeviceBuffer));
    }
    private static native int nppiMinMaxIndx_16u_C3CRNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        int nCOI, 
        TypedPointer<Npp16u> pMinValue, 
        TypedPointer<Npp16u> pMaxValue, 
        NppiPoint[] pMinIndex, 
        NppiPoint[] pMaxIndex, 
        TypedPointer<Npp8u> pDeviceBuffer);


    public static int nppiMinMaxIndx_32f_C3CR(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        int nCOI, 
        TypedPointer<Npp32f> pMinValue, 
        TypedPointer<Npp32f> pMaxValue, 
        NppiPoint[] pMinIndex, 
        NppiPoint[] pMaxIndex, 
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppiMinMaxIndx_32f_C3CRNative(pSrc, nSrcStep, oSizeROI, nCOI, pMinValue, pMaxValue, pMinIndex, pMaxIndex, pDeviceBuffer));
    }
    private static native int nppiMinMaxIndx_32f_C3CRNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        int nCOI, 
        TypedPointer<Npp32f> pMinValue, 
        TypedPointer<Npp32f> pMaxValue, 
        NppiPoint[] pMinIndex, 
        NppiPoint[] pMaxIndex, 
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 3-channel 8-bit unsigned char image minimum and maximum values with their indices, \ref masked_operation, \ref channel_of_interest.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pMask \ref mask_image_pointer.
     * @param nMaskStep \ref mask_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nCOI \ref channel_of_interest_number.
     * @param pMinValue Device-memory pointer receiving the minimum value.
     * @param pMaxValue Device-memory pointer receiving the maximum value.
     * @param pMinIndex Device-memory pointer receiving the indicies (X and Y coordinates) of the minimum value.
     * @param pMaxIndex Device-memory pointer receiving the indicies (X and Y coordinates) of the maximum value.
     * @param pDeviceBuffer Buffer to a scratch memory. Use \ref nppiMinMaxIndxGetBufferHostSize_8u_C3CMR to determine
     *          the minium number of bytes required.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, or NPP_COI_ERROR if an invalid channel of interest is specified.
     * If the mask is filled with zeros, then all the returned values are zeros, i.e., pMinIndex = {0, 0}, pMaxIndex = {0, 0},
     * pMinValue = 0, pMaxValue = 0.
     * If any of pMinValue, pMaxValue, pMinIndex, or pMaxIndex is not needed, zero pointer must be passed correspondingly.
     * </pre>
     */
    public static int nppiMinMaxIndx_8u_C3CMR(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep, 
        NppiSize oSizeROI, 
        int nCOI, 
        TypedPointer<Npp8u> pMinValue, 
        TypedPointer<Npp8u> pMaxValue, 
        NppiPoint[] pMinIndex, 
        NppiPoint[] pMaxIndex, 
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppiMinMaxIndx_8u_C3CMRNative(pSrc, nSrcStep, pMask, nMaskStep, oSizeROI, nCOI, pMinValue, pMaxValue, pMinIndex, pMaxIndex, pDeviceBuffer));
    }
    private static native int nppiMinMaxIndx_8u_C3CMRNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep, 
        NppiSize oSizeROI, 
        int nCOI, 
        TypedPointer<Npp8u> pMinValue, 
        TypedPointer<Npp8u> pMaxValue, 
        NppiPoint[] pMinIndex, 
        NppiPoint[] pMaxIndex, 
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 3-channel 8-bit signed char image minimum and maximum values with their indices, \ref masked_operation, \ref channel_of_interest.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pMask \ref mask_image_pointer.
     * @param nMaskStep \ref mask_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nCOI \ref channel_of_interest_number.
     * @param pMinValue Device-memory pointer receiving the minimum value.
     * @param pMaxValue Device-memory pointer receiving the maximum value.
     * @param pMinIndex Device-memory pointer receiving the indicies (X and Y coordinates) of the minimum value.
     * @param pMaxIndex Device-memory pointer receiving the indicies (X and Y coordinates) of the maximum value.
     * @param pDeviceBuffer Buffer to a scratch memory. Use \ref nppiMinMaxIndxGetBufferHostSize_8s_C3CMR to determine
     *          the minium number of bytes required.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, or NPP_COI_ERROR if an invalid channel of interest is specified.
     * If the mask is filled with zeros, then all the returned values are zeros, i.e., pMinIndex = {0, 0}, pMaxIndex = {0, 0},
     * pMinValue = 0, pMaxValue = 0.
     * If any of pMinValue, pMaxValue, pMinIndex, or pMaxIndex is not needed, zero pointer must be passed correspondingly.
     * </pre>
     */
    public static int nppiMinMaxIndx_8s_C3CMR(
        TypedPointer<Npp8s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep, 
        NppiSize oSizeROI, 
        int nCOI, 
        TypedPointer<Npp8s> pMinValue, 
        TypedPointer<Npp8s> pMaxValue, 
        NppiPoint[] pMinIndex, 
        NppiPoint[] pMaxIndex, 
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppiMinMaxIndx_8s_C3CMRNative(pSrc, nSrcStep, pMask, nMaskStep, oSizeROI, nCOI, pMinValue, pMaxValue, pMinIndex, pMaxIndex, pDeviceBuffer));
    }
    private static native int nppiMinMaxIndx_8s_C3CMRNative(
        TypedPointer<Npp8s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep, 
        NppiSize oSizeROI, 
        int nCOI, 
        TypedPointer<Npp8s> pMinValue, 
        TypedPointer<Npp8s> pMaxValue, 
        NppiPoint[] pMinIndex, 
        NppiPoint[] pMaxIndex, 
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 3-channel 16-bit unsigned short image minimum and maximum values with their indices, \ref masked_operation, \ref channel_of_interest.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pMask \ref mask_image_pointer.
     * @param nMaskStep \ref mask_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nCOI \ref channel_of_interest_number.
     * @param pMinValue Device-memory pointer receiving the minimum value.
     * @param pMaxValue Device-memory pointer receiving the maximum value.
     * @param pMinIndex Device-memory pointer receiving the indicies (X and Y coordinates) of the minimum value.
     * @param pMaxIndex Device-memory pointer receiving the indicies (X and Y coordinates) of the maximum value.
     * @param pDeviceBuffer Buffer to a scratch memory. Use \ref nppiMinMaxIndxGetBufferHostSize_16u_C3CMR to determine
     *          the minium number of bytes required.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, or NPP_COI_ERROR if an invalid channel of interest is specified.
     * If the mask is filled with zeros, then all the returned values are zeros, i.e., pMinIndex = {0, 0}, pMaxIndex = {0, 0},
     * pMinValue = 0, pMaxValue = 0.
     * If any of pMinValue, pMaxValue, pMinIndex, or pMaxIndex is not needed, zero pointer must be passed correspondingly.
     * </pre>
     */
    public static int nppiMinMaxIndx_16u_C3CMR(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep, 
        NppiSize oSizeROI, 
        int nCOI, 
        TypedPointer<Npp16u> pMinValue, 
        TypedPointer<Npp16u> pMaxValue, 
        NppiPoint[] pMinIndex, 
        NppiPoint[] pMaxIndex, 
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppiMinMaxIndx_16u_C3CMRNative(pSrc, nSrcStep, pMask, nMaskStep, oSizeROI, nCOI, pMinValue, pMaxValue, pMinIndex, pMaxIndex, pDeviceBuffer));
    }
    private static native int nppiMinMaxIndx_16u_C3CMRNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep, 
        NppiSize oSizeROI, 
        int nCOI, 
        TypedPointer<Npp16u> pMinValue, 
        TypedPointer<Npp16u> pMaxValue, 
        NppiPoint[] pMinIndex, 
        NppiPoint[] pMaxIndex, 
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 3-channel 32-bit floating point image minimum and maximum values with their indices, \ref masked_operation, \ref channel_of_interest.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pMask \ref mask_image_pointer.
     * @param nMaskStep \ref mask_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nCOI \ref channel_of_interest_number.
     * @param pMinValue Device-memory pointer receiving the minimum value.
     * @param pMaxValue Device-memory pointer receiving the maximum value.
     * @param pMinIndex Device-memory pointer receiving the indicies (X and Y coordinates) of the minimum value.
     * @param pMaxIndex Device-memory pointer receiving the indicies (X and Y coordinates) of the maximum value.
     * @param pDeviceBuffer Buffer to a scratch memory. Use \ref nppiMinMaxIndxGetBufferHostSize_32f_C3CMR to determine
     *          the minium number of bytes required.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, NPP_NOT_EVEN_STEP_ERROR if an invalid floating-point image is specified, or NPP_COI_ERROR if an invalid channel of interest is specified.
     * If the mask is filled with zeros, then all the returned values are zeros, i.e., pMinIndex = {0, 0}, pMaxIndex = {0, 0},
     * pMinValue = 0, pMaxValue = 0.
     * If any of pMinValue, pMaxValue, pMinIndex, or pMaxIndex is not needed, zero pointer must be passed correspondingly.
     * </pre>
     */
    public static int nppiMinMaxIndx_32f_C3CMR(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep, 
        NppiSize oSizeROI, 
        int nCOI, 
        TypedPointer<Npp32f> pMinValue, 
        TypedPointer<Npp32f> pMaxValue, 
        NppiPoint[] pMinIndex, 
        NppiPoint[] pMaxIndex, 
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppiMinMaxIndx_32f_C3CMRNative(pSrc, nSrcStep, pMask, nMaskStep, oSizeROI, nCOI, pMinValue, pMaxValue, pMinIndex, pMaxIndex, pDeviceBuffer));
    }
    private static native int nppiMinMaxIndx_32f_C3CMRNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep, 
        NppiSize oSizeROI, 
        int nCOI, 
        TypedPointer<Npp32f> pMinValue, 
        TypedPointer<Npp32f> pMaxValue, 
        NppiPoint[] pMinIndex, 
        NppiPoint[] pMaxIndex, 
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiMean_8u_C1R.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiMeanGetBufferHostSize_8u_C1R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiMeanGetBufferHostSize_8u_C1RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiMeanGetBufferHostSize_8u_C1RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);


    /** host pointer */
    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiMean_16u_C1R.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiMeanGetBufferHostSize_16u_C1R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)/** host pointer */
    {
        return JNpp.checkResult(nppiMeanGetBufferHostSize_16u_C1RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiMeanGetBufferHostSize_16u_C1RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);/** host pointer */


    public static int nppiMeanGetBufferHostSize_16s_C1R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)/** host pointer */
    {
        return JNpp.checkResult(nppiMeanGetBufferHostSize_16s_C1RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiMeanGetBufferHostSize_16s_C1RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);/** host pointer */


    public static int nppiMeanGetBufferHostSize_32f_C1R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)/** host pointer */
    {
        return JNpp.checkResult(nppiMeanGetBufferHostSize_32f_C1RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiMeanGetBufferHostSize_32f_C1RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);/** host pointer */


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiMean_8u_C3R.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiMeanGetBufferHostSize_8u_C3R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)/** host pointer */
    {
        return JNpp.checkResult(nppiMeanGetBufferHostSize_8u_C3RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiMeanGetBufferHostSize_8u_C3RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);/** host pointer */


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiMean_16u_C3R.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiMeanGetBufferHostSize_16u_C3R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiMeanGetBufferHostSize_16u_C3RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiMeanGetBufferHostSize_16u_C3RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);


    public static int nppiMeanGetBufferHostSize_16s_C3R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiMeanGetBufferHostSize_16s_C3RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiMeanGetBufferHostSize_16s_C3RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiMean_32f_C3R.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiMeanGetBufferHostSize_32f_C3R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)/** host pointer */
    {
        return JNpp.checkResult(nppiMeanGetBufferHostSize_32f_C3RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiMeanGetBufferHostSize_32f_C3RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);/** host pointer */


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiMean_8u_AC4R.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiMeanGetBufferHostSize_8u_AC4R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiMeanGetBufferHostSize_8u_AC4RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiMeanGetBufferHostSize_8u_AC4RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);


    public static int nppiMeanGetBufferHostSize_16u_AC4R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiMeanGetBufferHostSize_16u_AC4RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiMeanGetBufferHostSize_16u_AC4RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiMean_16s_AC4R.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiMeanGetBufferHostSize_16s_AC4R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)/** host pointer */
    {
        return JNpp.checkResult(nppiMeanGetBufferHostSize_16s_AC4RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiMeanGetBufferHostSize_16s_AC4RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);/** host pointer */


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiMean_32f_AC4R.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiMeanGetBufferHostSize_32f_AC4R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiMeanGetBufferHostSize_32f_AC4RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiMeanGetBufferHostSize_32f_AC4RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiMean_8u_C4R.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiMeanGetBufferHostSize_8u_C4R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiMeanGetBufferHostSize_8u_C4RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiMeanGetBufferHostSize_8u_C4RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiMean_16u_C4R.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiMeanGetBufferHostSize_16u_C4R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)/** host pointer */
    {
        return JNpp.checkResult(nppiMeanGetBufferHostSize_16u_C4RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiMeanGetBufferHostSize_16u_C4RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);/** host pointer */


    public static int nppiMeanGetBufferHostSize_16s_C4R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiMeanGetBufferHostSize_16s_C4RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiMeanGetBufferHostSize_16s_C4RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiMean_32f_C4R.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiMeanGetBufferHostSize_32f_C4R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiMeanGetBufferHostSize_32f_C4RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiMeanGetBufferHostSize_32f_C4RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiMean_8u_C1MR.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiMeanGetBufferHostSize_8u_C1MR(
        NppiSize oSizeROI, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiMeanGetBufferHostSize_8u_C1MRNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiMeanGetBufferHostSize_8u_C1MRNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiMean_8s_C1MR.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiMeanGetBufferHostSize_8s_C1MR(
        NppiSize oSizeROI, 
        int[] hpBufferSize)/** host pointer */
    {
        return JNpp.checkResult(nppiMeanGetBufferHostSize_8s_C1MRNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiMeanGetBufferHostSize_8s_C1MRNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);/** host pointer */


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiMean_16u_C1MR.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiMeanGetBufferHostSize_16u_C1MR(
        NppiSize oSizeROI, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiMeanGetBufferHostSize_16u_C1MRNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiMeanGetBufferHostSize_16u_C1MRNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);


    public static int nppiMeanGetBufferHostSize_32f_C1MR(
        NppiSize oSizeROI, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiMeanGetBufferHostSize_32f_C1MRNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiMeanGetBufferHostSize_32f_C1MRNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiMean_8u_C3CMR.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiMeanGetBufferHostSize_8u_C3CMR(
        NppiSize oSizeROI, 
        int[] hpBufferSize)/** host pointer */
    {
        return JNpp.checkResult(nppiMeanGetBufferHostSize_8u_C3CMRNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiMeanGetBufferHostSize_8u_C3CMRNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);/** host pointer */


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiMean_8s_C3CMR.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiMeanGetBufferHostSize_8s_C3CMR(
        NppiSize oSizeROI, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiMeanGetBufferHostSize_8s_C3CMRNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiMeanGetBufferHostSize_8s_C3CMRNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiMean_16u_C3CMR.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiMeanGetBufferHostSize_16u_C3CMR(
        NppiSize oSizeROI, 
        int[] hpBufferSize)/** host pointer */
    {
        return JNpp.checkResult(nppiMeanGetBufferHostSize_16u_C3CMRNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiMeanGetBufferHostSize_16u_C3CMRNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);/** host pointer */


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiMean_32f_C3CMR.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiMeanGetBufferHostSize_32f_C3CMR(
        NppiSize oSizeROI, 
        int[] hpBufferSize)/** host pointer */
    {
        return JNpp.checkResult(nppiMeanGetBufferHostSize_32f_C3CMRNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiMeanGetBufferHostSize_32f_C3CMRNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);/** host pointer */


    public static int nppiMean_8u_C1R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        TypedPointer<Npp64f> pMean)
    {
        return JNpp.checkResult(nppiMean_8u_C1RNative(pSrc, nSrcStep, oSizeROI, pDeviceBuffer, pMean));
    }
    private static native int nppiMean_8u_C1RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        TypedPointer<Npp64f> pMean);


    /**
     * <pre>
     * 1-channel 16-bit unsigned short integer image mean with 64-bit double precision result.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer
     *        Use \ref nppiMeanGetBufferHostSize_16u_C1R to determine the minium number of bytes required.
     * @param pMean Device-memory pointer receiving the mean result.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMean_16u_C1R(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        TypedPointer<Npp64f> pMean)
    {
        return JNpp.checkResult(nppiMean_16u_C1RNative(pSrc, nSrcStep, oSizeROI, pDeviceBuffer, pMean));
    }
    private static native int nppiMean_16u_C1RNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        TypedPointer<Npp64f> pMean);


    /**
     * <pre>
     * 1-channel 16-bit signed short integer image mean with 64-bit double precision result.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer
     *        Use \ref nppiMeanGetBufferHostSize_16s_C1R to determine the minium number of bytes required.
     * @param pMean Device-memory pointer receiving the mean result.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMean_16s_C1R(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        TypedPointer<Npp64f> pMean)
    {
        return JNpp.checkResult(nppiMean_16s_C1RNative(pSrc, nSrcStep, oSizeROI, pDeviceBuffer, pMean));
    }
    private static native int nppiMean_16s_C1RNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        TypedPointer<Npp64f> pMean);


    /**
     * <pre>
     * 1-channel 32-bit floating point image mean with 64-bit double precision result.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer
     * @param pMean Device-memory pointer receiving the mean result.
     *        Use \ref nppiMeanGetBufferHostSize_32f_C1R to determine the minium number of bytes required.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, NPP_NOT_EVEN_STEP_ERROR if an invalid 
     * floating-point image is specified.
     * </pre>
     */
    public static int nppiMean_32f_C1R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        TypedPointer<Npp64f> pMean)
    {
        return JNpp.checkResult(nppiMean_32f_C1RNative(pSrc, nSrcStep, oSizeROI, pDeviceBuffer, pMean));
    }
    private static native int nppiMean_32f_C1RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        TypedPointer<Npp64f> pMean);


    /**
     * <pre>
     * 3-channel 8-bit unsigned char image mean with 64-bit double precision result.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer
     *        Use \ref nppiMeanGetBufferHostSize_8u_C3R to determine the minium number of bytes required.
     * @param aMean Array that contains computed mean, three elements for three channels.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMean_8u_C3R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        double[] aMean)
    {
        return JNpp.checkResult(nppiMean_8u_C3RNative(pSrc, nSrcStep, oSizeROI, pDeviceBuffer, aMean));
    }
    private static native int nppiMean_8u_C3RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        double[] aMean);


    public static int nppiMean_16u_C3R(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        double[] aMean)
    {
        return JNpp.checkResult(nppiMean_16u_C3RNative(pSrc, nSrcStep, oSizeROI, pDeviceBuffer, aMean));
    }
    private static native int nppiMean_16u_C3RNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        double[] aMean);


    public static int nppiMean_16s_C3R(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        double[] aMean)
    {
        return JNpp.checkResult(nppiMean_16s_C3RNative(pSrc, nSrcStep, oSizeROI, pDeviceBuffer, aMean));
    }
    private static native int nppiMean_16s_C3RNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        double[] aMean);


    public static int nppiMean_32f_C3R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        double[] aMean)
    {
        return JNpp.checkResult(nppiMean_32f_C3RNative(pSrc, nSrcStep, oSizeROI, pDeviceBuffer, aMean));
    }
    private static native int nppiMean_32f_C3RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        double[] aMean);


    /**
     * <pre>
     * 4-channel 8-bit unsigned char image mean with 64-bit double precision result.
     * Alpha channel is the last channel and is not processed.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer
     *        Use \ref nppiMeanGetBufferHostSize_8u_AC4R to determine the minium number of bytes required.
     * @param aMean Array that contains computed mean, three elements for the first three channels.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMean_8u_AC4R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        double[] aMean)
    {
        return JNpp.checkResult(nppiMean_8u_AC4RNative(pSrc, nSrcStep, oSizeROI, pDeviceBuffer, aMean));
    }
    private static native int nppiMean_8u_AC4RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        double[] aMean);


    /**
     * <pre>
     * 4-channel 16-bit unsigned short image mean with 64-bit double precision result.
     * Alpha channel is the last channel and is not processed.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer
     *        Use \ref nppiMeanGetBufferHostSize_16u_AC4R to determine the minium number of bytes required.
     * @param aMean Array that contains computed mean, three elements for the first three channels.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMean_16u_AC4R(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        double[] aMean)
    {
        return JNpp.checkResult(nppiMean_16u_AC4RNative(pSrc, nSrcStep, oSizeROI, pDeviceBuffer, aMean));
    }
    private static native int nppiMean_16u_AC4RNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        double[] aMean);


    /**
     * <pre>
     * 4-channel 16-bit signed short image mean with 64-bit double precision result.
     * Alpha channel is the last channel and is not processed.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer
     *        Use \ref nppiMeanGetBufferHostSize_16s_AC4R to determine the minium number of bytes required.
     * @param aMean Array that contains computed mean, three elements for the first three channels.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMean_16s_AC4R(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        double[] aMean)
    {
        return JNpp.checkResult(nppiMean_16s_AC4RNative(pSrc, nSrcStep, oSizeROI, pDeviceBuffer, aMean));
    }
    private static native int nppiMean_16s_AC4RNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        double[] aMean);


    /**
     * <pre>
     * 4-channel 32-bit floating point image mean with 64-bit double precision result.
     * Alpha channel is the last channel and is not processed.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer
     *        Use \ref nppiMeanGetBufferHostSize_32f_AC4R to determine the minium number of bytes required.
     * @param aMean Array that contains computed mean, three elements for the first three channels.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, NPP_NOT_EVEN_STEP_ERROR if an invalid 
     * floating-point image is specified.
     * </pre>
     */
    public static int nppiMean_32f_AC4R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        double[] aMean)
    {
        return JNpp.checkResult(nppiMean_32f_AC4RNative(pSrc, nSrcStep, oSizeROI, pDeviceBuffer, aMean));
    }
    private static native int nppiMean_32f_AC4RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        double[] aMean);


    /**
     * <pre>
     * 4-channel 8-bit unsigned char image mean with 64-bit double precision result.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer
     *        Use \ref nppiMeanGetBufferHostSize_8u_C4R to determine the minium number of bytes required.
     * @param aMean Array that contains computed mean, four elements for four channels.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMean_8u_C4R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        double[] aMean)
    {
        return JNpp.checkResult(nppiMean_8u_C4RNative(pSrc, nSrcStep, oSizeROI, pDeviceBuffer, aMean));
    }
    private static native int nppiMean_8u_C4RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        double[] aMean);


    /**
     * <pre>
     * 4-channel 16-bit unsigned short image mean with 64-bit double precision result.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer
     *        Use \ref nppiMeanGetBufferHostSize_16u_C4R to determine the minium number of bytes required.
     * @param aMean Array that contains computed mean, four elements for four channels.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMean_16u_C4R(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        double[] aMean)
    {
        return JNpp.checkResult(nppiMean_16u_C4RNative(pSrc, nSrcStep, oSizeROI, pDeviceBuffer, aMean));
    }
    private static native int nppiMean_16u_C4RNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        double[] aMean);


    /**
     * <pre>
     * 4-channel 16-bit signed short image mean with 64-bit double precision result.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer
     *        Use \ref nppiMeanGetBufferHostSize_16s_C4R to determine the minium number of bytes required.
     * @param aMean Array that contains computed mean, four elements for four channels.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMean_16s_C4R(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        double[] aMean)
    {
        return JNpp.checkResult(nppiMean_16s_C4RNative(pSrc, nSrcStep, oSizeROI, pDeviceBuffer, aMean));
    }
    private static native int nppiMean_16s_C4RNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        double[] aMean);


    /**
     * <pre>
     * 4-channel 32-bit floating point image mean with 64-bit double precision result.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer
     *        Use \ref nppiMeanGetBufferHostSize_32f_C4R to determine the minium number of bytes required.
     * @param aMean Array that contains computed mean, four elements for four channels.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, NPP_NOT_EVEN_STEP_ERROR if an invalid 
     * floating-point image is specified.
     * </pre>
     */
    public static int nppiMean_32f_C4R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        double[] aMean)
    {
        return JNpp.checkResult(nppiMean_32f_C4RNative(pSrc, nSrcStep, oSizeROI, pDeviceBuffer, aMean));
    }
    private static native int nppiMean_32f_C4RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        double[] aMean);


    /**
     * <pre>
     * 1-channel 8-bit unsigned char image mean with 64-bit double precision result, \ref masked_operation.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pMask \ref mask_image_pointer.
     * @param nMaskStep \ref mask_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer
     *        Use \ref nppiMeanGetBufferHostSize_8u_C1MR to determine the minium number of bytes required.
     * @param pMean Device-memory pointer receiving the mean result.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiMean_8u_C1MR(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        TypedPointer<Npp64f> pMean)
    {
        return JNpp.checkResult(nppiMean_8u_C1MRNative(pSrc, nSrcStep, pMask, nMaskStep, oSizeROI, pDeviceBuffer, pMean));
    }
    private static native int nppiMean_8u_C1MRNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        TypedPointer<Npp64f> pMean);


    /**
     * <pre>
     * 1-channel 8-bit signed char image mean with 64-bit double precision result, \ref masked_operation.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pMask \ref mask_image_pointer.
     * @param nMaskStep \ref mask_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer
     *        Use \ref nppiMeanGetBufferHostSize_8s_C1MR to determine the minium number of bytes required.
     * @param pMean Device-memory pointer receiving the mean result.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiMean_8s_C1MR(
        TypedPointer<Npp8s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        TypedPointer<Npp64f> pMean)
    {
        return JNpp.checkResult(nppiMean_8s_C1MRNative(pSrc, nSrcStep, pMask, nMaskStep, oSizeROI, pDeviceBuffer, pMean));
    }
    private static native int nppiMean_8s_C1MRNative(
        TypedPointer<Npp8s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        TypedPointer<Npp64f> pMean);


    /**
     * <pre>
     * 1-channel 16-bit unsigned short integer image mean with 64-bit double precision result, \ref masked_operation.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pMask \ref mask_image_pointer.
     * @param nMaskStep \ref mask_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer
     *        Use \ref nppiMeanGetBufferHostSize_16u_C1MR to determine the minium number of bytes required.
     * @param pMean Device-memory pointer receiving the mean result.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiMean_16u_C1MR(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        TypedPointer<Npp64f> pMean)
    {
        return JNpp.checkResult(nppiMean_16u_C1MRNative(pSrc, nSrcStep, pMask, nMaskStep, oSizeROI, pDeviceBuffer, pMean));
    }
    private static native int nppiMean_16u_C1MRNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        TypedPointer<Npp64f> pMean);


    /**
     * <pre>
     * 1-channel 32-bit floating point image mean with 64-bit double precision result, \ref masked_operation.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pMask \ref mask_image_pointer.
     * @param nMaskStep \ref mask_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer
     *        Use \ref nppiMeanGetBufferHostSize_32f_C1MR to determine the minium number of bytes required.
     * @param pMean Device-memory pointer receiving the mean result.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, NPP_NOT_EVEN_STEP_ERROR if an invalid 
     * floating-point image is specified.
     * </pre>
     */
    public static int nppiMean_32f_C1MR(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        TypedPointer<Npp64f> pMean)
    {
        return JNpp.checkResult(nppiMean_32f_C1MRNative(pSrc, nSrcStep, pMask, nMaskStep, oSizeROI, pDeviceBuffer, pMean));
    }
    private static native int nppiMean_32f_C1MRNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        TypedPointer<Npp64f> pMean);


    /**
     * <pre>
     * 3-channel 8-bit unsigned char image mean with 64-bit double precision result, \ref masked_operation, \ref channel_of_interest.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pMask \ref mask_image_pointer.
     * @param nMaskStep \ref mask_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nCOI \ref channel_of_interest_number.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer
     *        Use \ref nppiMeanGetBufferHostSize_8u_C3CMR to determine the minium number of bytes required.
     * @param pMean Device-memory pointer receiving the mean result.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, or NPP_COI_ERROR if an invalid channel of interest is specified.
     * </pre>
     */
    public static int nppiMean_8u_C3CMR(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep, 
        NppiSize oSizeROI, 
        int nCOI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        TypedPointer<Npp64f> pMean)
    {
        return JNpp.checkResult(nppiMean_8u_C3CMRNative(pSrc, nSrcStep, pMask, nMaskStep, oSizeROI, nCOI, pDeviceBuffer, pMean));
    }
    private static native int nppiMean_8u_C3CMRNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep, 
        NppiSize oSizeROI, 
        int nCOI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        TypedPointer<Npp64f> pMean);


    public static int nppiMean_8s_C3CMR(
        TypedPointer<Npp8s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep, 
        NppiSize oSizeROI, 
        int nCOI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        TypedPointer<Npp64f> pMean)
    {
        return JNpp.checkResult(nppiMean_8s_C3CMRNative(pSrc, nSrcStep, pMask, nMaskStep, oSizeROI, nCOI, pDeviceBuffer, pMean));
    }
    private static native int nppiMean_8s_C3CMRNative(
        TypedPointer<Npp8s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep, 
        NppiSize oSizeROI, 
        int nCOI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        TypedPointer<Npp64f> pMean);


    /**
     * <pre>
     * 3-channel 16-bit unsigned short integer image mean with 64-bit double precision result, \ref masked_operation, \ref channel_of_interest.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pMask \ref mask_image_pointer.
     * @param nMaskStep \ref mask_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nCOI \ref channel_of_interest_number.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer
     *        Use \ref nppiMeanGetBufferHostSize_16u_C3CMR to determine the minium number of bytes required.
     * @param pMean Device-memory pointer receiving the mean result.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, or NPP_COI_ERROR if an invalid channel of interest is specified.
     * </pre>
     */
    public static int nppiMean_16u_C3CMR(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep, 
        NppiSize oSizeROI, 
        int nCOI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        TypedPointer<Npp64f> pMean)
    {
        return JNpp.checkResult(nppiMean_16u_C3CMRNative(pSrc, nSrcStep, pMask, nMaskStep, oSizeROI, nCOI, pDeviceBuffer, pMean));
    }
    private static native int nppiMean_16u_C3CMRNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep, 
        NppiSize oSizeROI, 
        int nCOI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        TypedPointer<Npp64f> pMean);


    /**
     * <pre>
     * 3-channel 32-bit floating point image mean with 64-bit double precision result, \ref masked_operation, \ref channel_of_interest.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pMask \ref mask_image_pointer.
     * @param nMaskStep \ref mask_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nCOI \ref channel_of_interest_number.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer
     *        Use \ref nppiMeanGetBufferHostSize_32f_C3CMR to determine the minium number of bytes required.
     * @param pMean Device-memory pointer receiving the mean result.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, NPP_NOT_EVEN_STEP_ERROR if an invalid 
     * floating-point image is specified, or NPP_COI_ERROR if an invalid channel of interest is specified.
     * </pre>
     */
    public static int nppiMean_32f_C3CMR(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep, 
        NppiSize oSizeROI, 
        int nCOI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        TypedPointer<Npp64f> pMean)
    {
        return JNpp.checkResult(nppiMean_32f_C3CMRNative(pSrc, nSrcStep, pMask, nMaskStep, oSizeROI, nCOI, pDeviceBuffer, pMean));
    }
    private static native int nppiMean_32f_C3CMRNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep, 
        NppiSize oSizeROI, 
        int nCOI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        TypedPointer<Npp64f> pMean);


    public static int nppiMeanStdDevGetBufferHostSize_8u_C1R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiMeanStdDevGetBufferHostSize_8u_C1RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiMeanStdDevGetBufferHostSize_8u_C1RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiMean_StdDev_8s_C1R.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiMeanStdDevGetBufferHostSize_8s_C1R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)/** host pointer */
    {
        return JNpp.checkResult(nppiMeanStdDevGetBufferHostSize_8s_C1RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiMeanStdDevGetBufferHostSize_8s_C1RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);/** host pointer */


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiMean_StdDev_16u_C1R.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiMeanStdDevGetBufferHostSize_16u_C1R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiMeanStdDevGetBufferHostSize_16u_C1RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiMeanStdDevGetBufferHostSize_16u_C1RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiMean_StdDev_32f_C1R.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiMeanStdDevGetBufferHostSize_32f_C1R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)/** host pointer */
    {
        return JNpp.checkResult(nppiMeanStdDevGetBufferHostSize_32f_C1RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiMeanStdDevGetBufferHostSize_32f_C1RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);/** host pointer */


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiMean_StdDev_8u_C1MR.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiMeanStdDevGetBufferHostSize_8u_C1MR(
        NppiSize oSizeROI, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiMeanStdDevGetBufferHostSize_8u_C1MRNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiMeanStdDevGetBufferHostSize_8u_C1MRNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiMean_StdDev_8s_C1MR.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiMeanStdDevGetBufferHostSize_8s_C1MR(
        NppiSize oSizeROI, 
        int[] hpBufferSize)/** host pointer */
    {
        return JNpp.checkResult(nppiMeanStdDevGetBufferHostSize_8s_C1MRNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiMeanStdDevGetBufferHostSize_8s_C1MRNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);/** host pointer */


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiMean_StdDev_16u_C1MR.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiMeanStdDevGetBufferHostSize_16u_C1MR(
        NppiSize oSizeROI, 
        int[] hpBufferSize)/** host pointer */
    {
        return JNpp.checkResult(nppiMeanStdDevGetBufferHostSize_16u_C1MRNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiMeanStdDevGetBufferHostSize_16u_C1MRNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);/** host pointer */


    public static int nppiMeanStdDevGetBufferHostSize_32f_C1MR(
        NppiSize oSizeROI, 
        int[] hpBufferSize)/** host pointer */
    {
        return JNpp.checkResult(nppiMeanStdDevGetBufferHostSize_32f_C1MRNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiMeanStdDevGetBufferHostSize_32f_C1MRNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);/** host pointer */


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiMean_StdDev_8u_C3CR.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiMeanStdDevGetBufferHostSize_8u_C3CR(
        NppiSize oSizeROI, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiMeanStdDevGetBufferHostSize_8u_C3CRNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiMeanStdDevGetBufferHostSize_8u_C3CRNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);


    public static int nppiMeanStdDevGetBufferHostSize_8s_C3CR(
        NppiSize oSizeROI, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiMeanStdDevGetBufferHostSize_8s_C3CRNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiMeanStdDevGetBufferHostSize_8s_C3CRNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiMean_StdDev_16u_C3CR.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiMeanStdDevGetBufferHostSize_16u_C3CR(
        NppiSize oSizeROI, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiMeanStdDevGetBufferHostSize_16u_C3CRNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiMeanStdDevGetBufferHostSize_16u_C3CRNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiMean_StdDev_32f_C3CR.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiMeanStdDevGetBufferHostSize_32f_C3CR(
        NppiSize oSizeROI, 
        int[] hpBufferSize)/** host pointer */
    {
        return JNpp.checkResult(nppiMeanStdDevGetBufferHostSize_32f_C3CRNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiMeanStdDevGetBufferHostSize_32f_C3CRNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);/** host pointer */


    public static int nppiMeanStdDevGetBufferHostSize_8u_C3CMR(
        NppiSize oSizeROI, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiMeanStdDevGetBufferHostSize_8u_C3CMRNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiMeanStdDevGetBufferHostSize_8u_C3CMRNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiMean_StdDev_8s_C3CMR.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiMeanStdDevGetBufferHostSize_8s_C3CMR(
        NppiSize oSizeROI, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiMeanStdDevGetBufferHostSize_8s_C3CMRNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiMeanStdDevGetBufferHostSize_8s_C3CMRNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiMean_StdDev_16u_C3CMR.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiMeanStdDevGetBufferHostSize_16u_C3CMR(
        NppiSize oSizeROI, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiMeanStdDevGetBufferHostSize_16u_C3CMRNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiMeanStdDevGetBufferHostSize_16u_C3CMRNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiMean_StdDev_32f_C3CMR.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiMeanStdDevGetBufferHostSize_32f_C3CMR(
        NppiSize oSizeROI, 
        int[] hpBufferSize)/** host pointer */
    {
        return JNpp.checkResult(nppiMeanStdDevGetBufferHostSize_32f_C3CMRNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiMeanStdDevGetBufferHostSize_32f_C3CMRNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);/** host pointer */


    public static int nppiMean_StdDev_8u_C1R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        TypedPointer<Npp64f> pMean, 
        TypedPointer<Npp64f> pStdDev)
    {
        return JNpp.checkResult(nppiMean_StdDev_8u_C1RNative(pSrc, nSrcStep, oSizeROI, pDeviceBuffer, pMean, pStdDev));
    }
    private static native int nppiMean_StdDev_8u_C1RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        TypedPointer<Npp64f> pMean, 
        TypedPointer<Npp64f> pStdDev);


    /**
     * <pre>
     * 1-channel 8-bit signed char image mean and standard deviation.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer
     *        Use \ref nppiMeanStdDevGetBufferHostSize_8s_C1R to determine the minium number of bytes required.
     * @param pMean Contains computed mean.
     * @param pStdDev Contains computed standard deviation.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMean_StdDev_8s_C1R(
        TypedPointer<Npp8s> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        TypedPointer<Npp64f> pMean, 
        TypedPointer<Npp64f> pStdDev)
    {
        return JNpp.checkResult(nppiMean_StdDev_8s_C1RNative(pSrc, nSrcStep, oSizeROI, pDeviceBuffer, pMean, pStdDev));
    }
    private static native int nppiMean_StdDev_8s_C1RNative(
        TypedPointer<Npp8s> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        TypedPointer<Npp64f> pMean, 
        TypedPointer<Npp64f> pStdDev);


    /**
     * <pre>
     * 1-channel 16-bit unsigned short int image mean and standard deviation.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer
     *        Use \ref nppiMeanStdDevGetBufferHostSize_16u_C1R to determine the minium number of bytes required.
     * @param pMean Contains computed mean.
     * @param pStdDev Contains computed standard deviation.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMean_StdDev_16u_C1R(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        TypedPointer<Npp64f> pMean, 
        TypedPointer<Npp64f> pStdDev)
    {
        return JNpp.checkResult(nppiMean_StdDev_16u_C1RNative(pSrc, nSrcStep, oSizeROI, pDeviceBuffer, pMean, pStdDev));
    }
    private static native int nppiMean_StdDev_16u_C1RNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        TypedPointer<Npp64f> pMean, 
        TypedPointer<Npp64f> pStdDev);


    public static int nppiMean_StdDev_32f_C1R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        TypedPointer<Npp64f> pMean, 
        TypedPointer<Npp64f> pStdDev)
    {
        return JNpp.checkResult(nppiMean_StdDev_32f_C1RNative(pSrc, nSrcStep, oSizeROI, pDeviceBuffer, pMean, pStdDev));
    }
    private static native int nppiMean_StdDev_32f_C1RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        TypedPointer<Npp64f> pMean, 
        TypedPointer<Npp64f> pStdDev);


    /**
     * <pre>
     * 1-channel 8-bit unsigned char image mean and standard deviation, \ref masked_operation.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pMask \ref mask_image_pointer.
     * @param nMaskStep \ref mask_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer
     *        Use \ref nppiMeanStdDevGetBufferHostSize_8u_C1MR to determine the minium number of bytes required.
     * @param pMean Contains computed mean.
     * @param pStdDev Contains computed standard deviation.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMean_StdDev_8u_C1MR(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        TypedPointer<Npp64f> pMean, 
        TypedPointer<Npp64f> pStdDev)
    {
        return JNpp.checkResult(nppiMean_StdDev_8u_C1MRNative(pSrc, nSrcStep, pMask, nMaskStep, oSizeROI, pDeviceBuffer, pMean, pStdDev));
    }
    private static native int nppiMean_StdDev_8u_C1MRNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        TypedPointer<Npp64f> pMean, 
        TypedPointer<Npp64f> pStdDev);


    /**
     * <pre>
     * 1-channel 8-bit signed char image mean and standard deviation, \ref masked_operation.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pMask \ref mask_image_pointer.
     * @param nMaskStep \ref mask_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer
     *        Use \ref nppiMeanStdDevGetBufferHostSize_8s_C1MR to determine the minium number of bytes required.
     * @param pMean Contains computed mean.
     * @param pStdDev Contains computed standard deviation.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMean_StdDev_8s_C1MR(
        TypedPointer<Npp8s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        TypedPointer<Npp64f> pMean, 
        TypedPointer<Npp64f> pStdDev)
    {
        return JNpp.checkResult(nppiMean_StdDev_8s_C1MRNative(pSrc, nSrcStep, pMask, nMaskStep, oSizeROI, pDeviceBuffer, pMean, pStdDev));
    }
    private static native int nppiMean_StdDev_8s_C1MRNative(
        TypedPointer<Npp8s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        TypedPointer<Npp64f> pMean, 
        TypedPointer<Npp64f> pStdDev);


    /**
     * <pre>
     * 1-channel 16-bit unsigned short int image mean and standard deviation, \ref masked_operation.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pMask \ref mask_image_pointer.
     * @param nMaskStep \ref mask_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer
     *        Use \ref nppiMeanStdDevGetBufferHostSize_16u_C1MR to determine the minium number of bytes required.
     * @param pMean Contains computed mean.
     * @param pStdDev Contains computed standard deviation.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMean_StdDev_16u_C1MR(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        TypedPointer<Npp64f> pMean, 
        TypedPointer<Npp64f> pStdDev)
    {
        return JNpp.checkResult(nppiMean_StdDev_16u_C1MRNative(pSrc, nSrcStep, pMask, nMaskStep, oSizeROI, pDeviceBuffer, pMean, pStdDev));
    }
    private static native int nppiMean_StdDev_16u_C1MRNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        TypedPointer<Npp64f> pMean, 
        TypedPointer<Npp64f> pStdDev);


    /**
     * <pre>
     * 1-channel 32-bit floating-point image mean and standard deviation, \ref masked_operation.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pMask \ref mask_image_pointer.
     * @param nMaskStep \ref mask_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer
     *        Use \ref nppiMeanStdDevGetBufferHostSize_32f_C1MR to determine the minium number of bytes required.
     * @param pMean Contains computed mean.
     * @param pStdDev Contains computed standard deviation.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, or NPP_NOT_EVEN_STEP_ERROR if an invalid 
     * floating-point image is specified.
     * </pre>
     */
    public static int nppiMean_StdDev_32f_C1MR(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        TypedPointer<Npp64f> pMean, 
        TypedPointer<Npp64f> pStdDev)
    {
        return JNpp.checkResult(nppiMean_StdDev_32f_C1MRNative(pSrc, nSrcStep, pMask, nMaskStep, oSizeROI, pDeviceBuffer, pMean, pStdDev));
    }
    private static native int nppiMean_StdDev_32f_C1MRNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        TypedPointer<Npp64f> pMean, 
        TypedPointer<Npp64f> pStdDev);


    /**
     * <pre>
     * 3-channel 8-bit unsigned char image mean and standard deviation, \ref channel_of_interest.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nCOI \ref channel_of_interest_number.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer
     *        Use \ref nppiMeanStdDevGetBufferHostSize_8u_C3CR to determine the minium number of bytes required.
     * @param pMean Contains computed mean.
     * @param pStdDev Contains computed standard deviation.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, or NPP_COI_ERROR if an invalid channel of interest is specified.
     * </pre>
     */
    public static int nppiMean_StdDev_8u_C3CR(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        int nCOI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        TypedPointer<Npp64f> pMean, 
        TypedPointer<Npp64f> pStdDev)
    {
        return JNpp.checkResult(nppiMean_StdDev_8u_C3CRNative(pSrc, nSrcStep, oSizeROI, nCOI, pDeviceBuffer, pMean, pStdDev));
    }
    private static native int nppiMean_StdDev_8u_C3CRNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        int nCOI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        TypedPointer<Npp64f> pMean, 
        TypedPointer<Npp64f> pStdDev);


    /**
     * <pre>
     * 3-channel 8-bit signed char image mean and standard deviation, \ref channel_of_interest.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nCOI \ref channel_of_interest_number.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer
     *        Use \ref nppiMeanStdDevGetBufferHostSize_8s_C3CR to determine the minium number of bytes required.
     * @param pMean Contains computed mean.
     * @param pStdDev Contains computed standard deviation.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, or NPP_COI_ERROR if an invalid channel of interest is specified.
     * </pre>
     */
    public static int nppiMean_StdDev_8s_C3CR(
        TypedPointer<Npp8s> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        int nCOI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        TypedPointer<Npp64f> pMean, 
        TypedPointer<Npp64f> pStdDev)
    {
        return JNpp.checkResult(nppiMean_StdDev_8s_C3CRNative(pSrc, nSrcStep, oSizeROI, nCOI, pDeviceBuffer, pMean, pStdDev));
    }
    private static native int nppiMean_StdDev_8s_C3CRNative(
        TypedPointer<Npp8s> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        int nCOI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        TypedPointer<Npp64f> pMean, 
        TypedPointer<Npp64f> pStdDev);


    /**
     * <pre>
     * 3-channel 16-bit unsigned short int image mean and standard deviation, \ref channel_of_interest.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nCOI \ref channel_of_interest_number.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer
     *        Use \ref nppiMeanStdDevGetBufferHostSize_16u_C3CR to determine the minium number of bytes required.
     * @param pMean Contains computed mean.
     * @param pStdDev Contains computed standard deviation.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, or NPP_COI_ERROR if an invalid channel of interest is specified.
     * </pre>
     */
    public static int nppiMean_StdDev_16u_C3CR(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        int nCOI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        TypedPointer<Npp64f> pMean, 
        TypedPointer<Npp64f> pStdDev)
    {
        return JNpp.checkResult(nppiMean_StdDev_16u_C3CRNative(pSrc, nSrcStep, oSizeROI, nCOI, pDeviceBuffer, pMean, pStdDev));
    }
    private static native int nppiMean_StdDev_16u_C3CRNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        int nCOI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        TypedPointer<Npp64f> pMean, 
        TypedPointer<Npp64f> pStdDev);


    /**
     * <pre>
     * 3-channel 32-bit floating-point image mean and standard deviation, \ref channel_of_interest.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nCOI \ref channel_of_interest_number.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer
     *        Use \ref nppiMeanStdDevGetBufferHostSize_32f_C3CR to determine the minium number of bytes required.
     * @param pMean Contains computed mean.
     * @param pStdDev Contains computed standard deviation.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, NPP_NOT_EVEN_STEP_ERROR if an invalid 
     * floating-point image is specified, or NPP_COI_ERROR if an invalid channel of interest is specified.
     * </pre>
     */
    public static int nppiMean_StdDev_32f_C3CR(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        int nCOI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        TypedPointer<Npp64f> pMean, 
        TypedPointer<Npp64f> pStdDev)
    {
        return JNpp.checkResult(nppiMean_StdDev_32f_C3CRNative(pSrc, nSrcStep, oSizeROI, nCOI, pDeviceBuffer, pMean, pStdDev));
    }
    private static native int nppiMean_StdDev_32f_C3CRNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        int nCOI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        TypedPointer<Npp64f> pMean, 
        TypedPointer<Npp64f> pStdDev);


    /**
     * <pre>
     * 3-channel 8-bit unsigned char image mean and standard deviation, \ref masked_operation, \ref channel_of_interest.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pMask \ref mask_image_pointer.
     * @param nMaskStep \ref mask_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nCOI \ref channel_of_interest_number.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer
     *        Use \ref nppiMeanStdDevGetBufferHostSize_8u_C3CMR to determine the minium number of bytes required.
     * @param pMean Contains computed mean.
     * @param pStdDev Contains computed standard deviation.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, or NPP_COI_ERROR if an invalid channel of interest is specified.
     * </pre>
     */
    public static int nppiMean_StdDev_8u_C3CMR(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep, 
        NppiSize oSizeROI, 
        int nCOI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        TypedPointer<Npp64f> pMean, 
        TypedPointer<Npp64f> pStdDev)
    {
        return JNpp.checkResult(nppiMean_StdDev_8u_C3CMRNative(pSrc, nSrcStep, pMask, nMaskStep, oSizeROI, nCOI, pDeviceBuffer, pMean, pStdDev));
    }
    private static native int nppiMean_StdDev_8u_C3CMRNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep, 
        NppiSize oSizeROI, 
        int nCOI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        TypedPointer<Npp64f> pMean, 
        TypedPointer<Npp64f> pStdDev);


    /**
     * <pre>
     * 3-channel 8-bit signed char image mean and standard deviation, \ref masked_operation, \ref channel_of_interest.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pMask \ref mask_image_pointer.
     * @param nMaskStep \ref mask_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nCOI \ref channel_of_interest_number.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer
     *        Use \ref nppiMeanStdDevGetBufferHostSize_8s_C3CMR to determine the minium number of bytes required.
     * @param pMean Contains computed mean.
     * @param pStdDev Contains computed standard deviation.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, or NPP_COI_ERROR if an invalid channel of interest is specified.
     * </pre>
     */
    public static int nppiMean_StdDev_8s_C3CMR(
        TypedPointer<Npp8s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep, 
        NppiSize oSizeROI, 
        int nCOI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        TypedPointer<Npp64f> pMean, 
        TypedPointer<Npp64f> pStdDev)
    {
        return JNpp.checkResult(nppiMean_StdDev_8s_C3CMRNative(pSrc, nSrcStep, pMask, nMaskStep, oSizeROI, nCOI, pDeviceBuffer, pMean, pStdDev));
    }
    private static native int nppiMean_StdDev_8s_C3CMRNative(
        TypedPointer<Npp8s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep, 
        NppiSize oSizeROI, 
        int nCOI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        TypedPointer<Npp64f> pMean, 
        TypedPointer<Npp64f> pStdDev);


    /**
     * <pre>
     * 3-channel 16-bit unsigned short int image mean and standard deviation, \ref masked_operation, \ref channel_of_interest.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pMask \ref mask_image_pointer.
     * @param nMaskStep \ref mask_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nCOI \ref channel_of_interest_number.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer
     *        Use \ref nppiMeanStdDevGetBufferHostSize_16u_C3CMR to determine the minium number of bytes required.
     * @param pMean Contains computed mean.
     * @param pStdDev Contains computed standard deviation.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, or NPP_COI_ERROR if an invalid channel of interest is specified.
     * </pre>
     */
    public static int nppiMean_StdDev_16u_C3CMR(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep, 
        NppiSize oSizeROI, 
        int nCOI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        TypedPointer<Npp64f> pMean, 
        TypedPointer<Npp64f> pStdDev)
    {
        return JNpp.checkResult(nppiMean_StdDev_16u_C3CMRNative(pSrc, nSrcStep, pMask, nMaskStep, oSizeROI, nCOI, pDeviceBuffer, pMean, pStdDev));
    }
    private static native int nppiMean_StdDev_16u_C3CMRNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep, 
        NppiSize oSizeROI, 
        int nCOI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        TypedPointer<Npp64f> pMean, 
        TypedPointer<Npp64f> pStdDev);


    /**
     * <pre>
     * 3-channel 32-bit floating-point image mean and standard deviation, \ref masked_operation, \ref channel_of_interest.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pMask \ref mask_image_pointer.
     * @param nMaskStep \ref mask_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nCOI \ref channel_of_interest_number.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer
     *        Use \ref nppiMeanStdDevGetBufferHostSize_32f_C3CMR to determine the minium number of bytes required.
     * @param pMean Contains computed mean.
     * @param pStdDev Contains computed standard deviation.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, NPP_NOT_EVEN_STEP_ERROR if an invalid 
     * floating-point image is specified, or NPP_COI_ERROR if an invalid channel of interest is specified.
     * </pre>
     */
    public static int nppiMean_StdDev_32f_C3CMR(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep, 
        NppiSize oSizeROI, 
        int nCOI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        TypedPointer<Npp64f> pMean, 
        TypedPointer<Npp64f> pStdDev)
    {
        return JNpp.checkResult(nppiMean_StdDev_32f_C3CMRNative(pSrc, nSrcStep, pMask, nMaskStep, oSizeROI, nCOI, pDeviceBuffer, pMean, pStdDev));
    }
    private static native int nppiMean_StdDev_32f_C3CMRNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep, 
        NppiSize oSizeROI, 
        int nCOI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        TypedPointer<Npp64f> pMean, 
        TypedPointer<Npp64f> pStdDev);


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiNormInf_8u_C1R.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiNormInfGetBufferHostSize_8u_C1R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiNormInfGetBufferHostSize_8u_C1RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiNormInfGetBufferHostSize_8u_C1RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiNormInf_16u_C1R.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiNormInfGetBufferHostSize_16u_C1R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)/** host pointer */
    {
        return JNpp.checkResult(nppiNormInfGetBufferHostSize_16u_C1RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiNormInfGetBufferHostSize_16u_C1RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);/** host pointer */


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiNormInf_16s_C1R.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiNormInfGetBufferHostSize_16s_C1R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)/** host pointer */
    {
        return JNpp.checkResult(nppiNormInfGetBufferHostSize_16s_C1RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiNormInfGetBufferHostSize_16s_C1RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);/** host pointer */


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiNormInf_32s_C1R.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiNormInfGetBufferHostSize_32s_C1R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)/** host pointer */
    {
        return JNpp.checkResult(nppiNormInfGetBufferHostSize_32s_C1RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiNormInfGetBufferHostSize_32s_C1RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);/** host pointer */


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiNormInf_32f_C1R.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiNormInfGetBufferHostSize_32f_C1R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)/** host pointer */
    {
        return JNpp.checkResult(nppiNormInfGetBufferHostSize_32f_C1RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiNormInfGetBufferHostSize_32f_C1RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);/** host pointer */


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiNormInf_8u_C1MR.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiNormInfGetBufferHostSize_8u_C1MR(
        NppiSize oSizeROI, 
        int[] hpBufferSize)/** host pointer */
    {
        return JNpp.checkResult(nppiNormInfGetBufferHostSize_8u_C1MRNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiNormInfGetBufferHostSize_8u_C1MRNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);/** host pointer */


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiNormInf_8s_C1MR.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiNormInfGetBufferHostSize_8s_C1MR(
        NppiSize oSizeROI, 
        int[] hpBufferSize)/** host pointer */
    {
        return JNpp.checkResult(nppiNormInfGetBufferHostSize_8s_C1MRNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiNormInfGetBufferHostSize_8s_C1MRNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);/** host pointer */


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiNormInf_16u_C1MR.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiNormInfGetBufferHostSize_16u_C1MR(
        NppiSize oSizeROI, 
        int[] hpBufferSize)/** host pointer */
    {
        return JNpp.checkResult(nppiNormInfGetBufferHostSize_16u_C1MRNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiNormInfGetBufferHostSize_16u_C1MRNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);/** host pointer */


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiNormInf_32f_C1MR.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiNormInfGetBufferHostSize_32f_C1MR(
        NppiSize oSizeROI, 
        int[] hpBufferSize)/** host pointer */
    {
        return JNpp.checkResult(nppiNormInfGetBufferHostSize_32f_C1MRNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiNormInfGetBufferHostSize_32f_C1MRNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);/** host pointer */


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiNormInf_8u_C3R.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiNormInfGetBufferHostSize_8u_C3R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)/** host pointer */
    {
        return JNpp.checkResult(nppiNormInfGetBufferHostSize_8u_C3RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiNormInfGetBufferHostSize_8u_C3RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);/** host pointer */


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiNormInf_16u_C3R.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiNormInfGetBufferHostSize_16u_C3R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)/** host pointer */
    {
        return JNpp.checkResult(nppiNormInfGetBufferHostSize_16u_C3RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiNormInfGetBufferHostSize_16u_C3RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);/** host pointer */


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiNormInf_16s_C3R.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiNormInfGetBufferHostSize_16s_C3R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)/** host pointer */
    {
        return JNpp.checkResult(nppiNormInfGetBufferHostSize_16s_C3RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiNormInfGetBufferHostSize_16s_C3RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);/** host pointer */


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiNormInf_32f_C3R.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiNormInfGetBufferHostSize_32f_C3R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiNormInfGetBufferHostSize_32f_C3RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiNormInfGetBufferHostSize_32f_C3RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiNormInf_8u_AC4R.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiNormInfGetBufferHostSize_8u_AC4R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)/** host pointer */
    {
        return JNpp.checkResult(nppiNormInfGetBufferHostSize_8u_AC4RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiNormInfGetBufferHostSize_8u_AC4RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);/** host pointer */


    public static int nppiNormInfGetBufferHostSize_16u_AC4R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiNormInfGetBufferHostSize_16u_AC4RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiNormInfGetBufferHostSize_16u_AC4RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);


    /** host pointer */
    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiNormInf_16s_AC4R.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiNormInfGetBufferHostSize_16s_AC4R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)/** host pointer */
    {
        return JNpp.checkResult(nppiNormInfGetBufferHostSize_16s_AC4RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiNormInfGetBufferHostSize_16s_AC4RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);/** host pointer */


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiNormInf_32f_AC4R.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiNormInfGetBufferHostSize_32f_AC4R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiNormInfGetBufferHostSize_32f_AC4RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiNormInfGetBufferHostSize_32f_AC4RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiNormInf_8u_C4R.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiNormInfGetBufferHostSize_8u_C4R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)/** host pointer */
    {
        return JNpp.checkResult(nppiNormInfGetBufferHostSize_8u_C4RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiNormInfGetBufferHostSize_8u_C4RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);/** host pointer */


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiNormInf_16u_C4R.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiNormInfGetBufferHostSize_16u_C4R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)/** host pointer */
    {
        return JNpp.checkResult(nppiNormInfGetBufferHostSize_16u_C4RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiNormInfGetBufferHostSize_16u_C4RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);/** host pointer */


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiNormInf_16s_C4R.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiNormInfGetBufferHostSize_16s_C4R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)/** host pointer */
    {
        return JNpp.checkResult(nppiNormInfGetBufferHostSize_16s_C4RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiNormInfGetBufferHostSize_16s_C4RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);/** host pointer */


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiNormInf_32f_C4R.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiNormInfGetBufferHostSize_32f_C4R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)/** host pointer */
    {
        return JNpp.checkResult(nppiNormInfGetBufferHostSize_32f_C4RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiNormInfGetBufferHostSize_32f_C4RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);/** host pointer */


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiNormInf_8u_C3CMR.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiNormInfGetBufferHostSize_8u_C3CMR(
        NppiSize oSizeROI, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiNormInfGetBufferHostSize_8u_C3CMRNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiNormInfGetBufferHostSize_8u_C3CMRNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);


    /** host pointer */
    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiNormInf_8s_C3CMR.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiNormInfGetBufferHostSize_8s_C3CMR(
        NppiSize oSizeROI, 
        int[] hpBufferSize)/** host pointer */
    {
        return JNpp.checkResult(nppiNormInfGetBufferHostSize_8s_C3CMRNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiNormInfGetBufferHostSize_8s_C3CMRNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);/** host pointer */


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiNormInf_16u_C3CMR.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiNormInfGetBufferHostSize_16u_C3CMR(
        NppiSize oSizeROI, 
        int[] hpBufferSize)/** host pointer */
    {
        return JNpp.checkResult(nppiNormInfGetBufferHostSize_16u_C3CMRNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiNormInfGetBufferHostSize_16u_C3CMRNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);/** host pointer */


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiNormInf_32f_C3CMR.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiNormInfGetBufferHostSize_32f_C3CMR(
        NppiSize oSizeROI, 
        int[] hpBufferSize)/** host pointer */
    {
        return JNpp.checkResult(nppiNormInfGetBufferHostSize_32f_C3CMRNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiNormInfGetBufferHostSize_32f_C3CMRNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);/** host pointer */


    /**
     * <pre>
     * 1-channel 8-bit unsigned char image infinity norm.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pNorm Pointer to the norm value.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer. 
     * Use \ref nppiNormInfGetBufferHostSize_8u_C1R to compute the required size (in bytes).
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiNorm_Inf_8u_C1R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp64f> pNorm, 
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppiNorm_Inf_8u_C1RNative(pSrc, nSrcStep, oSizeROI, pNorm, pDeviceBuffer));
    }
    private static native int nppiNorm_Inf_8u_C1RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp64f> pNorm, 
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 1-channel 16-bit unsigned short image infinity norm.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pNorm Pointer to the norm value.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer. 
     * Use \ref nppiNormInfGetBufferHostSize_16u_C1R to compute the required size (in bytes).
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiNorm_Inf_16u_C1R(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp64f> pNorm, 
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppiNorm_Inf_16u_C1RNative(pSrc, nSrcStep, oSizeROI, pNorm, pDeviceBuffer));
    }
    private static native int nppiNorm_Inf_16u_C1RNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp64f> pNorm, 
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 1-channel 16-bit signed short image infinity norm.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pNorm Pointer to the norm value.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer. 
     * Use \ref nppiNormInfGetBufferHostSize_16s_C1R to compute the required size (in bytes).
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiNorm_Inf_16s_C1R(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp64f> pNorm, 
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppiNorm_Inf_16s_C1RNative(pSrc, nSrcStep, oSizeROI, pNorm, pDeviceBuffer));
    }
    private static native int nppiNorm_Inf_16s_C1RNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp64f> pNorm, 
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 1-channel 32-bit signed int image infinity norm.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pNorm Pointer to the norm value.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer. 
     * Use \ref nppiNormInfGetBufferHostSize_32s_C1R to compute the required size (in bytes).
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiNorm_Inf_32s_C1R(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp64f> pNorm, 
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppiNorm_Inf_32s_C1RNative(pSrc, nSrcStep, oSizeROI, pNorm, pDeviceBuffer));
    }
    private static native int nppiNorm_Inf_32s_C1RNative(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp64f> pNorm, 
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 1-channel 32-bit floating-point image infinity norm.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pNorm Pointer to the norm value.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer. 
     * Use \ref nppiNormInfGetBufferHostSize_32f_C1R to compute the required size (in bytes).
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiNorm_Inf_32f_C1R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp64f> pNorm, 
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppiNorm_Inf_32f_C1RNative(pSrc, nSrcStep, oSizeROI, pNorm, pDeviceBuffer));
    }
    private static native int nppiNorm_Inf_32f_C1RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp64f> pNorm, 
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 1-channel 8-bit unsigned char image infinity norm, \ref masked_operation.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pMask \ref mask_image_pointer.
     * @param nMaskStep \ref mask_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pNorm Pointer to the norm value.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer. 
     * Use \ref nppiNormInfGetBufferHostSize_8u_C1MR to compute the required size (in bytes).
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiNorm_Inf_8u_C1MR(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp64f> pNorm, 
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppiNorm_Inf_8u_C1MRNative(pSrc, nSrcStep, pMask, nMaskStep, oSizeROI, pNorm, pDeviceBuffer));
    }
    private static native int nppiNorm_Inf_8u_C1MRNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp64f> pNorm, 
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 1-channel 8-bit signed char image infinity norm, \ref masked_operation.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pMask \ref mask_image_pointer.
     * @param nMaskStep \ref mask_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pNorm Pointer to the norm value.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer. 
     * Use \ref nppiNormInfGetBufferHostSize_8s_C1MR to compute the required size (in bytes).
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiNorm_Inf_8s_C1MR(
        TypedPointer<Npp8s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp64f> pNorm, 
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppiNorm_Inf_8s_C1MRNative(pSrc, nSrcStep, pMask, nMaskStep, oSizeROI, pNorm, pDeviceBuffer));
    }
    private static native int nppiNorm_Inf_8s_C1MRNative(
        TypedPointer<Npp8s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp64f> pNorm, 
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 1-channel 16-bit unsigned short image infinity norm, \ref masked_operation.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pMask \ref mask_image_pointer.
     * @param nMaskStep \ref mask_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pNorm Pointer to the norm value.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer. 
     * Use \ref nppiNormInfGetBufferHostSize_16u_C1MR to compute the required size (in bytes).
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiNorm_Inf_16u_C1MR(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp64f> pNorm, 
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppiNorm_Inf_16u_C1MRNative(pSrc, nSrcStep, pMask, nMaskStep, oSizeROI, pNorm, pDeviceBuffer));
    }
    private static native int nppiNorm_Inf_16u_C1MRNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp64f> pNorm, 
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 1-channel 32-bit floating-point image infinity norm, \ref masked_operation.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pMask \ref mask_image_pointer.
     * @param nMaskStep \ref mask_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pNorm Pointer to the norm value.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer. 
     * Use \ref nppiNormInfGetBufferHostSize_32f_C1MR to compute the required size (in bytes).
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiNorm_Inf_32f_C1MR(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp64f> pNorm, 
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppiNorm_Inf_32f_C1MRNative(pSrc, nSrcStep, pMask, nMaskStep, oSizeROI, pNorm, pDeviceBuffer));
    }
    private static native int nppiNorm_Inf_32f_C1MRNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp64f> pNorm, 
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 3-channel 8-bit unsigned char image infinity norm.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param aNorm Array that contains the norm values of three channels.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer. 
     * Use \ref nppiNormInfGetBufferHostSize_8u_C3R to compute the required size (in bytes).
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiNorm_Inf_8u_C3R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        double[] aNorm, 
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppiNorm_Inf_8u_C3RNative(pSrc, nSrcStep, oSizeROI, aNorm, pDeviceBuffer));
    }
    private static native int nppiNorm_Inf_8u_C3RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        double[] aNorm, 
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 3-channel 16-bit unsigned short image infinity norm.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param aNorm Array that contains the norm values of three channels.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer. 
     * Use \ref nppiNormInfGetBufferHostSize_16u_C3R to compute the required size (in bytes).
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiNorm_Inf_16u_C3R(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        double[] aNorm, 
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppiNorm_Inf_16u_C3RNative(pSrc, nSrcStep, oSizeROI, aNorm, pDeviceBuffer));
    }
    private static native int nppiNorm_Inf_16u_C3RNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        double[] aNorm, 
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 3-channel 16-bit signed short image infinity norm.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param aNorm Array that contains the norm values of three channels.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer. 
     * Use \ref nppiNormInfGetBufferHostSize_16s_C3R to compute the required size (in bytes).
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiNorm_Inf_16s_C3R(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        double[] aNorm, 
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppiNorm_Inf_16s_C3RNative(pSrc, nSrcStep, oSizeROI, aNorm, pDeviceBuffer));
    }
    private static native int nppiNorm_Inf_16s_C3RNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        double[] aNorm, 
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 3-channel 32-bit floating-point image infinity norm.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param aNorm Array that contains the norm values of three channels.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer. 
     * Use \ref nppiNormInfGetBufferHostSize_32f_C3R to compute the required size (in bytes).
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiNorm_Inf_32f_C3R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        double[] aNorm, 
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppiNorm_Inf_32f_C3RNative(pSrc, nSrcStep, oSizeROI, aNorm, pDeviceBuffer));
    }
    private static native int nppiNorm_Inf_32f_C3RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        double[] aNorm, 
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 4-channel 8-bit unsigned char image infinity norm (alpha channel is not computed).
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param aNorm Array that contains the norm values of three channels.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer. 
     * Use \ref nppiNormInfGetBufferHostSize_8u_AC4R to compute the required size (in bytes).
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiNorm_Inf_8u_AC4R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        double[] aNorm, 
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppiNorm_Inf_8u_AC4RNative(pSrc, nSrcStep, oSizeROI, aNorm, pDeviceBuffer));
    }
    private static native int nppiNorm_Inf_8u_AC4RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        double[] aNorm, 
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 4-channel 16-bit unsigned short image infinity norm (alpha channel is not computed).
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param aNorm Array that contains the norm values of three channels.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer. 
     * Use \ref nppiNormInfGetBufferHostSize_16u_AC4R to compute the required size (in bytes).
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiNorm_Inf_16u_AC4R(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        double[] aNorm, 
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppiNorm_Inf_16u_AC4RNative(pSrc, nSrcStep, oSizeROI, aNorm, pDeviceBuffer));
    }
    private static native int nppiNorm_Inf_16u_AC4RNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        double[] aNorm, 
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 4-channel 16-bit signed short image infinity norm (alpha channel is not computed).
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param aNorm Array that contains the norm values of three channels.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer. 
     * Use \ref nppiNormInfGetBufferHostSize_16s_AC4R to compute the required size (in bytes).
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiNorm_Inf_16s_AC4R(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        double[] aNorm, 
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppiNorm_Inf_16s_AC4RNative(pSrc, nSrcStep, oSizeROI, aNorm, pDeviceBuffer));
    }
    private static native int nppiNorm_Inf_16s_AC4RNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        double[] aNorm, 
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 4-channel 32-bit floating-point image infinity norm (alpha channel is not computed).
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param aNorm Array that contains the norm values of three channels.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer. 
     * Use \ref nppiNormInfGetBufferHostSize_32f_AC4R to compute the required size (in bytes).
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiNorm_Inf_32f_AC4R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        double[] aNorm, 
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppiNorm_Inf_32f_AC4RNative(pSrc, nSrcStep, oSizeROI, aNorm, pDeviceBuffer));
    }
    private static native int nppiNorm_Inf_32f_AC4RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        double[] aNorm, 
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 4-channel 8-bit unsigned char image infinity norm.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param aNorm Array that contains the norm values of four channels.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer. 
     * Use \ref nppiNormInfGetBufferHostSize_8u_C4R to compute the required size (in bytes).
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiNorm_Inf_8u_C4R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        double[] aNorm, 
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppiNorm_Inf_8u_C4RNative(pSrc, nSrcStep, oSizeROI, aNorm, pDeviceBuffer));
    }
    private static native int nppiNorm_Inf_8u_C4RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        double[] aNorm, 
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 4-channel 16-bit unsigned short image infinity norm.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param aNorm Array that contains the norm values of four channels.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer. 
     * Use \ref nppiNormInfGetBufferHostSize_16u_C4R to compute the required size (in bytes).
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiNorm_Inf_16u_C4R(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        double[] aNorm, 
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppiNorm_Inf_16u_C4RNative(pSrc, nSrcStep, oSizeROI, aNorm, pDeviceBuffer));
    }
    private static native int nppiNorm_Inf_16u_C4RNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        double[] aNorm, 
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 4-channel 16-bit signed short image infinity norm.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param aNorm Array that contains the norm values of four channels.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer. 
     * Use \ref nppiNormInfGetBufferHostSize_16s_C4R to compute the required size (in bytes).
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiNorm_Inf_16s_C4R(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        double[] aNorm, 
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppiNorm_Inf_16s_C4RNative(pSrc, nSrcStep, oSizeROI, aNorm, pDeviceBuffer));
    }
    private static native int nppiNorm_Inf_16s_C4RNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        double[] aNorm, 
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 4-channel 32-bit floating-point image infinity norm.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param aNorm Array that contains the norm values of four channels.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer. 
     * Use \ref nppiNormInfGetBufferHostSize_32f_C4R to compute the required size (in bytes).
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiNorm_Inf_32f_C4R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        double[] aNorm, 
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppiNorm_Inf_32f_C4RNative(pSrc, nSrcStep, oSizeROI, aNorm, pDeviceBuffer));
    }
    private static native int nppiNorm_Inf_32f_C4RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        double[] aNorm, 
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 3-channel 8-bit unsigned char image infinity norm, \ref masked_operation, \ref channel_of_interest.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pMask \ref mask_image_pointer.
     * @param nMaskStep \ref mask_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nCOI \ref channel_of_interest_number.
     * @param pNorm Pointer to the norm value.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer. 
     * Use \ref nppiNormInfGetBufferHostSize_8u_C3CMR to compute the required size (in bytes).
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, or NPP_COI_ERROR if an invalid channel of interest is specified.
     * </pre>
     */
    public static int nppiNorm_Inf_8u_C3CMR(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep, 
        NppiSize oSizeROI, 
        int nCOI, 
        TypedPointer<Npp64f> pNorm, 
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppiNorm_Inf_8u_C3CMRNative(pSrc, nSrcStep, pMask, nMaskStep, oSizeROI, nCOI, pNorm, pDeviceBuffer));
    }
    private static native int nppiNorm_Inf_8u_C3CMRNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep, 
        NppiSize oSizeROI, 
        int nCOI, 
        TypedPointer<Npp64f> pNorm, 
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 3-channel 8-bit signed char image infinity norm, \ref masked_operation, \ref channel_of_interest.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pMask \ref mask_image_pointer.
     * @param nMaskStep \ref mask_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nCOI \ref channel_of_interest_number.
     * @param pNorm Pointer to the norm value.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer. 
     * Use \ref nppiNormInfGetBufferHostSize_8s_C3CMR to compute the required size (in bytes).
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, or NPP_COI_ERROR if an invalid channel of interest is specified.
     * </pre>
     */
    public static int nppiNorm_Inf_8s_C3CMR(
        TypedPointer<Npp8s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep, 
        NppiSize oSizeROI, 
        int nCOI, 
        TypedPointer<Npp64f> pNorm, 
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppiNorm_Inf_8s_C3CMRNative(pSrc, nSrcStep, pMask, nMaskStep, oSizeROI, nCOI, pNorm, pDeviceBuffer));
    }
    private static native int nppiNorm_Inf_8s_C3CMRNative(
        TypedPointer<Npp8s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep, 
        NppiSize oSizeROI, 
        int nCOI, 
        TypedPointer<Npp64f> pNorm, 
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 3-channel 16-bit unsigned short image infinity norm, \ref masked_operation, \ref channel_of_interest.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pMask \ref mask_image_pointer.
     * @param nMaskStep \ref mask_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nCOI \ref channel_of_interest_number.
     * @param pNorm Pointer to the norm value.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer. 
     * Use \ref nppiNormInfGetBufferHostSize_16u_C3CMR to compute the required size (in bytes).
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, or NPP_COI_ERROR if an invalid channel of interest is specified.
     * </pre>
     */
    public static int nppiNorm_Inf_16u_C3CMR(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep, 
        NppiSize oSizeROI, 
        int nCOI, 
        TypedPointer<Npp64f> pNorm, 
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppiNorm_Inf_16u_C3CMRNative(pSrc, nSrcStep, pMask, nMaskStep, oSizeROI, nCOI, pNorm, pDeviceBuffer));
    }
    private static native int nppiNorm_Inf_16u_C3CMRNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep, 
        NppiSize oSizeROI, 
        int nCOI, 
        TypedPointer<Npp64f> pNorm, 
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 3-channel 32-bit floating-point image infinity norm, \ref masked_operation, \ref channel_of_interest.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pMask \ref mask_image_pointer.
     * @param nMaskStep \ref mask_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nCOI \ref channel_of_interest_number.
     * @param pNorm Pointer to the norm value.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer. 
     * Use \ref nppiNormInfGetBufferHostSize_32f_C3CMR to compute the required size (in bytes).
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, NPP_NOT_EVEN_STEP_ERROR if an invalid 
     * floating-point image is specified, or NPP_COI_ERROR if an invalid channel of interest is specified.
     * </pre>
     */
    public static int nppiNorm_Inf_32f_C3CMR(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep, 
        NppiSize oSizeROI, 
        int nCOI, 
        TypedPointer<Npp64f> pNorm, 
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppiNorm_Inf_32f_C3CMRNative(pSrc, nSrcStep, pMask, nMaskStep, oSizeROI, nCOI, pNorm, pDeviceBuffer));
    }
    private static native int nppiNorm_Inf_32f_C3CMRNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep, 
        NppiSize oSizeROI, 
        int nCOI, 
        TypedPointer<Npp64f> pNorm, 
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiNormL1_8u_C1R.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiNormL1GetBufferHostSize_8u_C1R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)/** host pointer */
    {
        return JNpp.checkResult(nppiNormL1GetBufferHostSize_8u_C1RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiNormL1GetBufferHostSize_8u_C1RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);/** host pointer */


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiNormL1_16u_C1R.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiNormL1GetBufferHostSize_16u_C1R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiNormL1GetBufferHostSize_16u_C1RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiNormL1GetBufferHostSize_16u_C1RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiNormL1_16s_C1R.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiNormL1GetBufferHostSize_16s_C1R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)/** host pointer */
    {
        return JNpp.checkResult(nppiNormL1GetBufferHostSize_16s_C1RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiNormL1GetBufferHostSize_16s_C1RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);/** host pointer */


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiNormL1_32f_C1R.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiNormL1GetBufferHostSize_32f_C1R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)/** host pointer */
    {
        return JNpp.checkResult(nppiNormL1GetBufferHostSize_32f_C1RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiNormL1GetBufferHostSize_32f_C1RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);/** host pointer */


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiNormL1_8u_C1MR.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiNormL1GetBufferHostSize_8u_C1MR(
        NppiSize oSizeROI, 
        int[] hpBufferSize)/** host pointer */
    {
        return JNpp.checkResult(nppiNormL1GetBufferHostSize_8u_C1MRNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiNormL1GetBufferHostSize_8u_C1MRNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);/** host pointer */


    public static int nppiNormL1GetBufferHostSize_8s_C1MR(
        NppiSize oSizeROI, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiNormL1GetBufferHostSize_8s_C1MRNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiNormL1GetBufferHostSize_8s_C1MRNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiNormL1_16u_C1MR.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiNormL1GetBufferHostSize_16u_C1MR(
        NppiSize oSizeROI, 
        int[] hpBufferSize)/** host pointer */
    {
        return JNpp.checkResult(nppiNormL1GetBufferHostSize_16u_C1MRNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiNormL1GetBufferHostSize_16u_C1MRNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);/** host pointer */


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiNormL1_32f_C1MR.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiNormL1GetBufferHostSize_32f_C1MR(
        NppiSize oSizeROI, 
        int[] hpBufferSize)/** host pointer */
    {
        return JNpp.checkResult(nppiNormL1GetBufferHostSize_32f_C1MRNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiNormL1GetBufferHostSize_32f_C1MRNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);/** host pointer */


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiNormL1_8u_C3R.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiNormL1GetBufferHostSize_8u_C3R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)/** host pointer */
    {
        return JNpp.checkResult(nppiNormL1GetBufferHostSize_8u_C3RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiNormL1GetBufferHostSize_8u_C3RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);/** host pointer */


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiNormL1_16u_C3R.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiNormL1GetBufferHostSize_16u_C3R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiNormL1GetBufferHostSize_16u_C3RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiNormL1GetBufferHostSize_16u_C3RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiNormL1_16s_C3R.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiNormL1GetBufferHostSize_16s_C3R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)/** host pointer */
    {
        return JNpp.checkResult(nppiNormL1GetBufferHostSize_16s_C3RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiNormL1GetBufferHostSize_16s_C3RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);/** host pointer */


    public static int nppiNormL1GetBufferHostSize_32f_C3R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)/** host pointer */
    {
        return JNpp.checkResult(nppiNormL1GetBufferHostSize_32f_C3RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiNormL1GetBufferHostSize_32f_C3RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);/** host pointer */


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiNormL1_8u_AC4R.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiNormL1GetBufferHostSize_8u_AC4R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)/** host pointer */
    {
        return JNpp.checkResult(nppiNormL1GetBufferHostSize_8u_AC4RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiNormL1GetBufferHostSize_8u_AC4RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);/** host pointer */


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiNormL1_16u_AC4R.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiNormL1GetBufferHostSize_16u_AC4R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiNormL1GetBufferHostSize_16u_AC4RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiNormL1GetBufferHostSize_16u_AC4RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiNormL1_16s_AC4R.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiNormL1GetBufferHostSize_16s_AC4R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)/** host pointer */
    {
        return JNpp.checkResult(nppiNormL1GetBufferHostSize_16s_AC4RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiNormL1GetBufferHostSize_16s_AC4RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);/** host pointer */


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiNormL1_32f_AC4R.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiNormL1GetBufferHostSize_32f_AC4R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiNormL1GetBufferHostSize_32f_AC4RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiNormL1GetBufferHostSize_32f_AC4RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);


    /** host pointer */
    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiNormL1_8u_C4R.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiNormL1GetBufferHostSize_8u_C4R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)/** host pointer */
    {
        return JNpp.checkResult(nppiNormL1GetBufferHostSize_8u_C4RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiNormL1GetBufferHostSize_8u_C4RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);/** host pointer */


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiNormL1_16u_C4R.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiNormL1GetBufferHostSize_16u_C4R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiNormL1GetBufferHostSize_16u_C4RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiNormL1GetBufferHostSize_16u_C4RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);


    /** host pointer */
    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiNormL1_16s_C4R.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiNormL1GetBufferHostSize_16s_C4R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)/** host pointer */
    {
        return JNpp.checkResult(nppiNormL1GetBufferHostSize_16s_C4RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiNormL1GetBufferHostSize_16s_C4RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);/** host pointer */


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiNormL1_32f_C4R.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiNormL1GetBufferHostSize_32f_C4R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)/** host pointer */
    {
        return JNpp.checkResult(nppiNormL1GetBufferHostSize_32f_C4RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiNormL1GetBufferHostSize_32f_C4RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);/** host pointer */


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiNormL1_8u_C3CMR.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiNormL1GetBufferHostSize_8u_C3CMR(
        NppiSize oSizeROI, 
        int[] hpBufferSize)/** host pointer */
    {
        return JNpp.checkResult(nppiNormL1GetBufferHostSize_8u_C3CMRNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiNormL1GetBufferHostSize_8u_C3CMRNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);/** host pointer */


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiNormL1_8s_C3CMR.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiNormL1GetBufferHostSize_8s_C3CMR(
        NppiSize oSizeROI, 
        int[] hpBufferSize)/** host pointer */
    {
        return JNpp.checkResult(nppiNormL1GetBufferHostSize_8s_C3CMRNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiNormL1GetBufferHostSize_8s_C3CMRNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);/** host pointer */


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiNormL1_16u_C3CMR.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiNormL1GetBufferHostSize_16u_C3CMR(
        NppiSize oSizeROI, 
        int[] hpBufferSize)/** host pointer */
    {
        return JNpp.checkResult(nppiNormL1GetBufferHostSize_16u_C3CMRNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiNormL1GetBufferHostSize_16u_C3CMRNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);/** host pointer */


    public static int nppiNormL1GetBufferHostSize_32f_C3CMR(
        NppiSize oSizeROI, 
        int[] hpBufferSize)/** host pointer */
    {
        return JNpp.checkResult(nppiNormL1GetBufferHostSize_32f_C3CMRNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiNormL1GetBufferHostSize_32f_C3CMRNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);/** host pointer */


    public static int nppiNorm_L1_8u_C1R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp64f> pNorm, 
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppiNorm_L1_8u_C1RNative(pSrc, nSrcStep, oSizeROI, pNorm, pDeviceBuffer));
    }
    private static native int nppiNorm_L1_8u_C1RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp64f> pNorm, 
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 1-channel 16-bit unsigned short image L1 norm.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pNorm Pointer to the norm value.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer. 
     * Use \ref nppiNormL1GetBufferHostSize_16u_C1R to compute the required size (in bytes).
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiNorm_L1_16u_C1R(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp64f> pNorm, 
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppiNorm_L1_16u_C1RNative(pSrc, nSrcStep, oSizeROI, pNorm, pDeviceBuffer));
    }
    private static native int nppiNorm_L1_16u_C1RNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp64f> pNorm, 
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 1-channel 16-bit signed short image L1 norm.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pNorm Pointer to the norm value.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer. 
     * Use \ref nppiNormL1GetBufferHostSize_16s_C1R to compute the required size (in bytes).
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiNorm_L1_16s_C1R(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp64f> pNorm, 
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppiNorm_L1_16s_C1RNative(pSrc, nSrcStep, oSizeROI, pNorm, pDeviceBuffer));
    }
    private static native int nppiNorm_L1_16s_C1RNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp64f> pNorm, 
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 1-channel 32-bit floating-point image L1 norm.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pNorm Pointer to the norm value.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer. 
     * Use \ref nppiNormL1GetBufferHostSize_32f_C1R to compute the required size (in bytes).
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiNorm_L1_32f_C1R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp64f> pNorm, 
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppiNorm_L1_32f_C1RNative(pSrc, nSrcStep, oSizeROI, pNorm, pDeviceBuffer));
    }
    private static native int nppiNorm_L1_32f_C1RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp64f> pNorm, 
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 1-channel 8-bit unsigned char image L1 norm, \ref masked_operation
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pMask \ref mask_image_pointer.
     * @param nMaskStep \ref mask_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pNorm Pointer to the norm value.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer. 
     * Use \ref nppiNormL1GetBufferHostSize_8u_C1MR to compute the required size (in bytes).
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiNorm_L1_8u_C1MR(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp64f> pNorm, 
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppiNorm_L1_8u_C1MRNative(pSrc, nSrcStep, pMask, nMaskStep, oSizeROI, pNorm, pDeviceBuffer));
    }
    private static native int nppiNorm_L1_8u_C1MRNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp64f> pNorm, 
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 1-channel 8-bit signed char image L1 norm, \ref masked_operation
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pMask \ref mask_image_pointer.
     * @param nMaskStep \ref mask_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pNorm Pointer to the norm value.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer. 
     * Use \ref nppiNormL1GetBufferHostSize_8s_C1MR to compute the required size (in bytes).
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiNorm_L1_8s_C1MR(
        TypedPointer<Npp8s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp64f> pNorm, 
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppiNorm_L1_8s_C1MRNative(pSrc, nSrcStep, pMask, nMaskStep, oSizeROI, pNorm, pDeviceBuffer));
    }
    private static native int nppiNorm_L1_8s_C1MRNative(
        TypedPointer<Npp8s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp64f> pNorm, 
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 1-channel 16-bit unsigned short image L1 norm, \ref masked_operation
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pMask \ref mask_image_pointer.
     * @param nMaskStep \ref mask_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pNorm Pointer to the norm value.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer. 
     * Use \ref nppiNormL1GetBufferHostSize_16u_C1MR to compute the required size (in bytes).
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiNorm_L1_16u_C1MR(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp64f> pNorm, 
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppiNorm_L1_16u_C1MRNative(pSrc, nSrcStep, pMask, nMaskStep, oSizeROI, pNorm, pDeviceBuffer));
    }
    private static native int nppiNorm_L1_16u_C1MRNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp64f> pNorm, 
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 1-channel 32-bit floating-point image L1 norm, \ref masked_operation. 
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pMask \ref mask_image_pointer.
     * @param nMaskStep \ref mask_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pNorm Pointer to the norm value.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer. 
     * Use \ref nppiNormL1GetBufferHostSize_32f_C1MR to compute the required size (in bytes).
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiNorm_L1_32f_C1MR(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp64f> pNorm, 
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppiNorm_L1_32f_C1MRNative(pSrc, nSrcStep, pMask, nMaskStep, oSizeROI, pNorm, pDeviceBuffer));
    }
    private static native int nppiNorm_L1_32f_C1MRNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp64f> pNorm, 
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 3-channel 8-bit unsigned char image L1 norm.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param aNorm Array that contains the norm values of three channels.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer. 
     * Use \ref nppiNormL1GetBufferHostSize_8u_C3R to compute the required size (in bytes).
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiNorm_L1_8u_C3R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        double[] aNorm, 
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppiNorm_L1_8u_C3RNative(pSrc, nSrcStep, oSizeROI, aNorm, pDeviceBuffer));
    }
    private static native int nppiNorm_L1_8u_C3RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        double[] aNorm, 
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 3-channel 16-bit unsigned short image L1 norm.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param aNorm Array that contains the norm values of three channels.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer. 
     * Use \ref nppiNormL1GetBufferHostSize_16u_C3R to compute the required size (in bytes).
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiNorm_L1_16u_C3R(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        double[] aNorm, 
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppiNorm_L1_16u_C3RNative(pSrc, nSrcStep, oSizeROI, aNorm, pDeviceBuffer));
    }
    private static native int nppiNorm_L1_16u_C3RNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        double[] aNorm, 
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 3-channel 16-bit signed short image L1 norm.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param aNorm Array that contains the norm values of three channels.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer. 
     * Use \ref nppiNormL1GetBufferHostSize_16s_C3R to compute the required size (in bytes).
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiNorm_L1_16s_C3R(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        double[] aNorm, 
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppiNorm_L1_16s_C3RNative(pSrc, nSrcStep, oSizeROI, aNorm, pDeviceBuffer));
    }
    private static native int nppiNorm_L1_16s_C3RNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        double[] aNorm, 
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 3-channel 32-bit floating-point image L1 norm.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param aNorm Array that contains the norm values of three channels.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer. 
     * Use \ref nppiNormL1GetBufferHostSize_32f_C3R to compute the required size (in bytes).
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiNorm_L1_32f_C3R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        double[] aNorm, 
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppiNorm_L1_32f_C3RNative(pSrc, nSrcStep, oSizeROI, aNorm, pDeviceBuffer));
    }
    private static native int nppiNorm_L1_32f_C3RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        double[] aNorm, 
        TypedPointer<Npp8u> pDeviceBuffer);


    public static int nppiNorm_L1_8u_AC4R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        double[] aNorm, 
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppiNorm_L1_8u_AC4RNative(pSrc, nSrcStep, oSizeROI, aNorm, pDeviceBuffer));
    }
    private static native int nppiNorm_L1_8u_AC4RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        double[] aNorm, 
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 4-channel 16-bit unsigned short image L1 norm (alpha channel is not computed).
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param aNorm Array that contains the norm values of three channels.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer. 
     * Use \ref nppiNormL1GetBufferHostSize_16u_AC4R to compute the required size (in bytes).
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiNorm_L1_16u_AC4R(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        double[] aNorm, 
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppiNorm_L1_16u_AC4RNative(pSrc, nSrcStep, oSizeROI, aNorm, pDeviceBuffer));
    }
    private static native int nppiNorm_L1_16u_AC4RNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        double[] aNorm, 
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 4-channel 16-bit signed short image L1 norm (alpha channel is not computed).
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param aNorm Array that contains the norm values of three channels.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer. 
     * Use \ref nppiNormL1GetBufferHostSize_16s_AC4R to compute the required size (in bytes).
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiNorm_L1_16s_AC4R(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        double[] aNorm, 
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppiNorm_L1_16s_AC4RNative(pSrc, nSrcStep, oSizeROI, aNorm, pDeviceBuffer));
    }
    private static native int nppiNorm_L1_16s_AC4RNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        double[] aNorm, 
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 4-channel 32-bit floating-point image L1 norm (alpha channel is not computed).
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param aNorm Array that contains the norm values of three channels.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer. 
     * Use \ref nppiNormL1GetBufferHostSize_32f_AC4R to compute the required size (in bytes).
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiNorm_L1_32f_AC4R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        double[] aNorm, 
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppiNorm_L1_32f_AC4RNative(pSrc, nSrcStep, oSizeROI, aNorm, pDeviceBuffer));
    }
    private static native int nppiNorm_L1_32f_AC4RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        double[] aNorm, 
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 4-channel 8-bit unsigned char image L1 norm.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param aNorm Array that contains the norm values of four channels.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer. 
     * Use \ref nppiNormL1GetBufferHostSize_8u_C4R to compute the required size (in bytes).
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiNorm_L1_8u_C4R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        double[] aNorm, 
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppiNorm_L1_8u_C4RNative(pSrc, nSrcStep, oSizeROI, aNorm, pDeviceBuffer));
    }
    private static native int nppiNorm_L1_8u_C4RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        double[] aNorm, 
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 4-channel 16-bit unsigned short image L1 norm.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param aNorm Array that contains the norm values of four channels.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer. 
     * Use \ref nppiNormL1GetBufferHostSize_16u_C4R to compute the required size (in bytes).
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiNorm_L1_16u_C4R(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        double[] aNorm, 
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppiNorm_L1_16u_C4RNative(pSrc, nSrcStep, oSizeROI, aNorm, pDeviceBuffer));
    }
    private static native int nppiNorm_L1_16u_C4RNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        double[] aNorm, 
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 4-channel 16-bit signed short image L1 norm.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param aNorm Array that contains the norm values of four channels.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer. 
     * Use \ref nppiNormL1GetBufferHostSize_16s_C4R to compute the required size (in bytes).
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiNorm_L1_16s_C4R(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        double[] aNorm, 
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppiNorm_L1_16s_C4RNative(pSrc, nSrcStep, oSizeROI, aNorm, pDeviceBuffer));
    }
    private static native int nppiNorm_L1_16s_C4RNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        double[] aNorm, 
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 4-channel 32-bit floating-point image L1 norm.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param aNorm Array that contains the norm values of four channels.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer. 
     * Use \ref nppiNormL1GetBufferHostSize_32f_C4R to compute the required size (in bytes).
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiNorm_L1_32f_C4R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        double[] aNorm, 
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppiNorm_L1_32f_C4RNative(pSrc, nSrcStep, oSizeROI, aNorm, pDeviceBuffer));
    }
    private static native int nppiNorm_L1_32f_C4RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        double[] aNorm, 
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 3-channel 8-bit unsigned char image L1 norm, \ref masked_operation, \ref channel_of_interest.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pMask \ref mask_image_pointer.
     * @param nMaskStep \ref mask_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nCOI \ref channel_of_interest_number.
     * @param pNorm Pointer to the norm value.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer. 
     * Use \ref nppiNormL1GetBufferHostSize_8u_C3CMR to compute the required size (in bytes).
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, or NPP_COI_ERROR if an invalid channel of interest is specified.
     * </pre>
     */
    public static int nppiNorm_L1_8u_C3CMR(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep, 
        NppiSize oSizeROI, 
        int nCOI, 
        TypedPointer<Npp64f> pNorm, 
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppiNorm_L1_8u_C3CMRNative(pSrc, nSrcStep, pMask, nMaskStep, oSizeROI, nCOI, pNorm, pDeviceBuffer));
    }
    private static native int nppiNorm_L1_8u_C3CMRNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep, 
        NppiSize oSizeROI, 
        int nCOI, 
        TypedPointer<Npp64f> pNorm, 
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 3-channel 8-bit signed char image L1 norm, \ref masked_operation, \ref channel_of_interest.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pMask \ref mask_image_pointer.
     * @param nMaskStep \ref mask_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nCOI \ref channel_of_interest_number.
     * @param pNorm Pointer to the norm value.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer. 
     * Use \ref nppiNormL1GetBufferHostSize_8s_C3CMR to compute the required size (in bytes).
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, or NPP_COI_ERROR if an invalid channel of interest is specified.
     * </pre>
     */
    public static int nppiNorm_L1_8s_C3CMR(
        TypedPointer<Npp8s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep, 
        NppiSize oSizeROI, 
        int nCOI, 
        TypedPointer<Npp64f> pNorm, 
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppiNorm_L1_8s_C3CMRNative(pSrc, nSrcStep, pMask, nMaskStep, oSizeROI, nCOI, pNorm, pDeviceBuffer));
    }
    private static native int nppiNorm_L1_8s_C3CMRNative(
        TypedPointer<Npp8s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep, 
        NppiSize oSizeROI, 
        int nCOI, 
        TypedPointer<Npp64f> pNorm, 
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 3-channel 16-bit unsigned short image L1 norm, \ref masked_operation, \ref channel_of_interest.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pMask \ref mask_image_pointer.
     * @param nMaskStep \ref mask_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nCOI \ref channel_of_interest_number.
     * @param pNorm Pointer to the norm value.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer. 
     * Use \ref nppiNormL1GetBufferHostSize_16u_C3CMR to compute the required size (in bytes).
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, or NPP_COI_ERROR if an invalid channel of interest is specified.
     * </pre>
     */
    public static int nppiNorm_L1_16u_C3CMR(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep, 
        NppiSize oSizeROI, 
        int nCOI, 
        TypedPointer<Npp64f> pNorm, 
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppiNorm_L1_16u_C3CMRNative(pSrc, nSrcStep, pMask, nMaskStep, oSizeROI, nCOI, pNorm, pDeviceBuffer));
    }
    private static native int nppiNorm_L1_16u_C3CMRNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep, 
        NppiSize oSizeROI, 
        int nCOI, 
        TypedPointer<Npp64f> pNorm, 
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 3-channel 32-bit floating-point image L1 norm, \ref masked_operation, \ref channel_of_interest.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pMask \ref mask_image_pointer.
     * @param nMaskStep \ref mask_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nCOI \ref channel_of_interest_number.
     * @param pNorm Pointer to the norm value.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer. 
     * Use \ref nppiNormL1GetBufferHostSize_32f_C3CMR to compute the required size (in bytes).
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, NPP_NOT_EVEN_STEP_ERROR if the step of 
     * the source image cannot be divided by 4, or NPP_COI_ERROR if an invalid channel of interest is specified.
     * </pre>
     */
    public static int nppiNorm_L1_32f_C3CMR(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep, 
        NppiSize oSizeROI, 
        int nCOI, 
        TypedPointer<Npp64f> pNorm, 
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppiNorm_L1_32f_C3CMRNative(pSrc, nSrcStep, pMask, nMaskStep, oSizeROI, nCOI, pNorm, pDeviceBuffer));
    }
    private static native int nppiNorm_L1_32f_C3CMRNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep, 
        NppiSize oSizeROI, 
        int nCOI, 
        TypedPointer<Npp64f> pNorm, 
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiNormL2_8u_C1R.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiNormL2GetBufferHostSize_8u_C1R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)/** host pointer */
    {
        return JNpp.checkResult(nppiNormL2GetBufferHostSize_8u_C1RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiNormL2GetBufferHostSize_8u_C1RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);/** host pointer */


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiNormL2_16u_C1R.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiNormL2GetBufferHostSize_16u_C1R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiNormL2GetBufferHostSize_16u_C1RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiNormL2GetBufferHostSize_16u_C1RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiNormL2_16s_C1R.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiNormL2GetBufferHostSize_16s_C1R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)/** host pointer */
    {
        return JNpp.checkResult(nppiNormL2GetBufferHostSize_16s_C1RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiNormL2GetBufferHostSize_16s_C1RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);/** host pointer */


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiNormL2_32f_C1R.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiNormL2GetBufferHostSize_32f_C1R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)/** host pointer */
    {
        return JNpp.checkResult(nppiNormL2GetBufferHostSize_32f_C1RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiNormL2GetBufferHostSize_32f_C1RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);/** host pointer */


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiNormL2_8u_C1MR.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiNormL2GetBufferHostSize_8u_C1MR(
        NppiSize oSizeROI, 
        int[] hpBufferSize)/** host pointer */
    {
        return JNpp.checkResult(nppiNormL2GetBufferHostSize_8u_C1MRNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiNormL2GetBufferHostSize_8u_C1MRNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);/** host pointer */


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiNormL2_8s_C1MR.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiNormL2GetBufferHostSize_8s_C1MR(
        NppiSize oSizeROI, 
        int[] hpBufferSize)/** host pointer */
    {
        return JNpp.checkResult(nppiNormL2GetBufferHostSize_8s_C1MRNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiNormL2GetBufferHostSize_8s_C1MRNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);/** host pointer */


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiNormL2_16u_C1MR.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiNormL2GetBufferHostSize_16u_C1MR(
        NppiSize oSizeROI, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiNormL2GetBufferHostSize_16u_C1MRNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiNormL2GetBufferHostSize_16u_C1MRNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiNormL2_32f_C1MR.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiNormL2GetBufferHostSize_32f_C1MR(
        NppiSize oSizeROI, 
        int[] hpBufferSize)/** host pointer */
    {
        return JNpp.checkResult(nppiNormL2GetBufferHostSize_32f_C1MRNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiNormL2GetBufferHostSize_32f_C1MRNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);/** host pointer */


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiNormL2_8u_C3R.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiNormL2GetBufferHostSize_8u_C3R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)/** host pointer */
    {
        return JNpp.checkResult(nppiNormL2GetBufferHostSize_8u_C3RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiNormL2GetBufferHostSize_8u_C3RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);/** host pointer */


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiNormL2_16u_C3R.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiNormL2GetBufferHostSize_16u_C3R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)/** host pointer */
    {
        return JNpp.checkResult(nppiNormL2GetBufferHostSize_16u_C3RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiNormL2GetBufferHostSize_16u_C3RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);/** host pointer */


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiNormL2_16s_C3R.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiNormL2GetBufferHostSize_16s_C3R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)/** host pointer */
    {
        return JNpp.checkResult(nppiNormL2GetBufferHostSize_16s_C3RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiNormL2GetBufferHostSize_16s_C3RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);/** host pointer */


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiNormL2_32f_C3R.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiNormL2GetBufferHostSize_32f_C3R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiNormL2GetBufferHostSize_32f_C3RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiNormL2GetBufferHostSize_32f_C3RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiNormL2_8u_AC4R.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiNormL2GetBufferHostSize_8u_AC4R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)/** host pointer */
    {
        return JNpp.checkResult(nppiNormL2GetBufferHostSize_8u_AC4RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiNormL2GetBufferHostSize_8u_AC4RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);/** host pointer */


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiNormL2_16u_AC4R.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiNormL2GetBufferHostSize_16u_AC4R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)/** host pointer */
    {
        return JNpp.checkResult(nppiNormL2GetBufferHostSize_16u_AC4RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiNormL2GetBufferHostSize_16u_AC4RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);/** host pointer */


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiNormL2_16s_AC4R.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiNormL2GetBufferHostSize_16s_AC4R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)/** host pointer */
    {
        return JNpp.checkResult(nppiNormL2GetBufferHostSize_16s_AC4RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiNormL2GetBufferHostSize_16s_AC4RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);/** host pointer */


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiNormL2_32f_AC4R.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiNormL2GetBufferHostSize_32f_AC4R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)/** host pointer */
    {
        return JNpp.checkResult(nppiNormL2GetBufferHostSize_32f_AC4RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiNormL2GetBufferHostSize_32f_AC4RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);/** host pointer */


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiNormL2_8u_C4R.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiNormL2GetBufferHostSize_8u_C4R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)/** host pointer */
    {
        return JNpp.checkResult(nppiNormL2GetBufferHostSize_8u_C4RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiNormL2GetBufferHostSize_8u_C4RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);/** host pointer */


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiNormL2_16u_C4R.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiNormL2GetBufferHostSize_16u_C4R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)/** host pointer */
    {
        return JNpp.checkResult(nppiNormL2GetBufferHostSize_16u_C4RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiNormL2GetBufferHostSize_16u_C4RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);/** host pointer */


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiNormL2_16s_C4R.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiNormL2GetBufferHostSize_16s_C4R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)/** host pointer */
    {
        return JNpp.checkResult(nppiNormL2GetBufferHostSize_16s_C4RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiNormL2GetBufferHostSize_16s_C4RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);/** host pointer */


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiNormL2_32f_C4R.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiNormL2GetBufferHostSize_32f_C4R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)/** host pointer */
    {
        return JNpp.checkResult(nppiNormL2GetBufferHostSize_32f_C4RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiNormL2GetBufferHostSize_32f_C4RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);/** host pointer */


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiNormL2_8u_C3CMR.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiNormL2GetBufferHostSize_8u_C3CMR(
        NppiSize oSizeROI, 
        int[] hpBufferSize)/** host pointer */
    {
        return JNpp.checkResult(nppiNormL2GetBufferHostSize_8u_C3CMRNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiNormL2GetBufferHostSize_8u_C3CMRNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);/** host pointer */


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiNormL2_8s_C3CMR.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiNormL2GetBufferHostSize_8s_C3CMR(
        NppiSize oSizeROI, 
        int[] hpBufferSize)/** host pointer */
    {
        return JNpp.checkResult(nppiNormL2GetBufferHostSize_8s_C3CMRNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiNormL2GetBufferHostSize_8s_C3CMRNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);/** host pointer */


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiNormL2_16u_C3CMR.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiNormL2GetBufferHostSize_16u_C3CMR(
        NppiSize oSizeROI, 
        int[] hpBufferSize)/** host pointer */
    {
        return JNpp.checkResult(nppiNormL2GetBufferHostSize_16u_C3CMRNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiNormL2GetBufferHostSize_16u_C3CMRNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);/** host pointer */


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppiNormL2_32f_C3CMR.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiNormL2GetBufferHostSize_32f_C3CMR(
        NppiSize oSizeROI, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiNormL2GetBufferHostSize_32f_C3CMRNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiNormL2GetBufferHostSize_32f_C3CMRNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);


    /**
     * <pre>
     * 1-channel 8-bit unsigned char image L2 norm.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pNorm Pointer to the norm value.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer. 
     * Use \ref nppiNormL2GetBufferHostSize_8u_C1R to compute the required size (in bytes).
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiNorm_L2_8u_C1R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp64f> pNorm, 
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppiNorm_L2_8u_C1RNative(pSrc, nSrcStep, oSizeROI, pNorm, pDeviceBuffer));
    }
    private static native int nppiNorm_L2_8u_C1RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp64f> pNorm, 
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 1-channel 16-bit unsigned short image L2 norm.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pNorm Pointer to the norm value.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer. 
     * Use \ref nppiNormL2GetBufferHostSize_16u_C1R to compute the required size (in bytes).
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiNorm_L2_16u_C1R(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp64f> pNorm, 
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppiNorm_L2_16u_C1RNative(pSrc, nSrcStep, oSizeROI, pNorm, pDeviceBuffer));
    }
    private static native int nppiNorm_L2_16u_C1RNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp64f> pNorm, 
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 1-channel 16-bit signed short image L2 norm.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pNorm Pointer to the norm value.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer. 
     * Use \ref nppiNormL2GetBufferHostSize_16s_C1R to compute the required size (in bytes).
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiNorm_L2_16s_C1R(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp64f> pNorm, 
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppiNorm_L2_16s_C1RNative(pSrc, nSrcStep, oSizeROI, pNorm, pDeviceBuffer));
    }
    private static native int nppiNorm_L2_16s_C1RNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp64f> pNorm, 
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 1-channel 32-bit floating-point image L2 norm.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pNorm Pointer to the norm value.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer. 
     * Use \ref nppiNormL2GetBufferHostSize_32f_C1R to compute the required size (in bytes).
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiNorm_L2_32f_C1R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp64f> pNorm, 
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppiNorm_L2_32f_C1RNative(pSrc, nSrcStep, oSizeROI, pNorm, pDeviceBuffer));
    }
    private static native int nppiNorm_L2_32f_C1RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp64f> pNorm, 
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * \ref masked_operation 1-channel 8-bit unsigned char image L2 norm.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pMask \ref mask_image_pointer.
     * @param nMaskStep \ref mask_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pNorm Pointer to the norm value.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer. 
     * Use \ref nppiNormL2GetBufferHostSize_8u_C1MR to compute the required size (in bytes).
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiNorm_L2_8u_C1MR(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp64f> pNorm, 
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppiNorm_L2_8u_C1MRNative(pSrc, nSrcStep, pMask, nMaskStep, oSizeROI, pNorm, pDeviceBuffer));
    }
    private static native int nppiNorm_L2_8u_C1MRNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp64f> pNorm, 
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * \ref masked_operation 1-channel 8-bit signed char image L2 norm.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pMask \ref mask_image_pointer.
     * @param nMaskStep \ref mask_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pNorm Pointer to the norm value.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer. 
     * Use \ref nppiNormL2GetBufferHostSize_8s_C1MR to compute the required size (in bytes).
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiNorm_L2_8s_C1MR(
        TypedPointer<Npp8s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp64f> pNorm, 
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppiNorm_L2_8s_C1MRNative(pSrc, nSrcStep, pMask, nMaskStep, oSizeROI, pNorm, pDeviceBuffer));
    }
    private static native int nppiNorm_L2_8s_C1MRNative(
        TypedPointer<Npp8s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp64f> pNorm, 
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * \ref masked_operation 1-channel 16-bit unsigned short image L2 norm.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pMask \ref mask_image_pointer.
     * @param nMaskStep \ref mask_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pNorm Pointer to the norm value.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer. 
     * Use \ref nppiNormL2GetBufferHostSize_16u_C1MR to compute the required size (in bytes).
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiNorm_L2_16u_C1MR(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp64f> pNorm, 
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppiNorm_L2_16u_C1MRNative(pSrc, nSrcStep, pMask, nMaskStep, oSizeROI, pNorm, pDeviceBuffer));
    }
    private static native int nppiNorm_L2_16u_C1MRNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp64f> pNorm, 
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * \ref masked_operation 1-channel 32-bit floating-point image L2 norm.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pMask \ref mask_image_pointer.
     * @param nMaskStep \ref mask_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pNorm Pointer to the norm value.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer. 
     * Use \ref nppiNormL2GetBufferHostSize_32f_C1MR to compute the required size (in bytes).
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, or NPP_NOT_EVEN_STEP_ERROR if the step 
     * of the source image cannot be divided by 4. 
     * </pre>
     */
    public static int nppiNorm_L2_32f_C1MR(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp64f> pNorm, 
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppiNorm_L2_32f_C1MRNative(pSrc, nSrcStep, pMask, nMaskStep, oSizeROI, pNorm, pDeviceBuffer));
    }
    private static native int nppiNorm_L2_32f_C1MRNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp64f> pNorm, 
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 3-channel 8-bit unsigned char image L2 norm.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param aNorm Array that contains the norm values of three channels.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer. 
     * Use \ref nppiNormL2GetBufferHostSize_8u_C3R to compute the required size (in bytes).
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiNorm_L2_8u_C3R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        double[] aNorm, 
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppiNorm_L2_8u_C3RNative(pSrc, nSrcStep, oSizeROI, aNorm, pDeviceBuffer));
    }
    private static native int nppiNorm_L2_8u_C3RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        double[] aNorm, 
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 3-channel 16-bit unsigned short image L2 norm.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param aNorm Array that contains the norm values of three channels.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer. 
     * Use \ref nppiNormL2GetBufferHostSize_16u_C3R to compute the required size (in bytes).
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiNorm_L2_16u_C3R(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        double[] aNorm, 
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppiNorm_L2_16u_C3RNative(pSrc, nSrcStep, oSizeROI, aNorm, pDeviceBuffer));
    }
    private static native int nppiNorm_L2_16u_C3RNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        double[] aNorm, 
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 3-channel 16-bit signed short image L2 norm.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param aNorm Array that contains the norm values of three channels.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer. 
     * Use \ref nppiNormL2GetBufferHostSize_16s_C3R to compute the required size (in bytes).
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiNorm_L2_16s_C3R(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        double[] aNorm, 
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppiNorm_L2_16s_C3RNative(pSrc, nSrcStep, oSizeROI, aNorm, pDeviceBuffer));
    }
    private static native int nppiNorm_L2_16s_C3RNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        double[] aNorm, 
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 3-channel 32-bit floating-point image L2 norm.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param aNorm Array that contains the norm values of three channels.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer. 
     * Use \ref nppiNormL2GetBufferHostSize_32f_C3R to compute the required size (in bytes).
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiNorm_L2_32f_C3R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        double[] aNorm, 
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppiNorm_L2_32f_C3RNative(pSrc, nSrcStep, oSizeROI, aNorm, pDeviceBuffer));
    }
    private static native int nppiNorm_L2_32f_C3RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        double[] aNorm, 
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 4-channel 8-bit unsigned char image L2 norm (alpha channel is not computed).
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param aNorm Array that contains the norm values of three channels.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer. 
     * Use \ref nppiNormL2GetBufferHostSize_8u_AC4R to compute the required size (in bytes).
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiNorm_L2_8u_AC4R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        double[] aNorm, 
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppiNorm_L2_8u_AC4RNative(pSrc, nSrcStep, oSizeROI, aNorm, pDeviceBuffer));
    }
    private static native int nppiNorm_L2_8u_AC4RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        double[] aNorm, 
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 4-channel 16-bit unsigned short image L2 norm (alpha channel is not computed).
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param aNorm Array that contains the norm values of three channels.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer. 
     * Use \ref nppiNormL2GetBufferHostSize_16u_AC4R to compute the required size (in bytes).
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiNorm_L2_16u_AC4R(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        double[] aNorm, 
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppiNorm_L2_16u_AC4RNative(pSrc, nSrcStep, oSizeROI, aNorm, pDeviceBuffer));
    }
    private static native int nppiNorm_L2_16u_AC4RNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        double[] aNorm, 
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 4-channel 16-bit signed short image L2 norm (alpha channel is not computed).
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param aNorm Array that contains the norm values of three channels.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer. 
     * Use \ref nppiNormL2GetBufferHostSize_16s_AC4R to compute the required size (in bytes).
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiNorm_L2_16s_AC4R(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        double[] aNorm, 
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppiNorm_L2_16s_AC4RNative(pSrc, nSrcStep, oSizeROI, aNorm, pDeviceBuffer));
    }
    private static native int nppiNorm_L2_16s_AC4RNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        double[] aNorm, 
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 4-channel 32-bit floating-point image L2 norm (alpha channel is not computed).
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param aNorm Array that contains the norm values of three channels.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer. 
     * Use \ref nppiNormL2GetBufferHostSize_32f_AC4R to compute the required size (in bytes).
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiNorm_L2_32f_AC4R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        double[] aNorm, 
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppiNorm_L2_32f_AC4RNative(pSrc, nSrcStep, oSizeROI, aNorm, pDeviceBuffer));
    }
    private static native int nppiNorm_L2_32f_AC4RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        double[] aNorm, 
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 4-channel 8-bit unsigned char image L2 norm.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param aNorm Array that contains the norm values of four channels.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer. 
     * Use \ref nppiNormL2GetBufferHostSize_8u_C4R to compute the required size (in bytes).
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiNorm_L2_8u_C4R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        double[] aNorm, 
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppiNorm_L2_8u_C4RNative(pSrc, nSrcStep, oSizeROI, aNorm, pDeviceBuffer));
    }
    private static native int nppiNorm_L2_8u_C4RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        double[] aNorm, 
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 4-channel 16-bit unsigned short image L2 norm.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param aNorm Array that contains the norm values of four channels.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer. 
     * Use \ref nppiNormL2GetBufferHostSize_16u_C4R to compute the required size (in bytes).
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiNorm_L2_16u_C4R(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        double[] aNorm, 
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppiNorm_L2_16u_C4RNative(pSrc, nSrcStep, oSizeROI, aNorm, pDeviceBuffer));
    }
    private static native int nppiNorm_L2_16u_C4RNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        double[] aNorm, 
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 4-channel 16-bit signed short image L2 norm.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param aNorm Array that contains the norm values of four channels.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer. 
     * Use \ref nppiNormL2GetBufferHostSize_16s_C4R to compute the required size (in bytes).
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiNorm_L2_16s_C4R(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        double[] aNorm, 
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppiNorm_L2_16s_C4RNative(pSrc, nSrcStep, oSizeROI, aNorm, pDeviceBuffer));
    }
    private static native int nppiNorm_L2_16s_C4RNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        double[] aNorm, 
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 4-channel 32-bit floating-point image L2 norm.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param aNorm Array that contains the norm values of four channels.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer. 
     *        Use \ref nppiNormL2GetBufferHostSize_32f_C4R to compute the required size (in bytes).
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes.
     * </pre>
     */
    public static int nppiNorm_L2_32f_C4R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        double[] aNorm, 
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppiNorm_L2_32f_C4RNative(pSrc, nSrcStep, oSizeROI, aNorm, pDeviceBuffer));
    }
    private static native int nppiNorm_L2_32f_C4RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        double[] aNorm, 
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 3-channel 8-bit unsigned char image L2 norm, \ref masked_operation, \ref channel_of_interest.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pMask \ref mask_image_pointer.
     * @param nMaskStep \ref mask_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nCOI \ref channel_of_interest_number.
     * @param pNorm Pointer to the norm value.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer. 
     *        Use \ref nppiNormL2GetBufferHostSize_8u_C3CMR to compute the required size (in bytes).
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, or NPP_COI_ERROR if an invalid channel of interest is specified.
     * </pre>
     */
    public static int nppiNorm_L2_8u_C3CMR(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep, 
        NppiSize oSizeROI, 
        int nCOI, 
        TypedPointer<Npp64f> pNorm, 
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppiNorm_L2_8u_C3CMRNative(pSrc, nSrcStep, pMask, nMaskStep, oSizeROI, nCOI, pNorm, pDeviceBuffer));
    }
    private static native int nppiNorm_L2_8u_C3CMRNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep, 
        NppiSize oSizeROI, 
        int nCOI, 
        TypedPointer<Npp64f> pNorm, 
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 3-channel 8-bit signed char image L2 norm, \ref masked_operation, \ref channel_of_interest.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pMask \ref mask_image_pointer.
     * @param nMaskStep \ref mask_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nCOI \ref channel_of_interest_number.
     * @param pNorm Pointer to the norm value.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer. 
     *        Use \ref nppiNormL2GetBufferHostSize_8s_C3CMR to compute the required size (in bytes).
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, or NPP_COI_ERROR if an invalid channel of interest is specified.
     * </pre>
     */
    public static int nppiNorm_L2_8s_C3CMR(
        TypedPointer<Npp8s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep, 
        NppiSize oSizeROI, 
        int nCOI, 
        TypedPointer<Npp64f> pNorm, 
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppiNorm_L2_8s_C3CMRNative(pSrc, nSrcStep, pMask, nMaskStep, oSizeROI, nCOI, pNorm, pDeviceBuffer));
    }
    private static native int nppiNorm_L2_8s_C3CMRNative(
        TypedPointer<Npp8s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep, 
        NppiSize oSizeROI, 
        int nCOI, 
        TypedPointer<Npp64f> pNorm, 
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 3-channel 16-bit unsigned short image L2 norm, \ref masked_operation, \ref channel_of_interest.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pMask \ref mask_image_pointer.
     * @param nMaskStep \ref mask_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nCOI \ref channel_of_interest_number.
     * @param pNorm Pointer to the norm value.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer. 
     *        Use \ref nppiNormL2GetBufferHostSize_16u_C3CMR to compute the required size (in bytes).
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, or NPP_COI_ERROR if an invalid channel of interest is specified.
     * </pre>
     */
    public static int nppiNorm_L2_16u_C3CMR(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep, 
        NppiSize oSizeROI, 
        int nCOI, 
        TypedPointer<Npp64f> pNorm, 
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppiNorm_L2_16u_C3CMRNative(pSrc, nSrcStep, pMask, nMaskStep, oSizeROI, nCOI, pNorm, pDeviceBuffer));
    }
    private static native int nppiNorm_L2_16u_C3CMRNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep, 
        NppiSize oSizeROI, 
        int nCOI, 
        TypedPointer<Npp64f> pNorm, 
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 3-channel 32-bit floating-point image L2 norm, \ref masked_operation, \ref channel_of_interest.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pMask \ref mask_image_pointer.
     * @param nMaskStep \ref mask_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nCOI \ref channel_of_interest_number.
     * @param pNorm Pointer to the norm value.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer. 
     * Use \ref nppiNormL2GetBufferHostSize_32f_C3CMR to compute the required size (in bytes).
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, NPP_NOT_EVEN_STEP_ERROR if the step 
     * of the source image cannot be divided by 4, or NPP_COI_ERROR if an invalid channel of interest is specified.
     * </pre>
     */
    public static int nppiNorm_L2_32f_C3CMR(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep, 
        NppiSize oSizeROI, 
        int nCOI, 
        TypedPointer<Npp64f> pNorm, 
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppiNorm_L2_32f_C3CMRNative(pSrc, nSrcStep, pMask, nMaskStep, oSizeROI, nCOI, pNorm, pDeviceBuffer));
    }
    private static native int nppiNorm_L2_32f_C3CMRNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep, 
        NppiSize oSizeROI, 
        int nCOI, 
        TypedPointer<Npp64f> pNorm, 
        TypedPointer<Npp8u> pDeviceBuffer);


    /** @name NormDiff
     *  Norm of pixel differences between two images.
     */
    ///@{
    /**
     * <pre>
     * 8-bit unsigned L1 norm of pixel differences.
     *
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrcStep1 \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrcStep2 \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pRetVal Contains computed L1-norm of differences. This is a host pointer.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiNormDiff_L1_8u_C1R(
        TypedPointer<Npp8u> pSrc1, 
        int nSrcStep1, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrcStep2, 
        NppiSize oSizeROI, 
        TypedPointer<Npp64f> pRetVal)
    {
        return JNpp.checkResult(nppiNormDiff_L1_8u_C1RNative(pSrc1, nSrcStep1, pSrc2, nSrcStep2, oSizeROI, pRetVal));
    }
    private static native int nppiNormDiff_L1_8u_C1RNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrcStep1, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrcStep2, 
        NppiSize oSizeROI, 
        TypedPointer<Npp64f> pRetVal);


    /**
     * <pre>
     * 8-bit unsigned L2 norm of pixel differences.
     *
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrcStep1 \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrcStep2 \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pRetVal Contains computed L1-norm of differences. This is a host pointer.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiNormDiff_L2_8u_C1R(
        TypedPointer<Npp8u> pSrc1, 
        int nSrcStep1, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrcStep2, 
        NppiSize oSizeROI, 
        TypedPointer<Npp64f> pRetVal)
    {
        return JNpp.checkResult(nppiNormDiff_L2_8u_C1RNative(pSrc1, nSrcStep1, pSrc2, nSrcStep2, oSizeROI, pRetVal));
    }
    private static native int nppiNormDiff_L2_8u_C1RNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrcStep1, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrcStep2, 
        NppiSize oSizeROI, 
        TypedPointer<Npp64f> pRetVal);


    /**
     * <pre>
     * 8-bit unsigned Infinity Norm of pixel differences.
     *
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrcStep1 \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrcStep2 \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param *pRetVal Contains computed L1-norm of differences. This is a host pointer.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiNormDiff_Inf_8u_C1R(
        TypedPointer<Npp8u> pSrc1, 
        int nSrcStep1, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrcStep2, 
        NppiSize oSizeROI, 
        TypedPointer<Npp64f> pRetVal)
    {
        return JNpp.checkResult(nppiNormDiff_Inf_8u_C1RNative(pSrc1, nSrcStep1, pSrc2, nSrcStep2, oSizeROI, pRetVal));
    }
    private static native int nppiNormDiff_Inf_8u_C1RNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrcStep1, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrcStep2, 
        NppiSize oSizeROI, 
        TypedPointer<Npp64f> pRetVal);


    /**
     * <pre>
     * SqrIntegral Transforms an image to integral and integral of pixel squares
     * representation. This function assumes that the integral and integral of squares 
     * images.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param pSqr \ref destination_image_pointer.
     * @param nSqrStep \ref destination_image_line_step.
     * @param oSrcROI \ref roi_specification.
     * @param val The value to add to pDst image pixels
     * @param valSqr The value to add to pSqr image pixels
     * @param integralImageNewHeight Extended height of output surfaces (needed by
     *        transpose in primitive)
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSqrIntegral_8u32s32f_C1R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        TypedPointer<Npp32f> pSqr, 
        int nSqrStep, 
        NppiSize oSrcROI, 
        int val, 
        float valSqr, 
        int integralImageNewHeight)
    {
        return JNpp.checkResult(nppiSqrIntegral_8u32s32f_C1RNative(pSrc, nSrcStep, pDst, nDstStep, pSqr, nSqrStep, oSrcROI, val, valSqr, integralImageNewHeight));
    }
    private static native int nppiSqrIntegral_8u32s32f_C1RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        TypedPointer<Npp32f> pSqr, 
        int nSqrStep, 
        NppiSize oSrcROI, 
        int val, 
        float valSqr, 
        int integralImageNewHeight);


    /**
     * <pre>
     * RectStdDev Computes the standard deviation of integral images
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSqr \ref destination_image_pointer.
     * @param nSqrStep \ref destination_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param rect rectangular window
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiRectStdDev_32s32f_C1R(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp64f> pSqr, 
        int nSqrStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        NppiRect rect)
    {
        return JNpp.checkResult(nppiRectStdDev_32s32f_C1RNative(pSrc, nSrcStep, pSqr, nSqrStep, pDst, nDstStep, oSizeROI, rect));
    }
    private static native int nppiRectStdDev_32s32f_C1RNative(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp64f> pSqr, 
        int nSqrStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        NppiRect rect);


    /**
     * <pre>
     * Compute levels with even distribution.
     *
     * @param hpLevels A host pointer to array which receives the levels being
     *        computed. The array needs to be of size nLevels.
     * @param nLevels The number of levels being computed. nLevels must be at least
     *        2, otherwise an NPP_HISTO_NUMBER_OF_LEVELS_ERROR error is returned.
     * @param nLowerLevel Lower boundary value of the lowest level.
     * @param nUpperLevel Upper boundary value of the greatest level.
     * @return
     *  Error code.
     * </pre>
     */
    public static int nppiEvenLevelsHost_32s(
        TypedPointer<Npp32s> hpLevels, 
        int nLevels, 
        int nLowerLevel, 
        int nUpperLevel)
    {
        return JNpp.checkResult(nppiEvenLevelsHost_32sNative(hpLevels, nLevels, nLowerLevel, nUpperLevel));
    }
    private static native int nppiEvenLevelsHost_32sNative(
        TypedPointer<Npp32s> hpLevels, 
        int nLevels, 
        int nLowerLevel, 
        int nUpperLevel);


    /**
     * <pre>
     * Scratch-buffer size for nppiHistogramEven_8u_C1R.
     * 
     * @param oSizeROI \ref roi_specification.
     * @param nLevels Number of levels in the histogram.
     * @param hpBufferSize Host pointer where required buffer size is returned.
     * @return
     *  Error Code.
     * </pre>
     */
    public static int nppiHistogramEvenGetBufferSize_8u_C1R(
        NppiSize oSizeROI, 
        int nLevels, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiHistogramEvenGetBufferSize_8u_C1RNative(oSizeROI, nLevels, hpBufferSize));
    }
    private static native int nppiHistogramEvenGetBufferSize_8u_C1RNative(
        NppiSize oSizeROI, 
        int nLevels, 
        int[] hpBufferSize);


    /**
     * <pre>
     * 8-bit unsigned histogram with evenly distributed bins.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pHist Pointer to array that receives the computed histogram. 
     *      The array must be of size nLevels-1. 
     * @param nLevels Number of levels.
     * @param nLowerLevel Lower boundary of lowest level bin.
     * @param nUpperLevel Upper boundary of highest level bin.
     * @param pBuffer Pointer to appropriately sized (nppiHistogramEvenGetBufferSize_8u_C1R) 
     *      scratch buffer.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiHistogramEven_8u_C1R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp32s> pHist, 
        int nLevels, 
        int nLowerLevel, 
        int nUpperLevel, 
        TypedPointer<Npp8u> pBuffer)
    {
        return JNpp.checkResult(nppiHistogramEven_8u_C1RNative(pSrc, nSrcStep, oSizeROI, pHist, nLevels, nLowerLevel, nUpperLevel, pBuffer));
    }
    private static native int nppiHistogramEven_8u_C1RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp32s> pHist, 
        int nLevels, 
        int nLowerLevel, 
        int nUpperLevel, 
        TypedPointer<Npp8u> pBuffer);


    /**
     * <pre>
     * Scratch-buffer size for nppiHistogramEven_8u_C3R.
     * 
     * @param oSizeROI \ref roi_specification.
     * @param nLevels Number of levels in the histogram.
     * @param hpBufferSize Host pointer where required buffer size is returned.
     * @return
     *  Error Code.
     * </pre>
     */
    public static int nppiHistogramEvenGetBufferSize_8u_C3R(
        NppiSize oSizeROI, 
        int[] nLevels, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiHistogramEvenGetBufferSize_8u_C3RNative(oSizeROI, nLevels, hpBufferSize));
    }
    private static native int nppiHistogramEvenGetBufferSize_8u_C3RNative(
        NppiSize oSizeROI, 
        int[] nLevels, 
        int[] hpBufferSize);


    /**
     * <pre>
     * 3 channel 8-bit unsigned histogram with evenly distributed bins.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pHist Array of pointers which are receiving computed histograms per color channel. 
     *      Array pointed by pHist[i] be of size nLevels[i]-1.
     * @param nLevels Array containing number of levels per color channel. 
     * @param nLowerLevel Array containing lower-level of lowest bin per color channel.
     * @param nUpperLevel Array containing upper-level of highest bin per color channel.
     * @param pBuffer Pointer to appropriately sized (nppiHistogramEvenGetBufferSize_8u_C3R) 
     *      scratch buffer.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiHistogramEven_8u_C3R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp32s>[] pHist, 
        int[] nLevels, 
        int[] nLowerLevel, 
        int[] nUpperLevel, 
        TypedPointer<Npp8u> pBuffer)
    {
        return JNpp.checkResult(nppiHistogramEven_8u_C3RNative(pSrc, nSrcStep, oSizeROI, pHist, nLevels, nLowerLevel, nUpperLevel, pBuffer));
    }
    private static native int nppiHistogramEven_8u_C3RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp32s>[] pHist, 
        int[] nLevels, 
        int[] nLowerLevel, 
        int[] nUpperLevel, 
        TypedPointer<Npp8u> pBuffer);


    /**
     * <pre>
     * Scratch-buffer size for nppiHistogramEven_8u_C4R.
     * 
     * @param oSizeROI ROI size.
     * @param nLevels Array containing number of levels per color channel.
     * @param hpBufferSize Host pointer where required buffer size is returned.
     * @return
     *  Error Code.
     * </pre>
     */
    public static int nppiHistogramEvenGetBufferSize_8u_C4R(
        NppiSize oSizeROI, 
        int[] nLevels, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiHistogramEvenGetBufferSize_8u_C4RNative(oSizeROI, nLevels, hpBufferSize));
    }
    private static native int nppiHistogramEvenGetBufferSize_8u_C4RNative(
        NppiSize oSizeROI, 
        int[] nLevels, 
        int[] hpBufferSize);


    /**
     * <pre>
     * 4 channel 8-bit unsigned histogram with evenly distributed bins.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pHist Array of pointers which are receiving computed histograms per color channel. 
     *      Array pointed by pHist[i] be of size nLevels[i]-1.
     * @param nLevels Array containing number of levels per color channel. 
     * @param nLowerLevel Array containing lower-level of lowest bin per color channel.
     * @param nUpperLevel Array containing upper-level of highest bin per color channel.
     * @param pBuffer Pointer to appropriately sized (nppiHistogramEvenGetBufferSize_8u_C4R) 
     *      scratch buffer.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiHistogramEven_8u_C4R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp32s>[] pHist, 
        int[] nLevels, 
        int[] nLowerLevel, 
        int[] nUpperLevel, 
        TypedPointer<Npp8u> pBuffer)
    {
        return JNpp.checkResult(nppiHistogramEven_8u_C4RNative(pSrc, nSrcStep, oSizeROI, pHist, nLevels, nLowerLevel, nUpperLevel, pBuffer));
    }
    private static native int nppiHistogramEven_8u_C4RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp32s>[] pHist, 
        int[] nLevels, 
        int[] nLowerLevel, 
        int[] nUpperLevel, 
        TypedPointer<Npp8u> pBuffer);


    /**
     * <pre>
     * Scratch-buffer size for nppiHistogramEven_8u_AC4R.
     * 
     * @param oSizeROI ROI size.
     * @param nLevels Array containing number of levels per color channel.
     * @param hpBufferSize Host pointer where required buffer size is returned.
     * @return
     *  Error Code.
     * </pre>
     */
    public static int nppiHistogramEvenGetBufferSize_8u_AC4R(
        NppiSize oSizeROI, 
        int[] nLevels, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiHistogramEvenGetBufferSize_8u_AC4RNative(oSizeROI, nLevels, hpBufferSize));
    }
    private static native int nppiHistogramEvenGetBufferSize_8u_AC4RNative(
        NppiSize oSizeROI, 
        int[] nLevels, 
        int[] hpBufferSize);


    /**
     * <pre>
     * 4 channel (alpha as the last channel) 8-bit unsigned histogram with evenly distributed bins.
     * Alpha channel is ignored during histogram computation.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pHist Array of pointers which are receiving computed histograms per color channel. 
     *      Array pointed by pHist[i] be of size nLevels[i]-1.
     * @param nLevels Array containing number of levels per color channel. 
     * @param nLowerLevel Array containing lower-level of lowest bin per color channel.
     * @param nUpperLevel Array containing upper-level of highest bin per color channel.
     * @param pBuffer Pointer to appropriately sized (nppiHistogramEvenGetBufferSize_8u_AC4R) 
     *      scratch buffer.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiHistogramEven_8u_AC4R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp32s>[] pHist, 
        int[] nLevels, 
        int[] nLowerLevel, 
        int[] nUpperLevel, 
        TypedPointer<Npp8u> pBuffer)
    {
        return JNpp.checkResult(nppiHistogramEven_8u_AC4RNative(pSrc, nSrcStep, oSizeROI, pHist, nLevels, nLowerLevel, nUpperLevel, pBuffer));
    }
    private static native int nppiHistogramEven_8u_AC4RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp32s>[] pHist, 
        int[] nLevels, 
        int[] nLowerLevel, 
        int[] nUpperLevel, 
        TypedPointer<Npp8u> pBuffer);


    /**
     * <pre>
     * Scratch-buffer size for nppiHistogramEven_16u_C1R.
     * 
     * @param oSizeROI \ref roi_specification.
     * @param nLevels Number of levels in the histogram.
     * @param hpBufferSize Host pointer where required buffer size is returned.
     * @return
     *  Error Code.
     * </pre>
     */
    public static int nppiHistogramEvenGetBufferSize_16u_C1R(
        NppiSize oSizeROI, 
        int nLevels, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiHistogramEvenGetBufferSize_16u_C1RNative(oSizeROI, nLevels, hpBufferSize));
    }
    private static native int nppiHistogramEvenGetBufferSize_16u_C1RNative(
        NppiSize oSizeROI, 
        int nLevels, 
        int[] hpBufferSize);


    public static int nppiHistogramEven_16u_C1R(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp32s> pHist, 
        int nLevels, 
        int nLowerLevel, 
        int nUpperLevel, 
        TypedPointer<Npp8u> pBuffer)
    {
        return JNpp.checkResult(nppiHistogramEven_16u_C1RNative(pSrc, nSrcStep, oSizeROI, pHist, nLevels, nLowerLevel, nUpperLevel, pBuffer));
    }
    private static native int nppiHistogramEven_16u_C1RNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp32s> pHist, 
        int nLevels, 
        int nLowerLevel, 
        int nUpperLevel, 
        TypedPointer<Npp8u> pBuffer);


    /**
     * <pre>
     * Scratch-buffer size for nppiHistogramEven_16u_C3R.
     * 
     * @param oSizeROI ROI size.
     * @param nLevels Array containing number of levels per color channel.
     * @param hpBufferSize Host pointer where required buffer size is returned.
     * @return
     *  Error Code.
     * </pre>
     */
    public static int nppiHistogramEvenGetBufferSize_16u_C3R(
        NppiSize oSizeROI, 
        int[] nLevels, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiHistogramEvenGetBufferSize_16u_C3RNative(oSizeROI, nLevels, hpBufferSize));
    }
    private static native int nppiHistogramEvenGetBufferSize_16u_C3RNative(
        NppiSize oSizeROI, 
        int[] nLevels, 
        int[] hpBufferSize);


    /**
     * <pre>
     * 3 channel 16-bit unsigned histogram with evenly distributed bins.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pHist Array of pointers which are receiving computed histograms per color channel. 
     *      Array pointed by pHist[i] be of size nLevels[i]-1.
     * @param nLevels Array containing number of levels per color channel. 
     * @param nLowerLevel Array containing lower-level of lowest bin per color channel.
     * @param nUpperLevel Array containing upper-level of highest bin per color channel.
     * @param pBuffer Pointer to appropriately sized (nppiHistogramEvenGetBufferSize_16u_C3R) 
     *      scratch buffer.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiHistogramEven_16u_C3R(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp32s>[] pHist, 
        int[] nLevels, 
        int[] nLowerLevel, 
        int[] nUpperLevel, 
        TypedPointer<Npp8u> pBuffer)
    {
        return JNpp.checkResult(nppiHistogramEven_16u_C3RNative(pSrc, nSrcStep, oSizeROI, pHist, nLevels, nLowerLevel, nUpperLevel, pBuffer));
    }
    private static native int nppiHistogramEven_16u_C3RNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp32s>[] pHist, 
        int[] nLevels, 
        int[] nLowerLevel, 
        int[] nUpperLevel, 
        TypedPointer<Npp8u> pBuffer);


    /**
     * <pre>
     * Scratch-buffer size for nppiHistogramEven_16u_C4R.
     * 
     * @param oSizeROI ROI size.
     * @param nLevels Array containing number of levels per color channel.
     * @param hpBufferSize Host pointer where required buffer size is returned.
     * @return
     *  Error Code.
     * </pre>
     */
    public static int nppiHistogramEvenGetBufferSize_16u_C4R(
        NppiSize oSizeROI, 
        int[] nLevels, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiHistogramEvenGetBufferSize_16u_C4RNative(oSizeROI, nLevels, hpBufferSize));
    }
    private static native int nppiHistogramEvenGetBufferSize_16u_C4RNative(
        NppiSize oSizeROI, 
        int[] nLevels, 
        int[] hpBufferSize);


    /**
     * <pre>
     * 4 channel 16-bit unsigned histogram with evenly distributed bins.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pHist Array of pointers which are receiving computed histograms per color channel. 
     *      Array pointed by pHist[i] be of size nLevels[i]-1.
     * @param nLevels Array containing number of levels per color channel. 
     * @param nLowerLevel Array containing lower-level of lowest bin per color channel.
     * @param nUpperLevel Array containing upper-level of highest bin per color channel.
     * @param pBuffer Pointer to appropriately sized (nppiHistogramEvenGetBufferSize_16u_C4R) 
     *      scratch buffer.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiHistogramEven_16u_C4R(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp32s>[] pHist, 
        int[] nLevels, 
        int[] nLowerLevel, 
        int[] nUpperLevel, 
        TypedPointer<Npp8u> pBuffer)
    {
        return JNpp.checkResult(nppiHistogramEven_16u_C4RNative(pSrc, nSrcStep, oSizeROI, pHist, nLevels, nLowerLevel, nUpperLevel, pBuffer));
    }
    private static native int nppiHistogramEven_16u_C4RNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp32s>[] pHist, 
        int[] nLevels, 
        int[] nLowerLevel, 
        int[] nUpperLevel, 
        TypedPointer<Npp8u> pBuffer);


    /**
     * <pre>
     * Scratch-buffer size for nppiHistogramEven_16u_AC4R.
     * 
     * @param oSizeROI ROI size.
     * @param nLevels Array containing number of levels per color channel.
     * @param hpBufferSize Host pointer where required buffer size is returned.
     * @return
     *  Error Code.
     * </pre>
     */
    public static int nppiHistogramEvenGetBufferSize_16u_AC4R(
        NppiSize oSizeROI, 
        int[] nLevels, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiHistogramEvenGetBufferSize_16u_AC4RNative(oSizeROI, nLevels, hpBufferSize));
    }
    private static native int nppiHistogramEvenGetBufferSize_16u_AC4RNative(
        NppiSize oSizeROI, 
        int[] nLevels, 
        int[] hpBufferSize);


    /**
     * <pre>
     * 4 channel (alpha as the last channel) 16-bit unsigned histogram with evenly distributed bins.
     * Alpha channel is ignored during histogram computation.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pHist Array of pointers which are receiving computed histograms per color channel. 
     *      Array pointed by pHist[i] be of size nLevels[i]-1.
     * @param nLevels Array containing number of levels per color channel. 
     * @param nLowerLevel Array containing lower-level of lowest bin per color channel.
     * @param nUpperLevel Array containing upper-level of highest bin per color channel.
     * @param pBuffer Pointer to appropriately sized (nppiHistogramEvenGetBufferSize_16u_AC4R) 
     *      scratch buffer.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiHistogramEven_16u_AC4R(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp32s>[] pHist, 
        int[] nLevels, 
        int[] nLowerLevel, 
        int[] nUpperLevel, 
        TypedPointer<Npp8u> pBuffer)
    {
        return JNpp.checkResult(nppiHistogramEven_16u_AC4RNative(pSrc, nSrcStep, oSizeROI, pHist, nLevels, nLowerLevel, nUpperLevel, pBuffer));
    }
    private static native int nppiHistogramEven_16u_AC4RNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp32s>[] pHist, 
        int[] nLevels, 
        int[] nLowerLevel, 
        int[] nUpperLevel, 
        TypedPointer<Npp8u> pBuffer);


    /**
     * <pre>
     * Scratch-buffer size for nppiHistogramEven_16s_C1R.
     * 
     * @param oSizeROI \ref roi_specification.
     * @param nLevels Number of levels in the histogram.
     * @param hpBufferSize Host pointer where required buffer size is returned.
     * @return
     *  Error Code.
     * </pre>
     */
    public static int nppiHistogramEvenGetBufferSize_16s_C1R(
        NppiSize oSizeROI, 
        int nLevels, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiHistogramEvenGetBufferSize_16s_C1RNative(oSizeROI, nLevels, hpBufferSize));
    }
    private static native int nppiHistogramEvenGetBufferSize_16s_C1RNative(
        NppiSize oSizeROI, 
        int nLevels, 
        int[] hpBufferSize);


    /**
     * <pre>
     * 16-bit signed histogram with evenly distributed bins.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pHist Pointer to array that receives the computed histogram. 
     *      The array must be of size nLevels-1. 
     * @param nLevels Number of levels.
     * @param nLowerLevel Lower boundary of lowest level bin.
     * @param nUpperLevel Upper boundary of highest level bin.
     * @param pBuffer Pointer to appropriately sized (nppiHistogramEvenGetBufferSize_16s_C1R) 
     *      scratch buffer.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiHistogramEven_16s_C1R(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp32s> pHist, 
        int nLevels, 
        int nLowerLevel, 
        int nUpperLevel, 
        TypedPointer<Npp8u> pBuffer)
    {
        return JNpp.checkResult(nppiHistogramEven_16s_C1RNative(pSrc, nSrcStep, oSizeROI, pHist, nLevels, nLowerLevel, nUpperLevel, pBuffer));
    }
    private static native int nppiHistogramEven_16s_C1RNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp32s> pHist, 
        int nLevels, 
        int nLowerLevel, 
        int nUpperLevel, 
        TypedPointer<Npp8u> pBuffer);


    /**
     * <pre>
     * Scratch-buffer size for nppiHistogramEven_16s_C3R.
     * 
     * @param oSizeROI ROI size.
     * @param nLevels Array containing number of levels per color channel.
     * @param hpBufferSize Host pointer where required buffer size is returned.
     * @return
     *  Error Code.
     * </pre>
     */
    public static int nppiHistogramEvenGetBufferSize_16s_C3R(
        NppiSize oSizeROI, 
        int[] nLevels, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiHistogramEvenGetBufferSize_16s_C3RNative(oSizeROI, nLevels, hpBufferSize));
    }
    private static native int nppiHistogramEvenGetBufferSize_16s_C3RNative(
        NppiSize oSizeROI, 
        int[] nLevels, 
        int[] hpBufferSize);


    public static int nppiHistogramEven_16s_C3R(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp32s>[] pHist, 
        int[] nLevels, 
        int[] nLowerLevel, 
        int[] nUpperLevel, 
        TypedPointer<Npp8u> pBuffer)
    {
        return JNpp.checkResult(nppiHistogramEven_16s_C3RNative(pSrc, nSrcStep, oSizeROI, pHist, nLevels, nLowerLevel, nUpperLevel, pBuffer));
    }
    private static native int nppiHistogramEven_16s_C3RNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp32s>[] pHist, 
        int[] nLevels, 
        int[] nLowerLevel, 
        int[] nUpperLevel, 
        TypedPointer<Npp8u> pBuffer);


    /**
     * <pre>
     * Scratch-buffer size for nppiHistogramEven_16s_C4R.
     * 
     * @param oSizeROI ROI size.
     * @param nLevels Array containing number of levels per color channel.
     * @param hpBufferSize Host pointer where required buffer size is returned.
     * @return
     *  Error Code.
     * </pre>
     */
    public static int nppiHistogramEvenGetBufferSize_16s_C4R(
        NppiSize oSizeROI, 
        int[] nLevels, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiHistogramEvenGetBufferSize_16s_C4RNative(oSizeROI, nLevels, hpBufferSize));
    }
    private static native int nppiHistogramEvenGetBufferSize_16s_C4RNative(
        NppiSize oSizeROI, 
        int[] nLevels, 
        int[] hpBufferSize);


    /**
     * <pre>
     * 4 channel 16-bit signed histogram with evenly distributed bins.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pHist Array of pointers which are receiving computed histograms per color channel. 
     *      Array pointed by pHist[i] be of size nLevels[i]-1.
     * @param nLevels Array containing number of levels per color channel. 
     * @param nLowerLevel Array containing lower-level of lowest bin per color channel.
     * @param nUpperLevel Array containing upper-level of highest bin per color channel.
     * @param pBuffer Pointer to appropriately sized (nppiHistogramEvenGetBufferSize_16s_C4R) 
     *      scratch buffer.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiHistogramEven_16s_C4R(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp32s>[] pHist, 
        int[] nLevels, 
        int[] nLowerLevel, 
        int[] nUpperLevel, 
        TypedPointer<Npp8u> pBuffer)
    {
        return JNpp.checkResult(nppiHistogramEven_16s_C4RNative(pSrc, nSrcStep, oSizeROI, pHist, nLevels, nLowerLevel, nUpperLevel, pBuffer));
    }
    private static native int nppiHistogramEven_16s_C4RNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp32s>[] pHist, 
        int[] nLevels, 
        int[] nLowerLevel, 
        int[] nUpperLevel, 
        TypedPointer<Npp8u> pBuffer);


    /**
     * <pre>
     * Scratch-buffer size for nppiHistogramEven_16s_AC4R.
     * 
     * @param oSizeROI ROI size.
     * @param nLevels Array containing number of levels per color channel.
     * @param hpBufferSize Host pointer where required buffer size is returned.
     * @return
     *  Error Code.
     * </pre>
     */
    public static int nppiHistogramEvenGetBufferSize_16s_AC4R(
        NppiSize oSizeROI, 
        int[] nLevels, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiHistogramEvenGetBufferSize_16s_AC4RNative(oSizeROI, nLevels, hpBufferSize));
    }
    private static native int nppiHistogramEvenGetBufferSize_16s_AC4RNative(
        NppiSize oSizeROI, 
        int[] nLevels, 
        int[] hpBufferSize);


    /**
     * <pre>
     * 4 channel (alpha as the last channel) 16-bit signed histogram with evenly distributed bins.
     * Alpha channel is ignored during histogram computation.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pHist Array of pointers which are receiving computed histograms per color channel. 
     *      Array pointed by pHist[i] be of size nLevels[i]-1.
     * @param nLevels Array containing number of levels per color channel. 
     * @param nLowerLevel Array containing lower-level of lowest bin per color channel.
     * @param nUpperLevel Array containing upper-level of highest bin per color channel.
     * @param pBuffer Pointer to appropriately sized (nppiHistogramEvenGetBufferSize_16s_AC4R) 
     *      scratch buffer.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiHistogramEven_16s_AC4R(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp32s>[] pHist, 
        int[] nLevels, 
        int[] nLowerLevel, 
        int[] nUpperLevel, 
        TypedPointer<Npp8u> pBuffer)
    {
        return JNpp.checkResult(nppiHistogramEven_16s_AC4RNative(pSrc, nSrcStep, oSizeROI, pHist, nLevels, nLowerLevel, nUpperLevel, pBuffer));
    }
    private static native int nppiHistogramEven_16s_AC4RNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp32s>[] pHist, 
        int[] nLevels, 
        int[] nLowerLevel, 
        int[] nUpperLevel, 
        TypedPointer<Npp8u> pBuffer);


    /**
     * <pre>
     * Scratch-buffer size for nppiHistogramRange_8u_C1R.
     * 
     * @param oSizeROI \ref roi_specification.
     * @param nLevels Number of levels in the histogram.
     * @param hpBufferSize Host pointer where required buffer size is returned.
     * @return
     *  Error Code.
     * </pre>
     */
    public static int nppiHistogramRangeGetBufferSize_8u_C1R(
        NppiSize oSizeROI, 
        int nLevels, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiHistogramRangeGetBufferSize_8u_C1RNative(oSizeROI, nLevels, hpBufferSize));
    }
    private static native int nppiHistogramRangeGetBufferSize_8u_C1RNative(
        NppiSize oSizeROI, 
        int nLevels, 
        int[] hpBufferSize);


    /**
     * <pre>
     * 8-bit unsigned histogram with bins determined by pLevels array.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pHist Pointer to array that receives the computed histogram. 
     *      The array must be of size nLevels-1. 
     * @param pLevels Pointer to array containing the level sizes of the bins.
            The array must be of size nLevels.
     * @param nLevels Number of levels in histogram.
     * @param pBuffer Pointer to appropriately sized (nppiHistogramRangeGetBufferSize_8u_C1R) 
     *      scratch buffer.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiHistogramRange_8u_C1R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp32s> pHist, 
        TypedPointer<Npp32s> pLevels, 
        int nLevels, 
        TypedPointer<Npp8u> pBuffer)
    {
        return JNpp.checkResult(nppiHistogramRange_8u_C1RNative(pSrc, nSrcStep, oSizeROI, pHist, pLevels, nLevels, pBuffer));
    }
    private static native int nppiHistogramRange_8u_C1RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp32s> pHist, 
        TypedPointer<Npp32s> pLevels, 
        int nLevels, 
        TypedPointer<Npp8u> pBuffer);


    /**
     * <pre>
     * Scratch-buffer size for nppiHistogramRange_8u_C3R.
     * 
     * @param oSizeROI ROI size.
     * @param nLevels Array containing number of levels per color channel.
     * @param hpBufferSize Host pointer where required buffer size is returned.
     * @return
     *  Error Code.
     * </pre>
     */
    public static int nppiHistogramRangeGetBufferSize_8u_C3R(
        NppiSize oSizeROI, 
        int[] nLevels, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiHistogramRangeGetBufferSize_8u_C3RNative(oSizeROI, nLevels, hpBufferSize));
    }
    private static native int nppiHistogramRangeGetBufferSize_8u_C3RNative(
        NppiSize oSizeROI, 
        int[] nLevels, 
        int[] hpBufferSize);


    /**
     * <pre>
     * 3 channel 8-bit unsigned histogram with bins determined by pLevels.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pHist Array of pointers which are receiving the computed histograms per color channel. 
     *      Array pointed by pHist[i] must be of size nLevels[i]-1.
     * @param nLevels Array containing number of levels per color channel. 
     * @param pLevels Array containing pointers to level-arrays per color channel.
            Array pointed by pLevel[i] must be of size nLevels[i].
     * @param pBuffer Pointer to appropriately sized (nppiHistogramRangeGetBufferSize_8u_C3R) 
     *      scratch buffer.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiHistogramRange_8u_C3R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp32s>[] pHist, 
        TypedPointer<Npp32s>[] pLevels, 
        int[] nLevels, 
        TypedPointer<Npp8u> pBuffer)
    {
        return JNpp.checkResult(nppiHistogramRange_8u_C3RNative(pSrc, nSrcStep, oSizeROI, pHist, pLevels, nLevels, pBuffer));
    }
    private static native int nppiHistogramRange_8u_C3RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp32s>[] pHist, 
        TypedPointer<Npp32s>[] pLevels, 
        int[] nLevels, 
        TypedPointer<Npp8u> pBuffer);


    /**
     * <pre>
     * Scratch-buffer size for nppiHistogramRange_8u_C4R.
     * 
     * @param oSizeROI ROI size.
     * @param nLevels Array containing number of levels per color channel.
     * @param hpBufferSize Host pointer where required buffer size is returned.
     * @return
     *  Error Code.
     * </pre>
     */
    public static int nppiHistogramRangeGetBufferSize_8u_C4R(
        NppiSize oSizeROI, 
        int[] nLevels, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiHistogramRangeGetBufferSize_8u_C4RNative(oSizeROI, nLevels, hpBufferSize));
    }
    private static native int nppiHistogramRangeGetBufferSize_8u_C4RNative(
        NppiSize oSizeROI, 
        int[] nLevels, 
        int[] hpBufferSize);


    /**
     * <pre>
     * 4 channel 8-bit unsigned histogram with bins determined by pLevels.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pHist Array of pointers which are receiving the computed histograms per color channel. 
     *      Array pointed by pHist[i] must be of size nLevels[i]-1.
     * @param nLevels Array containing number of levels per color channel. 
     * @param pLevels Array containing pointers to level-arrays per color channel.
            Array pointed by pLevel[i] must be of size nLevels[i].
     * @param pBuffer Pointer to appropriately sized (nppiHistogramRangeGetBufferSize_8u_C4R) 
     *      scratch buffer.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiHistogramRange_8u_C4R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp32s>[] pHist, 
        TypedPointer<Npp32s>[] pLevels, 
        int[] nLevels, 
        TypedPointer<Npp8u> pBuffer)
    {
        return JNpp.checkResult(nppiHistogramRange_8u_C4RNative(pSrc, nSrcStep, oSizeROI, pHist, pLevels, nLevels, pBuffer));
    }
    private static native int nppiHistogramRange_8u_C4RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp32s>[] pHist, 
        TypedPointer<Npp32s>[] pLevels, 
        int[] nLevels, 
        TypedPointer<Npp8u> pBuffer);


    /**
     * <pre>
     * Scratch-buffer size for nppiHistogramRange_8u_AC4R.
     * 
     * @param oSizeROI ROI size.
     * @param nLevels Array containing number of levels per color channel.
     * @param hpBufferSize Host pointer where required buffer size is returned.
     * @return
     *  Error Code.
     * </pre>
     */
    public static int nppiHistogramRangeGetBufferSize_8u_AC4R(
        NppiSize oSizeROI, 
        int[] nLevels, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiHistogramRangeGetBufferSize_8u_AC4RNative(oSizeROI, nLevels, hpBufferSize));
    }
    private static native int nppiHistogramRangeGetBufferSize_8u_AC4RNative(
        NppiSize oSizeROI, 
        int[] nLevels, 
        int[] hpBufferSize);


    /**
     * <pre>
     * 4 channel (alpha as a last channel) 8-bit unsigned histogram with bins determined by pLevels.
     * Alpha channel is ignored during the histograms computations.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pHist Array of pointers which are receiving the computed histograms per color channel. 
     *      Array pointed by pHist[i] must be of size nLevels[i]-1.
     * @param nLevels Array containing number of levels per color channel. 
     * @param pLevels Array containing pointers to level-arrays per color channel.
            Array pointed by pLevel[i] must be of size nLevels[i].
     * @param pBuffer Pointer to appropriately sized (nppiHistogramRangeGetBufferSize_8u_AC4R) 
     *      scratch buffer.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiHistogramRange_8u_AC4R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp32s>[] pHist, 
        TypedPointer<Npp32s>[] pLevels, 
        int[] nLevels, 
        TypedPointer<Npp8u> pBuffer)
    {
        return JNpp.checkResult(nppiHistogramRange_8u_AC4RNative(pSrc, nSrcStep, oSizeROI, pHist, pLevels, nLevels, pBuffer));
    }
    private static native int nppiHistogramRange_8u_AC4RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp32s>[] pHist, 
        TypedPointer<Npp32s>[] pLevels, 
        int[] nLevels, 
        TypedPointer<Npp8u> pBuffer);


    public static int nppiHistogramRangeGetBufferSize_16u_C1R(
        NppiSize oSizeROI, 
        int nLevels, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiHistogramRangeGetBufferSize_16u_C1RNative(oSizeROI, nLevels, hpBufferSize));
    }
    private static native int nppiHistogramRangeGetBufferSize_16u_C1RNative(
        NppiSize oSizeROI, 
        int nLevels, 
        int[] hpBufferSize);


    /**
     * <pre>
     * 16-bit unsigned histogram with bins determined by pLevels array.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pHist Pointer to array that receives the computed histogram. 
     *      The array must be of size nLevels-1. 
     * @param pLevels Pointer to array containing the level sizes of the bins.
            The array must be of size nLevels.
     * @param nLevels Number of levels in histogram.
     * @param pBuffer Pointer to appropriately sized (nppiHistogramRangeGetBufferSize_16u_C1R) 
     *      scratch buffer.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiHistogramRange_16u_C1R(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp32s> pHist, 
        TypedPointer<Npp32s> pLevels, 
        int nLevels, 
        TypedPointer<Npp8u> pBuffer)
    {
        return JNpp.checkResult(nppiHistogramRange_16u_C1RNative(pSrc, nSrcStep, oSizeROI, pHist, pLevels, nLevels, pBuffer));
    }
    private static native int nppiHistogramRange_16u_C1RNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp32s> pHist, 
        TypedPointer<Npp32s> pLevels, 
        int nLevels, 
        TypedPointer<Npp8u> pBuffer);


    /**
     * <pre>
     * Scratch-buffer size for nppiHistogramRange_16u_C3R.
     * 
     * @param oSizeROI ROI size.
     * @param nLevels Array containing number of levels per color channel.
     * @param hpBufferSize Host pointer where required buffer size is returned.
     * @return
     *  Error Code.
     * </pre>
     */
    public static int nppiHistogramRangeGetBufferSize_16u_C3R(
        NppiSize oSizeROI, 
        int[] nLevels, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiHistogramRangeGetBufferSize_16u_C3RNative(oSizeROI, nLevels, hpBufferSize));
    }
    private static native int nppiHistogramRangeGetBufferSize_16u_C3RNative(
        NppiSize oSizeROI, 
        int[] nLevels, 
        int[] hpBufferSize);


    /**
     * <pre>
     * 3 channel 16-bit unsigned histogram with bins determined by pLevels.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pHist Array of pointers which are receiving the computed histograms per color channel. 
     *      Array pointed by pHist[i] must be of size nLevels[i]-1.
     * @param nLevels Array containing number of levels per color channel. 
     * @param pLevels Array containing pointers to level-arrays per color channel.
            Array pointed by pLevel[i] must be of size nLevels[i].
     * @param pBuffer Pointer to appropriately sized (nppiHistogramRangeGetBufferSize_16u_C3R) 
     *      scratch buffer.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiHistogramRange_16u_C3R(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp32s>[] pHist, 
        TypedPointer<Npp32s>[] pLevels, 
        int[] nLevels, 
        TypedPointer<Npp8u> pBuffer)
    {
        return JNpp.checkResult(nppiHistogramRange_16u_C3RNative(pSrc, nSrcStep, oSizeROI, pHist, pLevels, nLevels, pBuffer));
    }
    private static native int nppiHistogramRange_16u_C3RNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp32s>[] pHist, 
        TypedPointer<Npp32s>[] pLevels, 
        int[] nLevels, 
        TypedPointer<Npp8u> pBuffer);


    /**
     * <pre>
     * Scratch-buffer size for nppiHistogramRange_16u_C4R.
     * 
     * @param oSizeROI ROI size.
     * @param nLevels Array containing number of levels per color channel.
     * @param hpBufferSize Host pointer where required buffer size is returned.
     * @return
     *  Error Code.
     * </pre>
     */
    public static int nppiHistogramRangeGetBufferSize_16u_C4R(
        NppiSize oSizeROI, 
        int[] nLevels, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiHistogramRangeGetBufferSize_16u_C4RNative(oSizeROI, nLevels, hpBufferSize));
    }
    private static native int nppiHistogramRangeGetBufferSize_16u_C4RNative(
        NppiSize oSizeROI, 
        int[] nLevels, 
        int[] hpBufferSize);


    /**
     * <pre>
     * 4 channel 16-bit unsigned histogram with bins determined by pLevels.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pHist Array of pointers which are receiving the computed histograms per color channel. 
     *      Array pointed by pHist[i] must be of size nLevels[i]-1.
     * @param nLevels Array containing number of levels per color channel. 
     * @param pLevels Array containing pointers to level-arrays per color channel.
            Array pointed by pLevel[i] must be of size nLevels[i].
     * @param pBuffer Pointer to appropriately sized (nppiHistogramRangeGetBufferSize_16u_C4R) 
     *      scratch buffer.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiHistogramRange_16u_C4R(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp32s>[] pHist, 
        TypedPointer<Npp32s>[] pLevels, 
        int[] nLevels, 
        TypedPointer<Npp8u> pBuffer)
    {
        return JNpp.checkResult(nppiHistogramRange_16u_C4RNative(pSrc, nSrcStep, oSizeROI, pHist, pLevels, nLevels, pBuffer));
    }
    private static native int nppiHistogramRange_16u_C4RNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp32s>[] pHist, 
        TypedPointer<Npp32s>[] pLevels, 
        int[] nLevels, 
        TypedPointer<Npp8u> pBuffer);


    /**
     * <pre>
     * Scratch-buffer size for nppiHistogramRange_16u_AC4R.
     * 
     * @param oSizeROI ROI size.
     * @param nLevels Array containing number of levels per color channel.
     * @param hpBufferSize Host pointer where required buffer size is returned.
     * @return
     *  Error Code.
     * </pre>
     */
    public static int nppiHistogramRangeGetBufferSize_16u_AC4R(
        NppiSize oSizeROI, 
        int[] nLevels, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiHistogramRangeGetBufferSize_16u_AC4RNative(oSizeROI, nLevels, hpBufferSize));
    }
    private static native int nppiHistogramRangeGetBufferSize_16u_AC4RNative(
        NppiSize oSizeROI, 
        int[] nLevels, 
        int[] hpBufferSize);


    public static int nppiHistogramRange_16u_AC4R(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp32s>[] pHist, 
        TypedPointer<Npp32s>[] pLevels, 
        int[] nLevels, 
        TypedPointer<Npp8u> pBuffer)
    {
        return JNpp.checkResult(nppiHistogramRange_16u_AC4RNative(pSrc, nSrcStep, oSizeROI, pHist, pLevels, nLevels, pBuffer));
    }
    private static native int nppiHistogramRange_16u_AC4RNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp32s>[] pHist, 
        TypedPointer<Npp32s>[] pLevels, 
        int[] nLevels, 
        TypedPointer<Npp8u> pBuffer);


    /**
     * <pre>
     * Scratch-buffer size for nppiHistogramRange_16s_C1R.
     * 
     * @param oSizeROI \ref roi_specification.
     * @param nLevels Number of levels in the histogram.
     * @param hpBufferSize Host pointer where required buffer size is returned.
     * @return
     *  Error Code.
     * </pre>
     */
    public static int nppiHistogramRangeGetBufferSize_16s_C1R(
        NppiSize oSizeROI, 
        int nLevels, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiHistogramRangeGetBufferSize_16s_C1RNative(oSizeROI, nLevels, hpBufferSize));
    }
    private static native int nppiHistogramRangeGetBufferSize_16s_C1RNative(
        NppiSize oSizeROI, 
        int nLevels, 
        int[] hpBufferSize);


    /**
     * <pre>
     * 16-bit signed histogram with bins determined by pLevels array.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pHist Pointer to array that receives the computed histogram. 
     *      The array must be of size nLevels-1. 
     * @param pLevels Pointer to array containing the level sizes of the bins.
            The array must be of size nLevels.
     * @param nLevels Number of levels in histogram.
     * @param pBuffer Pointer to appropriately sized (nppiHistogramRangeGetBufferSize_16_C1R) 
     *      scratch buffer.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiHistogramRange_16s_C1R(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp32s> pHist, 
        TypedPointer<Npp32s> pLevels, 
        int nLevels, 
        TypedPointer<Npp8u> pBuffer)
    {
        return JNpp.checkResult(nppiHistogramRange_16s_C1RNative(pSrc, nSrcStep, oSizeROI, pHist, pLevels, nLevels, pBuffer));
    }
    private static native int nppiHistogramRange_16s_C1RNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp32s> pHist, 
        TypedPointer<Npp32s> pLevels, 
        int nLevels, 
        TypedPointer<Npp8u> pBuffer);


    /**
     * <pre>
     * Scratch-buffer size for nppiHistogramRange_16s_C3R.
     * 
     * @param oSizeROI ROI size.
     * @param nLevels Array containing number of levels per color channel.
     * @param hpBufferSize Host pointer where required buffer size is returned.
     * @return
     *  Error Code.
     * </pre>
     */
    public static int nppiHistogramRangeGetBufferSize_16s_C3R(
        NppiSize oSizeROI, 
        int[] nLevels, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiHistogramRangeGetBufferSize_16s_C3RNative(oSizeROI, nLevels, hpBufferSize));
    }
    private static native int nppiHistogramRangeGetBufferSize_16s_C3RNative(
        NppiSize oSizeROI, 
        int[] nLevels, 
        int[] hpBufferSize);


    /**
     * <pre>
     * 3 channel 16-bit signed histogram with bins determined by pLevels.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pHist Array of pointers which are receiving the computed histograms per color channel. 
     *      Array pointed by pHist[i] must be of size nLevels[i]-1.
     * @param nLevels Array containing number of levels per color channel. 
     * @param pLevels Array containing pointers to level-arrays per color channel.
            Array pointed by pLevel[i] must be of size nLevels[i].
     * @param pBuffer Pointer to appropriately sized (nppiHistogramRangeGetBufferSize_16_C3R) 
     *      scratch buffer.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiHistogramRange_16s_C3R(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp32s>[] pHist, 
        TypedPointer<Npp32s>[] pLevels, 
        int[] nLevels, 
        TypedPointer<Npp8u> pBuffer)
    {
        return JNpp.checkResult(nppiHistogramRange_16s_C3RNative(pSrc, nSrcStep, oSizeROI, pHist, pLevels, nLevels, pBuffer));
    }
    private static native int nppiHistogramRange_16s_C3RNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp32s>[] pHist, 
        TypedPointer<Npp32s>[] pLevels, 
        int[] nLevels, 
        TypedPointer<Npp8u> pBuffer);


    /**
     * <pre>
     * Scratch-buffer size for nppiHistogramRange_16s_C4R.
     * 
     * @param oSizeROI ROI size.
     * @param nLevels Array containing number of levels per color channel.
     * @param hpBufferSize Host pointer where required buffer size is returned.
     * @return
     *  Error Code.
     * </pre>
     */
    public static int nppiHistogramRangeGetBufferSize_16s_C4R(
        NppiSize oSizeROI, 
        int[] nLevels, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiHistogramRangeGetBufferSize_16s_C4RNative(oSizeROI, nLevels, hpBufferSize));
    }
    private static native int nppiHistogramRangeGetBufferSize_16s_C4RNative(
        NppiSize oSizeROI, 
        int[] nLevels, 
        int[] hpBufferSize);


    /**
     * <pre>
     * 4 channel 16-bit signed histogram with bins determined by pLevels.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pHist Array of pointers which are receiving the computed histograms per color channel. 
     *      Array pointed by pHist[i] must be of size nLevels[i]-1.
     * @param nLevels Array containing number of levels per color channel. 
     * @param pLevels Array containing pointers to level-arrays per color channel.
            Array pointed by pLevel[i] must be of size nLevels[i].
     * @param pBuffer Pointer to appropriately sized (nppiHistogramRangeGetBufferSize_16s_C4R) 
     *      scratch buffer.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiHistogramRange_16s_C4R(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp32s>[] pHist, 
        TypedPointer<Npp32s>[] pLevels, 
        int[] nLevels, 
        TypedPointer<Npp8u> pBuffer)
    {
        return JNpp.checkResult(nppiHistogramRange_16s_C4RNative(pSrc, nSrcStep, oSizeROI, pHist, pLevels, nLevels, pBuffer));
    }
    private static native int nppiHistogramRange_16s_C4RNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp32s>[] pHist, 
        TypedPointer<Npp32s>[] pLevels, 
        int[] nLevels, 
        TypedPointer<Npp8u> pBuffer);


    /**
     * <pre>
     * Scratch-buffer size for nppiHistogramRange_16s_AC4R.
     * 
     * @param oSizeROI ROI size.
     * @param nLevels Array containing number of levels per color channel.
     * @param hpBufferSize Host pointer where required buffer size is returned.
     * @return
     *  Error Code.
     * </pre>
     */
    public static int nppiHistogramRangeGetBufferSize_16s_AC4R(
        NppiSize oSizeROI, 
        int[] nLevels, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiHistogramRangeGetBufferSize_16s_AC4RNative(oSizeROI, nLevels, hpBufferSize));
    }
    private static native int nppiHistogramRangeGetBufferSize_16s_AC4RNative(
        NppiSize oSizeROI, 
        int[] nLevels, 
        int[] hpBufferSize);


    /**
     * <pre>
     * 4 channel (alpha as a last channel) 16-bit signed histogram with bins determined by pLevels.
     * Alpha channel is ignored during the histograms computations.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pHist Array of pointers which are receiving the computed histograms per color channel. 
     *      Array pointed by pHist[i] must be of size nLevels[i]-1.
     * @param nLevels Array containing number of levels per color channel. 
     * @param pLevels Array containing pointers to level-arrays per color channel.
            Array pointed by pLevel[i] must be of size nLevels[i].
     * @param pBuffer Pointer to appropriately sized (nppiHistogramRangeGetBufferSize_16_AC4R) 
     *      scratch buffer.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiHistogramRange_16s_AC4R(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp32s>[] pHist, 
        TypedPointer<Npp32s>[] pLevels, 
        int[] nLevels, 
        TypedPointer<Npp8u> pBuffer)
    {
        return JNpp.checkResult(nppiHistogramRange_16s_AC4RNative(pSrc, nSrcStep, oSizeROI, pHist, pLevels, nLevels, pBuffer));
    }
    private static native int nppiHistogramRange_16s_AC4RNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp32s>[] pHist, 
        TypedPointer<Npp32s>[] pLevels, 
        int[] nLevels, 
        TypedPointer<Npp8u> pBuffer);


    /**
     * <pre>
     * Scratch-buffer size for nppiHistogramRange_32f_C1R.
     * 
     * @param oSizeROI \ref roi_specification.
     * @param nLevels Number of levels in the histogram.
     * @param hpBufferSize Host pointer where required buffer size is returned.
     * @return
     *  Error Code.
     * </pre>
     */
    public static int nppiHistogramRangeGetBufferSize_32f_C1R(
        NppiSize oSizeROI, 
        int nLevels, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiHistogramRangeGetBufferSize_32f_C1RNative(oSizeROI, nLevels, hpBufferSize));
    }
    private static native int nppiHistogramRangeGetBufferSize_32f_C1RNative(
        NppiSize oSizeROI, 
        int nLevels, 
        int[] hpBufferSize);


    /**
     * <pre>
     * 32-bit float histogram with bins determined by pLevels array.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pHist Pointer to array that receives the computed histogram. 
     *      The array must be of size nLevels-1. 
     * @param pLevels Pointer to array containing the level sizes of the bins.
            The array must be of size nLevels.
     * @param nLevels Number of levels in histogram.
     * @param pBuffer Pointer to appropriately sized (nppiHistogramRangeGetBufferSize_32f_C1R) 
     *      scratch buffer.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiHistogramRange_32f_C1R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp32s> pHist, 
        TypedPointer<Npp32f> pLevels, 
        int nLevels, 
        TypedPointer<Npp8u> pBuffer)
    {
        return JNpp.checkResult(nppiHistogramRange_32f_C1RNative(pSrc, nSrcStep, oSizeROI, pHist, pLevels, nLevels, pBuffer));
    }
    private static native int nppiHistogramRange_32f_C1RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp32s> pHist, 
        TypedPointer<Npp32f> pLevels, 
        int nLevels, 
        TypedPointer<Npp8u> pBuffer);


    /**
     * <pre>
     * Scratch-buffer size for nppiHistogramRange_32f_C3R.
     * 
     * @param oSizeROI ROI size.
     * @param nLevels Array containing number of levels per color channel.
     * @param hpBufferSize Host pointer where required buffer size is returned.
     * @return
     *  Error Code.
     * </pre>
     */
    public static int nppiHistogramRangeGetBufferSize_32f_C3R(
        NppiSize oSizeROI, 
        int[] nLevels, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiHistogramRangeGetBufferSize_32f_C3RNative(oSizeROI, nLevels, hpBufferSize));
    }
    private static native int nppiHistogramRangeGetBufferSize_32f_C3RNative(
        NppiSize oSizeROI, 
        int[] nLevels, 
        int[] hpBufferSize);


    /**
     * <pre>
     * 3 channel 32-bit float histogram with bins determined by pLevels.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pHist Array of pointers which are receiving the computed histograms per color channel. 
     *      Array pointed by pHist[i] must be of size nLevels[i]-1.
     * @param nLevels Array containing number of levels per color channel. 
     * @param pLevels Array containing pointers to level-arrays per color channel.
            Array pointed by pLevel[i] must be of size nLevels[i].
     * @param pBuffer Pointer to appropriately sized (nppiHistogramRangeGetBufferSize_32f_C3R) 
     *      scratch buffer.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiHistogramRange_32f_C3R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp32s>[] pHist, 
        TypedPointer<Npp32f>[] pLevels, 
        int[] nLevels, 
        TypedPointer<Npp8u> pBuffer)
    {
        return JNpp.checkResult(nppiHistogramRange_32f_C3RNative(pSrc, nSrcStep, oSizeROI, pHist, pLevels, nLevels, pBuffer));
    }
    private static native int nppiHistogramRange_32f_C3RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp32s>[] pHist, 
        TypedPointer<Npp32f>[] pLevels, 
        int[] nLevels, 
        TypedPointer<Npp8u> pBuffer);


    /**
     * <pre>
     * Scratch-buffer size for nppiHistogramRange_32f_C4R.
     * 
     * @param oSizeROI ROI size.
     * @param nLevels Array containing number of levels per color channel.
     * @param hpBufferSize Host pointer where required buffer size is returned.
     * @return
     *  Error Code.
     * </pre>
     */
    public static int nppiHistogramRangeGetBufferSize_32f_C4R(
        NppiSize oSizeROI, 
        int[] nLevels, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiHistogramRangeGetBufferSize_32f_C4RNative(oSizeROI, nLevels, hpBufferSize));
    }
    private static native int nppiHistogramRangeGetBufferSize_32f_C4RNative(
        NppiSize oSizeROI, 
        int[] nLevels, 
        int[] hpBufferSize);


    /**
     * <pre>
     * 4 channel 32-bit float histogram with bins determined by pLevels.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pHist Array of pointers which are receiving the computed histograms per color channel. 
     *      Array pointed by pHist[i] must be of size nLevels[i]-1.
     * @param nLevels Array containing number of levels per color channel. 
     * @param pLevels Array containing pointers to level-arrays per color channel.
            Array pointed by pLevel[i] must be of size nLevels[i].
     * @param pBuffer Pointer to appropriately sized (nppiHistogramRangeGetBufferSize_32f_C4R) 
     *      scratch buffer.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiHistogramRange_32f_C4R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp32s>[] pHist, 
        TypedPointer<Npp32f>[] pLevels, 
        int[] nLevels, 
        TypedPointer<Npp8u> pBuffer)
    {
        return JNpp.checkResult(nppiHistogramRange_32f_C4RNative(pSrc, nSrcStep, oSizeROI, pHist, pLevels, nLevels, pBuffer));
    }
    private static native int nppiHistogramRange_32f_C4RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp32s>[] pHist, 
        TypedPointer<Npp32f>[] pLevels, 
        int[] nLevels, 
        TypedPointer<Npp8u> pBuffer);


    /**
     * <pre>
     * Scratch-buffer size for nppiHistogramRange_32f_AC4R.
     * 
     * @param oSizeROI ROI size.
     * @param nLevels Array containing number of levels per color channel.
     * @param hpBufferSize Host pointer where required buffer size is returned.
     * @return
     *  Error Code.
     * </pre>
     */
    public static int nppiHistogramRangeGetBufferSize_32f_AC4R(
        NppiSize oSizeROI, 
        int[] nLevels, 
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppiHistogramRangeGetBufferSize_32f_AC4RNative(oSizeROI, nLevels, hpBufferSize));
    }
    private static native int nppiHistogramRangeGetBufferSize_32f_AC4RNative(
        NppiSize oSizeROI, 
        int[] nLevels, 
        int[] hpBufferSize);


    /**
     * <pre>
     * 4 channel (alpha as a last channel) 32-bit float histogram with bins determined by pLevels.
     * Alpha channel is ignored during the histograms computations.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pHist Array of pointers which are receiving the computed histograms per color channel. 
     *      Array pointed by pHist[i] must be of size nLevels[i]-1.
     * @param nLevels Array containing number of levels per color channel. 
     * @param pLevels Array containing pointers to level-arrays per color channel.
            Array pointed by pLevel[i] must be of size nLevels[i].
     * @param pBuffer Pointer to appropriately sized (nppiHistogramRangeGetBufferSize_32f_AC4R) 
     *      scratch buffer.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiHistogramRange_32f_AC4R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp32s>[] pHist, 
        TypedPointer<Npp32f>[] pLevels, 
        int[] nLevels, 
        TypedPointer<Npp8u> pBuffer)
    {
        return JNpp.checkResult(nppiHistogramRange_32f_AC4RNative(pSrc, nSrcStep, oSizeROI, pHist, pLevels, nLevels, pBuffer));
    }
    private static native int nppiHistogramRange_32f_AC4RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp32s>[] pHist, 
        TypedPointer<Npp32f>[] pLevels, 
        int[] nLevels, 
        TypedPointer<Npp8u> pBuffer);


    /**
     * <pre>
     * 32-bit floating point complex to 32-bit floating point magnitude.
     * 
     * Converts complex-number pixel image to single channel image computing
     * the result pixels as the magnitude of the complex values.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMagnitude_32fc32f_C1R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiMagnitude_32fc32f_C1RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiMagnitude_32fc32f_C1RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    public static int nppiMagnitudeSqr_32fc32f_C1R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiMagnitudeSqr_32fc32f_C1RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiMagnitudeSqr_32fc32f_C1RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 8-bit unsigned image resize.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcSize Size in pixels of the source image
     * @param oSrcROI Region of interest in the source image.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param dstROISize Size in pixels of the destination image
     * @param xFactor Factors by which x dimension is changed 
     * @param yFactor Factors by which y dimension is changed 
     * @param eInterpolation The type of eInterpolation to perform resampling
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref resize_error_codes
     * </pre>
     */
    public static int nppiResize_8u_C1R(
        TypedPointer<Npp8u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize dstROISize, 
        double xFactor, 
        double yFactor, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiResize_8u_C1RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, pDst, nDstStep, dstROISize, xFactor, yFactor, eInterpolation));
    }
    private static native int nppiResize_8u_C1RNative(
        TypedPointer<Npp8u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize dstROISize, 
        double xFactor, 
        double yFactor, 
        int eInterpolation);


    /**
     * <pre>
     * 4 channel 8-bit unsigned image resize.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcSize Size in pixels of the source image
     * @param oSrcROI Region of interest in the source image.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param dstROISize Size in pixels of the destination image
     * @param xFactor Factors by which x dimension is changed 
     * @param yFactor Factors by which y dimension is changed 
     * @param eInterpolation The type of interpolation to perform resampling
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref resize_error_codes
     * </pre>
     */
    public static int nppiResize_8u_C4R(
        TypedPointer<Npp8u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize dstROISize, 
        double xFactor, 
        double yFactor, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiResize_8u_C4RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, pDst, nDstStep, dstROISize, xFactor, yFactor, eInterpolation));
    }
    private static native int nppiResize_8u_C4RNative(
        TypedPointer<Npp8u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize dstROISize, 
        double xFactor, 
        double yFactor, 
        int eInterpolation);


    /**
     * <pre>
     * Compute shape of rotated image.
     * 
     * @param oSrcROI Region-of-interest of the source image.
     * @param aQuad Array of 2D points. These points are the locations of the corners
     *      of the rotated ROI. 
     * @param nAngle The rotation nAngle.
     * @param nShiftX Post-rotation shift in x-direction
     * @param nShiftY Post-rotation shift in y-direction
     * @return
     *  \ref roi_error_codes.
     * </pre>
     */
    public static int nppiGetRotateQuad(
        NppiRect oSrcROI, 
        double[][] aQuad, 
        double nAngle, 
        double nShiftX, 
        double nShiftY)
    {
        return JNpp.checkResult(nppiGetRotateQuadNative(oSrcROI, aQuad, nAngle, nShiftX, nShiftY));
    }
    private static native int nppiGetRotateQuadNative(
        NppiRect oSrcROI, 
        double[][] aQuad, 
        double nAngle, 
        double nShiftX, 
        double nShiftY);


    public static int nppiGetRotateBound(
        NppiRect oSrcROI, 
        double[][] aBoundingBox, 
        double nAngle, 
        double nShiftX, 
        double nShiftY)
    {
        return JNpp.checkResult(nppiGetRotateBoundNative(oSrcROI, aBoundingBox, nAngle, nShiftX, nShiftY));
    }
    private static native int nppiGetRotateBoundNative(
        NppiRect oSrcROI, 
        double[][] aBoundingBox, 
        double nAngle, 
        double nShiftX, 
        double nShiftY);


    /**
     * <pre>
     * 8-bit unsigned image rotate.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcSize Size in pixels of the source image
     * @param oSrcROI Region of interest in the source image.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstROI Region of interest in the destination image.
     * @param nAngle The angle of rotation in degrees.
     * @param nShiftX Shift along horizontal axis 
     * @param nShiftY Shift along vertical axis 
     * @param eInterpolation The type of interpolation to perform resampling
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref rotate_error_codes
     * </pre>
     */
    public static int nppiRotate_8u_C1R(
        TypedPointer<Npp8u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double nAngle, 
        double nShiftX, 
        double nShiftY, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiRotate_8u_C1RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, pDst, nDstStep, oDstROI, nAngle, nShiftX, nShiftY, eInterpolation));
    }
    private static native int nppiRotate_8u_C1RNative(
        TypedPointer<Npp8u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double nAngle, 
        double nShiftX, 
        double nShiftY, 
        int eInterpolation);


    /**
     * <pre>
     * 3 channel 8-bit unsigned image rotate.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcSize Size in pixels of the source image
     * @param oSrcROI Region of interest in the source image.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstROI Region of interest in the destination image.
     * @param nAngle The angle of rotation in degrees.
     * @param nShiftX Shift along horizontal axis 
     * @param nShiftY Shift along vertical axis 
     * @param eInterpolation The type of interpolation to perform resampling
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref rotate_error_codes
     * </pre>
     */
    public static int nppiRotate_8u_C3R(
        TypedPointer<Npp8u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double nAngle, 
        double nShiftX, 
        double nShiftY, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiRotate_8u_C3RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, pDst, nDstStep, oDstROI, nAngle, nShiftX, nShiftY, eInterpolation));
    }
    private static native int nppiRotate_8u_C3RNative(
        TypedPointer<Npp8u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double nAngle, 
        double nShiftX, 
        double nShiftY, 
        int eInterpolation);


    public static int nppiRotate_8u_C4R(
        TypedPointer<Npp8u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double nAngle, 
        double nShiftX, 
        double nShiftY, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiRotate_8u_C4RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, pDst, nDstStep, oDstROI, nAngle, nShiftX, nShiftY, eInterpolation));
    }
    private static native int nppiRotate_8u_C4RNative(
        TypedPointer<Npp8u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double nAngle, 
        double nShiftX, 
        double nShiftY, 
        int eInterpolation);


    /**
     * <pre>
     * 4 channel 8-bit unsigned image rotate ignoring alpha channel.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcSize Size in pixels of the source image
     * @param oSrcROI Region of interest in the source image.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstROI Region of interest in the destination image.
     * @param nAngle The angle of rotation in degrees.
     * @param nShiftX Shift along horizontal axis 
     * @param nShiftY Shift along vertical axis 
     * @param eInterpolation The type of interpolation to perform resampling
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref rotate_error_codes
     * </pre>
     */
    public static int nppiRotate_8u_AC4R(
        TypedPointer<Npp8u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double nAngle, 
        double nShiftX, 
        double nShiftY, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiRotate_8u_AC4RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, pDst, nDstStep, oDstROI, nAngle, nShiftX, nShiftY, eInterpolation));
    }
    private static native int nppiRotate_8u_AC4RNative(
        TypedPointer<Npp8u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double nAngle, 
        double nShiftX, 
        double nShiftY, 
        int eInterpolation);


    /**
     * <pre>
     * 16-bit unsigned image rotate.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcSize Size in pixels of the source image
     * @param oSrcROI Region of interest in the source image.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstROI Region of interest in the destination image.
     * @param nAngle The angle of rotation in degrees.
     * @param nShiftX Shift along horizontal axis 
     * @param nShiftY Shift along vertical axis 
     * @param eInterpolation The type of interpolation to perform resampling
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref rotate_error_codes
     * </pre>
     */
    public static int nppiRotate_16u_C1R(
        TypedPointer<Npp16u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double nAngle, 
        double nShiftX, 
        double nShiftY, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiRotate_16u_C1RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, pDst, nDstStep, oDstROI, nAngle, nShiftX, nShiftY, eInterpolation));
    }
    private static native int nppiRotate_16u_C1RNative(
        TypedPointer<Npp16u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double nAngle, 
        double nShiftX, 
        double nShiftY, 
        int eInterpolation);


    public static int nppiRotate_16u_C3R(
        TypedPointer<Npp16u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double nAngle, 
        double nShiftX, 
        double nShiftY, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiRotate_16u_C3RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, pDst, nDstStep, oDstROI, nAngle, nShiftX, nShiftY, eInterpolation));
    }
    private static native int nppiRotate_16u_C3RNative(
        TypedPointer<Npp16u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double nAngle, 
        double nShiftX, 
        double nShiftY, 
        int eInterpolation);


    /**
     * <pre>
     * 4 channel 16-bit unsigned image rotate.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcSize Size in pixels of the source image
     * @param oSrcROI Region of interest in the source image.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstROI Region of interest in the destination image.
     * @param nAngle The angle of rotation in degrees.
     * @param nShiftX Shift along horizontal axis 
     * @param nShiftY Shift along vertical axis 
     * @param eInterpolation The type of interpolation to perform resampling
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref rotate_error_codes
     * </pre>
     */
    public static int nppiRotate_16u_C4R(
        TypedPointer<Npp16u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double nAngle, 
        double nShiftX, 
        double nShiftY, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiRotate_16u_C4RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, pDst, nDstStep, oDstROI, nAngle, nShiftX, nShiftY, eInterpolation));
    }
    private static native int nppiRotate_16u_C4RNative(
        TypedPointer<Npp16u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double nAngle, 
        double nShiftX, 
        double nShiftY, 
        int eInterpolation);


    public static int nppiRotate_16u_AC4R(
        TypedPointer<Npp16u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double nAngle, 
        double nShiftX, 
        double nShiftY, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiRotate_16u_AC4RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, pDst, nDstStep, oDstROI, nAngle, nShiftX, nShiftY, eInterpolation));
    }
    private static native int nppiRotate_16u_AC4RNative(
        TypedPointer<Npp16u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double nAngle, 
        double nShiftX, 
        double nShiftY, 
        int eInterpolation);


    /**
     * <pre>
     * 32-bit float image rotate.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcSize Size in pixels of the source image
     * @param oSrcROI Region of interest in the source image.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstROI Region of interest in the destination image.
     * @param nAngle The angle of rotation in degrees.
     * @param nShiftX Shift along horizontal axis 
     * @param nShiftY Shift along vertical axis 
     * @param eInterpolation The type of interpolation to perform resampling
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref rotate_error_codes
     * </pre>
     */
    public static int nppiRotate_32f_C1R(
        TypedPointer<Npp32f> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double nAngle, 
        double nShiftX, 
        double nShiftY, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiRotate_32f_C1RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, pDst, nDstStep, oDstROI, nAngle, nShiftX, nShiftY, eInterpolation));
    }
    private static native int nppiRotate_32f_C1RNative(
        TypedPointer<Npp32f> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double nAngle, 
        double nShiftX, 
        double nShiftY, 
        int eInterpolation);


    public static int nppiRotate_32f_C3R(
        TypedPointer<Npp32f> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double nAngle, 
        double nShiftX, 
        double nShiftY, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiRotate_32f_C3RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, pDst, nDstStep, oDstROI, nAngle, nShiftX, nShiftY, eInterpolation));
    }
    private static native int nppiRotate_32f_C3RNative(
        TypedPointer<Npp32f> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double nAngle, 
        double nShiftX, 
        double nShiftY, 
        int eInterpolation);


    /**
     * <pre>
     * 4 channel 32-bit float image rotate.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcSize Size in pixels of the source image
     * @param oSrcROI Region of interest in the source image.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstROI Region of interest in the destination image.
     * @param nAngle The angle of rotation in degrees.
     * @param nShiftX Shift along horizontal axis 
     * @param nShiftY Shift along vertical axis 
     * @param eInterpolation The type of interpolation to perform resampling
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref rotate_error_codes
     * </pre>
     */
    public static int nppiRotate_32f_C4R(
        TypedPointer<Npp32f> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double nAngle, 
        double nShiftX, 
        double nShiftY, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiRotate_32f_C4RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, pDst, nDstStep, oDstROI, nAngle, nShiftX, nShiftY, eInterpolation));
    }
    private static native int nppiRotate_32f_C4RNative(
        TypedPointer<Npp32f> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double nAngle, 
        double nShiftX, 
        double nShiftY, 
        int eInterpolation);


    /**
     * <pre>
     * 4 channel 32-bit float image rotate ignoring alpha channel.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcSize Size in pixels of the source image
     * @param oSrcROI Region of interest in the source image.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstROI Region of interest in the destination image.
     * @param nAngle The angle of rotation in degrees.
     * @param nShiftX Shift along horizontal axis 
     * @param nShiftY Shift along vertical axis 
     * @param eInterpolation The type of interpolation to perform resampling
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref rotate_error_codes
     * </pre>
     */
    public static int nppiRotate_32f_AC4R(
        TypedPointer<Npp32f> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double nAngle, 
        double nShiftX, 
        double nShiftY, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiRotate_32f_AC4RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, pDst, nDstStep, oDstROI, nAngle, nShiftX, nShiftY, eInterpolation));
    }
    private static native int nppiRotate_32f_AC4RNative(
        TypedPointer<Npp32f> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double nAngle, 
        double nShiftX, 
        double nShiftY, 
        int eInterpolation);


    public static int nppiMirror_8u_C1R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oROI, 
        int flip)
    {
        return JNpp.checkResult(nppiMirror_8u_C1RNative(pSrc, nSrcStep, pDst, nDstStep, oROI, flip));
    }
    private static native int nppiMirror_8u_C1RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oROI, 
        int flip);


    /**
     * <pre>
     * 3 channel 8-bit unsigned image mirror.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oROI \ref roi_specification.
     * @param flip Specifies the axis about which the image is to be mirrored.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref mirror_error_codes
     * </pre>
     */
    public static int nppiMirror_8u_C3R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oROI, 
        int flip)
    {
        return JNpp.checkResult(nppiMirror_8u_C3RNative(pSrc, nSrcStep, pDst, nDstStep, oROI, flip));
    }
    private static native int nppiMirror_8u_C3RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oROI, 
        int flip);


    /**
     * <pre>
     * 4 channel 8-bit unsigned image mirror.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep Distance in bytes between starts of consecutive lines of the
     *        destination image.
     * @param oROI \ref roi_specification.
     * @param flip Specifies the axis about which the image is to be mirrored.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref mirror_error_codes
     * </pre>
     */
    public static int nppiMirror_8u_C4R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oROI, 
        int flip)
    {
        return JNpp.checkResult(nppiMirror_8u_C4RNative(pSrc, nSrcStep, pDst, nDstStep, oROI, flip));
    }
    private static native int nppiMirror_8u_C4RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oROI, 
        int flip);


    /**
     * <pre>
     * 4 channel 8-bit unsigned image mirror not affecting alpha.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep Distance in bytes between starts of consecutive lines of the
     *        destination image.
     * @param oROI \ref roi_specification.
     * @param flip Specifies the axis about which the image is to be mirrored.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref mirror_error_codes
     * </pre>
     */
    public static int nppiMirror_8u_AC4R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oROI, 
        int flip)
    {
        return JNpp.checkResult(nppiMirror_8u_AC4RNative(pSrc, nSrcStep, pDst, nDstStep, oROI, flip));
    }
    private static native int nppiMirror_8u_AC4RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oROI, 
        int flip);


    /**
     * <pre>
     * 16-bit unsigned image mirror.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oROI \ref roi_specification.
     * @param flip Specifies the axis about which the image is to be mirrored.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref mirror_error_codes
     * </pre>
     */
    public static int nppiMirror_16u_C1R(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oROI, 
        int flip)
    {
        return JNpp.checkResult(nppiMirror_16u_C1RNative(pSrc, nSrcStep, pDst, nDstStep, oROI, flip));
    }
    private static native int nppiMirror_16u_C1RNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oROI, 
        int flip);


    public static int nppiMirror_16u_C3R(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oROI, 
        int flip)
    {
        return JNpp.checkResult(nppiMirror_16u_C3RNative(pSrc, nSrcStep, pDst, nDstStep, oROI, flip));
    }
    private static native int nppiMirror_16u_C3RNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oROI, 
        int flip);


    /**
     * <pre>
     * 4 channel 16-bit unsigned image mirror.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep Distance in bytes between starts of consecutive lines of the
     *        destination image.
     * @param oROI \ref roi_specification.
     * @param flip Specifies the axis about which the image is to be mirrored.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref mirror_error_codes
     * </pre>
     */
    public static int nppiMirror_16u_C4R(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oROI, 
        int flip)
    {
        return JNpp.checkResult(nppiMirror_16u_C4RNative(pSrc, nSrcStep, pDst, nDstStep, oROI, flip));
    }
    private static native int nppiMirror_16u_C4RNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oROI, 
        int flip);


    /**
     * <pre>
     * 4 channel 16-bit unsigned image mirror not affecting alpha.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep Distance in bytes between starts of consecutive lines of the
     *        destination image.
     * @param oROI \ref roi_specification.
     * @param flip Specifies the axis about which the image is to be mirrored.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref mirror_error_codes
     * </pre>
     */
    public static int nppiMirror_16u_AC4R(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oROI, 
        int flip)
    {
        return JNpp.checkResult(nppiMirror_16u_AC4RNative(pSrc, nSrcStep, pDst, nDstStep, oROI, flip));
    }
    private static native int nppiMirror_16u_AC4RNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oROI, 
        int flip);


    public static int nppiMirror_32s_C1R(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oROI, 
        int flip)
    {
        return JNpp.checkResult(nppiMirror_32s_C1RNative(pSrc, nSrcStep, pDst, nDstStep, oROI, flip));
    }
    private static native int nppiMirror_32s_C1RNative(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oROI, 
        int flip);


    /**
     * <pre>
     * 3 channel 32-bit image mirror.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oROI \ref roi_specification.
     * @param flip Specifies the axis about which the image is to be mirrored.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref mirror_error_codes
     * </pre>
     */
    public static int nppiMirror_32s_C3R(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oROI, 
        int flip)
    {
        return JNpp.checkResult(nppiMirror_32s_C3RNative(pSrc, nSrcStep, pDst, nDstStep, oROI, flip));
    }
    private static native int nppiMirror_32s_C3RNative(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oROI, 
        int flip);


    /**
     * <pre>
     * 4 channel 32-bit image mirror.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep Distance in bytes between starts of consecutive lines of the
     *        destination image.
     * @param oROI \ref roi_specification.
     * @param flip Specifies the axis about which the image is to be mirrored.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref mirror_error_codes
     * </pre>
     */
    public static int nppiMirror_32s_C4R(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oROI, 
        int flip)
    {
        return JNpp.checkResult(nppiMirror_32s_C4RNative(pSrc, nSrcStep, pDst, nDstStep, oROI, flip));
    }
    private static native int nppiMirror_32s_C4RNative(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oROI, 
        int flip);


    /**
     * <pre>
     * 4 channel 32-bit image mirror not affecting alpha.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep Distance in bytes between starts of consecutive lines of the
     *        destination image.
     * @param oROI \ref roi_specification.
     * @param flip Specifies the axis about which the image is to be mirrored.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref mirror_error_codes
     * </pre>
     */
    public static int nppiMirror_32s_AC4R(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oROI, 
        int flip)
    {
        return JNpp.checkResult(nppiMirror_32s_AC4RNative(pSrc, nSrcStep, pDst, nDstStep, oROI, flip));
    }
    private static native int nppiMirror_32s_AC4RNative(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oROI, 
        int flip);


    /**
     * <pre>
     * 32-bit float image mirror.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oROI \ref roi_specification.
     * @param flip Specifies the axis about which the image is to be mirrored.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref mirror_error_codes
     * </pre>
     */
    public static int nppiMirror_32f_C1R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oROI, 
        int flip)
    {
        return JNpp.checkResult(nppiMirror_32f_C1RNative(pSrc, nSrcStep, pDst, nDstStep, oROI, flip));
    }
    private static native int nppiMirror_32f_C1RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oROI, 
        int flip);


    /**
     * <pre>
     * 3 channel 32-bit float image mirror.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oROI \ref roi_specification.
     * @param flip Specifies the axis about which the image is to be mirrored.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref mirror_error_codes
     * </pre>
     */
    public static int nppiMirror_32f_C3R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oROI, 
        int flip)
    {
        return JNpp.checkResult(nppiMirror_32f_C3RNative(pSrc, nSrcStep, pDst, nDstStep, oROI, flip));
    }
    private static native int nppiMirror_32f_C3RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oROI, 
        int flip);


    /**
     * <pre>
     * 4 channel 32-bit float image mirror.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep Distance in bytes between starts of consecutive lines of the
     *        destination image.
     * @param oROI \ref roi_specification.
     * @param flip Specifies the axis about which the image is to be mirrored.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref mirror_error_codes
     * </pre>
     */
    public static int nppiMirror_32f_C4R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oROI, 
        int flip)
    {
        return JNpp.checkResult(nppiMirror_32f_C4RNative(pSrc, nSrcStep, pDst, nDstStep, oROI, flip));
    }
    private static native int nppiMirror_32f_C4RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oROI, 
        int flip);


    /**
     * <pre>
     * 4 channel 32-bit float image mirror not affecting alpha.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep Distance in bytes between starts of consecutive lines of the
     *        destination image.
     * @param oROI \ref roi_specification.
     * @param flip Specifies the axis about which the image is to be mirrored.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref mirror_error_codes
     * </pre>
     */
    public static int nppiMirror_32f_AC4R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oROI, 
        int flip)
    {
        return JNpp.checkResult(nppiMirror_32f_AC4RNative(pSrc, nSrcStep, pDst, nDstStep, oROI, flip));
    }
    private static native int nppiMirror_32f_AC4RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oROI, 
        int flip);


    /**
     * <pre>
     * Computes affine transform coefficients based on source ROI and destination quadrilateral.
     *
     * The function computes the coefficients of an affine transformation that maps the
     * given source ROI (axis aligned rectangle with integer coordinates) to a quadrilateral
     * in the destination image.
     *
     * An affine transform in 2D is fully determined by the mapping of just three vertices.
     * This function's API allows for passing a complete quadrilateral effectively making the 
     * prolem overdetermined. What this means in practice is, that for certain quadrilaterals it is
     * not possible to find an affine transform that would map all four corners of the source
     * ROI to the four vertices of that quadrilateral.
     *
     * The function circumvents this problem by only looking at the first three vertices of
     * the destination image quadrilateral to determine the affine transformation's coefficients.
     * If the destination quadrilateral is indeed one that cannot be mapped using an affine
     * transformation the functions informs the user of this situation by returning a 
     * ::NPP_AFFINE_QUAD_INCORRECT_WARNING.
     *
     * @param oSrcROI The source ROI. This rectangle needs to be at least one pixel wide and
     *          high. If either width or hight are less than one an ::NPP_RECT_ERROR is returned.
     * @param aQuad The destination quadrilateral.
     * @param aCoeffs The resulting affine transform coefficients.
     * @return
     *  Error codes:
     *         - ::NPP_SIZE_ERROR Indicates an error condition if any image dimension
     *           has zero or negative value
     *         - ::NPP_RECT_ERROR Indicates an error condition if width or height of
     *           the intersection of the oSrcROI and source image is less than or
     *           equal to 1
     *         - ::NPP_COEFF_ERROR Indicates an error condition if coefficient values
     *           are invalid
     *         - ::NPP_AFFINE_QUAD_INCORRECT_WARNING Indicates a warning when quad
     *           does not conform to the transform properties. Fourth vertex is
     *           ignored, internally computed coordinates are used instead
     * </pre>
     */
    public static int nppiGetAffineTransform(
        NppiRect oSrcROI, 
        double[][] aQuad, 
        double[][] aCoeffs)
    {
        return JNpp.checkResult(nppiGetAffineTransformNative(oSrcROI, aQuad, aCoeffs));
    }
    private static native int nppiGetAffineTransformNative(
        NppiRect oSrcROI, 
        double[][] aQuad, 
        double[][] aCoeffs);


    /**
     * <pre>
     * Compute shape of transformed image.
     *
     * This method computes the quadrilateral in the destination image that 
     * the source ROI is transformed into by the affine transformation expressed
     * by the coefficients array (aCoeffs).
     *
     * @param oSrcROI The source ROI.
     * @param aQuad The resulting destination quadrangle.
     * @param aCoeffs The afine transform coefficients.
     * @return
     *  Error codes:
     *         - ::NPP_SIZE_ERROR Indicates an error condition if any image dimension
     *           has zero or negative value
     *         - ::NPP_RECT_ERROR Indicates an error condition if width or height of
     *           the intersection of the oSrcROI and source image is less than or
     *           equal to 1
     *         - ::NPP_COEFF_ERROR Indicates an error condition if coefficient values
     *           are invalid
     * </pre>
     */
    public static int nppiGetAffineQuad(
        NppiRect oSrcROI, 
        double[][] aQuad, 
        double[][] aCoeffs)
    {
        return JNpp.checkResult(nppiGetAffineQuadNative(oSrcROI, aQuad, aCoeffs));
    }
    private static native int nppiGetAffineQuadNative(
        NppiRect oSrcROI, 
        double[][] aQuad, 
        double[][] aCoeffs);


    /**
     * <pre>
     * Compute bounding-box of transformed image.
     *
     * The method effectively computes the bounding box (axis aligned rectangle) of
     * the transformed source ROI (see nppiGetAffineQuad()). 
     *
     * @param oSrcROI The source ROI.
     * @param aBound The resulting bounding box.
     * @param aCoeffs The afine transform coefficients.
     * @return
     *  Error codes:
     *         - ::NPP_SIZE_ERROR Indicates an error condition if any image dimension
     *           has zero or negative value
     *         - ::NPP_RECT_ERROR Indicates an error condition if width or height of
     *           the intersection of the oSrcROI and source image is less than or
     *           equal to 1
     *         - ::NPP_COEFF_ERROR Indicates an error condition if coefficient values
     *           are invalid
     * </pre>
     */
    public static int nppiGetAffineBound(
        NppiRect oSrcROI, 
        double[][] aBound, 
        double[][] aCoeffs)
    {
        return JNpp.checkResult(nppiGetAffineBoundNative(oSrcROI, aBound, aCoeffs));
    }
    private static native int nppiGetAffineBoundNative(
        NppiRect oSrcROI, 
        double[][] aBound, 
        double[][] aCoeffs);


    /**
     * <pre>
     * Single-channel 8-bit unsigned affine warp.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcROI Source ROI
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstROI Destination ROI
     * @param aCoeffs Affine transform coefficients
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref affine_transform_error_codes
     * </pre>
     */
    public static int nppiWarpAffine_8u_C1R(
        TypedPointer<Npp8u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpAffine_8u_C1RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, pDst, nDstStep, oDstROI, aCoeffs, eInterpolation));
    }
    private static native int nppiWarpAffine_8u_C1RNative(
        TypedPointer<Npp8u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Three-channel 8-bit unsigned affine warp.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcROI Source ROI
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstROI Destination ROI
     * @param aCoeffs Affine transform coefficients
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref affine_transform_error_codes
     * </pre>
     */
    public static int nppiWarpAffine_8u_C3R(
        TypedPointer<Npp8u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpAffine_8u_C3RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, pDst, nDstStep, oDstROI, aCoeffs, eInterpolation));
    }
    private static native int nppiWarpAffine_8u_C3RNative(
        TypedPointer<Npp8u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Four-channel 8-bit unsigned affine warp.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcROI Source ROI
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstROI Destination ROI
     * @param aCoeffs Affine transform coefficients
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref affine_transform_error_codes
     * </pre>
     */
    public static int nppiWarpAffine_8u_C4R(
        TypedPointer<Npp8u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpAffine_8u_C4RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, pDst, nDstStep, oDstROI, aCoeffs, eInterpolation));
    }
    private static native int nppiWarpAffine_8u_C4RNative(
        TypedPointer<Npp8u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Four-channel 8-bit unsigned affine warp, ignoring alpha channel.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcROI Source ROI
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstROI Destination ROI
     * @param aCoeffs Affine transform coefficients
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref affine_transform_error_codes
     * </pre>
     */
    public static int nppiWarpAffine_8u_AC4R(
        TypedPointer<Npp8u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpAffine_8u_AC4RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, pDst, nDstStep, oDstROI, aCoeffs, eInterpolation));
    }
    private static native int nppiWarpAffine_8u_AC4RNative(
        TypedPointer<Npp8u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation);


    public static int nppiWarpAffine_8u_P3R(
        TypedPointer<Npp8u>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp8u>[] pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpAffine_8u_P3RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, pDst, nDstStep, oDstROI, aCoeffs, eInterpolation));
    }
    private static native int nppiWarpAffine_8u_P3RNative(
        TypedPointer<Npp8u>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp8u>[] pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Four-channel planar 8-bit unsigned affine warp.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcROI Source ROI
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstROI Destination ROI
     * @param aCoeffs Affine transform coefficients
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref affine_transform_error_codes
     * </pre>
     */
    public static int nppiWarpAffine_8u_P4R(
        TypedPointer<Npp8u>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp8u>[] pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpAffine_8u_P4RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, pDst, nDstStep, oDstROI, aCoeffs, eInterpolation));
    }
    private static native int nppiWarpAffine_8u_P4RNative(
        TypedPointer<Npp8u>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp8u>[] pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Single-channel 16-bit unsigned affine warp.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcROI Source ROI
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstROI Destination ROI
     * @param aCoeffs Affine transform coefficients
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref affine_transform_error_codes
     * </pre>
     */
    public static int nppiWarpAffine_16u_C1R(
        TypedPointer<Npp16u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpAffine_16u_C1RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, pDst, nDstStep, oDstROI, aCoeffs, eInterpolation));
    }
    private static native int nppiWarpAffine_16u_C1RNative(
        TypedPointer<Npp16u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Three-channel 16-bit unsigned affine warp.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcROI Source ROI
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstROI Destination ROI
     * @param aCoeffs Affine transform coefficients
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref affine_transform_error_codes
     * </pre>
     */
    public static int nppiWarpAffine_16u_C3R(
        TypedPointer<Npp16u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpAffine_16u_C3RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, pDst, nDstStep, oDstROI, aCoeffs, eInterpolation));
    }
    private static native int nppiWarpAffine_16u_C3RNative(
        TypedPointer<Npp16u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Four-channel 16-bit unsigned affine warp.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcROI Source ROI
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstROI Destination ROI
     * @param aCoeffs Affine transform coefficients
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref affine_transform_error_codes
     * </pre>
     */
    public static int nppiWarpAffine_16u_C4R(
        TypedPointer<Npp16u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpAffine_16u_C4RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, pDst, nDstStep, oDstROI, aCoeffs, eInterpolation));
    }
    private static native int nppiWarpAffine_16u_C4RNative(
        TypedPointer<Npp16u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Four-channel 16-bit unsigned affine warp, ignoring alpha channel.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcROI Source ROI
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstROI Destination ROI
     * @param aCoeffs Affine transform coefficients
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref affine_transform_error_codes
     * </pre>
     */
    public static int nppiWarpAffine_16u_AC4R(
        TypedPointer<Npp16u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpAffine_16u_AC4RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, pDst, nDstStep, oDstROI, aCoeffs, eInterpolation));
    }
    private static native int nppiWarpAffine_16u_AC4RNative(
        TypedPointer<Npp16u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Three-channel planar 16-bit unsigned affine warp.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcROI Source ROI
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstROI Destination ROI
     * @param aCoeffs Affine transform coefficients
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref affine_transform_error_codes
     * </pre>
     */
    public static int nppiWarpAffine_16u_P3R(
        TypedPointer<Npp16u>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp16u>[] pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpAffine_16u_P3RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, pDst, nDstStep, oDstROI, aCoeffs, eInterpolation));
    }
    private static native int nppiWarpAffine_16u_P3RNative(
        TypedPointer<Npp16u>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp16u>[] pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Four-channel planar 16-bit unsigned affine warp.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcROI Source ROI
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstROI Destination ROI
     * @param aCoeffs Affine transform coefficients
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref affine_transform_error_codes
     * </pre>
     */
    public static int nppiWarpAffine_16u_P4R(
        TypedPointer<Npp16u>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp16u>[] pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpAffine_16u_P4RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, pDst, nDstStep, oDstROI, aCoeffs, eInterpolation));
    }
    private static native int nppiWarpAffine_16u_P4RNative(
        TypedPointer<Npp16u>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp16u>[] pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Single-channel 32-bit signed affine warp.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcROI Source ROI
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstROI Destination ROI
     * @param aCoeffs Affine transform coefficients
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref affine_transform_error_codes
     * </pre>
     */
    public static int nppiWarpAffine_32s_C1R(
        TypedPointer<Npp32s> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpAffine_32s_C1RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, pDst, nDstStep, oDstROI, aCoeffs, eInterpolation));
    }
    private static native int nppiWarpAffine_32s_C1RNative(
        TypedPointer<Npp32s> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Three-channel 32-bit signed affine warp.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcROI Source ROI
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstROI Destination ROI
     * @param aCoeffs Affine transform coefficients
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref affine_transform_error_codes
     * </pre>
     */
    public static int nppiWarpAffine_32s_C3R(
        TypedPointer<Npp32s> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpAffine_32s_C3RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, pDst, nDstStep, oDstROI, aCoeffs, eInterpolation));
    }
    private static native int nppiWarpAffine_32s_C3RNative(
        TypedPointer<Npp32s> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation);


    public static int nppiWarpAffine_32s_C4R(
        TypedPointer<Npp32s> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpAffine_32s_C4RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, pDst, nDstStep, oDstROI, aCoeffs, eInterpolation));
    }
    private static native int nppiWarpAffine_32s_C4RNative(
        TypedPointer<Npp32s> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation);


    public static int nppiWarpAffine_32s_AC4R(
        TypedPointer<Npp32s> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpAffine_32s_AC4RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, pDst, nDstStep, oDstROI, aCoeffs, eInterpolation));
    }
    private static native int nppiWarpAffine_32s_AC4RNative(
        TypedPointer<Npp32s> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Three-channel planar 32-bit signed affine warp.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcROI Source ROI
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstROI Destination ROI
     * @param aCoeffs Affine transform coefficients
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref affine_transform_error_codes
     * </pre>
     */
    public static int nppiWarpAffine_32s_P3R(
        TypedPointer<Npp32s>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp32s>[] pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpAffine_32s_P3RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, pDst, nDstStep, oDstROI, aCoeffs, eInterpolation));
    }
    private static native int nppiWarpAffine_32s_P3RNative(
        TypedPointer<Npp32s>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp32s>[] pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Four-channel planar 32-bit signed affine warp.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcROI Source ROI
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstROI Destination ROI
     * @param aCoeffs Affine transform coefficients
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref affine_transform_error_codes
     * </pre>
     */
    public static int nppiWarpAffine_32s_P4R(
        TypedPointer<Npp32s>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp32s>[] pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpAffine_32s_P4RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, pDst, nDstStep, oDstROI, aCoeffs, eInterpolation));
    }
    private static native int nppiWarpAffine_32s_P4RNative(
        TypedPointer<Npp32s>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp32s>[] pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Single-channel 32-bit floating-point affine warp.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcROI Source ROI
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstROI Destination ROI
     * @param aCoeffs Affine transform coefficients
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref affine_transform_error_codes
     * </pre>
     */
    public static int nppiWarpAffine_32f_C1R(
        TypedPointer<Npp32f> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpAffine_32f_C1RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, pDst, nDstStep, oDstROI, aCoeffs, eInterpolation));
    }
    private static native int nppiWarpAffine_32f_C1RNative(
        TypedPointer<Npp32f> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Three-channel 32-bit floating-point affine warp.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcROI Source ROI
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstROI Destination ROI
     * @param aCoeffs Affine transform coefficients
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref affine_transform_error_codes
     * </pre>
     */
    public static int nppiWarpAffine_32f_C3R(
        TypedPointer<Npp32f> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpAffine_32f_C3RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, pDst, nDstStep, oDstROI, aCoeffs, eInterpolation));
    }
    private static native int nppiWarpAffine_32f_C3RNative(
        TypedPointer<Npp32f> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation);


    public static int nppiWarpAffine_32f_C4R(
        TypedPointer<Npp32f> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpAffine_32f_C4RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, pDst, nDstStep, oDstROI, aCoeffs, eInterpolation));
    }
    private static native int nppiWarpAffine_32f_C4RNative(
        TypedPointer<Npp32f> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Four-channel 32-bit floating-point affine warp, ignoring alpha channel.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcROI Source ROI
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstROI Destination ROI
     * @param aCoeffs Affine transform coefficients
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref affine_transform_error_codes
     * </pre>
     */
    public static int nppiWarpAffine_32f_AC4R(
        TypedPointer<Npp32f> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpAffine_32f_AC4RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, pDst, nDstStep, oDstROI, aCoeffs, eInterpolation));
    }
    private static native int nppiWarpAffine_32f_AC4RNative(
        TypedPointer<Npp32f> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Three-channel planar 32-bit floating-point affine warp.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcROI Source ROI
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstROI Destination ROI
     * @param aCoeffs Affine transform coefficients
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref affine_transform_error_codes
     * </pre>
     */
    public static int nppiWarpAffine_32f_P3R(
        TypedPointer<Npp32f>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp32f>[] pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpAffine_32f_P3RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, pDst, nDstStep, oDstROI, aCoeffs, eInterpolation));
    }
    private static native int nppiWarpAffine_32f_P3RNative(
        TypedPointer<Npp32f>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp32f>[] pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation);


    public static int nppiWarpAffine_32f_P4R(
        TypedPointer<Npp32f>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp32f>[] pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpAffine_32f_P4RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, pDst, nDstStep, oDstROI, aCoeffs, eInterpolation));
    }
    private static native int nppiWarpAffine_32f_P4RNative(
        TypedPointer<Npp32f>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp32f>[] pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Single-channel 64-bit floating-point affine warp.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcROI Source ROI
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstROI Destination ROI
     * @param aCoeffs Affine transform coefficients
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref affine_transform_error_codes
     * </pre>
     */
    public static int nppiWarpAffine_64f_C1R(
        TypedPointer<Npp64f> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp64f> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpAffine_64f_C1RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, pDst, nDstStep, oDstROI, aCoeffs, eInterpolation));
    }
    private static native int nppiWarpAffine_64f_C1RNative(
        TypedPointer<Npp64f> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp64f> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Three-channel 64-bit floating-point affine warp.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcROI Source ROI
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstROI Destination ROI
     * @param aCoeffs Affine transform coefficients
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref affine_transform_error_codes
     * </pre>
     */
    public static int nppiWarpAffine_64f_C3R(
        TypedPointer<Npp64f> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp64f> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpAffine_64f_C3RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, pDst, nDstStep, oDstROI, aCoeffs, eInterpolation));
    }
    private static native int nppiWarpAffine_64f_C3RNative(
        TypedPointer<Npp64f> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp64f> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Four-channel 64-bit floating-point affine warp.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcROI Source ROI
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstROI Destination ROI
     * @param aCoeffs Affine transform coefficients
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref affine_transform_error_codes
     * </pre>
     */
    public static int nppiWarpAffine_64f_C4R(
        TypedPointer<Npp64f> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp64f> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpAffine_64f_C4RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, pDst, nDstStep, oDstROI, aCoeffs, eInterpolation));
    }
    private static native int nppiWarpAffine_64f_C4RNative(
        TypedPointer<Npp64f> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp64f> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation);


    public static int nppiWarpAffine_64f_AC4R(
        TypedPointer<Npp64f> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp64f> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpAffine_64f_AC4RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, pDst, nDstStep, oDstROI, aCoeffs, eInterpolation));
    }
    private static native int nppiWarpAffine_64f_AC4RNative(
        TypedPointer<Npp64f> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp64f> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Three-channel planar 64-bit floating-point affine warp.
     * 
     * @param aSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcROI Source ROI
     * @param aDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstROI Destination ROI
     * @param aCoeffs Affine transform coefficients
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref affine_transform_error_codes
     * </pre>
     */
    public static int nppiWarpAffine_64f_P3R(
        TypedPointer<Npp64f>[] aSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp64f>[] aDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpAffine_64f_P3RNative(aSrc, oSrcSize, nSrcStep, oSrcROI, aDst, nDstStep, oDstROI, aCoeffs, eInterpolation));
    }
    private static native int nppiWarpAffine_64f_P3RNative(
        TypedPointer<Npp64f>[] aSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp64f>[] aDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Four-channel planar 64-bit floating-point affine warp.
     * 
     * @param aSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcROI Source ROI
     * @param aDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstROI Destination ROI
     * @param aCoeffs Affine transform coefficients
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref affine_transform_error_codes
     * </pre>
     */
    public static int nppiWarpAffine_64f_P4R(
        TypedPointer<Npp64f>[] aSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp64f>[] aDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpAffine_64f_P4RNative(aSrc, oSrcSize, nSrcStep, oSrcROI, aDst, nDstStep, oDstROI, aCoeffs, eInterpolation));
    }
    private static native int nppiWarpAffine_64f_P4RNative(
        TypedPointer<Npp64f>[] aSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp64f>[] aDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Single-channel 8-bit unsigned integer backwards affine warp.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcROI Source ROI
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstROI Destination ROI
     * @param aCoeffs Affine transform coefficients
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref affine_transform_error_codes
     * </pre>
     */
    public static int nppiWarpAffineBack_8u_C1R(
        TypedPointer<Npp8u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpAffineBack_8u_C1RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, pDst, nDstStep, oDstROI, aCoeffs, eInterpolation));
    }
    private static native int nppiWarpAffineBack_8u_C1RNative(
        TypedPointer<Npp8u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Three-channel 8-bit unsigned integer backwards affine warp.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcROI Source ROI
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstROI Destination ROI
     * @param aCoeffs Affine transform coefficients
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref affine_transform_error_codes
     * </pre>
     */
    public static int nppiWarpAffineBack_8u_C3R(
        TypedPointer<Npp8u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpAffineBack_8u_C3RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, pDst, nDstStep, oDstROI, aCoeffs, eInterpolation));
    }
    private static native int nppiWarpAffineBack_8u_C3RNative(
        TypedPointer<Npp8u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Four-channel 8-bit unsigned integer backwards affine warp.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcROI Source ROI
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstROI Destination ROI
     * @param aCoeffs Affine transform coefficients
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref affine_transform_error_codes
     * </pre>
     */
    public static int nppiWarpAffineBack_8u_C4R(
        TypedPointer<Npp8u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpAffineBack_8u_C4RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, pDst, nDstStep, oDstROI, aCoeffs, eInterpolation));
    }
    private static native int nppiWarpAffineBack_8u_C4RNative(
        TypedPointer<Npp8u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation);


    public static int nppiWarpAffineBack_8u_AC4R(
        TypedPointer<Npp8u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpAffineBack_8u_AC4RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, pDst, nDstStep, oDstROI, aCoeffs, eInterpolation));
    }
    private static native int nppiWarpAffineBack_8u_AC4RNative(
        TypedPointer<Npp8u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Three-channel planar 8-bit unsigned integer backwards affine warp.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcROI Source ROI
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstROI Destination ROI
     * @param aCoeffs Affine transform coefficients
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref affine_transform_error_codes
     * </pre>
     */
    public static int nppiWarpAffineBack_8u_P3R(
        TypedPointer<Npp8u>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp8u>[] pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpAffineBack_8u_P3RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, pDst, nDstStep, oDstROI, aCoeffs, eInterpolation));
    }
    private static native int nppiWarpAffineBack_8u_P3RNative(
        TypedPointer<Npp8u>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp8u>[] pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Four-channel planar 8-bit unsigned integer backwards affine warp.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcROI Source ROI
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstROI Destination ROI
     * @param aCoeffs Affine transform coefficients
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref affine_transform_error_codes
     * </pre>
     */
    public static int nppiWarpAffineBack_8u_P4R(
        TypedPointer<Npp8u>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp8u>[] pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpAffineBack_8u_P4RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, pDst, nDstStep, oDstROI, aCoeffs, eInterpolation));
    }
    private static native int nppiWarpAffineBack_8u_P4RNative(
        TypedPointer<Npp8u>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp8u>[] pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Single-channel 16-bit unsigned integer backwards affine warp.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcROI Source ROI
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstROI Destination ROI
     * @param aCoeffs Affine transform coefficients
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref affine_transform_error_codes
     * </pre>
     */
    public static int nppiWarpAffineBack_16u_C1R(
        TypedPointer<Npp16u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpAffineBack_16u_C1RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, pDst, nDstStep, oDstROI, aCoeffs, eInterpolation));
    }
    private static native int nppiWarpAffineBack_16u_C1RNative(
        TypedPointer<Npp16u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Three-channel 16-bit unsigned integer backwards affine warp.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcROI Source ROI
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstROI Destination ROI
     * @param aCoeffs Affine transform coefficients
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref affine_transform_error_codes
     * </pre>
     */
    public static int nppiWarpAffineBack_16u_C3R(
        TypedPointer<Npp16u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpAffineBack_16u_C3RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, pDst, nDstStep, oDstROI, aCoeffs, eInterpolation));
    }
    private static native int nppiWarpAffineBack_16u_C3RNative(
        TypedPointer<Npp16u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Four-channel 16-bit unsigned integer backwards affine warp.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcROI Source ROI
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstROI Destination ROI
     * @param aCoeffs Affine transform coefficients
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref affine_transform_error_codes
     * </pre>
     */
    public static int nppiWarpAffineBack_16u_C4R(
        TypedPointer<Npp16u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpAffineBack_16u_C4RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, pDst, nDstStep, oDstROI, aCoeffs, eInterpolation));
    }
    private static native int nppiWarpAffineBack_16u_C4RNative(
        TypedPointer<Npp16u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Four-channel 16-bit unsigned integer backwards affine warp, ignoring alpha channel.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcROI Source ROI
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstROI Destination ROI
     * @param aCoeffs Affine transform coefficients
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref affine_transform_error_codes
     * </pre>
     */
    public static int nppiWarpAffineBack_16u_AC4R(
        TypedPointer<Npp16u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpAffineBack_16u_AC4RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, pDst, nDstStep, oDstROI, aCoeffs, eInterpolation));
    }
    private static native int nppiWarpAffineBack_16u_AC4RNative(
        TypedPointer<Npp16u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Three-channel planar 16-bit unsigned integer backwards affine warp.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcROI Source ROI
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstROI Destination ROI
     * @param aCoeffs Affine transform coefficients
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref affine_transform_error_codes
     * </pre>
     */
    public static int nppiWarpAffineBack_16u_P3R(
        TypedPointer<Npp16u>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp16u>[] pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpAffineBack_16u_P3RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, pDst, nDstStep, oDstROI, aCoeffs, eInterpolation));
    }
    private static native int nppiWarpAffineBack_16u_P3RNative(
        TypedPointer<Npp16u>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp16u>[] pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Four-channel planar 16-bit unsigned integer backwards affine warp.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcROI Source ROI
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstROI Destination ROI
     * @param aCoeffs Affine transform coefficients
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref affine_transform_error_codes
     * </pre>
     */
    public static int nppiWarpAffineBack_16u_P4R(
        TypedPointer<Npp16u>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp16u>[] pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpAffineBack_16u_P4RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, pDst, nDstStep, oDstROI, aCoeffs, eInterpolation));
    }
    private static native int nppiWarpAffineBack_16u_P4RNative(
        TypedPointer<Npp16u>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp16u>[] pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Single-channel 32-bit signed integer backwards affine warp.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcROI Source ROI
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstROI Destination ROI
     * @param aCoeffs Affine transform coefficients
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref affine_transform_error_codes
     * </pre>
     */
    public static int nppiWarpAffineBack_32s_C1R(
        TypedPointer<Npp32s> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpAffineBack_32s_C1RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, pDst, nDstStep, oDstROI, aCoeffs, eInterpolation));
    }
    private static native int nppiWarpAffineBack_32s_C1RNative(
        TypedPointer<Npp32s> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Three-channel 32-bit signed integer backwards affine warp.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcROI Source ROI
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstROI Destination ROI
     * @param aCoeffs Affine transform coefficients
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref affine_transform_error_codes
     * </pre>
     */
    public static int nppiWarpAffineBack_32s_C3R(
        TypedPointer<Npp32s> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpAffineBack_32s_C3RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, pDst, nDstStep, oDstROI, aCoeffs, eInterpolation));
    }
    private static native int nppiWarpAffineBack_32s_C3RNative(
        TypedPointer<Npp32s> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Four-channel 32-bit signed integer backwards affine warp.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcROI Source ROI
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstROI Destination ROI
     * @param aCoeffs Affine transform coefficients
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref affine_transform_error_codes
     * </pre>
     */
    public static int nppiWarpAffineBack_32s_C4R(
        TypedPointer<Npp32s> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpAffineBack_32s_C4RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, pDst, nDstStep, oDstROI, aCoeffs, eInterpolation));
    }
    private static native int nppiWarpAffineBack_32s_C4RNative(
        TypedPointer<Npp32s> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation);


    public static int nppiWarpAffineBack_32s_AC4R(
        TypedPointer<Npp32s> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpAffineBack_32s_AC4RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, pDst, nDstStep, oDstROI, aCoeffs, eInterpolation));
    }
    private static native int nppiWarpAffineBack_32s_AC4RNative(
        TypedPointer<Npp32s> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Three-channel planar 32-bit signed integer backwards affine warp.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcROI Source ROI
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstROI Destination ROI
     * @param aCoeffs Affine transform coefficients
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref affine_transform_error_codes
     * </pre>
     */
    public static int nppiWarpAffineBack_32s_P3R(
        TypedPointer<Npp32s>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp32s>[] pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpAffineBack_32s_P3RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, pDst, nDstStep, oDstROI, aCoeffs, eInterpolation));
    }
    private static native int nppiWarpAffineBack_32s_P3RNative(
        TypedPointer<Npp32s>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp32s>[] pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Four-channel planar 32-bit signed integer backwards affine warp.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcROI Source ROI
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstROI Destination ROI
     * @param aCoeffs Affine transform coefficients
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref affine_transform_error_codes
     * </pre>
     */
    public static int nppiWarpAffineBack_32s_P4R(
        TypedPointer<Npp32s>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp32s>[] pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpAffineBack_32s_P4RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, pDst, nDstStep, oDstROI, aCoeffs, eInterpolation));
    }
    private static native int nppiWarpAffineBack_32s_P4RNative(
        TypedPointer<Npp32s>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp32s>[] pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation);


    public static int nppiWarpAffineBack_32f_C1R(
        TypedPointer<Npp32f> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpAffineBack_32f_C1RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, pDst, nDstStep, oDstROI, aCoeffs, eInterpolation));
    }
    private static native int nppiWarpAffineBack_32f_C1RNative(
        TypedPointer<Npp32f> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Three-channel 32-bit floating-point backwards affine warp.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcROI Source ROI
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstROI Destination ROI
     * @param aCoeffs Affine transform coefficients
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref affine_transform_error_codes
     * </pre>
     */
    public static int nppiWarpAffineBack_32f_C3R(
        TypedPointer<Npp32f> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpAffineBack_32f_C3RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, pDst, nDstStep, oDstROI, aCoeffs, eInterpolation));
    }
    private static native int nppiWarpAffineBack_32f_C3RNative(
        TypedPointer<Npp32f> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation);


    public static int nppiWarpAffineBack_32f_C4R(
        TypedPointer<Npp32f> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpAffineBack_32f_C4RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, pDst, nDstStep, oDstROI, aCoeffs, eInterpolation));
    }
    private static native int nppiWarpAffineBack_32f_C4RNative(
        TypedPointer<Npp32f> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Four-channel 32-bit floating-point backwards affine warp, ignoring alpha channel.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcROI Source ROI
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstROI Destination ROI
     * @param aCoeffs Affine transform coefficients
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref affine_transform_error_codes
     * </pre>
     */
    public static int nppiWarpAffineBack_32f_AC4R(
        TypedPointer<Npp32f> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpAffineBack_32f_AC4RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, pDst, nDstStep, oDstROI, aCoeffs, eInterpolation));
    }
    private static native int nppiWarpAffineBack_32f_AC4RNative(
        TypedPointer<Npp32f> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Three-channel planar 32-bit floating-point backwards affine warp.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcROI Source ROI
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstROI Destination ROI
     * @param aCoeffs Affine transform coefficients
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref affine_transform_error_codes
     * </pre>
     */
    public static int nppiWarpAffineBack_32f_P3R(
        TypedPointer<Npp32f>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp32f>[] pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpAffineBack_32f_P3RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, pDst, nDstStep, oDstROI, aCoeffs, eInterpolation));
    }
    private static native int nppiWarpAffineBack_32f_P3RNative(
        TypedPointer<Npp32f>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp32f>[] pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Four-channel planar 32-bit floating-point backwards affine warp.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcROI Source ROI
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstROI Destination ROI
     * @param aCoeffs Affine transform coefficients
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref affine_transform_error_codes
     * </pre>
     */
    public static int nppiWarpAffineBack_32f_P4R(
        TypedPointer<Npp32f>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp32f>[] pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpAffineBack_32f_P4RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, pDst, nDstStep, oDstROI, aCoeffs, eInterpolation));
    }
    private static native int nppiWarpAffineBack_32f_P4RNative(
        TypedPointer<Npp32f>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp32f>[] pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Single-channel 32-bit floating-point quad-based affine warp.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcROI Source ROI
     * @param aSrcQuad Source quad.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstROI Destination ROI
     * @param aDstQuad Destination quad.
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref affine_transform_error_codes
     * </pre>
     */
    public static int nppiWarpAffineQuad_8u_C1R(
        TypedPointer<Npp8u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        double[][] aSrcQuad, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aDstQuad, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpAffineQuad_8u_C1RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, aSrcQuad, pDst, nDstStep, oDstROI, aDstQuad, eInterpolation));
    }
    private static native int nppiWarpAffineQuad_8u_C1RNative(
        TypedPointer<Npp8u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        double[][] aSrcQuad, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aDstQuad, 
        int eInterpolation);


    /**
     * <pre>
     * Three-channel 8-bit unsigned integer quad-based affine warp.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcROI Source ROI
     * @param aSrcQuad Source quad.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstROI Destination ROI
     * @param aDstQuad Destination quad.
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref affine_transform_error_codes
     * </pre>
     */
    public static int nppiWarpAffineQuad_8u_C3R(
        TypedPointer<Npp8u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        double[][] aSrcQuad, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aDstQuad, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpAffineQuad_8u_C3RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, aSrcQuad, pDst, nDstStep, oDstROI, aDstQuad, eInterpolation));
    }
    private static native int nppiWarpAffineQuad_8u_C3RNative(
        TypedPointer<Npp8u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        double[][] aSrcQuad, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aDstQuad, 
        int eInterpolation);


    public static int nppiWarpAffineQuad_8u_C4R(
        TypedPointer<Npp8u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        double[][] aSrcQuad, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aDstQuad, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpAffineQuad_8u_C4RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, aSrcQuad, pDst, nDstStep, oDstROI, aDstQuad, eInterpolation));
    }
    private static native int nppiWarpAffineQuad_8u_C4RNative(
        TypedPointer<Npp8u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        double[][] aSrcQuad, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aDstQuad, 
        int eInterpolation);


    /**
     * <pre>
     * Four-channel 8-bit unsigned integer quad-based affine warp, ignoring alpha channel.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcROI Source ROI
     * @param aSrcQuad Source quad.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstROI Destination ROI
     * @param aDstQuad Destination quad.
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref affine_transform_error_codes
     * </pre>
     */
    public static int nppiWarpAffineQuad_8u_AC4R(
        TypedPointer<Npp8u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        double[][] aSrcQuad, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aDstQuad, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpAffineQuad_8u_AC4RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, aSrcQuad, pDst, nDstStep, oDstROI, aDstQuad, eInterpolation));
    }
    private static native int nppiWarpAffineQuad_8u_AC4RNative(
        TypedPointer<Npp8u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        double[][] aSrcQuad, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aDstQuad, 
        int eInterpolation);


    /**
     * <pre>
     * Three-channel planar 8-bit unsigned integer quad-based affine warp.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcROI Source ROI
     * @param aSrcQuad Source quad.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstROI Destination ROI
     * @param aDstQuad Destination quad.
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref affine_transform_error_codes
     * </pre>
     */
    public static int nppiWarpAffineQuad_8u_P3R(
        TypedPointer<Npp8u>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        double[][] aSrcQuad, 
        TypedPointer<Npp8u>[] pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aDstQuad, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpAffineQuad_8u_P3RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, aSrcQuad, pDst, nDstStep, oDstROI, aDstQuad, eInterpolation));
    }
    private static native int nppiWarpAffineQuad_8u_P3RNative(
        TypedPointer<Npp8u>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        double[][] aSrcQuad, 
        TypedPointer<Npp8u>[] pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aDstQuad, 
        int eInterpolation);


    public static int nppiWarpAffineQuad_8u_P4R(
        TypedPointer<Npp8u>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        double[][] aSrcQuad, 
        TypedPointer<Npp8u>[] pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aDstQuad, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpAffineQuad_8u_P4RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, aSrcQuad, pDst, nDstStep, oDstROI, aDstQuad, eInterpolation));
    }
    private static native int nppiWarpAffineQuad_8u_P4RNative(
        TypedPointer<Npp8u>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        double[][] aSrcQuad, 
        TypedPointer<Npp8u>[] pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aDstQuad, 
        int eInterpolation);


    /**
     * <pre>
     * Single-channel 16-bit unsigned integer quad-based affine warp.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcROI Source ROI
     * @param aSrcQuad Source quad.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstROI Destination ROI
     * @param aDstQuad Destination quad.
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref affine_transform_error_codes
     * </pre>
     */
    public static int nppiWarpAffineQuad_16u_C1R(
        TypedPointer<Npp16u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        double[][] aSrcQuad, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aDstQuad, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpAffineQuad_16u_C1RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, aSrcQuad, pDst, nDstStep, oDstROI, aDstQuad, eInterpolation));
    }
    private static native int nppiWarpAffineQuad_16u_C1RNative(
        TypedPointer<Npp16u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        double[][] aSrcQuad, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aDstQuad, 
        int eInterpolation);


    /**
     * <pre>
     * Three-channel 16-bit unsigned integer quad-based affine warp.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcROI Source ROI
     * @param aSrcQuad Source quad.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstROI Destination ROI
     * @param aDstQuad Destination quad.
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref affine_transform_error_codes
     * </pre>
     */
    public static int nppiWarpAffineQuad_16u_C3R(
        TypedPointer<Npp16u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        double[][] aSrcQuad, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aDstQuad, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpAffineQuad_16u_C3RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, aSrcQuad, pDst, nDstStep, oDstROI, aDstQuad, eInterpolation));
    }
    private static native int nppiWarpAffineQuad_16u_C3RNative(
        TypedPointer<Npp16u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        double[][] aSrcQuad, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aDstQuad, 
        int eInterpolation);


    /**
     * <pre>
     * Four-channel 16-bit unsigned integer quad-based affine warp.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcROI Source ROI
     * @param aSrcQuad Source quad.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstROI Destination ROI
     * @param aDstQuad Destination quad.
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref affine_transform_error_codes
     * </pre>
     */
    public static int nppiWarpAffineQuad_16u_C4R(
        TypedPointer<Npp16u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        double[][] aSrcQuad, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aDstQuad, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpAffineQuad_16u_C4RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, aSrcQuad, pDst, nDstStep, oDstROI, aDstQuad, eInterpolation));
    }
    private static native int nppiWarpAffineQuad_16u_C4RNative(
        TypedPointer<Npp16u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        double[][] aSrcQuad, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aDstQuad, 
        int eInterpolation);


    /**
     * <pre>
     * Four-channel 16-bit unsigned integer quad-based affine warp, ignoring alpha channel.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcROI Source ROI
     * @param aSrcQuad Source quad.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstROI Destination ROI
     * @param aDstQuad Destination quad.
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref affine_transform_error_codes
     * </pre>
     */
    public static int nppiWarpAffineQuad_16u_AC4R(
        TypedPointer<Npp16u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        double[][] aSrcQuad, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aDstQuad, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpAffineQuad_16u_AC4RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, aSrcQuad, pDst, nDstStep, oDstROI, aDstQuad, eInterpolation));
    }
    private static native int nppiWarpAffineQuad_16u_AC4RNative(
        TypedPointer<Npp16u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        double[][] aSrcQuad, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aDstQuad, 
        int eInterpolation);


    /**
     * <pre>
     * Three-channel planar 16-bit unsigned integer quad-based affine warp.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcROI Source ROI
     * @param aSrcQuad Source quad.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstROI Destination ROI
     * @param aDstQuad Destination quad.
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref affine_transform_error_codes
     * </pre>
     */
    public static int nppiWarpAffineQuad_16u_P3R(
        TypedPointer<Npp16u>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        double[][] aSrcQuad, 
        TypedPointer<Npp16u>[] pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aDstQuad, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpAffineQuad_16u_P3RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, aSrcQuad, pDst, nDstStep, oDstROI, aDstQuad, eInterpolation));
    }
    private static native int nppiWarpAffineQuad_16u_P3RNative(
        TypedPointer<Npp16u>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        double[][] aSrcQuad, 
        TypedPointer<Npp16u>[] pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aDstQuad, 
        int eInterpolation);


    /**
     * <pre>
     * Four-channel planar 16-bit unsigned integer quad-based affine warp.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcROI Source ROI
     * @param aSrcQuad Source quad.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstROI Destination ROI
     * @param aDstQuad Destination quad.
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref affine_transform_error_codes
     * </pre>
     */
    public static int nppiWarpAffineQuad_16u_P4R(
        TypedPointer<Npp16u>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        double[][] aSrcQuad, 
        TypedPointer<Npp16u>[] pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aDstQuad, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpAffineQuad_16u_P4RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, aSrcQuad, pDst, nDstStep, oDstROI, aDstQuad, eInterpolation));
    }
    private static native int nppiWarpAffineQuad_16u_P4RNative(
        TypedPointer<Npp16u>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        double[][] aSrcQuad, 
        TypedPointer<Npp16u>[] pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aDstQuad, 
        int eInterpolation);


    public static int nppiWarpAffineQuad_32s_C1R(
        TypedPointer<Npp32s> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        double[][] aSrcQuad, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aDstQuad, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpAffineQuad_32s_C1RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, aSrcQuad, pDst, nDstStep, oDstROI, aDstQuad, eInterpolation));
    }
    private static native int nppiWarpAffineQuad_32s_C1RNative(
        TypedPointer<Npp32s> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        double[][] aSrcQuad, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aDstQuad, 
        int eInterpolation);


    public static int nppiWarpAffineQuad_32s_C3R(
        TypedPointer<Npp32s> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        double[][] aSrcQuad, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aDstQuad, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpAffineQuad_32s_C3RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, aSrcQuad, pDst, nDstStep, oDstROI, aDstQuad, eInterpolation));
    }
    private static native int nppiWarpAffineQuad_32s_C3RNative(
        TypedPointer<Npp32s> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        double[][] aSrcQuad, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aDstQuad, 
        int eInterpolation);


    /**
     * <pre>
     * Four-channel 32-bit signed integer quad-based affine warp.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcROI Source ROI
     * @param aSrcQuad Source quad.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstROI Destination ROI
     * @param aDstQuad Destination quad.
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref affine_transform_error_codes
     * </pre>
     */
    public static int nppiWarpAffineQuad_32s_C4R(
        TypedPointer<Npp32s> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        double[][] aSrcQuad, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aDstQuad, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpAffineQuad_32s_C4RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, aSrcQuad, pDst, nDstStep, oDstROI, aDstQuad, eInterpolation));
    }
    private static native int nppiWarpAffineQuad_32s_C4RNative(
        TypedPointer<Npp32s> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        double[][] aSrcQuad, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aDstQuad, 
        int eInterpolation);


    /**
     * <pre>
     * Four-channel 32-bit signed integer quad-based affine warp, ignoring alpha channel.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcROI Source ROI
     * @param aSrcQuad Source quad.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstROI Destination ROI
     * @param aDstQuad Destination quad.
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref affine_transform_error_codes
     * </pre>
     */
    public static int nppiWarpAffineQuad_32s_AC4R(
        TypedPointer<Npp32s> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        double[][] aSrcQuad, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aDstQuad, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpAffineQuad_32s_AC4RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, aSrcQuad, pDst, nDstStep, oDstROI, aDstQuad, eInterpolation));
    }
    private static native int nppiWarpAffineQuad_32s_AC4RNative(
        TypedPointer<Npp32s> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        double[][] aSrcQuad, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aDstQuad, 
        int eInterpolation);


    /**
     * <pre>
     * Three-channel planar 32-bit signed integer quad-based affine warp.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcROI Source ROI
     * @param aSrcQuad Source quad.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstROI Destination ROI
     * @param aDstQuad Destination quad.
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref affine_transform_error_codes
     * </pre>
     */
    public static int nppiWarpAffineQuad_32s_P3R(
        TypedPointer<Npp32s>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        double[][] aSrcQuad, 
        TypedPointer<Npp32s>[] pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aDstQuad, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpAffineQuad_32s_P3RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, aSrcQuad, pDst, nDstStep, oDstROI, aDstQuad, eInterpolation));
    }
    private static native int nppiWarpAffineQuad_32s_P3RNative(
        TypedPointer<Npp32s>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        double[][] aSrcQuad, 
        TypedPointer<Npp32s>[] pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aDstQuad, 
        int eInterpolation);


    /**
     * <pre>
     * Four-channel planar 32-bit signed integer quad-based affine warp.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcROI Source ROI
     * @param aSrcQuad Source quad.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstROI Destination ROI
     * @param aDstQuad Destination quad.
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref affine_transform_error_codes
     * </pre>
     */
    public static int nppiWarpAffineQuad_32s_P4R(
        TypedPointer<Npp32s>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        double[][] aSrcQuad, 
        TypedPointer<Npp32s>[] pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aDstQuad, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpAffineQuad_32s_P4RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, aSrcQuad, pDst, nDstStep, oDstROI, aDstQuad, eInterpolation));
    }
    private static native int nppiWarpAffineQuad_32s_P4RNative(
        TypedPointer<Npp32s>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        double[][] aSrcQuad, 
        TypedPointer<Npp32s>[] pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aDstQuad, 
        int eInterpolation);


    /**
     * <pre>
     * Single-channel 32-bit floating-point quad-based affine warp.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcROI Source ROI
     * @param aSrcQuad Source quad.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstROI Destination ROI
     * @param aDstQuad Destination quad.
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref affine_transform_error_codes
     * </pre>
     */
    public static int nppiWarpAffineQuad_32f_C1R(
        TypedPointer<Npp32f> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        double[][] aSrcQuad, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aDstQuad, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpAffineQuad_32f_C1RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, aSrcQuad, pDst, nDstStep, oDstROI, aDstQuad, eInterpolation));
    }
    private static native int nppiWarpAffineQuad_32f_C1RNative(
        TypedPointer<Npp32f> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        double[][] aSrcQuad, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aDstQuad, 
        int eInterpolation);


    /**
     * <pre>
     * Three-channel 32-bit floating-point quad-based affine warp.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcROI Source ROI
     * @param aSrcQuad Source quad.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstROI Destination ROI
     * @param aDstQuad Destination quad.
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref affine_transform_error_codes
     * </pre>
     */
    public static int nppiWarpAffineQuad_32f_C3R(
        TypedPointer<Npp32f> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        double[][] aSrcQuad, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aDstQuad, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpAffineQuad_32f_C3RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, aSrcQuad, pDst, nDstStep, oDstROI, aDstQuad, eInterpolation));
    }
    private static native int nppiWarpAffineQuad_32f_C3RNative(
        TypedPointer<Npp32f> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        double[][] aSrcQuad, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aDstQuad, 
        int eInterpolation);


    /**
     * <pre>
     * Four-channel 32-bit floating-point quad-based affine warp.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcROI Source ROI
     * @param aSrcQuad Source quad.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstROI Destination ROI
     * @param aDstQuad Destination quad.
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref affine_transform_error_codes
     * </pre>
     */
    public static int nppiWarpAffineQuad_32f_C4R(
        TypedPointer<Npp32f> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        double[][] aSrcQuad, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aDstQuad, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpAffineQuad_32f_C4RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, aSrcQuad, pDst, nDstStep, oDstROI, aDstQuad, eInterpolation));
    }
    private static native int nppiWarpAffineQuad_32f_C4RNative(
        TypedPointer<Npp32f> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        double[][] aSrcQuad, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aDstQuad, 
        int eInterpolation);


    public static int nppiWarpAffineQuad_32f_AC4R(
        TypedPointer<Npp32f> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        double[][] aSrcQuad, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aDstQuad, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpAffineQuad_32f_AC4RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, aSrcQuad, pDst, nDstStep, oDstROI, aDstQuad, eInterpolation));
    }
    private static native int nppiWarpAffineQuad_32f_AC4RNative(
        TypedPointer<Npp32f> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        double[][] aSrcQuad, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aDstQuad, 
        int eInterpolation);


    /**
     * <pre>
     * Three-channel planar 32-bit floating-point quad-based affine warp.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcROI Source ROI
     * @param aSrcQuad Source quad.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstROI Destination ROI
     * @param aDstQuad Destination quad.
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref affine_transform_error_codes
     * </pre>
     */
    public static int nppiWarpAffineQuad_32f_P3R(
        TypedPointer<Npp32f>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        double[][] aSrcQuad, 
        TypedPointer<Npp32f>[] pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aDstQuad, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpAffineQuad_32f_P3RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, aSrcQuad, pDst, nDstStep, oDstROI, aDstQuad, eInterpolation));
    }
    private static native int nppiWarpAffineQuad_32f_P3RNative(
        TypedPointer<Npp32f>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        double[][] aSrcQuad, 
        TypedPointer<Npp32f>[] pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aDstQuad, 
        int eInterpolation);


    public static int nppiWarpAffineQuad_32f_P4R(
        TypedPointer<Npp32f>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        double[][] aSrcQuad, 
        TypedPointer<Npp32f>[] pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aDstQuad, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpAffineQuad_32f_P4RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, aSrcQuad, pDst, nDstStep, oDstROI, aDstQuad, eInterpolation));
    }
    private static native int nppiWarpAffineQuad_32f_P4RNative(
        TypedPointer<Npp32f>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        double[][] aSrcQuad, 
        TypedPointer<Npp32f>[] pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aDstQuad, 
        int eInterpolation);


    /**
     * <pre>
     * Calculates perspective transform coefficients given source rectangular ROI
     * and its destination quadrangle projection
     *
     * @param oSrcROI Source ROI
     * @param quad Destination quadrangle
     * @param aCoeffs Perspective transform coefficients
     * @return
     *  Error codes:
     *         - ::NPP_SIZE_ERROR Indicates an error condition if any image dimension
     *           has zero or negative value
     *         - ::NPP_RECT_ERROR Indicates an error condition if width or height of
     *           the intersection of the oSrcROI and source image is less than or
     *           equal to 1
     *         - ::NPP_COEFF_ERROR Indicates an error condition if coefficient values
     *           are invalid
     * </pre>
     */
    public static int nppiGetPerspectiveTransform(
        NppiRect oSrcROI, 
        double[][] quad, 
        double[][] aCoeffs)
    {
        return JNpp.checkResult(nppiGetPerspectiveTransformNative(oSrcROI, quad, aCoeffs));
    }
    private static native int nppiGetPerspectiveTransformNative(
        NppiRect oSrcROI, 
        double[][] quad, 
        double[][] aCoeffs);


    /**
     * <pre>
     * Calculates perspective transform projection of given source rectangular
     * ROI
     *
     * @param oSrcROI Source ROI
     * @param quad Destination quadrangle
     * @param aCoeffs Perspective transform coefficients
     * @return
     *  Error codes:
     *         - ::NPP_SIZE_ERROR Indicates an error condition if any image dimension
     *           has zero or negative value
     *         - ::NPP_RECT_ERROR Indicates an error condition if width or height of
     *           the intersection of the oSrcROI and source image is less than or
     *           equal to 1
     *         - ::NPP_COEFF_ERROR Indicates an error condition if coefficient values
     *           are invalid
     * </pre>
     */
    public static int nppiGetPerspectiveQuad(
        NppiRect oSrcROI, 
        double[][] quad, 
        double[][] aCoeffs)
    {
        return JNpp.checkResult(nppiGetPerspectiveQuadNative(oSrcROI, quad, aCoeffs));
    }
    private static native int nppiGetPerspectiveQuadNative(
        NppiRect oSrcROI, 
        double[][] quad, 
        double[][] aCoeffs);


    public static int nppiGetPerspectiveBound(
        NppiRect oSrcROI, 
        double[][] bound, 
        double[][] aCoeffs)
    {
        return JNpp.checkResult(nppiGetPerspectiveBoundNative(oSrcROI, bound, aCoeffs));
    }
    private static native int nppiGetPerspectiveBoundNative(
        NppiRect oSrcROI, 
        double[][] bound, 
        double[][] aCoeffs);


    public static int nppiWarpPerspective_8u_C1R(
        TypedPointer<Npp8u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpPerspective_8u_C1RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, pDst, nDstStep, oDstROI, aCoeffs, eInterpolation));
    }
    private static native int nppiWarpPerspective_8u_C1RNative(
        TypedPointer<Npp8u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Three-channel 8-bit unsigned integer perspective warp.
     *
     * @param pSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcROI Source ROI
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstROI Destination ROI
     * @param aCoeffs Perspective transform coefficients
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref perspective_transform_error_codes
     * </pre>
     */
    public static int nppiWarpPerspective_8u_C3R(
        TypedPointer<Npp8u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpPerspective_8u_C3RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, pDst, nDstStep, oDstROI, aCoeffs, eInterpolation));
    }
    private static native int nppiWarpPerspective_8u_C3RNative(
        TypedPointer<Npp8u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Four-channel 8-bit unsigned integer perspective warp.
     *
     * @param pSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcROI Source ROI
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstROI Destination ROI
     * @param aCoeffs Perspective transform coefficients
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref perspective_transform_error_codes
     * </pre>
     */
    public static int nppiWarpPerspective_8u_C4R(
        TypedPointer<Npp8u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpPerspective_8u_C4RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, pDst, nDstStep, oDstROI, aCoeffs, eInterpolation));
    }
    private static native int nppiWarpPerspective_8u_C4RNative(
        TypedPointer<Npp8u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation);


    public static int nppiWarpPerspective_8u_AC4R(
        TypedPointer<Npp8u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpPerspective_8u_AC4RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, pDst, nDstStep, oDstROI, aCoeffs, eInterpolation));
    }
    private static native int nppiWarpPerspective_8u_AC4RNative(
        TypedPointer<Npp8u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Three-channel planar 8-bit unsigned integer perspective warp.
     *
     * @param pSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcROI Source ROI
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstROI Destination ROI
     * @param aCoeffs Perspective transform coefficients
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref perspective_transform_error_codes
     * </pre>
     */
    public static int nppiWarpPerspective_8u_P3R(
        TypedPointer<Npp8u>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp8u>[] pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpPerspective_8u_P3RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, pDst, nDstStep, oDstROI, aCoeffs, eInterpolation));
    }
    private static native int nppiWarpPerspective_8u_P3RNative(
        TypedPointer<Npp8u>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp8u>[] pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Four-channel planar 8-bit unsigned integer perspective warp.
     *
     * @param pSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcROI Source ROI
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstROI Destination ROI
     * @param aCoeffs Perspective transform coefficients
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref perspective_transform_error_codes
     * </pre>
     */
    public static int nppiWarpPerspective_8u_P4R(
        TypedPointer<Npp8u>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp8u>[] pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpPerspective_8u_P4RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, pDst, nDstStep, oDstROI, aCoeffs, eInterpolation));
    }
    private static native int nppiWarpPerspective_8u_P4RNative(
        TypedPointer<Npp8u>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp8u>[] pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Single-channel 16-bit unsigned integer perspective warp.
     *
     * @param pSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcROI Source ROI
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstROI Destination ROI
     * @param aCoeffs Perspective transform coefficients
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref perspective_transform_error_codes
     * </pre>
     */
    public static int nppiWarpPerspective_16u_C1R(
        TypedPointer<Npp16u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpPerspective_16u_C1RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, pDst, nDstStep, oDstROI, aCoeffs, eInterpolation));
    }
    private static native int nppiWarpPerspective_16u_C1RNative(
        TypedPointer<Npp16u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Three-channel 16-bit unsigned integer perspective warp.
     *
     * @param pSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcROI Source ROI
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstROI Destination ROI
     * @param aCoeffs Perspective transform coefficients
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref perspective_transform_error_codes
     * </pre>
     */
    public static int nppiWarpPerspective_16u_C3R(
        TypedPointer<Npp16u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpPerspective_16u_C3RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, pDst, nDstStep, oDstROI, aCoeffs, eInterpolation));
    }
    private static native int nppiWarpPerspective_16u_C3RNative(
        TypedPointer<Npp16u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation);


    public static int nppiWarpPerspective_16u_C4R(
        TypedPointer<Npp16u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpPerspective_16u_C4RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, pDst, nDstStep, oDstROI, aCoeffs, eInterpolation));
    }
    private static native int nppiWarpPerspective_16u_C4RNative(
        TypedPointer<Npp16u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation);


    public static int nppiWarpPerspective_16u_AC4R(
        TypedPointer<Npp16u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpPerspective_16u_AC4RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, pDst, nDstStep, oDstROI, aCoeffs, eInterpolation));
    }
    private static native int nppiWarpPerspective_16u_AC4RNative(
        TypedPointer<Npp16u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Three-channel planar 16-bit unsigned integer perspective warp.
     *
     * @param pSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcROI Source ROI
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstROI Destination ROI
     * @param aCoeffs Perspective transform coefficients
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref perspective_transform_error_codes
     * </pre>
     */
    public static int nppiWarpPerspective_16u_P3R(
        TypedPointer<Npp16u>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp16u>[] pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpPerspective_16u_P3RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, pDst, nDstStep, oDstROI, aCoeffs, eInterpolation));
    }
    private static native int nppiWarpPerspective_16u_P3RNative(
        TypedPointer<Npp16u>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp16u>[] pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Four-channel planar 16-bit unsigned integer perspective warp.
     *
     * @param pSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcROI Source ROI
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstROI Destination ROI
     * @param aCoeffs Perspective transform coefficients
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref perspective_transform_error_codes
     * </pre>
     */
    public static int nppiWarpPerspective_16u_P4R(
        TypedPointer<Npp16u>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp16u>[] pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpPerspective_16u_P4RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, pDst, nDstStep, oDstROI, aCoeffs, eInterpolation));
    }
    private static native int nppiWarpPerspective_16u_P4RNative(
        TypedPointer<Npp16u>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp16u>[] pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Single-channel 32-bit signed integer perspective warp.
     *
     * @param pSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcROI Source ROI
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstROI Destination ROI
     * @param aCoeffs Perspective transform coefficients
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref perspective_transform_error_codes
     * </pre>
     */
    public static int nppiWarpPerspective_32s_C1R(
        TypedPointer<Npp32s> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpPerspective_32s_C1RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, pDst, nDstStep, oDstROI, aCoeffs, eInterpolation));
    }
    private static native int nppiWarpPerspective_32s_C1RNative(
        TypedPointer<Npp32s> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Three-channel 32-bit signed integer perspective warp.
     *
     * @param pSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcROI Source ROI
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstROI Destination ROI
     * @param aCoeffs Perspective transform coefficients
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref perspective_transform_error_codes
     * </pre>
     */
    public static int nppiWarpPerspective_32s_C3R(
        TypedPointer<Npp32s> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpPerspective_32s_C3RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, pDst, nDstStep, oDstROI, aCoeffs, eInterpolation));
    }
    private static native int nppiWarpPerspective_32s_C3RNative(
        TypedPointer<Npp32s> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation);


    public static int nppiWarpPerspective_32s_C4R(
        TypedPointer<Npp32s> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpPerspective_32s_C4RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, pDst, nDstStep, oDstROI, aCoeffs, eInterpolation));
    }
    private static native int nppiWarpPerspective_32s_C4RNative(
        TypedPointer<Npp32s> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Four-channel 32-bit signed integer perspective warp, igoring alpha channel.
     *
     * @param pSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcROI Source ROI
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstROI Destination ROI
     * @param aCoeffs Perspective transform coefficients
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref perspective_transform_error_codes
     * </pre>
     */
    public static int nppiWarpPerspective_32s_AC4R(
        TypedPointer<Npp32s> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpPerspective_32s_AC4RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, pDst, nDstStep, oDstROI, aCoeffs, eInterpolation));
    }
    private static native int nppiWarpPerspective_32s_AC4RNative(
        TypedPointer<Npp32s> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation);


    public static int nppiWarpPerspective_32s_P3R(
        TypedPointer<Npp32s>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp32s>[] pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpPerspective_32s_P3RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, pDst, nDstStep, oDstROI, aCoeffs, eInterpolation));
    }
    private static native int nppiWarpPerspective_32s_P3RNative(
        TypedPointer<Npp32s>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp32s>[] pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Four-channel planar 32-bit signed integer perspective warp.
     *
     * @param pSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcROI Source ROI
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstROI Destination ROI
     * @param aCoeffs Perspective transform coefficients
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref perspective_transform_error_codes
     * </pre>
     */
    public static int nppiWarpPerspective_32s_P4R(
        TypedPointer<Npp32s>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp32s>[] pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpPerspective_32s_P4RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, pDst, nDstStep, oDstROI, aCoeffs, eInterpolation));
    }
    private static native int nppiWarpPerspective_32s_P4RNative(
        TypedPointer<Npp32s>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp32s>[] pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation);


    public static int nppiWarpPerspective_32f_C1R(
        TypedPointer<Npp32f> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpPerspective_32f_C1RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, pDst, nDstStep, oDstROI, aCoeffs, eInterpolation));
    }
    private static native int nppiWarpPerspective_32f_C1RNative(
        TypedPointer<Npp32f> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Three-channel 32-bit floating-point perspective warp.
     *
     * @param pSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcROI Source ROI
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstROI Destination ROI
     * @param aCoeffs Perspective transform coefficients
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref perspective_transform_error_codes
     * </pre>
     */
    public static int nppiWarpPerspective_32f_C3R(
        TypedPointer<Npp32f> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpPerspective_32f_C3RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, pDst, nDstStep, oDstROI, aCoeffs, eInterpolation));
    }
    private static native int nppiWarpPerspective_32f_C3RNative(
        TypedPointer<Npp32f> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Four-channel 32-bit floating-point perspective warp.
     *
     * @param pSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcROI Source ROI
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstROI Destination ROI
     * @param aCoeffs Perspective transform coefficients
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref perspective_transform_error_codes
     * </pre>
     */
    public static int nppiWarpPerspective_32f_C4R(
        TypedPointer<Npp32f> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpPerspective_32f_C4RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, pDst, nDstStep, oDstROI, aCoeffs, eInterpolation));
    }
    private static native int nppiWarpPerspective_32f_C4RNative(
        TypedPointer<Npp32f> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Four-channel 32-bit floating-point perspective warp, ignoring alpha channel.
     *
     * @param pSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcROI Source ROI
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstROI Destination ROI
     * @param aCoeffs Perspective transform coefficients
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref perspective_transform_error_codes
     * </pre>
     */
    public static int nppiWarpPerspective_32f_AC4R(
        TypedPointer<Npp32f> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpPerspective_32f_AC4RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, pDst, nDstStep, oDstROI, aCoeffs, eInterpolation));
    }
    private static native int nppiWarpPerspective_32f_AC4RNative(
        TypedPointer<Npp32f> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Three-channel planar 32-bit floating-point perspective warp.
     *
     * @param pSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcROI Source ROI
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstROI Destination ROI
     * @param aCoeffs Perspective transform coefficients
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref perspective_transform_error_codes
     * </pre>
     */
    public static int nppiWarpPerspective_32f_P3R(
        TypedPointer<Npp32f>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp32f>[] pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpPerspective_32f_P3RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, pDst, nDstStep, oDstROI, aCoeffs, eInterpolation));
    }
    private static native int nppiWarpPerspective_32f_P3RNative(
        TypedPointer<Npp32f>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp32f>[] pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation);


    public static int nppiWarpPerspective_32f_P4R(
        TypedPointer<Npp32f>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp32f>[] pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpPerspective_32f_P4RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, pDst, nDstStep, oDstROI, aCoeffs, eInterpolation));
    }
    private static native int nppiWarpPerspective_32f_P4RNative(
        TypedPointer<Npp32f>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp32f>[] pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Single-channel 8-bit unsigned integer backwards perspective warp.
     *
     * @param pSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcROI Source ROI
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstROI Destination ROI
     * @param aCoeffs Perspective transform coefficients
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref perspective_transform_error_codes
     * </pre>
     */
    public static int nppiWarpPerspectiveBack_8u_C1R(
        TypedPointer<Npp8u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpPerspectiveBack_8u_C1RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, pDst, nDstStep, oDstROI, aCoeffs, eInterpolation));
    }
    private static native int nppiWarpPerspectiveBack_8u_C1RNative(
        TypedPointer<Npp8u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Three-channel 8-bit unsigned integer backwards perspective warp.
     *
     * @param pSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcROI Source ROI
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstROI Destination ROI
     * @param aCoeffs Perspective transform coefficients
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref perspective_transform_error_codes
     * </pre>
     */
    public static int nppiWarpPerspectiveBack_8u_C3R(
        TypedPointer<Npp8u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpPerspectiveBack_8u_C3RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, pDst, nDstStep, oDstROI, aCoeffs, eInterpolation));
    }
    private static native int nppiWarpPerspectiveBack_8u_C3RNative(
        TypedPointer<Npp8u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Four-channel 8-bit unsigned integer backwards perspective warp.
     *
     * @param pSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcROI Source ROI
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstROI Destination ROI
     * @param aCoeffs Perspective transform coefficients
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref perspective_transform_error_codes
     * </pre>
     */
    public static int nppiWarpPerspectiveBack_8u_C4R(
        TypedPointer<Npp8u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpPerspectiveBack_8u_C4RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, pDst, nDstStep, oDstROI, aCoeffs, eInterpolation));
    }
    private static native int nppiWarpPerspectiveBack_8u_C4RNative(
        TypedPointer<Npp8u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Four-channel 8-bit unsigned integer backwards perspective warp, igoring alpha channel.
     *
     * @param pSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcROI Source ROI
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstROI Destination ROI
     * @param aCoeffs Perspective transform coefficients
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref perspective_transform_error_codes
     * </pre>
     */
    public static int nppiWarpPerspectiveBack_8u_AC4R(
        TypedPointer<Npp8u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpPerspectiveBack_8u_AC4RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, pDst, nDstStep, oDstROI, aCoeffs, eInterpolation));
    }
    private static native int nppiWarpPerspectiveBack_8u_AC4RNative(
        TypedPointer<Npp8u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Three-channel planar 8-bit unsigned integer backwards perspective warp.
     *
     * @param pSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcROI Source ROI
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstROI Destination ROI
     * @param aCoeffs Perspective transform coefficients
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref perspective_transform_error_codes
     * </pre>
     */
    public static int nppiWarpPerspectiveBack_8u_P3R(
        TypedPointer<Npp8u>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp8u>[] pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpPerspectiveBack_8u_P3RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, pDst, nDstStep, oDstROI, aCoeffs, eInterpolation));
    }
    private static native int nppiWarpPerspectiveBack_8u_P3RNative(
        TypedPointer<Npp8u>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp8u>[] pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation);


    public static int nppiWarpPerspectiveBack_8u_P4R(
        TypedPointer<Npp8u>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp8u>[] pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpPerspectiveBack_8u_P4RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, pDst, nDstStep, oDstROI, aCoeffs, eInterpolation));
    }
    private static native int nppiWarpPerspectiveBack_8u_P4RNative(
        TypedPointer<Npp8u>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp8u>[] pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Single-channel 16-bit unsigned integer backwards perspective warp.
     *
     * @param pSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcROI Source ROI
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstROI Destination ROI
     * @param aCoeffs Perspective transform coefficients
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref perspective_transform_error_codes
     * </pre>
     */
    public static int nppiWarpPerspectiveBack_16u_C1R(
        TypedPointer<Npp16u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpPerspectiveBack_16u_C1RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, pDst, nDstStep, oDstROI, aCoeffs, eInterpolation));
    }
    private static native int nppiWarpPerspectiveBack_16u_C1RNative(
        TypedPointer<Npp16u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Three-channel 16-bit unsigned integer backwards perspective warp.
     *
     * @param pSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcROI Source ROI
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstROI Destination ROI
     * @param aCoeffs Perspective transform coefficients
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref perspective_transform_error_codes
     * </pre>
     */
    public static int nppiWarpPerspectiveBack_16u_C3R(
        TypedPointer<Npp16u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpPerspectiveBack_16u_C3RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, pDst, nDstStep, oDstROI, aCoeffs, eInterpolation));
    }
    private static native int nppiWarpPerspectiveBack_16u_C3RNative(
        TypedPointer<Npp16u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation);


    public static int nppiWarpPerspectiveBack_16u_C4R(
        TypedPointer<Npp16u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpPerspectiveBack_16u_C4RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, pDst, nDstStep, oDstROI, aCoeffs, eInterpolation));
    }
    private static native int nppiWarpPerspectiveBack_16u_C4RNative(
        TypedPointer<Npp16u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Four-channel 16-bit unsigned integer backwards perspective warp, ignoring alpha channel.
     *
     * @param pSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcROI Source ROI
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstROI Destination ROI
     * @param aCoeffs Perspective transform coefficients
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref perspective_transform_error_codes
     * </pre>
     */
    public static int nppiWarpPerspectiveBack_16u_AC4R(
        TypedPointer<Npp16u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpPerspectiveBack_16u_AC4RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, pDst, nDstStep, oDstROI, aCoeffs, eInterpolation));
    }
    private static native int nppiWarpPerspectiveBack_16u_AC4RNative(
        TypedPointer<Npp16u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation);


    public static int nppiWarpPerspectiveBack_16u_P3R(
        TypedPointer<Npp16u>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp16u>[] pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpPerspectiveBack_16u_P3RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, pDst, nDstStep, oDstROI, aCoeffs, eInterpolation));
    }
    private static native int nppiWarpPerspectiveBack_16u_P3RNative(
        TypedPointer<Npp16u>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp16u>[] pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation);


    public static int nppiWarpPerspectiveBack_16u_P4R(
        TypedPointer<Npp16u>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp16u>[] pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpPerspectiveBack_16u_P4RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, pDst, nDstStep, oDstROI, aCoeffs, eInterpolation));
    }
    private static native int nppiWarpPerspectiveBack_16u_P4RNative(
        TypedPointer<Npp16u>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp16u>[] pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Single-channel 32-bit signed integer backwards perspective warp.
     *
     * @param pSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcROI Source ROI
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstROI Destination ROI
     * @param aCoeffs Perspective transform coefficients
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref perspective_transform_error_codes
     * </pre>
     */
    public static int nppiWarpPerspectiveBack_32s_C1R(
        TypedPointer<Npp32s> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpPerspectiveBack_32s_C1RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, pDst, nDstStep, oDstROI, aCoeffs, eInterpolation));
    }
    private static native int nppiWarpPerspectiveBack_32s_C1RNative(
        TypedPointer<Npp32s> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Three-channel 32-bit signed integer backwards perspective warp.
     *
     * @param pSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcROI Source ROI
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstROI Destination ROI
     * @param aCoeffs Perspective transform coefficients
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref perspective_transform_error_codes
     * </pre>
     */
    public static int nppiWarpPerspectiveBack_32s_C3R(
        TypedPointer<Npp32s> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpPerspectiveBack_32s_C3RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, pDst, nDstStep, oDstROI, aCoeffs, eInterpolation));
    }
    private static native int nppiWarpPerspectiveBack_32s_C3RNative(
        TypedPointer<Npp32s> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Four-channel 32-bit signed integer backwards perspective warp.
     *
     * @param pSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcROI Source ROI
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstROI Destination ROI
     * @param aCoeffs Perspective transform coefficients
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref perspective_transform_error_codes
     * </pre>
     */
    public static int nppiWarpPerspectiveBack_32s_C4R(
        TypedPointer<Npp32s> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpPerspectiveBack_32s_C4RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, pDst, nDstStep, oDstROI, aCoeffs, eInterpolation));
    }
    private static native int nppiWarpPerspectiveBack_32s_C4RNative(
        TypedPointer<Npp32s> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Four-channel 32-bit signed integer backwards perspective warp, ignoring alpha channel.
     *
     * @param pSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcROI Source ROI
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstROI Destination ROI
     * @param aCoeffs Perspective transform coefficients
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref perspective_transform_error_codes
     * </pre>
     */
    public static int nppiWarpPerspectiveBack_32s_AC4R(
        TypedPointer<Npp32s> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpPerspectiveBack_32s_AC4RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, pDst, nDstStep, oDstROI, aCoeffs, eInterpolation));
    }
    private static native int nppiWarpPerspectiveBack_32s_AC4RNative(
        TypedPointer<Npp32s> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Three-channel planar 32-bit signed integer backwards perspective warp.
     *
     * @param pSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcROI Source ROI
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstROI Destination ROI
     * @param aCoeffs Perspective transform coefficients
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref perspective_transform_error_codes
     * </pre>
     */
    public static int nppiWarpPerspectiveBack_32s_P3R(
        TypedPointer<Npp32s>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp32s>[] pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpPerspectiveBack_32s_P3RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, pDst, nDstStep, oDstROI, aCoeffs, eInterpolation));
    }
    private static native int nppiWarpPerspectiveBack_32s_P3RNative(
        TypedPointer<Npp32s>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp32s>[] pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Four-channel planar 32-bit signed integer backwards perspective warp.
     *
     * @param pSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcROI Source ROI
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstROI Destination ROI
     * @param aCoeffs Perspective transform coefficients
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref perspective_transform_error_codes
     * </pre>
     */
    public static int nppiWarpPerspectiveBack_32s_P4R(
        TypedPointer<Npp32s>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp32s>[] pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpPerspectiveBack_32s_P4RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, pDst, nDstStep, oDstROI, aCoeffs, eInterpolation));
    }
    private static native int nppiWarpPerspectiveBack_32s_P4RNative(
        TypedPointer<Npp32s>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp32s>[] pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Single-channel 32-bit floating-point backwards perspective warp.
     *
     * @param pSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcROI Source ROI
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstROI Destination ROI
     * @param aCoeffs Perspective transform coefficients
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref perspective_transform_error_codes
     * </pre>
     */
    public static int nppiWarpPerspectiveBack_32f_C1R(
        TypedPointer<Npp32f> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpPerspectiveBack_32f_C1RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, pDst, nDstStep, oDstROI, aCoeffs, eInterpolation));
    }
    private static native int nppiWarpPerspectiveBack_32f_C1RNative(
        TypedPointer<Npp32f> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Three-channel 32-bit floating-point backwards perspective warp.
     *
     * @param pSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcROI Source ROI
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstROI Destination ROI
     * @param aCoeffs Perspective transform coefficients
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref perspective_transform_error_codes
     * </pre>
     */
    public static int nppiWarpPerspectiveBack_32f_C3R(
        TypedPointer<Npp32f> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpPerspectiveBack_32f_C3RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, pDst, nDstStep, oDstROI, aCoeffs, eInterpolation));
    }
    private static native int nppiWarpPerspectiveBack_32f_C3RNative(
        TypedPointer<Npp32f> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Four-channel 32-bit floating-point backwards perspective warp.
     *
     * @param pSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcROI Source ROI
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstROI Destination ROI
     * @param aCoeffs Perspective transform coefficients
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref perspective_transform_error_codes
     * </pre>
     */
    public static int nppiWarpPerspectiveBack_32f_C4R(
        TypedPointer<Npp32f> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpPerspectiveBack_32f_C4RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, pDst, nDstStep, oDstROI, aCoeffs, eInterpolation));
    }
    private static native int nppiWarpPerspectiveBack_32f_C4RNative(
        TypedPointer<Npp32f> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Four-channel 32-bit floating-point backwards perspective warp, ignorning alpha channel.
     *
     * @param pSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcROI Source ROI
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstROI Destination ROI
     * @param aCoeffs Perspective transform coefficients
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref perspective_transform_error_codes
     * </pre>
     */
    public static int nppiWarpPerspectiveBack_32f_AC4R(
        TypedPointer<Npp32f> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpPerspectiveBack_32f_AC4RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, pDst, nDstStep, oDstROI, aCoeffs, eInterpolation));
    }
    private static native int nppiWarpPerspectiveBack_32f_AC4RNative(
        TypedPointer<Npp32f> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Three-channel planar 32-bit floating-point backwards perspective warp.
     *
     * @param pSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcROI Source ROI
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstROI Destination ROI
     * @param aCoeffs Perspective transform coefficients
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref perspective_transform_error_codes
     * </pre>
     */
    public static int nppiWarpPerspectiveBack_32f_P3R(
        TypedPointer<Npp32f>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp32f>[] pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpPerspectiveBack_32f_P3RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, pDst, nDstStep, oDstROI, aCoeffs, eInterpolation));
    }
    private static native int nppiWarpPerspectiveBack_32f_P3RNative(
        TypedPointer<Npp32f>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp32f>[] pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation);


    public static int nppiWarpPerspectiveBack_32f_P4R(
        TypedPointer<Npp32f>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp32f>[] pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpPerspectiveBack_32f_P4RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, pDst, nDstStep, oDstROI, aCoeffs, eInterpolation));
    }
    private static native int nppiWarpPerspectiveBack_32f_P4RNative(
        TypedPointer<Npp32f>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp32f>[] pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aCoeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Single-channel 8-bit unsigned integer quad-based perspective warp.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcROI Source ROI
     * @param aSrcQuad Source quad.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstROI Destination ROI
     * @param aDstQuad Destination quad.
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref perspective_transform_error_codes
     * </pre>
     */
    public static int nppiWarpPerspectiveQuad_8u_C1R(
        TypedPointer<Npp8u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        double[][] aSrcQuad, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aDstQuad, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpPerspectiveQuad_8u_C1RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, aSrcQuad, pDst, nDstStep, oDstROI, aDstQuad, eInterpolation));
    }
    private static native int nppiWarpPerspectiveQuad_8u_C1RNative(
        TypedPointer<Npp8u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        double[][] aSrcQuad, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aDstQuad, 
        int eInterpolation);


    /**
     * <pre>
     * Three-channel 8-bit unsigned integer quad-based perspective warp.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcROI Source ROI
     * @param aSrcQuad Source quad.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstROI Destination ROI
     * @param aDstQuad Destination quad.
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref perspective_transform_error_codes
     * </pre>
     */
    public static int nppiWarpPerspectiveQuad_8u_C3R(
        TypedPointer<Npp8u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        double[][] aSrcQuad, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aDstQuad, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpPerspectiveQuad_8u_C3RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, aSrcQuad, pDst, nDstStep, oDstROI, aDstQuad, eInterpolation));
    }
    private static native int nppiWarpPerspectiveQuad_8u_C3RNative(
        TypedPointer<Npp8u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        double[][] aSrcQuad, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aDstQuad, 
        int eInterpolation);


    /**
     * <pre>
     * Four-channel 8-bit unsigned integer quad-based perspective warp.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcROI Source ROI
     * @param aSrcQuad Source quad.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstROI Destination ROI
     * @param aDstQuad Destination quad.
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref perspective_transform_error_codes
     * </pre>
     */
    public static int nppiWarpPerspectiveQuad_8u_C4R(
        TypedPointer<Npp8u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        double[][] aSrcQuad, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aDstQuad, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpPerspectiveQuad_8u_C4RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, aSrcQuad, pDst, nDstStep, oDstROI, aDstQuad, eInterpolation));
    }
    private static native int nppiWarpPerspectiveQuad_8u_C4RNative(
        TypedPointer<Npp8u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        double[][] aSrcQuad, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aDstQuad, 
        int eInterpolation);


    /**
     * <pre>
     * Four-channel 8-bit unsigned integer quad-based perspective warp, ignoring alpha channel.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcROI Source ROI
     * @param aSrcQuad Source quad.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstROI Destination ROI
     * @param aDstQuad Destination quad.
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref perspective_transform_error_codes
     * </pre>
     */
    public static int nppiWarpPerspectiveQuad_8u_AC4R(
        TypedPointer<Npp8u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        double[][] aSrcQuad, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aDstQuad, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpPerspectiveQuad_8u_AC4RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, aSrcQuad, pDst, nDstStep, oDstROI, aDstQuad, eInterpolation));
    }
    private static native int nppiWarpPerspectiveQuad_8u_AC4RNative(
        TypedPointer<Npp8u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        double[][] aSrcQuad, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aDstQuad, 
        int eInterpolation);


    /**
     * <pre>
     * Three-channel planar 8-bit unsigned integer quad-based perspective warp.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcROI Source ROI
     * @param aSrcQuad Source quad.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstROI Destination ROI
     * @param aDstQuad Destination quad.
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref perspective_transform_error_codes
     * </pre>
     */
    public static int nppiWarpPerspectiveQuad_8u_P3R(
        TypedPointer<Npp8u>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        double[][] aSrcQuad, 
        TypedPointer<Npp8u>[] pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aDstQuad, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpPerspectiveQuad_8u_P3RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, aSrcQuad, pDst, nDstStep, oDstROI, aDstQuad, eInterpolation));
    }
    private static native int nppiWarpPerspectiveQuad_8u_P3RNative(
        TypedPointer<Npp8u>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        double[][] aSrcQuad, 
        TypedPointer<Npp8u>[] pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aDstQuad, 
        int eInterpolation);


    /**
     * <pre>
     * Four-channel planar 8-bit unsigned integer quad-based perspective warp.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcROI Source ROI
     * @param aSrcQuad Source quad.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstROI Destination ROI
     * @param aDstQuad Destination quad.
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref perspective_transform_error_codes
     * </pre>
     */
    public static int nppiWarpPerspectiveQuad_8u_P4R(
        TypedPointer<Npp8u>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        double[][] aSrcQuad, 
        TypedPointer<Npp8u>[] pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aDstQuad, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpPerspectiveQuad_8u_P4RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, aSrcQuad, pDst, nDstStep, oDstROI, aDstQuad, eInterpolation));
    }
    private static native int nppiWarpPerspectiveQuad_8u_P4RNative(
        TypedPointer<Npp8u>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        double[][] aSrcQuad, 
        TypedPointer<Npp8u>[] pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aDstQuad, 
        int eInterpolation);


    /**
     * <pre>
     * Single-channel 16-bit unsigned integer quad-based perspective warp.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcROI Source ROI
     * @param aSrcQuad Source quad.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstROI Destination ROI
     * @param aDstQuad Destination quad.
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref perspective_transform_error_codes
     * </pre>
     */
    public static int nppiWarpPerspectiveQuad_16u_C1R(
        TypedPointer<Npp16u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        double[][] aSrcQuad, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aDstQuad, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpPerspectiveQuad_16u_C1RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, aSrcQuad, pDst, nDstStep, oDstROI, aDstQuad, eInterpolation));
    }
    private static native int nppiWarpPerspectiveQuad_16u_C1RNative(
        TypedPointer<Npp16u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        double[][] aSrcQuad, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aDstQuad, 
        int eInterpolation);


    /**
     * <pre>
     * Three-channel 16-bit unsigned integer quad-based perspective warp.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcROI Source ROI
     * @param aSrcQuad Source quad.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstROI Destination ROI
     * @param aDstQuad Destination quad.
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref perspective_transform_error_codes
     * </pre>
     */
    public static int nppiWarpPerspectiveQuad_16u_C3R(
        TypedPointer<Npp16u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        double[][] aSrcQuad, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aDstQuad, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpPerspectiveQuad_16u_C3RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, aSrcQuad, pDst, nDstStep, oDstROI, aDstQuad, eInterpolation));
    }
    private static native int nppiWarpPerspectiveQuad_16u_C3RNative(
        TypedPointer<Npp16u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        double[][] aSrcQuad, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aDstQuad, 
        int eInterpolation);


    /**
     * <pre>
     * Four-channel 16-bit unsigned integer quad-based perspective warp.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcROI Source ROI
     * @param aSrcQuad Source quad.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstROI Destination ROI
     * @param aDstQuad Destination quad.
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref perspective_transform_error_codes
     * </pre>
     */
    public static int nppiWarpPerspectiveQuad_16u_C4R(
        TypedPointer<Npp16u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        double[][] aSrcQuad, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aDstQuad, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpPerspectiveQuad_16u_C4RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, aSrcQuad, pDst, nDstStep, oDstROI, aDstQuad, eInterpolation));
    }
    private static native int nppiWarpPerspectiveQuad_16u_C4RNative(
        TypedPointer<Npp16u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        double[][] aSrcQuad, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aDstQuad, 
        int eInterpolation);


    /**
     * <pre>
     * Four-channel 16-bit unsigned integer quad-based perspective warp, ignoring alpha channel.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcROI Source ROI
     * @param aSrcQuad Source quad.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstROI Destination ROI
     * @param aDstQuad Destination quad.
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref perspective_transform_error_codes
     * </pre>
     */
    public static int nppiWarpPerspectiveQuad_16u_AC4R(
        TypedPointer<Npp16u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        double[][] aSrcQuad, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aDstQuad, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpPerspectiveQuad_16u_AC4RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, aSrcQuad, pDst, nDstStep, oDstROI, aDstQuad, eInterpolation));
    }
    private static native int nppiWarpPerspectiveQuad_16u_AC4RNative(
        TypedPointer<Npp16u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        double[][] aSrcQuad, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aDstQuad, 
        int eInterpolation);


    /**
     * <pre>
     * Three-channel planar 16-bit unsigned integer quad-based perspective warp.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcROI Source ROI
     * @param aSrcQuad Source quad.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstROI Destination ROI
     * @param aDstQuad Destination quad.
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref perspective_transform_error_codes
     * </pre>
     */
    public static int nppiWarpPerspectiveQuad_16u_P3R(
        TypedPointer<Npp16u>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        double[][] aSrcQuad, 
        TypedPointer<Npp16u>[] pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aDstQuad, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpPerspectiveQuad_16u_P3RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, aSrcQuad, pDst, nDstStep, oDstROI, aDstQuad, eInterpolation));
    }
    private static native int nppiWarpPerspectiveQuad_16u_P3RNative(
        TypedPointer<Npp16u>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        double[][] aSrcQuad, 
        TypedPointer<Npp16u>[] pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aDstQuad, 
        int eInterpolation);


    /**
     * <pre>
     * Four-channel planar 16-bit unsigned integer quad-based perspective warp.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcROI Source ROI
     * @param aSrcQuad Source quad.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstROI Destination ROI
     * @param aDstQuad Destination quad.
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref perspective_transform_error_codes
     * </pre>
     */
    public static int nppiWarpPerspectiveQuad_16u_P4R(
        TypedPointer<Npp16u>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        double[][] aSrcQuad, 
        TypedPointer<Npp16u>[] pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aDstQuad, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpPerspectiveQuad_16u_P4RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, aSrcQuad, pDst, nDstStep, oDstROI, aDstQuad, eInterpolation));
    }
    private static native int nppiWarpPerspectiveQuad_16u_P4RNative(
        TypedPointer<Npp16u>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        double[][] aSrcQuad, 
        TypedPointer<Npp16u>[] pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aDstQuad, 
        int eInterpolation);


    /**
     * <pre>
     * Single-channel 32-bit signed integer quad-based perspective warp.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcROI Source ROI
     * @param aSrcQuad Source quad.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstROI Destination ROI
     * @param aDstQuad Destination quad.
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref perspective_transform_error_codes
     * </pre>
     */
    public static int nppiWarpPerspectiveQuad_32s_C1R(
        TypedPointer<Npp32s> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        double[][] aSrcQuad, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aDstQuad, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpPerspectiveQuad_32s_C1RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, aSrcQuad, pDst, nDstStep, oDstROI, aDstQuad, eInterpolation));
    }
    private static native int nppiWarpPerspectiveQuad_32s_C1RNative(
        TypedPointer<Npp32s> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        double[][] aSrcQuad, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aDstQuad, 
        int eInterpolation);


    /**
     * <pre>
     * Three-channel 32-bit signed integer quad-based perspective warp.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcROI Source ROI
     * @param aSrcQuad Source quad.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstROI Destination ROI
     * @param aDstQuad Destination quad.
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref perspective_transform_error_codes
     * </pre>
     */
    public static int nppiWarpPerspectiveQuad_32s_C3R(
        TypedPointer<Npp32s> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        double[][] aSrcQuad, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aDstQuad, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpPerspectiveQuad_32s_C3RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, aSrcQuad, pDst, nDstStep, oDstROI, aDstQuad, eInterpolation));
    }
    private static native int nppiWarpPerspectiveQuad_32s_C3RNative(
        TypedPointer<Npp32s> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        double[][] aSrcQuad, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aDstQuad, 
        int eInterpolation);


    /**
     * <pre>
     * Four-channel 32-bit signed integer quad-based perspective warp.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcROI Source ROI
     * @param aSrcQuad Source quad.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstROI Destination ROI
     * @param aDstQuad Destination quad.
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref perspective_transform_error_codes
     * </pre>
     */
    public static int nppiWarpPerspectiveQuad_32s_C4R(
        TypedPointer<Npp32s> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        double[][] aSrcQuad, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aDstQuad, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpPerspectiveQuad_32s_C4RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, aSrcQuad, pDst, nDstStep, oDstROI, aDstQuad, eInterpolation));
    }
    private static native int nppiWarpPerspectiveQuad_32s_C4RNative(
        TypedPointer<Npp32s> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        double[][] aSrcQuad, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aDstQuad, 
        int eInterpolation);


    /**
     * <pre>
     * Four-channel 32-bit signed integer quad-based perspective warp, ignoring alpha channel.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcROI Source ROI
     * @param aSrcQuad Source quad.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstROI Destination ROI
     * @param aDstQuad Destination quad.
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref perspective_transform_error_codes
     * </pre>
     */
    public static int nppiWarpPerspectiveQuad_32s_AC4R(
        TypedPointer<Npp32s> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        double[][] aSrcQuad, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aDstQuad, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpPerspectiveQuad_32s_AC4RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, aSrcQuad, pDst, nDstStep, oDstROI, aDstQuad, eInterpolation));
    }
    private static native int nppiWarpPerspectiveQuad_32s_AC4RNative(
        TypedPointer<Npp32s> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        double[][] aSrcQuad, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aDstQuad, 
        int eInterpolation);


    /**
     * <pre>
     * Three-channel planar 32-bit signed integer quad-based perspective warp.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcROI Source ROI
     * @param aSrcQuad Source quad.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstROI Destination ROI
     * @param aDstQuad Destination quad.
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref perspective_transform_error_codes
     * </pre>
     */
    public static int nppiWarpPerspectiveQuad_32s_P3R(
        TypedPointer<Npp32s>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        double[][] aSrcQuad, 
        TypedPointer<Npp32s>[] pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aDstQuad, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpPerspectiveQuad_32s_P3RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, aSrcQuad, pDst, nDstStep, oDstROI, aDstQuad, eInterpolation));
    }
    private static native int nppiWarpPerspectiveQuad_32s_P3RNative(
        TypedPointer<Npp32s>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        double[][] aSrcQuad, 
        TypedPointer<Npp32s>[] pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aDstQuad, 
        int eInterpolation);


    /**
     * <pre>
     * Four-channel planar 32-bit signed integer quad-based perspective warp.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcROI Source ROI
     * @param aSrcQuad Source quad.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstROI Destination ROI
     * @param aDstQuad Destination quad.
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref perspective_transform_error_codes
     * </pre>
     */
    public static int nppiWarpPerspectiveQuad_32s_P4R(
        TypedPointer<Npp32s>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        double[][] aSrcQuad, 
        TypedPointer<Npp32s>[] pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aDstQuad, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpPerspectiveQuad_32s_P4RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, aSrcQuad, pDst, nDstStep, oDstROI, aDstQuad, eInterpolation));
    }
    private static native int nppiWarpPerspectiveQuad_32s_P4RNative(
        TypedPointer<Npp32s>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        double[][] aSrcQuad, 
        TypedPointer<Npp32s>[] pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aDstQuad, 
        int eInterpolation);


    /**
     * <pre>
     * Single-channel 32-bit floating-point quad-based perspective warp.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcROI Source ROI
     * @param aSrcQuad Source quad.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstROI Destination ROI
     * @param aDstQuad Destination quad.
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref perspective_transform_error_codes
     * </pre>
     */
    public static int nppiWarpPerspectiveQuad_32f_C1R(
        TypedPointer<Npp32f> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        double[][] aSrcQuad, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aDstQuad, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpPerspectiveQuad_32f_C1RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, aSrcQuad, pDst, nDstStep, oDstROI, aDstQuad, eInterpolation));
    }
    private static native int nppiWarpPerspectiveQuad_32f_C1RNative(
        TypedPointer<Npp32f> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        double[][] aSrcQuad, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aDstQuad, 
        int eInterpolation);


    /**
     * <pre>
     * Three-channel 32-bit floating-point quad-based perspective warp.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcROI Source ROI
     * @param aSrcQuad Source quad.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstROI Destination ROI
     * @param aDstQuad Destination quad.
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref perspective_transform_error_codes
     * </pre>
     */
    public static int nppiWarpPerspectiveQuad_32f_C3R(
        TypedPointer<Npp32f> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        double[][] aSrcQuad, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aDstQuad, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpPerspectiveQuad_32f_C3RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, aSrcQuad, pDst, nDstStep, oDstROI, aDstQuad, eInterpolation));
    }
    private static native int nppiWarpPerspectiveQuad_32f_C3RNative(
        TypedPointer<Npp32f> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        double[][] aSrcQuad, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aDstQuad, 
        int eInterpolation);


    /**
     * <pre>
     * Four-channel 32-bit floating-point quad-based perspective warp.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcROI Source ROI
     * @param aSrcQuad Source quad.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstROI Destination ROI
     * @param aDstQuad Destination quad.
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref perspective_transform_error_codes
     * </pre>
     */
    public static int nppiWarpPerspectiveQuad_32f_C4R(
        TypedPointer<Npp32f> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        double[][] aSrcQuad, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aDstQuad, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpPerspectiveQuad_32f_C4RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, aSrcQuad, pDst, nDstStep, oDstROI, aDstQuad, eInterpolation));
    }
    private static native int nppiWarpPerspectiveQuad_32f_C4RNative(
        TypedPointer<Npp32f> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        double[][] aSrcQuad, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aDstQuad, 
        int eInterpolation);


    /**
     * <pre>
     * Four-channel 32-bit floating-point quad-based perspective warp, ignoring alpha channel.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcROI Source ROI
     * @param aSrcQuad Source quad.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstROI Destination ROI
     * @param aDstQuad Destination quad.
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref perspective_transform_error_codes
     * </pre>
     */
    public static int nppiWarpPerspectiveQuad_32f_AC4R(
        TypedPointer<Npp32f> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        double[][] aSrcQuad, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aDstQuad, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpPerspectiveQuad_32f_AC4RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, aSrcQuad, pDst, nDstStep, oDstROI, aDstQuad, eInterpolation));
    }
    private static native int nppiWarpPerspectiveQuad_32f_AC4RNative(
        TypedPointer<Npp32f> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        double[][] aSrcQuad, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aDstQuad, 
        int eInterpolation);


    /**
     * <pre>
     * Three-channel planar 32-bit floating-point quad-based perspective warp.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcROI Source ROI
     * @param aSrcQuad Source quad.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstROI Destination ROI
     * @param aDstQuad Destination quad.
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref perspective_transform_error_codes
     * </pre>
     */
    public static int nppiWarpPerspectiveQuad_32f_P3R(
        TypedPointer<Npp32f>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        double[][] aSrcQuad, 
        TypedPointer<Npp32f>[] pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aDstQuad, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpPerspectiveQuad_32f_P3RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, aSrcQuad, pDst, nDstStep, oDstROI, aDstQuad, eInterpolation));
    }
    private static native int nppiWarpPerspectiveQuad_32f_P3RNative(
        TypedPointer<Npp32f>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        double[][] aSrcQuad, 
        TypedPointer<Npp32f>[] pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aDstQuad, 
        int eInterpolation);


    /**
     * <pre>
     * Four-channel planar 32-bit floating-point quad-based perspective warp.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcROI Source ROI
     * @param aSrcQuad Source quad.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstROI Destination ROI
     * @param aDstQuad Destination quad.
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref perspective_transform_error_codes
     * </pre>
     */
    public static int nppiWarpPerspectiveQuad_32f_P4R(
        TypedPointer<Npp32f>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        double[][] aSrcQuad, 
        TypedPointer<Npp32f>[] pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aDstQuad, 
        int eInterpolation)
    {
        return JNpp.checkResult(nppiWarpPerspectiveQuad_32f_P4RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, aSrcQuad, pDst, nDstStep, oDstROI, aDstQuad, eInterpolation));
    }
    private static native int nppiWarpPerspectiveQuad_32f_P4RNative(
        TypedPointer<Npp32f>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        double[][] aSrcQuad, 
        TypedPointer<Npp32f>[] pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double[][] aDstQuad, 
        int eInterpolation);


    /**
     * <pre>
     * Apply quality factor to raw 8-bit quantization table.
     *
     * This is effectively and in-place method that modifies a given raw
     * quantization table based on a quality factor.
     * Note that this method is a host method and that the pointer to the
     * raw quantization table is a host pointer.
     *
     * @param hpQuantRawTable Raw quantization table.
     * @param nQualityFactor Quality factor for the table. Range is [1:100].
     * @return
     *  Error code:
     *      #NPP_NULL_POINTER_ERROR is returned if hpQuantRawTable is 0.
     * </pre>
     */
    public static int nppiQuantFwdRawTableInit_JPEG_8u(
        TypedPointer<Npp8u> hpQuantRawTable, 
        int nQualityFactor)
    {
        return JNpp.checkResult(nppiQuantFwdRawTableInit_JPEG_8uNative(hpQuantRawTable, nQualityFactor));
    }
    private static native int nppiQuantFwdRawTableInit_JPEG_8uNative(
        TypedPointer<Npp8u> hpQuantRawTable, 
        int nQualityFactor);


    public static int nppiQuantFwdTableInit_JPEG_8u16u(
        TypedPointer<Npp8u> hpQuantRawTable, 
        TypedPointer<Npp16u> hpQuantFwdRawTable)
    {
        return JNpp.checkResult(nppiQuantFwdTableInit_JPEG_8u16uNative(hpQuantRawTable, hpQuantFwdRawTable));
    }
    private static native int nppiQuantFwdTableInit_JPEG_8u16uNative(
        TypedPointer<Npp8u> hpQuantRawTable, 
        TypedPointer<Npp16u> hpQuantFwdRawTable);


    /**
     * <pre>
     * Initializes a quantization table for nppiDCTQuantInv8x8LS_JPEG_16s8u_C1R().
     *      The nppiDCTQuantFwd8x8LS_JPEG_8u16s_C1R() method uses a quantization table
     * in a 16-bit format allowing for faster processing. In addition it converts the 
     * data order from zigzag layout to original row-order layout. Typically raw
     * quantization tables are stored in zigzag format.
     *
     * This method is a host method and consumes and produces host data. I.e. the pointers
     * passed to this function must be host pointers. The resulting table needs to be
     * transferred to device memory in order to be used with nppiDCTQuantFwd8x8LS_JPEG_8u16s_C1R()
     * function.
     *
     * @param hpQuantRawTable Raw quantization table.
     * @param hpQuantFwdRawTable Inverse quantization table.
     * @return
     *  #NPP_NULL_POINTER_ERROR pQuantRawTable or pQuantFwdRawTable is0.
     * </pre>
     */
    public static int nppiQuantInvTableInit_JPEG_8u16u(
        TypedPointer<Npp8u> hpQuantRawTable, 
        TypedPointer<Npp16u> hpQuantFwdRawTable)
    {
        return JNpp.checkResult(nppiQuantInvTableInit_JPEG_8u16uNative(hpQuantRawTable, hpQuantFwdRawTable));
    }
    private static native int nppiQuantInvTableInit_JPEG_8u16uNative(
        TypedPointer<Npp8u> hpQuantRawTable, 
        TypedPointer<Npp16u> hpQuantFwdRawTable);


    /**
     * <pre>
     * Forward DCT, quantization and level shift part of the JPEG encoding.
     * Input is expected in 8x8 macro blocks and output is expected to be in 64x1
     * macro blocks.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param pQuantFwdTable Forward quantization tables for JPEG encoding created
     *          using nppiQuantInvTableInit_JPEG_8u16u().
     * @param oSizeROI \ref roi_specification.
     * @return
     *  Error codes:
     *         - #NPP_SIZE_ERROR For negative input height/width or not a multiple of
     *           8 width/height.
     *         - #NPP_STEP_ERROR If input image width is not multiple of 8 or does not
     *           match ROI.
     *         - #NPP_NULL_POINTER_ERROR If the destination pointer is 0.
     * </pre>
     */
    public static int nppiDCTQuantFwd8x8LS_JPEG_8u16s_C1R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        TypedPointer<Npp16u> pQuantFwdTable, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiDCTQuantFwd8x8LS_JPEG_8u16s_C1RNative(pSrc, nSrcStep, pDst, nDstStep, pQuantFwdTable, oSizeROI));
    }
    private static native int nppiDCTQuantFwd8x8LS_JPEG_8u16s_C1RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        TypedPointer<Npp16u> pQuantFwdTable, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Inverse DCT, de-quantization and level shift part of the JPEG decoding.
     * Input is expected in 64x1 macro blocks and output is expected to be in 8x8
     * macro blocks.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param pQuantInvTable Inverse quantization tables for JPEG decoding created
     *           using nppiQuantInvTableInit_JPEG_8u16u().
     * @param oSizeROI \ref roi_specification.
     * @return
     *  Error codes:
     *         - #NPP_SIZE_ERROR For negative input height/width or not a multiple of
     *           8 width/height.
     *         - #NPP_STEP_ERROR If input image width is not multiple of 8 or does not
     *           match ROI.
     *         - #NPP_NULL_POINTER_ERROR If the destination pointer is 0.
     * </pre>
     */
    public static int nppiDCTQuantInv8x8LS_JPEG_16s8u_C1R(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        TypedPointer<Npp16u> pQuantInvTable, 
        NppiSize oSizeROI)
    {
        return JNpp.checkResult(nppiDCTQuantInv8x8LS_JPEG_16s8u_C1RNative(pSrc, nSrcStep, pDst, nDstStep, pQuantInvTable, oSizeROI));
    }
    private static native int nppiDCTQuantInv8x8LS_JPEG_16s8u_C1RNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        TypedPointer<Npp16u> pQuantInvTable, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Calculates the size of the temporary buffer for graph-cut with 4 neighborhood labeling.
     *
     * @see nppiGraphcutInitAlloc(), nppiGraphcut_32s8u().
     * 
     * @param oSize Graph size.
     * @param pBufSize Pointer to variable that returns the size of the
     *        temporary buffer. 
     *
     * @return
     *  NPP_SUCCESS Indicates no error. Any other value indicates an error
     *         or a warning
     *  NPP_SIZE_ERROR Indicates an error condition if any image dimension
     *         has zero or negative value
     *  NPP_NULL_POINTER_ERROR Indicates an error condition if pBufSize
     *         pointer is NULL
     * </pre>
     */
    public static int nppiGraphcutGetSize(
        NppiSize oSize, 
        int[] pBufSize)
    {
        return JNpp.checkResult(nppiGraphcutGetSizeNative(oSize, pBufSize));
    }
    private static native int nppiGraphcutGetSizeNative(
        NppiSize oSize, 
        int[] pBufSize);


    /**
     * <pre>
     * Calculates the size of the temporary buffer for graph-cut with 8 neighborhood labeling.
     *
     * @see nppiGraphcut8InitAlloc(), nppiGraphcut8_32s8u().
     * 
     * @param oSize Graph size.
     * @param pBufSize Pointer to variable that returns the size of the
     *        temporary buffer. 
     *
     * @return
     *  NPP_SUCCESS Indicates no error. Any other value indicates an error
     *         or a warning
     *  NPP_SIZE_ERROR Indicates an error condition if any image dimension
     *         has zero or negative value
     *  NPP_NULL_POINTER_ERROR Indicates an error condition if pBufSize
     *         pointer is NULL
     * </pre>
     */
    public static int nppiGraphcut8GetSize(
        NppiSize oSize, 
        int[] pBufSize)
    {
        return JNpp.checkResult(nppiGraphcut8GetSizeNative(oSize, pBufSize));
    }
    private static native int nppiGraphcut8GetSizeNative(
        NppiSize oSize, 
        int[] pBufSize);


    public static int nppiGraphcutInitAlloc(
        NppiSize oSize, 
        NppiGraphcutState[] ppState, 
        TypedPointer<Npp8u> pDeviceMem)
    {
        return JNpp.checkResult(nppiGraphcutInitAllocNative(oSize, ppState, pDeviceMem));
    }
    private static native int nppiGraphcutInitAllocNative(
        NppiSize oSize, 
        NppiGraphcutState[] ppState, 
        TypedPointer<Npp8u> pDeviceMem);


    /**
     * <pre>
     * Allocates and initializes the graph-cut state structure and additional resources for graph-cut with 8 neighborhood labeling.
     *
     * @see nppiGraphcut8_32s8u(), nppiGraphcut8GetSize().
     * 
     * @param oSize Graph size
     * @param ppState Pointer to pointer to graph-cut state structure. 
     * @param pDeviceMem to the sufficient amount of device memory. The CUDA runtime or NPP memory allocators
     *      must be used to allocate this memory. The minimum amount of device memory required
     *      to run graph-cut on a for a specific image size is computed by nppiGraphcut8GetSize().
     *
     * @return
     *  NPP_SUCCESS Indicates no error. Any other value indicates an error
     *         or a warning
     *  NPP_SIZE_ERROR Indicates an error condition if any image dimension
     *         has zero or negative value
     *  NPP_NULL_POINTER_ERROR Indicates an error condition if pBufSize
     *         pointer is NULL
     * </pre>
     */
    public static int nppiGraphcut8InitAlloc(
        NppiSize oSize, 
        NppiGraphcutState[] ppState, 
        TypedPointer<Npp8u> pDeviceMem)
    {
        return JNpp.checkResult(nppiGraphcut8InitAllocNative(oSize, ppState, pDeviceMem));
    }
    private static native int nppiGraphcut8InitAllocNative(
        NppiSize oSize, 
        NppiGraphcutState[] ppState, 
        TypedPointer<Npp8u> pDeviceMem);


    /**
     * <pre>
     * Frees the additional resources of the graph-cut state structure.
     *
     * @see nppiGraphcutInitAlloc
     * @see nppiGraphcut8InitAlloc
     * 
     * @param pState Pointer to graph-cut state structure. 
     *
     * @return
     *  NPP_SUCCESS Indicates no error. Any other value indicates an error
     *         or a warning
     *  NPP_SIZE_ERROR Indicates an error condition if any image dimension
     *         has zero or negative value
     *  NPP_NULL_POINTER_ERROR Indicates an error condition if pState
     *         pointer is NULL
     * </pre>
     */
    public static int nppiGraphcutFree(
        NppiGraphcutState pState)
    {
        return JNpp.checkResult(nppiGraphcutFreeNative(pState));
    }
    private static native int nppiGraphcutFreeNative(
        NppiGraphcutState pState);


    public static int nppiGraphcut_32s8u(
        TypedPointer<Npp32s> pTerminals, 
        TypedPointer<Npp32s> pLeftTransposed, 
        TypedPointer<Npp32s> pRightTransposed, 
        TypedPointer<Npp32s> pTop, 
        TypedPointer<Npp32s> pBottom, 
        int nStep, 
        int nTransposedStep, 
        NppiSize size, 
        TypedPointer<Npp8u> pLabel, 
        int nLabelStep, 
        NppiGraphcutState pState)
    {
        return JNpp.checkResult(nppiGraphcut_32s8uNative(pTerminals, pLeftTransposed, pRightTransposed, pTop, pBottom, nStep, nTransposedStep, size, pLabel, nLabelStep, pState));
    }
    private static native int nppiGraphcut_32s8uNative(
        TypedPointer<Npp32s> pTerminals, 
        TypedPointer<Npp32s> pLeftTransposed, 
        TypedPointer<Npp32s> pRightTransposed, 
        TypedPointer<Npp32s> pTop, 
        TypedPointer<Npp32s> pBottom, 
        int nStep, 
        int nTransposedStep, 
        NppiSize size, 
        TypedPointer<Npp8u> pLabel, 
        int nLabelStep, 
        NppiGraphcutState pState);


    /**
     * <pre>
     * Graphcut of a flow network (32bit signed integer edge capacities). The
     * function computes the minimal cut (graphcut) of a 2D regular 8-connected
     * graph. 
     * The inputs are the capacities of the horizontal (in transposed form),
     * vertical and terminal (source and sink) edges. The capacities to source and
     * sink 
     * are stored as capacity differences in the terminals array 
     * ( terminals(x) = source(x) - sink(x) ). The implementation assumes that the
     * edge capacities 
     * for boundary edges that would connect to nodes outside the specified domain
     * are set to 0 (for example left(0,*) == 0). If this is not fulfilled the
     * computed labeling may be wrong!
     * The computed binary labeling is encoded as unsigned 8bit values (0 and >0).
     *
     * @see nppiGraphcut8InitAlloc(), nppiGraphcutFree(), nppiGraphcut8GetSize().
     *
     * @param pTerminals Pointer to differences of terminal edge capacities
     *        (terminal(x) = source(x) - sink(x))
     * @param pLeftTransposed Pointer to transposed left edge capacities
     *        (left(0,*) must be 0)
     * @param pRightTransposed Pointer to transposed right edge capacities
     *        (right(width-1,*) must be 0)
     * @param pTop Pointer to top edge capacities (top(*,0) must be 0)
     * @param pTopLeft Pointer to top left edge capacities (topleft(*,0) 
     *        & topleft(0,*) must be 0)
     * @param pTopRight Pointer to top right edge capacities (topright(*,0)
     *        & topright(width-1,*) must be 0)
     * @param pBottom Pointer to bottom edge capacities (bottom(*,height-1)
     *        must be 0)
     * @param pBottomLeft Pointer to bottom left edge capacities 
     *        (bottomleft(*,height-1) && bottomleft(0,*) must be 0)
     * @param pBottomRight Pointer to bottom right edge capacities 
     *        (bottomright(*,height-1) && bottomright(width-1,*) must be 0)
     * @param nStep Step in bytes between any pair of sequential rows of edge
     *        capacities
     * @param nTransposedStep Step in bytes between any pair of sequential
     *        rows of tranposed edge capacities
     * @param size Graph size
     * @param pLabel Pointer to destination label image 
     * @param nLabelStep Step in bytes between any pair of sequential rows of
     *        label image
     * @param pState Pointer to graph-cut state structure. This structure must be
     *          initialized allocated and initialized using nppiGraphcut8InitAlloc().
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiGraphcut8_32s8u(
        TypedPointer<Npp32s> pTerminals, 
        TypedPointer<Npp32s> pLeftTransposed, 
        TypedPointer<Npp32s> pRightTransposed, 
        TypedPointer<Npp32s> pTop, 
        TypedPointer<Npp32s> pTopLeft, 
        TypedPointer<Npp32s> pTopRight, 
        TypedPointer<Npp32s> pBottom, 
        TypedPointer<Npp32s> pBottomLeft, 
        TypedPointer<Npp32s> pBottomRight, 
        int nStep, 
        int nTransposedStep, 
        NppiSize size, 
        TypedPointer<Npp8u> pLabel, 
        int nLabelStep, 
        NppiGraphcutState pState)
    {
        return JNpp.checkResult(nppiGraphcut8_32s8uNative(pTerminals, pLeftTransposed, pRightTransposed, pTop, pTopLeft, pTopRight, pBottom, pBottomLeft, pBottomRight, nStep, nTransposedStep, size, pLabel, nLabelStep, pState));
    }
    private static native int nppiGraphcut8_32s8uNative(
        TypedPointer<Npp32s> pTerminals, 
        TypedPointer<Npp32s> pLeftTransposed, 
        TypedPointer<Npp32s> pRightTransposed, 
        TypedPointer<Npp32s> pTop, 
        TypedPointer<Npp32s> pTopLeft, 
        TypedPointer<Npp32s> pTopRight, 
        TypedPointer<Npp32s> pBottom, 
        TypedPointer<Npp32s> pBottomLeft, 
        TypedPointer<Npp32s> pBottomRight, 
        int nStep, 
        int nTransposedStep, 
        NppiSize size, 
        TypedPointer<Npp8u> pLabel, 
        int nLabelStep, 
        NppiGraphcutState pState);


    /**
     * <pre>
     * Graphcut of a flow network (32bit float edge capacities). The
     * function computes the minimal cut (graphcut) of a 2D regular 4-connected
     * graph. 
     * The inputs are the capacities of the horizontal (in transposed form),
     * vertical and terminal (source and sink) edges. The capacities to source and
     * sink 
     * are stored as capacity differences in the terminals array 
     * ( terminals(x) = source(x) - sink(x) ). The implementation assumes that the
     * edge capacities 
     * for boundary edges that would connect to nodes outside the specified domain
     * are set to 0 (for example left(0,*) == 0). If this is not fulfilled the
     * computed labeling may be wrong!
     * The computed binary labeling is encoded as unsigned 8bit values (0 and >0).
     *
     * @see nppiGraphcutInitAlloc(), nppiGraphcutFree(), nppiGraphcutGetSize().
     *
     * @param pTerminals Pointer to differences of terminal edge capacities
     *        (terminal(x) = source(x) - sink(x))
     * @param pLeftTransposed Pointer to transposed left edge capacities
     *        (left(0,*) must be 0)
     * @param pRightTransposed Pointer to transposed right edge capacities
     *        (right(width-1,*) must be 0)
     * @param pTop Pointer to top edge capacities (top(*,0) must be 0)
     * @param pBottom Pointer to bottom edge capacities (bottom(*,height-1)
     *        must be 0)
     * @param nStep Step in bytes between any pair of sequential rows of edge
     *        capacities
     * @param nTransposedStep Step in bytes between any pair of sequential
     *        rows of tranposed edge capacities
     * @param size Graph size
     * @param pLabel Pointer to destination label image 
     * @param nLabelStep Step in bytes between any pair of sequential rows of
     *        label image
     * @param pState Pointer to graph-cut state structure. This structure must be
     *          initialized allocated and initialized using nppiGraphcutInitAlloc().
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiGraphcut_32f8u(
        TypedPointer<Npp32f> pTerminals, 
        TypedPointer<Npp32f> pLeftTransposed, 
        TypedPointer<Npp32f> pRightTransposed, 
        TypedPointer<Npp32f> pTop, 
        TypedPointer<Npp32f> pBottom, 
        int nStep, 
        int nTransposedStep, 
        NppiSize size, 
        TypedPointer<Npp8u> pLabel, 
        int nLabelStep, 
        NppiGraphcutState pState)
    {
        return JNpp.checkResult(nppiGraphcut_32f8uNative(pTerminals, pLeftTransposed, pRightTransposed, pTop, pBottom, nStep, nTransposedStep, size, pLabel, nLabelStep, pState));
    }
    private static native int nppiGraphcut_32f8uNative(
        TypedPointer<Npp32f> pTerminals, 
        TypedPointer<Npp32f> pLeftTransposed, 
        TypedPointer<Npp32f> pRightTransposed, 
        TypedPointer<Npp32f> pTop, 
        TypedPointer<Npp32f> pBottom, 
        int nStep, 
        int nTransposedStep, 
        NppiSize size, 
        TypedPointer<Npp8u> pLabel, 
        int nLabelStep, 
        NppiGraphcutState pState);


    public static int nppiGraphcut8_32f8u(
        TypedPointer<Npp32f> pTerminals, 
        TypedPointer<Npp32f> pLeftTransposed, 
        TypedPointer<Npp32f> pRightTransposed, 
        TypedPointer<Npp32f> pTop, 
        TypedPointer<Npp32f> pTopLeft, 
        TypedPointer<Npp32f> pTopRight, 
        TypedPointer<Npp32f> pBottom, 
        TypedPointer<Npp32f> pBottomLeft, 
        TypedPointer<Npp32f> pBottomRight, 
        int nStep, 
        int nTransposedStep, 
        NppiSize size, 
        TypedPointer<Npp8u> pLabel, 
        int nLabelStep, 
        NppiGraphcutState pState)
    {
        return JNpp.checkResult(nppiGraphcut8_32f8uNative(pTerminals, pLeftTransposed, pRightTransposed, pTop, pTopLeft, pTopRight, pBottom, pBottomLeft, pBottomRight, nStep, nTransposedStep, size, pLabel, nLabelStep, pState));
    }
    private static native int nppiGraphcut8_32f8uNative(
        TypedPointer<Npp32f> pTerminals, 
        TypedPointer<Npp32f> pLeftTransposed, 
        TypedPointer<Npp32f> pRightTransposed, 
        TypedPointer<Npp32f> pTop, 
        TypedPointer<Npp32f> pTopLeft, 
        TypedPointer<Npp32f> pTopRight, 
        TypedPointer<Npp32f> pBottom, 
        TypedPointer<Npp32f> pBottomLeft, 
        TypedPointer<Npp32f> pBottomRight, 
        int nStep, 
        int nTransposedStep, 
        NppiSize size, 
        TypedPointer<Npp8u> pLabel, 
        int nLabelStep, 
        NppiGraphcutState pState);



}

